export declare namespace Schemas {
    /** MutatingWebhook describes an admission webhook and the resources and operations it applies to. */
    interface io$k8s$api$admissionregistration$v1$MutatingWebhook {
        /** AdmissionReviewVersions is an ordered list of preferred `AdmissionReview` versions the Webhook expects. API server will try to use first version in the list which it supports. If none of the versions specified in this list supported by API server, validation will fail for this object. If a persisted webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail and be subject to the failure policy. */
        admissionReviewVersions: string[];
        clientConfig: Schemas.io$k8s$api$admissionregistration$v1$WebhookClientConfig;
        /** FailurePolicy defines how unrecognized errors from the admission endpoint are handled - allowed values are Ignore or Fail. Defaults to Fail. */
        failurePolicy?: string;
        /**
         * matchPolicy defines how the "rules" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent".
         *
         * - Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would not be sent to the webhook.
         *
         * - Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would be converted to apps/v1 and sent to the webhook.
         *
         * Defaults to "Equivalent"
         */
        matchPolicy?: string;
        /** The name of the admission webhook. Name should be fully qualified, e.g., imagepolicy.kubernetes.io, where "imagepolicy" is the name of the webhook, and kubernetes.io is the name of the organization. Required. */
        name: string;
        namespaceSelector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        objectSelector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        /**
         * reinvocationPolicy indicates whether this webhook should be called multiple times as part of a single admission evaluation. Allowed values are "Never" and "IfNeeded".
         *
         * Never: the webhook will not be called more than once in a single admission evaluation.
         *
         * IfNeeded: the webhook will be called at least one additional time as part of the admission evaluation if the object being admitted is modified by other admission plugins after the initial webhook call. Webhooks that specify this option *must* be idempotent, able to process objects they previously admitted. Note: * the number of additional invocations is not guaranteed to be exactly one. * if additional invocations result in further modifications to the object, webhooks are not guaranteed to be invoked again. * webhooks that use this option may be reordered to minimize the number of additional invocations. * to validate an object after all mutations are guaranteed complete, use a validating admission webhook instead.
         *
         * Defaults to "Never".
         */
        reinvocationPolicy?: string;
        /** Rules describes what operations on what resources/subresources the webhook cares about. The webhook cares about an operation if it matches _any_ Rule. However, in order to prevent ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks from putting the cluster in a state which cannot be recovered from without completely disabling the plugin, ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks are never called on admission requests for ValidatingWebhookConfiguration and MutatingWebhookConfiguration objects. */
        rules?: Schemas.io$k8s$api$admissionregistration$v1$RuleWithOperations[];
        /** SideEffects states whether this webhook has side effects. Acceptable values are: None, NoneOnDryRun (webhooks created via v1beta1 may also specify Some or Unknown). Webhooks with side effects MUST implement a reconciliation system, since a request may be rejected by a future step in the admission chain and the side effects therefore need to be undone. Requests with the dryRun attribute will be auto-rejected if they match a webhook with sideEffects == Unknown or Some. */
        sideEffects: string;
        /** TimeoutSeconds specifies the timeout for this webhook. After the timeout passes, the webhook call will be ignored or the API call will fail based on the failure policy. The timeout value must be between 1 and 30 seconds. Default to 10 seconds. */
        timeoutSeconds?: number;
    }
    /** MutatingWebhookConfiguration describes the configuration of and admission webhook that accept or reject and may change the object. */
    interface io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** Webhooks is a list of webhooks and the affected resources and operations. */
        webhooks?: Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhook[];
    }
    /** MutatingWebhookConfigurationList is a list of MutatingWebhookConfiguration. */
    interface io$k8s$api$admissionregistration$v1$MutatingWebhookConfigurationList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of MutatingWebhookConfiguration. */
        items: Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** RuleWithOperations is a tuple of Operations and Resources. It is recommended to make sure that all the tuple expansions are valid. */
    interface io$k8s$api$admissionregistration$v1$RuleWithOperations {
        /** APIGroups is the API groups the resources belong to. '*' is all groups. If '*' is present, the length of the slice must be one. Required. */
        apiGroups?: string[];
        /** APIVersions is the API versions the resources belong to. '*' is all versions. If '*' is present, the length of the slice must be one. Required. */
        apiVersions?: string[];
        /** Operations is the operations the admission hook cares about - CREATE, UPDATE, DELETE, CONNECT or * for all of those operations and any future admission operations that are added. If '*' is present, the length of the slice must be one. Required. */
        operations?: string[];
        /**
         * Resources is a list of resources this rule applies to.
         *
         * For example: 'pods' means pods. 'pods/log' means the log subresource of pods. '*' means all resources, but not subresources. 'pods/\\*' means all subresources of pods. '\*\\/scale' means all scale subresources. '\*\/\*' means all resources and their subresources.
         *
         * If wildcard is present, the validation rule will ensure resources do not overlap with each other.
         *
         * Depending on the enclosing object, subresources might not be allowed. Required.
         */
        resources?: string[];
        /** scope specifies the scope of this rule. Valid values are "Cluster", "Namespaced", and "*" "Cluster" means that only cluster-scoped resources will match this rule. Namespace API objects are cluster-scoped. "Namespaced" means that only namespaced resources will match this rule. "*" means that there are no scope restrictions. Subresources match the scope of their parent resource. Default is "*". */
        scope?: string;
    }
    /** ServiceReference holds a reference to Service.legacy.k8s.io */
    interface io$k8s$api$admissionregistration$v1$ServiceReference {
        /** `name` is the name of the service. Required */
        name: string;
        /** `namespace` is the namespace of the service. Required */
        namespace: string;
        /** `path` is an optional URL path which will be sent in any request to this service. */
        path?: string;
        /** If specified, the port on the service that hosting webhook. Default to 443 for backward compatibility. `port` should be a valid port number (1-65535, inclusive). */
        port?: number;
    }
    /** ValidatingWebhook describes an admission webhook and the resources and operations it applies to. */
    interface io$k8s$api$admissionregistration$v1$ValidatingWebhook {
        /** AdmissionReviewVersions is an ordered list of preferred `AdmissionReview` versions the Webhook expects. API server will try to use first version in the list which it supports. If none of the versions specified in this list supported by API server, validation will fail for this object. If a persisted webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail and be subject to the failure policy. */
        admissionReviewVersions: string[];
        clientConfig: Schemas.io$k8s$api$admissionregistration$v1$WebhookClientConfig;
        /** FailurePolicy defines how unrecognized errors from the admission endpoint are handled - allowed values are Ignore or Fail. Defaults to Fail. */
        failurePolicy?: string;
        /**
         * matchPolicy defines how the "rules" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent".
         *
         * - Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would not be sent to the webhook.
         *
         * - Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would be converted to apps/v1 and sent to the webhook.
         *
         * Defaults to "Equivalent"
         */
        matchPolicy?: string;
        /** The name of the admission webhook. Name should be fully qualified, e.g., imagepolicy.kubernetes.io, where "imagepolicy" is the name of the webhook, and kubernetes.io is the name of the organization. Required. */
        name: string;
        namespaceSelector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        objectSelector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        /** Rules describes what operations on what resources/subresources the webhook cares about. The webhook cares about an operation if it matches _any_ Rule. However, in order to prevent ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks from putting the cluster in a state which cannot be recovered from without completely disabling the plugin, ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks are never called on admission requests for ValidatingWebhookConfiguration and MutatingWebhookConfiguration objects. */
        rules?: Schemas.io$k8s$api$admissionregistration$v1$RuleWithOperations[];
        /** SideEffects states whether this webhook has side effects. Acceptable values are: None, NoneOnDryRun (webhooks created via v1beta1 may also specify Some or Unknown). Webhooks with side effects MUST implement a reconciliation system, since a request may be rejected by a future step in the admission chain and the side effects therefore need to be undone. Requests with the dryRun attribute will be auto-rejected if they match a webhook with sideEffects == Unknown or Some. */
        sideEffects: string;
        /** TimeoutSeconds specifies the timeout for this webhook. After the timeout passes, the webhook call will be ignored or the API call will fail based on the failure policy. The timeout value must be between 1 and 30 seconds. Default to 10 seconds. */
        timeoutSeconds?: number;
    }
    /** ValidatingWebhookConfiguration describes the configuration of and admission webhook that accept or reject and object without changing it. */
    interface io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** Webhooks is a list of webhooks and the affected resources and operations. */
        webhooks?: Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhook[];
    }
    /** ValidatingWebhookConfigurationList is a list of ValidatingWebhookConfiguration. */
    interface io$k8s$api$admissionregistration$v1$ValidatingWebhookConfigurationList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of ValidatingWebhookConfiguration. */
        items: Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** WebhookClientConfig contains the information to make a TLS connection with the webhook */
    interface io$k8s$api$admissionregistration$v1$WebhookClientConfig {
        /** `caBundle` is a PEM encoded CA bundle which will be used to validate the webhook's server certificate. If unspecified, system trust roots on the apiserver are used. */
        caBundle?: Blob;
        service?: Schemas.io$k8s$api$admissionregistration$v1$ServiceReference;
        /**
         * `url` gives the location of the webhook, in standard URL form (`scheme://host:port/path`). Exactly one of `url` or `service` must be specified.
         *
         * The `host` should not refer to a service running in the cluster; use the `service` field instead. The host might be resolved via external DNS in some apiservers (e.g., `kube-apiserver` cannot resolve in-cluster DNS as that would be a layering violation). `host` may also be an IP address.
         *
         * Please note that using `localhost` or `127.0.0.1` as a `host` is risky unless you take great care to run this webhook on all hosts which run an apiserver which might need to make calls to this webhook. Such installs are likely to be non-portable, i.e., not easy to turn up in a new cluster.
         *
         * The scheme must be "https"; the URL must begin with "https://".
         *
         * A path is optional, and if present may be any string permissible in a URL. You may use the path to pass an arbitrary string to the webhook, for example, a cluster identifier.
         *
         * Attempting to use a user or basic auth e.g. "user:password@" is not allowed. Fragments ("#...") and query parameters ("?...") are not allowed, either.
         */
        url?: string;
    }
    /** An API server instance reports the version it can decode and the version it encodes objects to when persisting objects in the backend. */
    interface io$k8s$api$apiserverinternal$v1alpha1$ServerStorageVersion {
        /** The ID of the reporting API server. */
        apiServerID?: string;
        /** The API server can decode objects encoded in these versions. The encodingVersion must be included in the decodableVersions. */
        decodableVersions?: string[];
        /** The API server encodes the object to this version when persisting it in the backend (e.g., etcd). */
        encodingVersion?: string;
    }
    /**
     *
     *  Storage version of a specific resource.
     */
    interface io$k8s$api$apiserverinternal$v1alpha1$StorageVersion {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersionSpec;
        status: Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersionStatus;
    }
    /** Describes the state of the storageVersion at a certain point. */
    interface io$k8s$api$apiserverinternal$v1alpha1$StorageVersionCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** A human readable message indicating details about the transition. */
        message?: string;
        /** If set, this represents the .metadata.generation that the condition was set based upon. */
        observedGeneration?: number;
        /** The reason for the condition's last transition. */
        reason: string;
        /** Status of the condition, one of True, False, Unknown. */
        status: string;
        /** Type of the condition. */
        type: string;
    }
    /** A list of StorageVersions. */
    interface io$k8s$api$apiserverinternal$v1alpha1$StorageVersionList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items holds a list of StorageVersion */
        items: Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** StorageVersionSpec is an empty spec. */
    interface io$k8s$api$apiserverinternal$v1alpha1$StorageVersionSpec {
    }
    /** API server instances report the versions they can decode and the version they encode objects to when persisting objects in the backend. */
    interface io$k8s$api$apiserverinternal$v1alpha1$StorageVersionStatus {
        /** If all API server instances agree on the same encoding storage version, then this field is set to that version. Otherwise this field is left empty. API servers should finish updating its storageVersionStatus entry before serving write operations, so that this field will be in sync with the reality. */
        commonEncodingVersion?: string;
        /** The latest available observations of the storageVersion's state. */
        conditions?: Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersionCondition[];
        /** The reported versions per API server instance. */
        storageVersions?: Schemas.io$k8s$api$apiserverinternal$v1alpha1$ServerStorageVersion[];
    }
    /** ControllerRevision implements an immutable snapshot of state data. Clients are responsible for serializing and deserializing the objects that contain their internal state. Once a ControllerRevision has been successfully created, it can not be updated. The API Server will fail validation of all requests that attempt to mutate the Data field. ControllerRevisions may, however, be deleted. Note that, due to its use by both the DaemonSet and StatefulSet controllers for update and rollback, this object is beta. However, it may be subject to name and representation changes in future releases, and clients should not depend on its stability. It is primarily for internal use by controllers. */
    interface io$k8s$api$apps$v1$ControllerRevision {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        data?: Schemas.io$k8s$apimachinery$pkg$runtime$RawExtension;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** Revision indicates the revision of the state represented by Data. */
        revision: number;
    }
    /** ControllerRevisionList is a resource containing a list of ControllerRevision objects. */
    interface io$k8s$api$apps$v1$ControllerRevisionList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is the list of ControllerRevisions */
        items: Schemas.io$k8s$api$apps$v1$ControllerRevision[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** DaemonSet represents the configuration of a daemon set. */
    interface io$k8s$api$apps$v1$DaemonSet {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$apps$v1$DaemonSetSpec;
        status?: Schemas.io$k8s$api$apps$v1$DaemonSetStatus;
    }
    /** DaemonSetCondition describes the state of a DaemonSet at a certain point. */
    interface io$k8s$api$apps$v1$DaemonSetCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** A human readable message indicating details about the transition. */
        message?: string;
        /** The reason for the condition's last transition. */
        reason?: string;
        /** Status of the condition, one of True, False, Unknown. */
        status: string;
        /** Type of DaemonSet condition. */
        type: string;
    }
    /** DaemonSetList is a collection of daemon sets. */
    interface io$k8s$api$apps$v1$DaemonSetList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** A list of daemon sets. */
        items: Schemas.io$k8s$api$apps$v1$DaemonSet[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** DaemonSetSpec is the specification of a daemon set. */
    interface io$k8s$api$apps$v1$DaemonSetSpec {
        /** The minimum number of seconds for which a newly created DaemonSet pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready). */
        minReadySeconds?: number;
        /** The number of old history to retain to allow rollback. This is a pointer to distinguish between explicit zero and not specified. Defaults to 10. */
        revisionHistoryLimit?: number;
        selector: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        template: Schemas.io$k8s$api$core$v1$PodTemplateSpec;
        updateStrategy?: Schemas.io$k8s$api$apps$v1$DaemonSetUpdateStrategy;
    }
    /** DaemonSetStatus represents the current status of a daemon set. */
    interface io$k8s$api$apps$v1$DaemonSetStatus {
        /** Count of hash collisions for the DaemonSet. The DaemonSet controller uses this field as a collision avoidance mechanism when it needs to create the name for the newest ControllerRevision. */
        collisionCount?: number;
        /** Represents the latest available observations of a DaemonSet's current state. */
        conditions?: Schemas.io$k8s$api$apps$v1$DaemonSetCondition[];
        /** The number of nodes that are running at least 1 daemon pod and are supposed to run the daemon pod. More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/ */
        currentNumberScheduled: number;
        /** The total number of nodes that should be running the daemon pod (including nodes correctly running the daemon pod). More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/ */
        desiredNumberScheduled: number;
        /** The number of nodes that should be running the daemon pod and have one or more of the daemon pod running and available (ready for at least spec.minReadySeconds) */
        numberAvailable?: number;
        /** The number of nodes that are running the daemon pod, but are not supposed to run the daemon pod. More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/ */
        numberMisscheduled: number;
        /** numberReady is the number of nodes that should be running the daemon pod and have one or more of the daemon pod running with a Ready Condition. */
        numberReady: number;
        /** The number of nodes that should be running the daemon pod and have none of the daemon pod running and available (ready for at least spec.minReadySeconds) */
        numberUnavailable?: number;
        /** The most recent generation observed by the daemon set controller. */
        observedGeneration?: number;
        /** The total number of nodes that are running updated daemon pod */
        updatedNumberScheduled?: number;
    }
    /** DaemonSetUpdateStrategy is a struct used to control the update strategy for a DaemonSet. */
    interface io$k8s$api$apps$v1$DaemonSetUpdateStrategy {
        rollingUpdate?: Schemas.io$k8s$api$apps$v1$RollingUpdateDaemonSet;
        /**
         * Type of daemon set update. Can be "RollingUpdate" or "OnDelete". Default is RollingUpdate.
         *
         */
        type?: string;
    }
    /** Deployment enables declarative updates for Pods and ReplicaSets. */
    interface io$k8s$api$apps$v1$Deployment {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$apps$v1$DeploymentSpec;
        status?: Schemas.io$k8s$api$apps$v1$DeploymentStatus;
    }
    /** DeploymentCondition describes the state of a deployment at a certain point. */
    interface io$k8s$api$apps$v1$DeploymentCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        lastUpdateTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** A human readable message indicating details about the transition. */
        message?: string;
        /** The reason for the condition's last transition. */
        reason?: string;
        /** Status of the condition, one of True, False, Unknown. */
        status: string;
        /** Type of deployment condition. */
        type: string;
    }
    /** DeploymentList is a list of Deployments. */
    interface io$k8s$api$apps$v1$DeploymentList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is the list of Deployments. */
        items: Schemas.io$k8s$api$apps$v1$Deployment[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** DeploymentSpec is the specification of the desired behavior of the Deployment. */
    interface io$k8s$api$apps$v1$DeploymentSpec {
        /** Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready) */
        minReadySeconds?: number;
        /** Indicates that the deployment is paused. */
        paused?: boolean;
        /** The maximum time in seconds for a deployment to make progress before it is considered to be failed. The deployment controller will continue to process failed deployments and a condition with a ProgressDeadlineExceeded reason will be surfaced in the deployment status. Note that progress will not be estimated during the time a deployment is paused. Defaults to 600s. */
        progressDeadlineSeconds?: number;
        /** Number of desired pods. This is a pointer to distinguish between explicit zero and not specified. Defaults to 1. */
        replicas?: number;
        /** The number of old ReplicaSets to retain to allow rollback. This is a pointer to distinguish between explicit zero and not specified. Defaults to 10. */
        revisionHistoryLimit?: number;
        selector: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        strategy?: Schemas.io$k8s$api$apps$v1$DeploymentStrategy;
        template: Schemas.io$k8s$api$core$v1$PodTemplateSpec;
    }
    /** DeploymentStatus is the most recently observed status of the Deployment. */
    interface io$k8s$api$apps$v1$DeploymentStatus {
        /** Total number of available pods (ready for at least minReadySeconds) targeted by this deployment. */
        availableReplicas?: number;
        /** Count of hash collisions for the Deployment. The Deployment controller uses this field as a collision avoidance mechanism when it needs to create the name for the newest ReplicaSet. */
        collisionCount?: number;
        /** Represents the latest available observations of a deployment's current state. */
        conditions?: Schemas.io$k8s$api$apps$v1$DeploymentCondition[];
        /** The generation observed by the deployment controller. */
        observedGeneration?: number;
        /** readyReplicas is the number of pods targeted by this Deployment with a Ready Condition. */
        readyReplicas?: number;
        /** Total number of non-terminated pods targeted by this deployment (their labels match the selector). */
        replicas?: number;
        /** Total number of unavailable pods targeted by this deployment. This is the total number of pods that are still required for the deployment to have 100% available capacity. They may either be pods that are running but not yet available or pods that still have not been created. */
        unavailableReplicas?: number;
        /** Total number of non-terminated pods targeted by this deployment that have the desired template spec. */
        updatedReplicas?: number;
    }
    /** DeploymentStrategy describes how to replace existing pods with new ones. */
    interface io$k8s$api$apps$v1$DeploymentStrategy {
        rollingUpdate?: Schemas.io$k8s$api$apps$v1$RollingUpdateDeployment;
        /**
         * Type of deployment. Can be "Recreate" or "RollingUpdate". Default is RollingUpdate.
         *
         */
        type?: string;
    }
    /** ReplicaSet ensures that a specified number of pod replicas are running at any given time. */
    interface io$k8s$api$apps$v1$ReplicaSet {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$apps$v1$ReplicaSetSpec;
        status?: Schemas.io$k8s$api$apps$v1$ReplicaSetStatus;
    }
    /** ReplicaSetCondition describes the state of a replica set at a certain point. */
    interface io$k8s$api$apps$v1$ReplicaSetCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** A human readable message indicating details about the transition. */
        message?: string;
        /** The reason for the condition's last transition. */
        reason?: string;
        /** Status of the condition, one of True, False, Unknown. */
        status: string;
        /** Type of replica set condition. */
        type: string;
    }
    /** ReplicaSetList is a collection of ReplicaSets. */
    interface io$k8s$api$apps$v1$ReplicaSetList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of ReplicaSets. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller */
        items: Schemas.io$k8s$api$apps$v1$ReplicaSet[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ReplicaSetSpec is the specification of a ReplicaSet. */
    interface io$k8s$api$apps$v1$ReplicaSetSpec {
        /** Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready) */
        minReadySeconds?: number;
        /** Replicas is the number of desired replicas. This is a pointer to distinguish between explicit zero and unspecified. Defaults to 1. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller/#what-is-a-replicationcontroller */
        replicas?: number;
        selector: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        template?: Schemas.io$k8s$api$core$v1$PodTemplateSpec;
    }
    /** ReplicaSetStatus represents the current status of a ReplicaSet. */
    interface io$k8s$api$apps$v1$ReplicaSetStatus {
        /** The number of available replicas (ready for at least minReadySeconds) for this replica set. */
        availableReplicas?: number;
        /** Represents the latest available observations of a replica set's current state. */
        conditions?: Schemas.io$k8s$api$apps$v1$ReplicaSetCondition[];
        /** The number of pods that have labels matching the labels of the pod template of the replicaset. */
        fullyLabeledReplicas?: number;
        /** ObservedGeneration reflects the generation of the most recently observed ReplicaSet. */
        observedGeneration?: number;
        /** readyReplicas is the number of pods targeted by this ReplicaSet with a Ready Condition. */
        readyReplicas?: number;
        /** Replicas is the most recently oberved number of replicas. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller/#what-is-a-replicationcontroller */
        replicas: number;
    }
    /** Spec to control the desired behavior of daemon set rolling update. */
    interface io$k8s$api$apps$v1$RollingUpdateDaemonSet {
        maxSurge?: Schemas.io$k8s$apimachinery$pkg$util$intstr$IntOrString;
        maxUnavailable?: Schemas.io$k8s$apimachinery$pkg$util$intstr$IntOrString;
    }
    /** Spec to control the desired behavior of rolling update. */
    interface io$k8s$api$apps$v1$RollingUpdateDeployment {
        maxSurge?: Schemas.io$k8s$apimachinery$pkg$util$intstr$IntOrString;
        maxUnavailable?: Schemas.io$k8s$apimachinery$pkg$util$intstr$IntOrString;
    }
    /** RollingUpdateStatefulSetStrategy is used to communicate parameter for RollingUpdateStatefulSetStrategyType. */
    interface io$k8s$api$apps$v1$RollingUpdateStatefulSetStrategy {
        /** Partition indicates the ordinal at which the StatefulSet should be partitioned. Default value is 0. */
        partition?: number;
    }
    /**
     * StatefulSet represents a set of pods with consistent identities. Identities are defined as:
     *  - Network: A single stable DNS and hostname.
     *  - Storage: As many VolumeClaims as requested.
     * The StatefulSet guarantees that a given network identity will always map to the same storage identity.
     */
    interface io$k8s$api$apps$v1$StatefulSet {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$apps$v1$StatefulSetSpec;
        status?: Schemas.io$k8s$api$apps$v1$StatefulSetStatus;
    }
    /** StatefulSetCondition describes the state of a statefulset at a certain point. */
    interface io$k8s$api$apps$v1$StatefulSetCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** A human readable message indicating details about the transition. */
        message?: string;
        /** The reason for the condition's last transition. */
        reason?: string;
        /** Status of the condition, one of True, False, Unknown. */
        status: string;
        /** Type of statefulset condition. */
        type: string;
    }
    /** StatefulSetList is a collection of StatefulSets. */
    interface io$k8s$api$apps$v1$StatefulSetList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is the list of stateful sets. */
        items: Schemas.io$k8s$api$apps$v1$StatefulSet[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** StatefulSetPersistentVolumeClaimRetentionPolicy describes the policy used for PVCs created from the StatefulSet VolumeClaimTemplates. */
    interface io$k8s$api$apps$v1$StatefulSetPersistentVolumeClaimRetentionPolicy {
        /** WhenDeleted specifies what happens to PVCs created from StatefulSet VolumeClaimTemplates when the StatefulSet is deleted. The default policy of `Retain` causes PVCs to not be affected by StatefulSet deletion. The `Delete` policy causes those PVCs to be deleted. */
        whenDeleted?: string;
        /** WhenScaled specifies what happens to PVCs created from StatefulSet VolumeClaimTemplates when the StatefulSet is scaled down. The default policy of `Retain` causes PVCs to not be affected by a scaledown. The `Delete` policy causes the associated PVCs for any excess pods above the replica count to be deleted. */
        whenScaled?: string;
    }
    /** A StatefulSetSpec is the specification of a StatefulSet. */
    interface io$k8s$api$apps$v1$StatefulSetSpec {
        /** Minimum number of seconds for which a newly created pod should be ready without any of its container crashing for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready) This is an alpha field and requires enabling StatefulSetMinReadySeconds feature gate. */
        minReadySeconds?: number;
        persistentVolumeClaimRetentionPolicy?: Schemas.io$k8s$api$apps$v1$StatefulSetPersistentVolumeClaimRetentionPolicy;
        /**
         * podManagementPolicy controls how pods are created during initial scale up, when replacing pods on nodes, or when scaling down. The default policy is `OrderedReady`, where pods are created in increasing order (pod-0, then pod-1, etc) and the controller will wait until each pod is ready before continuing. When scaling down, the pods are removed in the opposite order. The alternative policy is `Parallel` which will create pods in parallel to match the desired scale without waiting, and on scale down will delete all pods at once.
         *
         */
        podManagementPolicy?: string;
        /** replicas is the desired number of replicas of the given Template. These are replicas in the sense that they are instantiations of the same Template, but individual replicas also have a consistent identity. If unspecified, defaults to 1. */
        replicas?: number;
        /** revisionHistoryLimit is the maximum number of revisions that will be maintained in the StatefulSet's revision history. The revision history consists of all revisions not represented by a currently applied StatefulSetSpec version. The default value is 10. */
        revisionHistoryLimit?: number;
        selector: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        /** serviceName is the name of the service that governs this StatefulSet. This service must exist before the StatefulSet, and is responsible for the network identity of the set. Pods get DNS/hostnames that follow the pattern: pod-specific-string.serviceName.default.svc.cluster.local where "pod-specific-string" is managed by the StatefulSet controller. */
        serviceName: string;
        template: Schemas.io$k8s$api$core$v1$PodTemplateSpec;
        updateStrategy?: Schemas.io$k8s$api$apps$v1$StatefulSetUpdateStrategy;
        /** volumeClaimTemplates is a list of claims that pods are allowed to reference. The StatefulSet controller is responsible for mapping network identities to claims in a way that maintains the identity of a pod. Every claim in this list must have at least one matching (by name) volumeMount in one container in the template. A claim in this list takes precedence over any volumes in the template, with the same name. */
        volumeClaimTemplates?: Schemas.io$k8s$api$core$v1$PersistentVolumeClaim[];
    }
    /** StatefulSetStatus represents the current state of a StatefulSet. */
    interface io$k8s$api$apps$v1$StatefulSetStatus {
        /** Total number of available pods (ready for at least minReadySeconds) targeted by this statefulset. This is a beta field and enabled/disabled by StatefulSetMinReadySeconds feature gate. */
        availableReplicas: number;
        /** collisionCount is the count of hash collisions for the StatefulSet. The StatefulSet controller uses this field as a collision avoidance mechanism when it needs to create the name for the newest ControllerRevision. */
        collisionCount?: number;
        /** Represents the latest available observations of a statefulset's current state. */
        conditions?: Schemas.io$k8s$api$apps$v1$StatefulSetCondition[];
        /** currentReplicas is the number of Pods created by the StatefulSet controller from the StatefulSet version indicated by currentRevision. */
        currentReplicas?: number;
        /** currentRevision, if not empty, indicates the version of the StatefulSet used to generate Pods in the sequence [0,currentReplicas). */
        currentRevision?: string;
        /** observedGeneration is the most recent generation observed for this StatefulSet. It corresponds to the StatefulSet's generation, which is updated on mutation by the API Server. */
        observedGeneration?: number;
        /** readyReplicas is the number of pods created for this StatefulSet with a Ready Condition. */
        readyReplicas?: number;
        /** replicas is the number of Pods created by the StatefulSet controller. */
        replicas: number;
        /** updateRevision, if not empty, indicates the version of the StatefulSet used to generate Pods in the sequence [replicas-updatedReplicas,replicas) */
        updateRevision?: string;
        /** updatedReplicas is the number of Pods created by the StatefulSet controller from the StatefulSet version indicated by updateRevision. */
        updatedReplicas?: number;
    }
    /** StatefulSetUpdateStrategy indicates the strategy that the StatefulSet controller will use to perform updates. It includes any additional parameters necessary to perform the update for the indicated strategy. */
    interface io$k8s$api$apps$v1$StatefulSetUpdateStrategy {
        rollingUpdate?: Schemas.io$k8s$api$apps$v1$RollingUpdateStatefulSetStrategy;
        /**
         * Type indicates the type of the StatefulSetUpdateStrategy. Default is RollingUpdate.
         *
         */
        type?: string;
    }
    /** BoundObjectReference is a reference to an object that a token is bound to. */
    interface io$k8s$api$authentication$v1$BoundObjectReference {
        /** API version of the referent. */
        apiVersion?: string;
        /** Kind of the referent. Valid kinds are 'Pod' and 'Secret'. */
        kind?: string;
        /** Name of the referent. */
        name?: string;
        /** UID of the referent. */
        uid?: string;
    }
    /** TokenRequest requests a token for a given service account. */
    interface io$k8s$api$authentication$v1$TokenRequest {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$authentication$v1$TokenRequestSpec;
        status?: Schemas.io$k8s$api$authentication$v1$TokenRequestStatus;
    }
    /** TokenRequestSpec contains client provided parameters of a token request. */
    interface io$k8s$api$authentication$v1$TokenRequestSpec {
        /** Audiences are the intendend audiences of the token. A recipient of a token must identitfy themself with an identifier in the list of audiences of the token, and otherwise should reject the token. A token issued for multiple audiences may be used to authenticate against any of the audiences listed but implies a high degree of trust between the target audiences. */
        audiences: string[];
        boundObjectRef?: Schemas.io$k8s$api$authentication$v1$BoundObjectReference;
        /** ExpirationSeconds is the requested duration of validity of the request. The token issuer may return a token with a different validity duration so a client needs to check the 'expiration' field in a response. */
        expirationSeconds?: number;
    }
    /** TokenRequestStatus is the result of a token request. */
    interface io$k8s$api$authentication$v1$TokenRequestStatus {
        expirationTimestamp: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** Token is the opaque bearer token. */
        token: string;
    }
    /** TokenReview attempts to authenticate a token to a known user. Note: TokenReview requests may be cached by the webhook token authenticator plugin in the kube-apiserver. */
    interface io$k8s$api$authentication$v1$TokenReview {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$authentication$v1$TokenReviewSpec;
        status?: Schemas.io$k8s$api$authentication$v1$TokenReviewStatus;
    }
    /** TokenReviewSpec is a description of the token authentication request. */
    interface io$k8s$api$authentication$v1$TokenReviewSpec {
        /** Audiences is a list of the identifiers that the resource server presented with the token identifies as. Audience-aware token authenticators will verify that the token was intended for at least one of the audiences in this list. If no audiences are provided, the audience will default to the audience of the Kubernetes apiserver. */
        audiences?: string[];
        /** Token is the opaque bearer token. */
        token?: string;
    }
    /** TokenReviewStatus is the result of the token authentication request. */
    interface io$k8s$api$authentication$v1$TokenReviewStatus {
        /** Audiences are audience identifiers chosen by the authenticator that are compatible with both the TokenReview and token. An identifier is any identifier in the intersection of the TokenReviewSpec audiences and the token's audiences. A client of the TokenReview API that sets the spec.audiences field should validate that a compatible audience identifier is returned in the status.audiences field to ensure that the TokenReview server is audience aware. If a TokenReview returns an empty status.audience field where status.authenticated is "true", the token is valid against the audience of the Kubernetes API server. */
        audiences?: string[];
        /** Authenticated indicates that the token was associated with a known user. */
        authenticated?: boolean;
        /** Error indicates that the token couldn't be checked */
        error?: string;
        user?: Schemas.io$k8s$api$authentication$v1$UserInfo;
    }
    /** UserInfo holds the information about the user needed to implement the user.Info interface. */
    interface io$k8s$api$authentication$v1$UserInfo {
        /** Any additional information provided by the authenticator. */
        extra?: {
            [key: string]: string[];
        };
        /** The names of groups this user is a part of. */
        groups?: string[];
        /** A unique value that identifies this user across time. If this user is deleted and another user by the same name is added, they will have different UIDs. */
        uid?: string;
        /** The name that uniquely identifies this user among all active users. */
        username?: string;
    }
    /** LocalSubjectAccessReview checks whether or not a user or group can perform an action in a given namespace. Having a namespace scoped resource makes it much easier to grant namespace scoped policy that includes permissions checking. */
    interface io$k8s$api$authorization$v1$LocalSubjectAccessReview {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$authorization$v1$SubjectAccessReviewSpec;
        status?: Schemas.io$k8s$api$authorization$v1$SubjectAccessReviewStatus;
    }
    /** NonResourceAttributes includes the authorization attributes available for non-resource requests to the Authorizer interface */
    interface io$k8s$api$authorization$v1$NonResourceAttributes {
        /** Path is the URL path of the request */
        path?: string;
        /** Verb is the standard HTTP verb */
        verb?: string;
    }
    /** NonResourceRule holds information that describes a rule for the non-resource */
    interface io$k8s$api$authorization$v1$NonResourceRule {
        /** NonResourceURLs is a set of partial urls that a user should have access to.  *s are allowed, but only as the full, final step in the path.  "*" means all. */
        nonResourceURLs?: string[];
        /** Verb is a list of kubernetes non-resource API verbs, like: get, post, put, delete, patch, head, options.  "*" means all. */
        verbs: string[];
    }
    /** ResourceAttributes includes the authorization attributes available for resource requests to the Authorizer interface */
    interface io$k8s$api$authorization$v1$ResourceAttributes {
        /** Group is the API Group of the Resource.  "*" means all. */
        group?: string;
        /** Name is the name of the resource being requested for a "get" or deleted for a "delete". "" (empty) means all. */
        name?: string;
        /** Namespace is the namespace of the action being requested.  Currently, there is no distinction between no namespace and all namespaces "" (empty) is defaulted for LocalSubjectAccessReviews "" (empty) is empty for cluster-scoped resources "" (empty) means "all" for namespace scoped resources from a SubjectAccessReview or SelfSubjectAccessReview */
        namespace?: string;
        /** Resource is one of the existing resource types.  "*" means all. */
        resource?: string;
        /** Subresource is one of the existing resource types.  "" means none. */
        subresource?: string;
        /** Verb is a kubernetes resource API verb, like: get, list, watch, create, update, delete, proxy.  "*" means all. */
        verb?: string;
        /** Version is the API Version of the Resource.  "*" means all. */
        version?: string;
    }
    /** ResourceRule is the list of actions the subject is allowed to perform on resources. The list ordering isn't significant, may contain duplicates, and possibly be incomplete. */
    interface io$k8s$api$authorization$v1$ResourceRule {
        /** APIGroups is the name of the APIGroup that contains the resources.  If multiple API groups are specified, any action requested against one of the enumerated resources in any API group will be allowed.  "*" means all. */
        apiGroups?: string[];
        /** ResourceNames is an optional white list of names that the rule applies to.  An empty set means that everything is allowed.  "*" means all. */
        resourceNames?: string[];
        /**
         * Resources is a list of resources this rule applies to.  "*" means all in the specified apiGroups.
         *  "\*\\/foo" represents the subresource 'foo' for all resources in the specified apiGroups.
         */
        resources?: string[];
        /** Verb is a list of kubernetes resource API verbs, like: get, list, watch, create, update, delete, proxy.  "*" means all. */
        verbs: string[];
    }
    /** SelfSubjectAccessReview checks whether or the current user can perform an action.  Not filling in a spec.namespace means "in all namespaces".  Self is a special case, because users should always be able to check whether they can perform an action */
    interface io$k8s$api$authorization$v1$SelfSubjectAccessReview {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$authorization$v1$SelfSubjectAccessReviewSpec;
        status?: Schemas.io$k8s$api$authorization$v1$SubjectAccessReviewStatus;
    }
    /** SelfSubjectAccessReviewSpec is a description of the access request.  Exactly one of ResourceAuthorizationAttributes and NonResourceAuthorizationAttributes must be set */
    interface io$k8s$api$authorization$v1$SelfSubjectAccessReviewSpec {
        nonResourceAttributes?: Schemas.io$k8s$api$authorization$v1$NonResourceAttributes;
        resourceAttributes?: Schemas.io$k8s$api$authorization$v1$ResourceAttributes;
    }
    /** SelfSubjectRulesReview enumerates the set of actions the current user can perform within a namespace. The returned list of actions may be incomplete depending on the server's authorization mode, and any errors experienced during the evaluation. SelfSubjectRulesReview should be used by UIs to show/hide actions, or to quickly let an end user reason about their permissions. It should NOT Be used by external systems to drive authorization decisions as this raises confused deputy, cache lifetime/revocation, and correctness concerns. SubjectAccessReview, and LocalAccessReview are the correct way to defer authorization decisions to the API server. */
    interface io$k8s$api$authorization$v1$SelfSubjectRulesReview {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$authorization$v1$SelfSubjectRulesReviewSpec;
        status?: Schemas.io$k8s$api$authorization$v1$SubjectRulesReviewStatus;
    }
    /** SelfSubjectRulesReviewSpec defines the specification for SelfSubjectRulesReview. */
    interface io$k8s$api$authorization$v1$SelfSubjectRulesReviewSpec {
        /** Namespace to evaluate rules for. Required. */
        namespace?: string;
    }
    /** SubjectAccessReview checks whether or not a user or group can perform an action. */
    interface io$k8s$api$authorization$v1$SubjectAccessReview {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$authorization$v1$SubjectAccessReviewSpec;
        status?: Schemas.io$k8s$api$authorization$v1$SubjectAccessReviewStatus;
    }
    /** SubjectAccessReviewSpec is a description of the access request.  Exactly one of ResourceAuthorizationAttributes and NonResourceAuthorizationAttributes must be set */
    interface io$k8s$api$authorization$v1$SubjectAccessReviewSpec {
        /** Extra corresponds to the user.Info.GetExtra() method from the authenticator.  Since that is input to the authorizer it needs a reflection here. */
        extra?: {
            [key: string]: string[];
        };
        /** Groups is the groups you're testing for. */
        groups?: string[];
        nonResourceAttributes?: Schemas.io$k8s$api$authorization$v1$NonResourceAttributes;
        resourceAttributes?: Schemas.io$k8s$api$authorization$v1$ResourceAttributes;
        /** UID information about the requesting user. */
        uid?: string;
        /** User is the user you're testing for. If you specify "User" but not "Groups", then is it interpreted as "What if User were not a member of any groups */
        user?: string;
    }
    /** SubjectAccessReviewStatus */
    interface io$k8s$api$authorization$v1$SubjectAccessReviewStatus {
        /** Allowed is required. True if the action would be allowed, false otherwise. */
        allowed: boolean;
        /** Denied is optional. True if the action would be denied, otherwise false. If both allowed is false and denied is false, then the authorizer has no opinion on whether to authorize the action. Denied may not be true if Allowed is true. */
        denied?: boolean;
        /** EvaluationError is an indication that some error occurred during the authorization check. It is entirely possible to get an error and be able to continue determine authorization status in spite of it. For instance, RBAC can be missing a role, but enough roles are still present and bound to reason about the request. */
        evaluationError?: string;
        /** Reason is optional.  It indicates why a request was allowed or denied. */
        reason?: string;
    }
    /** SubjectRulesReviewStatus contains the result of a rules check. This check can be incomplete depending on the set of authorizers the server is configured with and any errors experienced during evaluation. Because authorization rules are additive, if a rule appears in a list it's safe to assume the subject has that permission, even if that list is incomplete. */
    interface io$k8s$api$authorization$v1$SubjectRulesReviewStatus {
        /** EvaluationError can appear in combination with Rules. It indicates an error occurred during rule evaluation, such as an authorizer that doesn't support rule evaluation, and that ResourceRules and/or NonResourceRules may be incomplete. */
        evaluationError?: string;
        /** Incomplete is true when the rules returned by this call are incomplete. This is most commonly encountered when an authorizer, such as an external authorizer, doesn't support rules evaluation. */
        incomplete: boolean;
        /** NonResourceRules is the list of actions the subject is allowed to perform on non-resources. The list ordering isn't significant, may contain duplicates, and possibly be incomplete. */
        nonResourceRules: Schemas.io$k8s$api$authorization$v1$NonResourceRule[];
        /** ResourceRules is the list of actions the subject is allowed to perform on resources. The list ordering isn't significant, may contain duplicates, and possibly be incomplete. */
        resourceRules: Schemas.io$k8s$api$authorization$v1$ResourceRule[];
    }
    /** CrossVersionObjectReference contains enough information to let you identify the referred resource. */
    interface io$k8s$api$autoscaling$v1$CrossVersionObjectReference {
        /** API version of the referent */
        apiVersion?: string;
        /** Kind of the referent; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds" */
        kind: string;
        /** Name of the referent; More info: http://kubernetes.io/docs/user-guide/identifiers#names */
        name: string;
    }
    /** configuration of a horizontal pod autoscaler. */
    interface io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerSpec;
        status?: Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerStatus;
    }
    /** list of horizontal pod autoscaler objects. */
    interface io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** list of horizontal pod autoscaler objects. */
        items: Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** specification of a horizontal pod autoscaler. */
    interface io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerSpec {
        /** upper limit for the number of pods that can be set by the autoscaler; cannot be smaller than MinReplicas. */
        maxReplicas: number;
        /** minReplicas is the lower limit for the number of replicas to which the autoscaler can scale down.  It defaults to 1 pod.  minReplicas is allowed to be 0 if the alpha feature gate HPAScaleToZero is enabled and at least one Object or External metric is configured.  Scaling is active as long as at least one metric value is available. */
        minReplicas?: number;
        scaleTargetRef: Schemas.io$k8s$api$autoscaling$v1$CrossVersionObjectReference;
        /** target average CPU utilization (represented as a percentage of requested CPU) over all the pods; if not specified the default autoscaling policy will be used. */
        targetCPUUtilizationPercentage?: number;
    }
    /** current status of a horizontal pod autoscaler */
    interface io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerStatus {
        /** current average CPU utilization over all pods, represented as a percentage of requested CPU, e.g. 70 means that an average pod is using now 70% of its requested CPU. */
        currentCPUUtilizationPercentage?: number;
        /** current number of replicas of pods managed by this autoscaler. */
        currentReplicas: number;
        /** desired number of replicas of pods managed by this autoscaler. */
        desiredReplicas: number;
        lastScaleTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** most recent generation observed by this autoscaler. */
        observedGeneration?: number;
    }
    /** Scale represents a scaling request for a resource. */
    interface io$k8s$api$autoscaling$v1$Scale {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$autoscaling$v1$ScaleSpec;
        status?: Schemas.io$k8s$api$autoscaling$v1$ScaleStatus;
    }
    /** ScaleSpec describes the attributes of a scale subresource. */
    interface io$k8s$api$autoscaling$v1$ScaleSpec {
        /** desired number of instances for the scaled object. */
        replicas?: number;
    }
    /** ScaleStatus represents the current status of a scale subresource. */
    interface io$k8s$api$autoscaling$v1$ScaleStatus {
        /** actual number of observed instances of the scaled object. */
        replicas: number;
        /** label query over pods that should match the replicas count. This is same as the label selector but in the string format to avoid introspection by clients. The string will be in the same format as the query-param syntax. More info about label selectors: http://kubernetes.io/docs/user-guide/labels#label-selectors */
        selector?: string;
    }
    /** ContainerResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set. */
    interface io$k8s$api$autoscaling$v2$ContainerResourceMetricSource {
        /** container is the name of the container in the pods of the scaling target */
        container: string;
        /** name is the name of the resource in question. */
        name: string;
        target: Schemas.io$k8s$api$autoscaling$v2$MetricTarget;
    }
    /** ContainerResourceMetricStatus indicates the current value of a resource metric known to Kubernetes, as specified in requests and limits, describing a single container in each pod in the current scale target (e.g. CPU or memory).  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source. */
    interface io$k8s$api$autoscaling$v2$ContainerResourceMetricStatus {
        /** Container is the name of the container in the pods of the scaling target */
        container: string;
        current: Schemas.io$k8s$api$autoscaling$v2$MetricValueStatus;
        /** Name is the name of the resource in question. */
        name: string;
    }
    /** CrossVersionObjectReference contains enough information to let you identify the referred resource. */
    interface io$k8s$api$autoscaling$v2$CrossVersionObjectReference {
        /** API version of the referent */
        apiVersion?: string;
        /** Kind of the referent; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds" */
        kind: string;
        /** Name of the referent; More info: http://kubernetes.io/docs/user-guide/identifiers#names */
        name: string;
    }
    /** ExternalMetricSource indicates how to scale on a metric not associated with any Kubernetes object (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster). */
    interface io$k8s$api$autoscaling$v2$ExternalMetricSource {
        metric: Schemas.io$k8s$api$autoscaling$v2$MetricIdentifier;
        target: Schemas.io$k8s$api$autoscaling$v2$MetricTarget;
    }
    /** ExternalMetricStatus indicates the current value of a global metric not associated with any Kubernetes object. */
    interface io$k8s$api$autoscaling$v2$ExternalMetricStatus {
        current: Schemas.io$k8s$api$autoscaling$v2$MetricValueStatus;
        metric: Schemas.io$k8s$api$autoscaling$v2$MetricIdentifier;
    }
    /** HPAScalingPolicy is a single policy which must hold true for a specified past interval. */
    interface io$k8s$api$autoscaling$v2$HPAScalingPolicy {
        /** PeriodSeconds specifies the window of time for which the policy should hold true. PeriodSeconds must be greater than zero and less than or equal to 1800 (30 min). */
        periodSeconds: number;
        /** Type is used to specify the scaling policy. */
        type: string;
        /** Value contains the amount of change which is permitted by the policy. It must be greater than zero */
        value: number;
    }
    /** HPAScalingRules configures the scaling behavior for one direction. These Rules are applied after calculating DesiredReplicas from metrics for the HPA. They can limit the scaling velocity by specifying scaling policies. They can prevent flapping by specifying the stabilization window, so that the number of replicas is not set instantly, instead, the safest value from the stabilization window is chosen. */
    interface io$k8s$api$autoscaling$v2$HPAScalingRules {
        /** policies is a list of potential scaling polices which can be used during scaling. At least one policy must be specified, otherwise the HPAScalingRules will be discarded as invalid */
        policies?: Schemas.io$k8s$api$autoscaling$v2$HPAScalingPolicy[];
        /** selectPolicy is used to specify which policy should be used. If not set, the default value Max is used. */
        selectPolicy?: string;
        /** StabilizationWindowSeconds is the number of seconds for which past recommendations should be considered while scaling up or scaling down. StabilizationWindowSeconds must be greater than or equal to zero and less than or equal to 3600 (one hour). If not set, use the default values: - For scale up: 0 (i.e. no stabilization is done). - For scale down: 300 (i.e. the stabilization window is 300 seconds long). */
        stabilizationWindowSeconds?: number;
    }
    /** HorizontalPodAutoscaler is the configuration for a horizontal pod autoscaler, which automatically manages the replica count of any resource implementing the scale subresource based on the metrics specified. */
    interface io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerSpec;
        status?: Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerStatus;
    }
    /** HorizontalPodAutoscalerBehavior configures the scaling behavior of the target in both Up and Down directions (scaleUp and scaleDown fields respectively). */
    interface io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerBehavior {
        scaleDown?: Schemas.io$k8s$api$autoscaling$v2$HPAScalingRules;
        scaleUp?: Schemas.io$k8s$api$autoscaling$v2$HPAScalingRules;
    }
    /** HorizontalPodAutoscalerCondition describes the state of a HorizontalPodAutoscaler at a certain point. */
    interface io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** message is a human-readable explanation containing details about the transition */
        message?: string;
        /** reason is the reason for the condition's last transition. */
        reason?: string;
        /** status is the status of the condition (True, False, Unknown) */
        status: string;
        /** type describes the current condition */
        type: string;
    }
    /** HorizontalPodAutoscalerList is a list of horizontal pod autoscaler objects. */
    interface io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of horizontal pod autoscaler objects. */
        items: Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** HorizontalPodAutoscalerSpec describes the desired functionality of the HorizontalPodAutoscaler. */
    interface io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerSpec {
        behavior?: Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerBehavior;
        /** maxReplicas is the upper limit for the number of replicas to which the autoscaler can scale up. It cannot be less that minReplicas. */
        maxReplicas: number;
        /** metrics contains the specifications for which to use to calculate the desired replica count (the maximum replica count across all metrics will be used).  The desired replica count is calculated multiplying the ratio between the target value and the current value by the current number of pods.  Ergo, metrics used must decrease as the pod count is increased, and vice-versa.  See the individual metric source types for more information about how each type of metric must respond. If not set, the default metric will be set to 80% average CPU utilization. */
        metrics?: Schemas.io$k8s$api$autoscaling$v2$MetricSpec[];
        /** minReplicas is the lower limit for the number of replicas to which the autoscaler can scale down.  It defaults to 1 pod.  minReplicas is allowed to be 0 if the alpha feature gate HPAScaleToZero is enabled and at least one Object or External metric is configured.  Scaling is active as long as at least one metric value is available. */
        minReplicas?: number;
        scaleTargetRef: Schemas.io$k8s$api$autoscaling$v2$CrossVersionObjectReference;
    }
    /** HorizontalPodAutoscalerStatus describes the current status of a horizontal pod autoscaler. */
    interface io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerStatus {
        /** conditions is the set of conditions required for this autoscaler to scale its target, and indicates whether or not those conditions are met. */
        conditions?: Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerCondition[];
        /** currentMetrics is the last read state of the metrics used by this autoscaler. */
        currentMetrics?: Schemas.io$k8s$api$autoscaling$v2$MetricStatus[];
        /** currentReplicas is current number of replicas of pods managed by this autoscaler, as last seen by the autoscaler. */
        currentReplicas?: number;
        /** desiredReplicas is the desired number of replicas of pods managed by this autoscaler, as last calculated by the autoscaler. */
        desiredReplicas: number;
        lastScaleTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** observedGeneration is the most recent generation observed by this autoscaler. */
        observedGeneration?: number;
    }
    /** MetricIdentifier defines the name and optionally selector for a metric */
    interface io$k8s$api$autoscaling$v2$MetricIdentifier {
        /** name is the name of the given metric */
        name: string;
        selector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
    }
    /** MetricSpec specifies how to scale based on a single metric (only `type` and one other matching field should be set at once). */
    interface io$k8s$api$autoscaling$v2$MetricSpec {
        containerResource?: Schemas.io$k8s$api$autoscaling$v2$ContainerResourceMetricSource;
        external?: Schemas.io$k8s$api$autoscaling$v2$ExternalMetricSource;
        object?: Schemas.io$k8s$api$autoscaling$v2$ObjectMetricSource;
        pods?: Schemas.io$k8s$api$autoscaling$v2$PodsMetricSource;
        resource?: Schemas.io$k8s$api$autoscaling$v2$ResourceMetricSource;
        /** type is the type of metric source.  It should be one of "ContainerResource", "External", "Object", "Pods" or "Resource", each mapping to a matching field in the object. Note: "ContainerResource" type is available on when the feature-gate HPAContainerMetrics is enabled */
        type: string;
    }
    /** MetricStatus describes the last-read state of a single metric. */
    interface io$k8s$api$autoscaling$v2$MetricStatus {
        containerResource?: Schemas.io$k8s$api$autoscaling$v2$ContainerResourceMetricStatus;
        external?: Schemas.io$k8s$api$autoscaling$v2$ExternalMetricStatus;
        object?: Schemas.io$k8s$api$autoscaling$v2$ObjectMetricStatus;
        pods?: Schemas.io$k8s$api$autoscaling$v2$PodsMetricStatus;
        resource?: Schemas.io$k8s$api$autoscaling$v2$ResourceMetricStatus;
        /** type is the type of metric source.  It will be one of "ContainerResource", "External", "Object", "Pods" or "Resource", each corresponds to a matching field in the object. Note: "ContainerResource" type is available on when the feature-gate HPAContainerMetrics is enabled */
        type: string;
    }
    /** MetricTarget defines the target value, average value, or average utilization of a specific metric */
    interface io$k8s$api$autoscaling$v2$MetricTarget {
        /** averageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods. Currently only valid for Resource metric source type */
        averageUtilization?: number;
        averageValue?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        /** type represents whether the metric type is Utilization, Value, or AverageValue */
        type: string;
        value?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
    }
    /** MetricValueStatus holds the current value for a metric */
    interface io$k8s$api$autoscaling$v2$MetricValueStatus {
        /** currentAverageUtilization is the current value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods. */
        averageUtilization?: number;
        averageValue?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        value?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
    }
    /** ObjectMetricSource indicates how to scale on a metric describing a kubernetes object (for example, hits-per-second on an Ingress object). */
    interface io$k8s$api$autoscaling$v2$ObjectMetricSource {
        describedObject: Schemas.io$k8s$api$autoscaling$v2$CrossVersionObjectReference;
        metric: Schemas.io$k8s$api$autoscaling$v2$MetricIdentifier;
        target: Schemas.io$k8s$api$autoscaling$v2$MetricTarget;
    }
    /** ObjectMetricStatus indicates the current value of a metric describing a kubernetes object (for example, hits-per-second on an Ingress object). */
    interface io$k8s$api$autoscaling$v2$ObjectMetricStatus {
        current: Schemas.io$k8s$api$autoscaling$v2$MetricValueStatus;
        describedObject: Schemas.io$k8s$api$autoscaling$v2$CrossVersionObjectReference;
        metric: Schemas.io$k8s$api$autoscaling$v2$MetricIdentifier;
    }
    /** PodsMetricSource indicates how to scale on a metric describing each pod in the current scale target (for example, transactions-processed-per-second). The values will be averaged together before being compared to the target value. */
    interface io$k8s$api$autoscaling$v2$PodsMetricSource {
        metric: Schemas.io$k8s$api$autoscaling$v2$MetricIdentifier;
        target: Schemas.io$k8s$api$autoscaling$v2$MetricTarget;
    }
    /** PodsMetricStatus indicates the current value of a metric describing each pod in the current scale target (for example, transactions-processed-per-second). */
    interface io$k8s$api$autoscaling$v2$PodsMetricStatus {
        current: Schemas.io$k8s$api$autoscaling$v2$MetricValueStatus;
        metric: Schemas.io$k8s$api$autoscaling$v2$MetricIdentifier;
    }
    /** ResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set. */
    interface io$k8s$api$autoscaling$v2$ResourceMetricSource {
        /** name is the name of the resource in question. */
        name: string;
        target: Schemas.io$k8s$api$autoscaling$v2$MetricTarget;
    }
    /** ResourceMetricStatus indicates the current value of a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source. */
    interface io$k8s$api$autoscaling$v2$ResourceMetricStatus {
        current: Schemas.io$k8s$api$autoscaling$v2$MetricValueStatus;
        /** Name is the name of the resource in question. */
        name: string;
    }
    /** ContainerResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set. */
    interface io$k8s$api$autoscaling$v2beta1$ContainerResourceMetricSource {
        /** container is the name of the container in the pods of the scaling target */
        container: string;
        /** name is the name of the resource in question. */
        name: string;
        /** targetAverageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods. */
        targetAverageUtilization?: number;
        targetAverageValue?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
    }
    /** ContainerResourceMetricStatus indicates the current value of a resource metric known to Kubernetes, as specified in requests and limits, describing a single container in each pod in the current scale target (e.g. CPU or memory).  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source. */
    interface io$k8s$api$autoscaling$v2beta1$ContainerResourceMetricStatus {
        /** container is the name of the container in the pods of the scaling target */
        container: string;
        /** currentAverageUtilization is the current value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.  It will only be present if `targetAverageValue` was set in the corresponding metric specification. */
        currentAverageUtilization?: number;
        currentAverageValue: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        /** name is the name of the resource in question. */
        name: string;
    }
    /** CrossVersionObjectReference contains enough information to let you identify the referred resource. */
    interface io$k8s$api$autoscaling$v2beta1$CrossVersionObjectReference {
        /** API version of the referent */
        apiVersion?: string;
        /** Kind of the referent; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds" */
        kind: string;
        /** Name of the referent; More info: http://kubernetes.io/docs/user-guide/identifiers#names */
        name: string;
    }
    /** ExternalMetricSource indicates how to scale on a metric not associated with any Kubernetes object (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster). Exactly one "target" type should be set. */
    interface io$k8s$api$autoscaling$v2beta1$ExternalMetricSource {
        /** metricName is the name of the metric in question. */
        metricName: string;
        metricSelector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        targetAverageValue?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        targetValue?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
    }
    /** ExternalMetricStatus indicates the current value of a global metric not associated with any Kubernetes object. */
    interface io$k8s$api$autoscaling$v2beta1$ExternalMetricStatus {
        currentAverageValue?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        currentValue: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        /** metricName is the name of a metric used for autoscaling in metric system. */
        metricName: string;
        metricSelector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
    }
    /** HorizontalPodAutoscaler is the configuration for a horizontal pod autoscaler, which automatically manages the replica count of any resource implementing the scale subresource based on the metrics specified. */
    interface io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscalerSpec;
        status?: Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscalerStatus;
    }
    /** HorizontalPodAutoscalerCondition describes the state of a HorizontalPodAutoscaler at a certain point. */
    interface io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscalerCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** message is a human-readable explanation containing details about the transition */
        message?: string;
        /** reason is the reason for the condition's last transition. */
        reason?: string;
        /** status is the status of the condition (True, False, Unknown) */
        status: string;
        /** type describes the current condition */
        type: string;
    }
    /** HorizontalPodAutoscaler is a list of horizontal pod autoscaler objects. */
    interface io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscalerList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of horizontal pod autoscaler objects. */
        items: Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** HorizontalPodAutoscalerSpec describes the desired functionality of the HorizontalPodAutoscaler. */
    interface io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscalerSpec {
        /** maxReplicas is the upper limit for the number of replicas to which the autoscaler can scale up. It cannot be less that minReplicas. */
        maxReplicas: number;
        /** metrics contains the specifications for which to use to calculate the desired replica count (the maximum replica count across all metrics will be used).  The desired replica count is calculated multiplying the ratio between the target value and the current value by the current number of pods.  Ergo, metrics used must decrease as the pod count is increased, and vice-versa.  See the individual metric source types for more information about how each type of metric must respond. */
        metrics?: Schemas.io$k8s$api$autoscaling$v2beta1$MetricSpec[];
        /** minReplicas is the lower limit for the number of replicas to which the autoscaler can scale down.  It defaults to 1 pod.  minReplicas is allowed to be 0 if the alpha feature gate HPAScaleToZero is enabled and at least one Object or External metric is configured.  Scaling is active as long as at least one metric value is available. */
        minReplicas?: number;
        scaleTargetRef: Schemas.io$k8s$api$autoscaling$v2beta1$CrossVersionObjectReference;
    }
    /** HorizontalPodAutoscalerStatus describes the current status of a horizontal pod autoscaler. */
    interface io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscalerStatus {
        /** conditions is the set of conditions required for this autoscaler to scale its target, and indicates whether or not those conditions are met. */
        conditions?: Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscalerCondition[];
        /** currentMetrics is the last read state of the metrics used by this autoscaler. */
        currentMetrics?: Schemas.io$k8s$api$autoscaling$v2beta1$MetricStatus[];
        /** currentReplicas is current number of replicas of pods managed by this autoscaler, as last seen by the autoscaler. */
        currentReplicas: number;
        /** desiredReplicas is the desired number of replicas of pods managed by this autoscaler, as last calculated by the autoscaler. */
        desiredReplicas: number;
        lastScaleTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** observedGeneration is the most recent generation observed by this autoscaler. */
        observedGeneration?: number;
    }
    /** MetricSpec specifies how to scale based on a single metric (only `type` and one other matching field should be set at once). */
    interface io$k8s$api$autoscaling$v2beta1$MetricSpec {
        containerResource?: Schemas.io$k8s$api$autoscaling$v2beta1$ContainerResourceMetricSource;
        external?: Schemas.io$k8s$api$autoscaling$v2beta1$ExternalMetricSource;
        object?: Schemas.io$k8s$api$autoscaling$v2beta1$ObjectMetricSource;
        pods?: Schemas.io$k8s$api$autoscaling$v2beta1$PodsMetricSource;
        resource?: Schemas.io$k8s$api$autoscaling$v2beta1$ResourceMetricSource;
        /** type is the type of metric source.  It should be one of "ContainerResource", "External", "Object", "Pods" or "Resource", each mapping to a matching field in the object. Note: "ContainerResource" type is available on when the feature-gate HPAContainerMetrics is enabled */
        type: string;
    }
    /** MetricStatus describes the last-read state of a single metric. */
    interface io$k8s$api$autoscaling$v2beta1$MetricStatus {
        containerResource?: Schemas.io$k8s$api$autoscaling$v2beta1$ContainerResourceMetricStatus;
        external?: Schemas.io$k8s$api$autoscaling$v2beta1$ExternalMetricStatus;
        object?: Schemas.io$k8s$api$autoscaling$v2beta1$ObjectMetricStatus;
        pods?: Schemas.io$k8s$api$autoscaling$v2beta1$PodsMetricStatus;
        resource?: Schemas.io$k8s$api$autoscaling$v2beta1$ResourceMetricStatus;
        /** type is the type of metric source.  It will be one of "ContainerResource", "External", "Object", "Pods" or "Resource", each corresponds to a matching field in the object. Note: "ContainerResource" type is available on when the feature-gate HPAContainerMetrics is enabled */
        type: string;
    }
    /** ObjectMetricSource indicates how to scale on a metric describing a kubernetes object (for example, hits-per-second on an Ingress object). */
    interface io$k8s$api$autoscaling$v2beta1$ObjectMetricSource {
        averageValue?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        /** metricName is the name of the metric in question. */
        metricName: string;
        selector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        target: Schemas.io$k8s$api$autoscaling$v2beta1$CrossVersionObjectReference;
        targetValue: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
    }
    /** ObjectMetricStatus indicates the current value of a metric describing a kubernetes object (for example, hits-per-second on an Ingress object). */
    interface io$k8s$api$autoscaling$v2beta1$ObjectMetricStatus {
        averageValue?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        currentValue: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        /** metricName is the name of the metric in question. */
        metricName: string;
        selector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        target: Schemas.io$k8s$api$autoscaling$v2beta1$CrossVersionObjectReference;
    }
    /** PodsMetricSource indicates how to scale on a metric describing each pod in the current scale target (for example, transactions-processed-per-second). The values will be averaged together before being compared to the target value. */
    interface io$k8s$api$autoscaling$v2beta1$PodsMetricSource {
        /** metricName is the name of the metric in question */
        metricName: string;
        selector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        targetAverageValue: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
    }
    /** PodsMetricStatus indicates the current value of a metric describing each pod in the current scale target (for example, transactions-processed-per-second). */
    interface io$k8s$api$autoscaling$v2beta1$PodsMetricStatus {
        currentAverageValue: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        /** metricName is the name of the metric in question */
        metricName: string;
        selector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
    }
    /** ResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set. */
    interface io$k8s$api$autoscaling$v2beta1$ResourceMetricSource {
        /** name is the name of the resource in question. */
        name: string;
        /** targetAverageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods. */
        targetAverageUtilization?: number;
        targetAverageValue?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
    }
    /** ResourceMetricStatus indicates the current value of a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source. */
    interface io$k8s$api$autoscaling$v2beta1$ResourceMetricStatus {
        /** currentAverageUtilization is the current value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods.  It will only be present if `targetAverageValue` was set in the corresponding metric specification. */
        currentAverageUtilization?: number;
        currentAverageValue: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        /** name is the name of the resource in question. */
        name: string;
    }
    /** ContainerResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set. */
    interface io$k8s$api$autoscaling$v2beta2$ContainerResourceMetricSource {
        /** container is the name of the container in the pods of the scaling target */
        container: string;
        /** name is the name of the resource in question. */
        name: string;
        target: Schemas.io$k8s$api$autoscaling$v2beta2$MetricTarget;
    }
    /** ContainerResourceMetricStatus indicates the current value of a resource metric known to Kubernetes, as specified in requests and limits, describing a single container in each pod in the current scale target (e.g. CPU or memory).  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source. */
    interface io$k8s$api$autoscaling$v2beta2$ContainerResourceMetricStatus {
        /** Container is the name of the container in the pods of the scaling target */
        container: string;
        current: Schemas.io$k8s$api$autoscaling$v2beta2$MetricValueStatus;
        /** Name is the name of the resource in question. */
        name: string;
    }
    /** CrossVersionObjectReference contains enough information to let you identify the referred resource. */
    interface io$k8s$api$autoscaling$v2beta2$CrossVersionObjectReference {
        /** API version of the referent */
        apiVersion?: string;
        /** Kind of the referent; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds" */
        kind: string;
        /** Name of the referent; More info: http://kubernetes.io/docs/user-guide/identifiers#names */
        name: string;
    }
    /** ExternalMetricSource indicates how to scale on a metric not associated with any Kubernetes object (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster). */
    interface io$k8s$api$autoscaling$v2beta2$ExternalMetricSource {
        metric: Schemas.io$k8s$api$autoscaling$v2beta2$MetricIdentifier;
        target: Schemas.io$k8s$api$autoscaling$v2beta2$MetricTarget;
    }
    /** ExternalMetricStatus indicates the current value of a global metric not associated with any Kubernetes object. */
    interface io$k8s$api$autoscaling$v2beta2$ExternalMetricStatus {
        current: Schemas.io$k8s$api$autoscaling$v2beta2$MetricValueStatus;
        metric: Schemas.io$k8s$api$autoscaling$v2beta2$MetricIdentifier;
    }
    /** HPAScalingPolicy is a single policy which must hold true for a specified past interval. */
    interface io$k8s$api$autoscaling$v2beta2$HPAScalingPolicy {
        /** PeriodSeconds specifies the window of time for which the policy should hold true. PeriodSeconds must be greater than zero and less than or equal to 1800 (30 min). */
        periodSeconds: number;
        /** Type is used to specify the scaling policy. */
        type: string;
        /** Value contains the amount of change which is permitted by the policy. It must be greater than zero */
        value: number;
    }
    /** HPAScalingRules configures the scaling behavior for one direction. These Rules are applied after calculating DesiredReplicas from metrics for the HPA. They can limit the scaling velocity by specifying scaling policies. They can prevent flapping by specifying the stabilization window, so that the number of replicas is not set instantly, instead, the safest value from the stabilization window is chosen. */
    interface io$k8s$api$autoscaling$v2beta2$HPAScalingRules {
        /** policies is a list of potential scaling polices which can be used during scaling. At least one policy must be specified, otherwise the HPAScalingRules will be discarded as invalid */
        policies?: Schemas.io$k8s$api$autoscaling$v2beta2$HPAScalingPolicy[];
        /** selectPolicy is used to specify which policy should be used. If not set, the default value MaxPolicySelect is used. */
        selectPolicy?: string;
        /** StabilizationWindowSeconds is the number of seconds for which past recommendations should be considered while scaling up or scaling down. StabilizationWindowSeconds must be greater than or equal to zero and less than or equal to 3600 (one hour). If not set, use the default values: - For scale up: 0 (i.e. no stabilization is done). - For scale down: 300 (i.e. the stabilization window is 300 seconds long). */
        stabilizationWindowSeconds?: number;
    }
    /** HorizontalPodAutoscaler is the configuration for a horizontal pod autoscaler, which automatically manages the replica count of any resource implementing the scale subresource based on the metrics specified. */
    interface io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscalerSpec;
        status?: Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscalerStatus;
    }
    /** HorizontalPodAutoscalerBehavior configures the scaling behavior of the target in both Up and Down directions (scaleUp and scaleDown fields respectively). */
    interface io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscalerBehavior {
        scaleDown?: Schemas.io$k8s$api$autoscaling$v2beta2$HPAScalingRules;
        scaleUp?: Schemas.io$k8s$api$autoscaling$v2beta2$HPAScalingRules;
    }
    /** HorizontalPodAutoscalerCondition describes the state of a HorizontalPodAutoscaler at a certain point. */
    interface io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscalerCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** message is a human-readable explanation containing details about the transition */
        message?: string;
        /** reason is the reason for the condition's last transition. */
        reason?: string;
        /** status is the status of the condition (True, False, Unknown) */
        status: string;
        /** type describes the current condition */
        type: string;
    }
    /** HorizontalPodAutoscalerList is a list of horizontal pod autoscaler objects. */
    interface io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscalerList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of horizontal pod autoscaler objects. */
        items: Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** HorizontalPodAutoscalerSpec describes the desired functionality of the HorizontalPodAutoscaler. */
    interface io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscalerSpec {
        behavior?: Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscalerBehavior;
        /** maxReplicas is the upper limit for the number of replicas to which the autoscaler can scale up. It cannot be less that minReplicas. */
        maxReplicas: number;
        /** metrics contains the specifications for which to use to calculate the desired replica count (the maximum replica count across all metrics will be used).  The desired replica count is calculated multiplying the ratio between the target value and the current value by the current number of pods.  Ergo, metrics used must decrease as the pod count is increased, and vice-versa.  See the individual metric source types for more information about how each type of metric must respond. If not set, the default metric will be set to 80% average CPU utilization. */
        metrics?: Schemas.io$k8s$api$autoscaling$v2beta2$MetricSpec[];
        /** minReplicas is the lower limit for the number of replicas to which the autoscaler can scale down.  It defaults to 1 pod.  minReplicas is allowed to be 0 if the alpha feature gate HPAScaleToZero is enabled and at least one Object or External metric is configured.  Scaling is active as long as at least one metric value is available. */
        minReplicas?: number;
        scaleTargetRef: Schemas.io$k8s$api$autoscaling$v2beta2$CrossVersionObjectReference;
    }
    /** HorizontalPodAutoscalerStatus describes the current status of a horizontal pod autoscaler. */
    interface io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscalerStatus {
        /** conditions is the set of conditions required for this autoscaler to scale its target, and indicates whether or not those conditions are met. */
        conditions?: Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscalerCondition[];
        /** currentMetrics is the last read state of the metrics used by this autoscaler. */
        currentMetrics?: Schemas.io$k8s$api$autoscaling$v2beta2$MetricStatus[];
        /** currentReplicas is current number of replicas of pods managed by this autoscaler, as last seen by the autoscaler. */
        currentReplicas: number;
        /** desiredReplicas is the desired number of replicas of pods managed by this autoscaler, as last calculated by the autoscaler. */
        desiredReplicas: number;
        lastScaleTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** observedGeneration is the most recent generation observed by this autoscaler. */
        observedGeneration?: number;
    }
    /** MetricIdentifier defines the name and optionally selector for a metric */
    interface io$k8s$api$autoscaling$v2beta2$MetricIdentifier {
        /** name is the name of the given metric */
        name: string;
        selector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
    }
    /** MetricSpec specifies how to scale based on a single metric (only `type` and one other matching field should be set at once). */
    interface io$k8s$api$autoscaling$v2beta2$MetricSpec {
        containerResource?: Schemas.io$k8s$api$autoscaling$v2beta2$ContainerResourceMetricSource;
        external?: Schemas.io$k8s$api$autoscaling$v2beta2$ExternalMetricSource;
        object?: Schemas.io$k8s$api$autoscaling$v2beta2$ObjectMetricSource;
        pods?: Schemas.io$k8s$api$autoscaling$v2beta2$PodsMetricSource;
        resource?: Schemas.io$k8s$api$autoscaling$v2beta2$ResourceMetricSource;
        /** type is the type of metric source.  It should be one of "ContainerResource", "External", "Object", "Pods" or "Resource", each mapping to a matching field in the object. Note: "ContainerResource" type is available on when the feature-gate HPAContainerMetrics is enabled */
        type: string;
    }
    /** MetricStatus describes the last-read state of a single metric. */
    interface io$k8s$api$autoscaling$v2beta2$MetricStatus {
        containerResource?: Schemas.io$k8s$api$autoscaling$v2beta2$ContainerResourceMetricStatus;
        external?: Schemas.io$k8s$api$autoscaling$v2beta2$ExternalMetricStatus;
        object?: Schemas.io$k8s$api$autoscaling$v2beta2$ObjectMetricStatus;
        pods?: Schemas.io$k8s$api$autoscaling$v2beta2$PodsMetricStatus;
        resource?: Schemas.io$k8s$api$autoscaling$v2beta2$ResourceMetricStatus;
        /** type is the type of metric source.  It will be one of "ContainerResource", "External", "Object", "Pods" or "Resource", each corresponds to a matching field in the object. Note: "ContainerResource" type is available on when the feature-gate HPAContainerMetrics is enabled */
        type: string;
    }
    /** MetricTarget defines the target value, average value, or average utilization of a specific metric */
    interface io$k8s$api$autoscaling$v2beta2$MetricTarget {
        /** averageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods. Currently only valid for Resource metric source type */
        averageUtilization?: number;
        averageValue?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        /** type represents whether the metric type is Utilization, Value, or AverageValue */
        type: string;
        value?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
    }
    /** MetricValueStatus holds the current value for a metric */
    interface io$k8s$api$autoscaling$v2beta2$MetricValueStatus {
        /** currentAverageUtilization is the current value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods. */
        averageUtilization?: number;
        averageValue?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        value?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
    }
    /** ObjectMetricSource indicates how to scale on a metric describing a kubernetes object (for example, hits-per-second on an Ingress object). */
    interface io$k8s$api$autoscaling$v2beta2$ObjectMetricSource {
        describedObject: Schemas.io$k8s$api$autoscaling$v2beta2$CrossVersionObjectReference;
        metric: Schemas.io$k8s$api$autoscaling$v2beta2$MetricIdentifier;
        target: Schemas.io$k8s$api$autoscaling$v2beta2$MetricTarget;
    }
    /** ObjectMetricStatus indicates the current value of a metric describing a kubernetes object (for example, hits-per-second on an Ingress object). */
    interface io$k8s$api$autoscaling$v2beta2$ObjectMetricStatus {
        current: Schemas.io$k8s$api$autoscaling$v2beta2$MetricValueStatus;
        describedObject: Schemas.io$k8s$api$autoscaling$v2beta2$CrossVersionObjectReference;
        metric: Schemas.io$k8s$api$autoscaling$v2beta2$MetricIdentifier;
    }
    /** PodsMetricSource indicates how to scale on a metric describing each pod in the current scale target (for example, transactions-processed-per-second). The values will be averaged together before being compared to the target value. */
    interface io$k8s$api$autoscaling$v2beta2$PodsMetricSource {
        metric: Schemas.io$k8s$api$autoscaling$v2beta2$MetricIdentifier;
        target: Schemas.io$k8s$api$autoscaling$v2beta2$MetricTarget;
    }
    /** PodsMetricStatus indicates the current value of a metric describing each pod in the current scale target (for example, transactions-processed-per-second). */
    interface io$k8s$api$autoscaling$v2beta2$PodsMetricStatus {
        current: Schemas.io$k8s$api$autoscaling$v2beta2$MetricValueStatus;
        metric: Schemas.io$k8s$api$autoscaling$v2beta2$MetricIdentifier;
    }
    /** ResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set. */
    interface io$k8s$api$autoscaling$v2beta2$ResourceMetricSource {
        /** name is the name of the resource in question. */
        name: string;
        target: Schemas.io$k8s$api$autoscaling$v2beta2$MetricTarget;
    }
    /** ResourceMetricStatus indicates the current value of a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source. */
    interface io$k8s$api$autoscaling$v2beta2$ResourceMetricStatus {
        current: Schemas.io$k8s$api$autoscaling$v2beta2$MetricValueStatus;
        /** Name is the name of the resource in question. */
        name: string;
    }
    /** CronJob represents the configuration of a single cron job. */
    interface io$k8s$api$batch$v1$CronJob {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$batch$v1$CronJobSpec;
        status?: Schemas.io$k8s$api$batch$v1$CronJobStatus;
    }
    /** CronJobList is a collection of cron jobs. */
    interface io$k8s$api$batch$v1$CronJobList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of CronJobs. */
        items: Schemas.io$k8s$api$batch$v1$CronJob[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** CronJobSpec describes how the job execution will look like and when it will actually run. */
    interface io$k8s$api$batch$v1$CronJobSpec {
        /**
         * Specifies how to treat concurrent executions of a Job. Valid values are: - "Allow" (default): allows CronJobs to run concurrently; - "Forbid": forbids concurrent runs, skipping next run if previous run hasn't finished yet; - "Replace": cancels currently running job and replaces it with a new one
         *
         */
        concurrencyPolicy?: string;
        /** The number of failed finished jobs to retain. Value must be non-negative integer. Defaults to 1. */
        failedJobsHistoryLimit?: number;
        jobTemplate: Schemas.io$k8s$api$batch$v1$JobTemplateSpec;
        /** The schedule in Cron format, see https://en.wikipedia.org/wiki/Cron. */
        schedule: string;
        /** Optional deadline in seconds for starting the job if it misses scheduled time for any reason.  Missed jobs executions will be counted as failed ones. */
        startingDeadlineSeconds?: number;
        /** The number of successful finished jobs to retain. Value must be non-negative integer. Defaults to 3. */
        successfulJobsHistoryLimit?: number;
        /** This flag tells the controller to suspend subsequent executions, it does not apply to already started executions.  Defaults to false. */
        suspend?: boolean;
    }
    /** CronJobStatus represents the current state of a cron job. */
    interface io$k8s$api$batch$v1$CronJobStatus {
        /** A list of pointers to currently running jobs. */
        active?: Schemas.io$k8s$api$core$v1$ObjectReference[];
        lastScheduleTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        lastSuccessfulTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
    }
    /** Job represents the configuration of a single job. */
    interface io$k8s$api$batch$v1$Job {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$batch$v1$JobSpec;
        status?: Schemas.io$k8s$api$batch$v1$JobStatus;
    }
    /** JobCondition describes current state of a job. */
    interface io$k8s$api$batch$v1$JobCondition {
        lastProbeTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** Human readable message indicating details about last transition. */
        message?: string;
        /** (brief) reason for the condition's last transition. */
        reason?: string;
        /** Status of the condition, one of True, False, Unknown. */
        status: string;
        /** Type of job condition, Complete or Failed. */
        type: string;
    }
    /** JobList is a collection of jobs. */
    interface io$k8s$api$batch$v1$JobList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of Jobs. */
        items: Schemas.io$k8s$api$batch$v1$Job[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** JobSpec describes how the job execution will look like. */
    interface io$k8s$api$batch$v1$JobSpec {
        /** Specifies the duration in seconds relative to the startTime that the job may be continuously active before the system tries to terminate it; value must be positive integer. If a Job is suspended (at creation or through an update), this timer will effectively be stopped and reset when the Job is resumed again. */
        activeDeadlineSeconds?: number;
        /** Specifies the number of retries before marking this job failed. Defaults to 6 */
        backoffLimit?: number;
        /**
         * CompletionMode specifies how Pod completions are tracked. It can be `NonIndexed` (default) or `Indexed`.
         *
         * `NonIndexed` means that the Job is considered complete when there have been .spec.completions successfully completed Pods. Each Pod completion is homologous to each other.
         *
         * `Indexed` means that the Pods of a Job get an associated completion index from 0 to (.spec.completions - 1), available in the annotation batch.kubernetes.io/job-completion-index. The Job is considered complete when there is one successfully completed Pod for each index. When value is `Indexed`, .spec.completions must be specified and `.spec.parallelism` must be less than or equal to 10^5. In addition, The Pod name takes the form `$(job-name)-$(index)-$(random-string)`, the Pod hostname takes the form `$(job-name)-$(index)`.
         *
         * This field is beta-level. More completion modes can be added in the future. If the Job controller observes a mode that it doesn't recognize, the controller skips updates for the Job.
         */
        completionMode?: string;
        /** Specifies the desired number of successfully finished pods the job should be run with.  Setting to nil means that the success of any pod signals the success of all pods, and allows parallelism to have any positive value.  Setting to 1 means that parallelism is limited to 1 and the success of that pod signals the success of the job. More info: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/ */
        completions?: number;
        /** manualSelector controls generation of pod labels and pod selectors. Leave `manualSelector` unset unless you are certain what you are doing. When false or unset, the system pick labels unique to this job and appends those labels to the pod template.  When true, the user is responsible for picking unique labels and specifying the selector.  Failure to pick a unique label may cause this and other jobs to not function correctly.  However, You may see `manualSelector=true` in jobs that were created with the old `extensions/v1beta1` API. More info: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/#specifying-your-own-pod-selector */
        manualSelector?: boolean;
        /** Specifies the maximum desired number of pods the job should run at any given time. The actual number of pods running in steady state will be less than this number when ((.spec.completions - .status.successful) < .spec.parallelism), i.e. when the work left to do is less than max parallelism. More info: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/ */
        parallelism?: number;
        selector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        /**
         * Suspend specifies whether the Job controller should create Pods or not. If a Job is created with suspend set to true, no Pods are created by the Job controller. If a Job is suspended after creation (i.e. the flag goes from false to true), the Job controller will delete all active Pods associated with this Job. Users must design their workload to gracefully handle this. Suspending a Job will reset the StartTime field of the Job, effectively resetting the ActiveDeadlineSeconds timer too. Defaults to false.
         *
         * This field is beta-level, gated by SuspendJob feature flag (enabled by default).
         */
        suspend?: boolean;
        template: Schemas.io$k8s$api$core$v1$PodTemplateSpec;
        /** ttlSecondsAfterFinished limits the lifetime of a Job that has finished execution (either Complete or Failed). If this field is set, ttlSecondsAfterFinished after the Job finishes, it is eligible to be automatically deleted. When the Job is being deleted, its lifecycle guarantees (e.g. finalizers) will be honored. If this field is unset, the Job won't be automatically deleted. If this field is set to zero, the Job becomes eligible to be deleted immediately after it finishes. */
        ttlSecondsAfterFinished?: number;
    }
    /** JobStatus represents the current state of a Job. */
    interface io$k8s$api$batch$v1$JobStatus {
        /** The number of pending and running pods. */
        active?: number;
        /** CompletedIndexes holds the completed indexes when .spec.completionMode = "Indexed" in a text format. The indexes are represented as decimal integers separated by commas. The numbers are listed in increasing order. Three or more consecutive numbers are compressed and represented by the first and last element of the series, separated by a hyphen. For example, if the completed indexes are 1, 3, 4, 5 and 7, they are represented as "1,3-5,7". */
        completedIndexes?: string;
        completionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** The latest available observations of an object's current state. When a Job fails, one of the conditions will have type "Failed" and status true. When a Job is suspended, one of the conditions will have type "Suspended" and status true; when the Job is resumed, the status of this condition will become false. When a Job is completed, one of the conditions will have type "Complete" and status true. More info: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/ */
        conditions?: Schemas.io$k8s$api$batch$v1$JobCondition[];
        /** The number of pods which reached phase Failed. */
        failed?: number;
        /**
         * The number of pods which have a Ready condition.
         *
         * This field is alpha-level. The job controller populates the field when the feature gate JobReadyPods is enabled (disabled by default).
         */
        ready?: number;
        startTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** The number of pods which reached phase Succeeded. */
        succeeded?: number;
        uncountedTerminatedPods?: Schemas.io$k8s$api$batch$v1$UncountedTerminatedPods;
    }
    /** JobTemplateSpec describes the data a Job should have when created from a template */
    interface io$k8s$api$batch$v1$JobTemplateSpec {
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$batch$v1$JobSpec;
    }
    /** UncountedTerminatedPods holds UIDs of Pods that have terminated but haven't been accounted in Job status counters. */
    interface io$k8s$api$batch$v1$UncountedTerminatedPods {
        /** Failed holds UIDs of failed Pods. */
        failed?: string[];
        /** Succeeded holds UIDs of succeeded Pods. */
        succeeded?: string[];
    }
    /** CronJob represents the configuration of a single cron job. */
    interface io$k8s$api$batch$v1beta1$CronJob {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$batch$v1beta1$CronJobSpec;
        status?: Schemas.io$k8s$api$batch$v1beta1$CronJobStatus;
    }
    /** CronJobList is a collection of cron jobs. */
    interface io$k8s$api$batch$v1beta1$CronJobList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of CronJobs. */
        items: Schemas.io$k8s$api$batch$v1beta1$CronJob[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** CronJobSpec describes how the job execution will look like and when it will actually run. */
    interface io$k8s$api$batch$v1beta1$CronJobSpec {
        /** Specifies how to treat concurrent executions of a Job. Valid values are: - "Allow" (default): allows CronJobs to run concurrently; - "Forbid": forbids concurrent runs, skipping next run if previous run hasn't finished yet; - "Replace": cancels currently running job and replaces it with a new one */
        concurrencyPolicy?: string;
        /** The number of failed finished jobs to retain. This is a pointer to distinguish between explicit zero and not specified. Defaults to 1. */
        failedJobsHistoryLimit?: number;
        jobTemplate: Schemas.io$k8s$api$batch$v1beta1$JobTemplateSpec;
        /** The schedule in Cron format, see https://en.wikipedia.org/wiki/Cron. */
        schedule: string;
        /** Optional deadline in seconds for starting the job if it misses scheduled time for any reason.  Missed jobs executions will be counted as failed ones. */
        startingDeadlineSeconds?: number;
        /** The number of successful finished jobs to retain. This is a pointer to distinguish between explicit zero and not specified. Defaults to 3. */
        successfulJobsHistoryLimit?: number;
        /** This flag tells the controller to suspend subsequent executions, it does not apply to already started executions.  Defaults to false. */
        suspend?: boolean;
    }
    /** CronJobStatus represents the current state of a cron job. */
    interface io$k8s$api$batch$v1beta1$CronJobStatus {
        /** A list of pointers to currently running jobs. */
        active?: Schemas.io$k8s$api$core$v1$ObjectReference[];
        lastScheduleTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        lastSuccessfulTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
    }
    /** JobTemplateSpec describes the data a Job should have when created from a template */
    interface io$k8s$api$batch$v1beta1$JobTemplateSpec {
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$batch$v1$JobSpec;
    }
    /**
     * CertificateSigningRequest objects provide a mechanism to obtain x509 certificates by submitting a certificate signing request, and having it asynchronously approved and issued.
     *
     * Kubelets use this API to obtain:
     *  1. client certificates to authenticate to kube-apiserver (with the "kubernetes.io/kube-apiserver-client-kubelet" signerName).
     *  2. serving certificates for TLS endpoints kube-apiserver can connect to securely (with the "kubernetes.io/kubelet-serving" signerName).
     *
     * This API can be used to request client certificates to authenticate to kube-apiserver (with the "kubernetes.io/kube-apiserver-client" signerName), or to obtain certificates from custom non-Kubernetes signers.
     */
    interface io$k8s$api$certificates$v1$CertificateSigningRequest {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$certificates$v1$CertificateSigningRequestSpec;
        status?: Schemas.io$k8s$api$certificates$v1$CertificateSigningRequestStatus;
    }
    /** CertificateSigningRequestCondition describes a condition of a CertificateSigningRequest object */
    interface io$k8s$api$certificates$v1$CertificateSigningRequestCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        lastUpdateTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** message contains a human readable message with details about the request state */
        message?: string;
        /** reason indicates a brief reason for the request state */
        reason?: string;
        /** status of the condition, one of True, False, Unknown. Approved, Denied, and Failed conditions may not be "False" or "Unknown". */
        status: string;
        /**
         * type of the condition. Known conditions are "Approved", "Denied", and "Failed".
         *
         * An "Approved" condition is added via the /approval subresource, indicating the request was approved and should be issued by the signer.
         *
         * A "Denied" condition is added via the /approval subresource, indicating the request was denied and should not be issued by the signer.
         *
         * A "Failed" condition is added via the /status subresource, indicating the signer failed to issue the certificate.
         *
         * Approved and Denied conditions are mutually exclusive. Approved, Denied, and Failed conditions cannot be removed once added.
         *
         * Only one condition of a given type is allowed.
         */
        type: string;
    }
    /** CertificateSigningRequestList is a collection of CertificateSigningRequest objects */
    interface io$k8s$api$certificates$v1$CertificateSigningRequestList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is a collection of CertificateSigningRequest objects */
        items: Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** CertificateSigningRequestSpec contains the certificate request. */
    interface io$k8s$api$certificates$v1$CertificateSigningRequestSpec {
        /**
         * expirationSeconds is the requested duration of validity of the issued certificate. The certificate signer may issue a certificate with a different validity duration so a client must check the delta between the notBefore and and notAfter fields in the issued certificate to determine the actual duration.
         *
         * The v1.22+ in-tree implementations of the well-known Kubernetes signers will honor this field as long as the requested duration is not greater than the maximum duration they will honor per the --cluster-signing-duration CLI flag to the Kubernetes controller manager.
         *
         * Certificate signers may not honor this field for various reasons:
         *
         *   1. Old signer that is unaware of the field (such as the in-tree
         *      implementations prior to v1.22)
         *   2. Signer whose configured maximum is shorter than the requested duration
         *   3. Signer whose configured minimum is longer than the requested duration
         *
         * The minimum valid value for expirationSeconds is 600, i.e. 10 minutes.
         *
         * As of v1.22, this field is beta and is controlled via the CSRDuration feature gate.
         */
        expirationSeconds?: number;
        /** extra contains extra attributes of the user that created the CertificateSigningRequest. Populated by the API server on creation and immutable. */
        extra?: {
            [key: string]: string[];
        };
        /** groups contains group membership of the user that created the CertificateSigningRequest. Populated by the API server on creation and immutable. */
        groups?: string[];
        /** request contains an x509 certificate signing request encoded in a "CERTIFICATE REQUEST" PEM block. When serialized as JSON or YAML, the data is additionally base64-encoded. */
        request: Blob;
        /**
         * signerName indicates the requested signer, and is a qualified name.
         *
         * List/watch requests for CertificateSigningRequests can filter on this field using a "spec.signerName=NAME" fieldSelector.
         *
         * Well-known Kubernetes signers are:
         *  1. "kubernetes.io/kube-apiserver-client": issues client certificates that can be used to authenticate to kube-apiserver.
         *   Requests for this signer are never auto-approved by kube-controller-manager, can be issued by the "csrsigning" controller in kube-controller-manager.
         *  2. "kubernetes.io/kube-apiserver-client-kubelet": issues client certificates that kubelets use to authenticate to kube-apiserver.
         *   Requests for this signer can be auto-approved by the "csrapproving" controller in kube-controller-manager, and can be issued by the "csrsigning" controller in kube-controller-manager.
         *  3. "kubernetes.io/kubelet-serving" issues serving certificates that kubelets use to serve TLS endpoints, which kube-apiserver can connect to securely.
         *   Requests for this signer are never auto-approved by kube-controller-manager, and can be issued by the "csrsigning" controller in kube-controller-manager.
         *
         * More details are available at https://k8s.io/docs/reference/access-authn-authz/certificate-signing-requests/#kubernetes-signers
         *
         * Custom signerNames can also be specified. The signer defines:
         *  1. Trust distribution: how trust (CA bundles) are distributed.
         *  2. Permitted subjects: and behavior when a disallowed subject is requested.
         *  3. Required, permitted, or forbidden x509 extensions in the request (including whether subjectAltNames are allowed, which types, restrictions on allowed values) and behavior when a disallowed extension is requested.
         *  4. Required, permitted, or forbidden key usages / extended key usages.
         *  5. Expiration/certificate lifetime: whether it is fixed by the signer, configurable by the admin.
         *  6. Whether or not requests for CA certificates are allowed.
         */
        signerName: string;
        /** uid contains the uid of the user that created the CertificateSigningRequest. Populated by the API server on creation and immutable. */
        uid?: string;
        /**
         * usages specifies a set of key usages requested in the issued certificate.
         *
         * Requests for TLS client certificates typically request: "digital signature", "key encipherment", "client auth".
         *
         * Requests for TLS serving certificates typically request: "key encipherment", "digital signature", "server auth".
         *
         * Valid values are:
         *  "signing", "digital signature", "content commitment",
         *  "key encipherment", "key agreement", "data encipherment",
         *  "cert sign", "crl sign", "encipher only", "decipher only", "any",
         *  "server auth", "client auth",
         *  "code signing", "email protection", "s/mime",
         *  "ipsec end system", "ipsec tunnel", "ipsec user",
         *  "timestamping", "ocsp signing", "microsoft sgc", "netscape sgc"
         */
        usages?: string[];
        /** username contains the name of the user that created the CertificateSigningRequest. Populated by the API server on creation and immutable. */
        username?: string;
    }
    /** CertificateSigningRequestStatus contains conditions used to indicate approved/denied/failed status of the request, and the issued certificate. */
    interface io$k8s$api$certificates$v1$CertificateSigningRequestStatus {
        /**
         * certificate is populated with an issued certificate by the signer after an Approved condition is present. This field is set via the /status subresource. Once populated, this field is immutable.
         *
         * If the certificate signing request is denied, a condition of type "Denied" is added and this field remains empty. If the signer cannot issue the certificate, a condition of type "Failed" is added and this field remains empty.
         *
         * Validation requirements:
         *  1. certificate must contain one or more PEM blocks.
         *  2. All PEM blocks must have the "CERTIFICATE" label, contain no headers, and the encoded data
         *   must be a BER-encoded ASN.1 Certificate structure as described in section 4 of RFC5280.
         *  3. Non-PEM content may appear before or after the "CERTIFICATE" PEM blocks and is unvalidated,
         *   to allow for explanatory text as described in section 5.2 of RFC7468.
         *
         * If more than one PEM block is present, and the definition of the requested spec.signerName does not indicate otherwise, the first block is the issued certificate, and subsequent blocks should be treated as intermediate certificates and presented in TLS handshakes.
         *
         * The certificate is encoded in PEM format.
         *
         * When serialized as JSON or YAML, the data is additionally base64-encoded, so it consists of:
         *
         *     base64(
         *     -----BEGIN CERTIFICATE-----
         *     ...
         *     -----END CERTIFICATE-----
         *     )
         */
        certificate?: Blob;
        /** conditions applied to the request. Known conditions are "Approved", "Denied", and "Failed". */
        conditions?: Schemas.io$k8s$api$certificates$v1$CertificateSigningRequestCondition[];
    }
    /** Lease defines a lease concept. */
    interface io$k8s$api$coordination$v1$Lease {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$coordination$v1$LeaseSpec;
    }
    /** LeaseList is a list of Lease objects. */
    interface io$k8s$api$coordination$v1$LeaseList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is a list of schema objects. */
        items: Schemas.io$k8s$api$coordination$v1$Lease[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** LeaseSpec is a specification of a Lease. */
    interface io$k8s$api$coordination$v1$LeaseSpec {
        acquireTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$MicroTime;
        /** holderIdentity contains the identity of the holder of a current lease. */
        holderIdentity?: string;
        /** leaseDurationSeconds is a duration that candidates for a lease need to wait to force acquire it. This is measure against time of last observed RenewTime. */
        leaseDurationSeconds?: number;
        /** leaseTransitions is the number of transitions of a lease between holders. */
        leaseTransitions?: number;
        renewTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$MicroTime;
    }
    /**
     * Represents a Persistent Disk resource in AWS.
     *
     * An AWS EBS disk must exist before mounting to a container. The disk must also be in the same AWS zone as the kubelet. An AWS EBS disk can only be mounted as read/write once. AWS EBS volumes support ownership management and SELinux relabeling.
     */
    interface io$k8s$api$core$v1$AWSElasticBlockStoreVolumeSource {
        /** Filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#awselasticblockstore */
        fsType?: string;
        /** The partition in the volume that you want to mount. If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty). */
        partition?: number;
        /** Specify "true" to force and set the ReadOnly property in VolumeMounts to "true". If omitted, the default is "false". More info: https://kubernetes.io/docs/concepts/storage/volumes#awselasticblockstore */
        readOnly?: boolean;
        /** Unique ID of the persistent disk resource in AWS (Amazon EBS volume). More info: https://kubernetes.io/docs/concepts/storage/volumes#awselasticblockstore */
        volumeID: string;
    }
    /** Affinity is a group of affinity scheduling rules. */
    interface io$k8s$api$core$v1$Affinity {
        nodeAffinity?: Schemas.io$k8s$api$core$v1$NodeAffinity;
        podAffinity?: Schemas.io$k8s$api$core$v1$PodAffinity;
        podAntiAffinity?: Schemas.io$k8s$api$core$v1$PodAntiAffinity;
    }
    /** AttachedVolume describes a volume attached to a node */
    interface io$k8s$api$core$v1$AttachedVolume {
        /** DevicePath represents the device path where the volume should be available */
        devicePath: string;
        /** Name of the attached volume */
        name: string;
    }
    /** AzureDisk represents an Azure Data Disk mount on the host and bind mount to the pod. */
    interface io$k8s$api$core$v1$AzureDiskVolumeSource {
        /** Host Caching mode: None, Read Only, Read Write. */
        cachingMode?: string;
        /** The Name of the data disk in the blob storage */
        diskName: string;
        /** The URI the data disk in the blob storage */
        diskURI: string;
        /** Filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. */
        fsType?: string;
        /** Expected values Shared: multiple blob disks per storage account  Dedicated: single blob disk per storage account  Managed: azure managed data disk (only in managed availability set). defaults to shared */
        kind?: string;
        /** Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. */
        readOnly?: boolean;
    }
    /** AzureFile represents an Azure File Service mount on the host and bind mount to the pod. */
    interface io$k8s$api$core$v1$AzureFilePersistentVolumeSource {
        /** Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. */
        readOnly?: boolean;
        /** the name of secret that contains Azure Storage Account Name and Key */
        secretName: string;
        /** the namespace of the secret that contains Azure Storage Account Name and Key default is the same as the Pod */
        secretNamespace?: string;
        /** Share Name */
        shareName: string;
    }
    /** AzureFile represents an Azure File Service mount on the host and bind mount to the pod. */
    interface io$k8s$api$core$v1$AzureFileVolumeSource {
        /** Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. */
        readOnly?: boolean;
        /** the name of secret that contains Azure Storage Account Name and Key */
        secretName: string;
        /** Share Name */
        shareName: string;
    }
    /** Binding ties one object to another; for example, a pod is bound to a node by a scheduler. Deprecated in 1.7, please use the bindings subresource of pods instead. */
    interface io$k8s$api$core$v1$Binding {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        target: Schemas.io$k8s$api$core$v1$ObjectReference;
    }
    /** Represents storage that is managed by an external CSI volume driver (Beta feature) */
    interface io$k8s$api$core$v1$CSIPersistentVolumeSource {
        controllerExpandSecretRef?: Schemas.io$k8s$api$core$v1$SecretReference;
        controllerPublishSecretRef?: Schemas.io$k8s$api$core$v1$SecretReference;
        /** Driver is the name of the driver to use for this volume. Required. */
        driver: string;
        /** Filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". */
        fsType?: string;
        nodePublishSecretRef?: Schemas.io$k8s$api$core$v1$SecretReference;
        nodeStageSecretRef?: Schemas.io$k8s$api$core$v1$SecretReference;
        /** Optional: The value to pass to ControllerPublishVolumeRequest. Defaults to false (read/write). */
        readOnly?: boolean;
        /** Attributes of the volume to publish. */
        volumeAttributes?: {
            [key: string]: string;
        };
        /** VolumeHandle is the unique volume name returned by the CSI volume plugin’s CreateVolume to refer to the volume on all subsequent calls. Required. */
        volumeHandle: string;
    }
    /** Represents a source location of a volume to mount, managed by an external CSI driver */
    interface io$k8s$api$core$v1$CSIVolumeSource {
        /** Driver is the name of the CSI driver that handles this volume. Consult with your admin for the correct name as registered in the cluster. */
        driver: string;
        /** Filesystem type to mount. Ex. "ext4", "xfs", "ntfs". If not provided, the empty value is passed to the associated CSI driver which will determine the default filesystem to apply. */
        fsType?: string;
        nodePublishSecretRef?: Schemas.io$k8s$api$core$v1$LocalObjectReference;
        /** Specifies a read-only configuration for the volume. Defaults to false (read/write). */
        readOnly?: boolean;
        /** VolumeAttributes stores driver-specific properties that are passed to the CSI driver. Consult your driver's documentation for supported values. */
        volumeAttributes?: {
            [key: string]: string;
        };
    }
    /** Adds and removes POSIX capabilities from running containers. */
    interface io$k8s$api$core$v1$Capabilities {
        /** Added capabilities */
        add?: string[];
        /** Removed capabilities */
        drop?: string[];
    }
    /** Represents a Ceph Filesystem mount that lasts the lifetime of a pod Cephfs volumes do not support ownership management or SELinux relabeling. */
    interface io$k8s$api$core$v1$CephFSPersistentVolumeSource {
        /** Required: Monitors is a collection of Ceph monitors More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it */
        monitors: string[];
        /** Optional: Used as the mounted root, rather than the full Ceph tree, default is / */
        path?: string;
        /** Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it */
        readOnly?: boolean;
        /** Optional: SecretFile is the path to key ring for User, default is /etc/ceph/user.secret More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it */
        secretFile?: string;
        secretRef?: Schemas.io$k8s$api$core$v1$SecretReference;
        /** Optional: User is the rados user name, default is admin More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it */
        user?: string;
    }
    /** Represents a Ceph Filesystem mount that lasts the lifetime of a pod Cephfs volumes do not support ownership management or SELinux relabeling. */
    interface io$k8s$api$core$v1$CephFSVolumeSource {
        /** Required: Monitors is a collection of Ceph monitors More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it */
        monitors: string[];
        /** Optional: Used as the mounted root, rather than the full Ceph tree, default is / */
        path?: string;
        /** Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it */
        readOnly?: boolean;
        /** Optional: SecretFile is the path to key ring for User, default is /etc/ceph/user.secret More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it */
        secretFile?: string;
        secretRef?: Schemas.io$k8s$api$core$v1$LocalObjectReference;
        /** Optional: User is the rados user name, default is admin More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it */
        user?: string;
    }
    /** Represents a cinder volume resource in Openstack. A Cinder volume must exist before mounting to a container. The volume must also be in the same region as the kubelet. Cinder volumes support ownership management and SELinux relabeling. */
    interface io$k8s$api$core$v1$CinderPersistentVolumeSource {
        /** Filesystem type to mount. Must be a filesystem type supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://examples.k8s.io/mysql-cinder-pd/README.md */
        fsType?: string;
        /** Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/mysql-cinder-pd/README.md */
        readOnly?: boolean;
        secretRef?: Schemas.io$k8s$api$core$v1$SecretReference;
        /** volume id used to identify the volume in cinder. More info: https://examples.k8s.io/mysql-cinder-pd/README.md */
        volumeID: string;
    }
    /** Represents a cinder volume resource in Openstack. A Cinder volume must exist before mounting to a container. The volume must also be in the same region as the kubelet. Cinder volumes support ownership management and SELinux relabeling. */
    interface io$k8s$api$core$v1$CinderVolumeSource {
        /** Filesystem type to mount. Must be a filesystem type supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://examples.k8s.io/mysql-cinder-pd/README.md */
        fsType?: string;
        /** Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/mysql-cinder-pd/README.md */
        readOnly?: boolean;
        secretRef?: Schemas.io$k8s$api$core$v1$LocalObjectReference;
        /** volume id used to identify the volume in cinder. More info: https://examples.k8s.io/mysql-cinder-pd/README.md */
        volumeID: string;
    }
    /** ClientIPConfig represents the configurations of Client IP based session affinity. */
    interface io$k8s$api$core$v1$ClientIPConfig {
        /** timeoutSeconds specifies the seconds of ClientIP type session sticky time. The value must be >0 && <=86400(for 1 day) if ServiceAffinity == "ClientIP". Default value is 10800(for 3 hours). */
        timeoutSeconds?: number;
    }
    /** Information about the condition of a component. */
    interface io$k8s$api$core$v1$ComponentCondition {
        /** Condition error code for a component. For example, a health check error code. */
        error?: string;
        /** Message about the condition for a component. For example, information about a health check. */
        message?: string;
        /** Status of the condition for a component. Valid values for "Healthy": "True", "False", or "Unknown". */
        status: string;
        /** Type of condition for a component. Valid value: "Healthy" */
        type: string;
    }
    /** ComponentStatus (and ComponentStatusList) holds the cluster validation info. Deprecated: This API is deprecated in v1.19+ */
    interface io$k8s$api$core$v1$ComponentStatus {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of component conditions observed */
        conditions?: Schemas.io$k8s$api$core$v1$ComponentCondition[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
    }
    /** Status of all the conditions for the component as a list of ComponentStatus objects. Deprecated: This API is deprecated in v1.19+ */
    interface io$k8s$api$core$v1$ComponentStatusList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of ComponentStatus objects. */
        items: Schemas.io$k8s$api$core$v1$ComponentStatus[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ConfigMap holds configuration data for pods to consume. */
    interface io$k8s$api$core$v1$ConfigMap {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** BinaryData contains the binary data. Each key must consist of alphanumeric characters, '-', '_' or '.'. BinaryData can contain byte sequences that are not in the UTF-8 range. The keys stored in BinaryData must not overlap with the ones in the Data field, this is enforced during validation process. Using this field will require 1.10+ apiserver and kubelet. */
        binaryData?: {
            [key: string]: Blob;
        };
        /** Data contains the configuration data. Each key must consist of alphanumeric characters, '-', '_' or '.'. Values with non-UTF-8 byte sequences must use the BinaryData field. The keys stored in Data must not overlap with the keys in the BinaryData field, this is enforced during validation process. */
        data?: {
            [key: string]: string;
        };
        /** Immutable, if set to true, ensures that data stored in the ConfigMap cannot be updated (only object metadata can be modified). If not set to true, the field can be modified at any time. Defaulted to nil. */
        immutable?: boolean;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
    }
    /**
     * ConfigMapEnvSource selects a ConfigMap to populate the environment variables with.
     *
     * The contents of the target ConfigMap's Data field will represent the key-value pairs as environment variables.
     */
    interface io$k8s$api$core$v1$ConfigMapEnvSource {
        /** Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names */
        name?: string;
        /** Specify whether the ConfigMap must be defined */
        optional?: boolean;
    }
    /** Selects a key from a ConfigMap. */
    interface io$k8s$api$core$v1$ConfigMapKeySelector {
        /** The key to select. */
        key: string;
        /** Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names */
        name?: string;
        /** Specify whether the ConfigMap or its key must be defined */
        optional?: boolean;
    }
    /** ConfigMapList is a resource containing a list of ConfigMap objects. */
    interface io$k8s$api$core$v1$ConfigMapList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is the list of ConfigMaps. */
        items: Schemas.io$k8s$api$core$v1$ConfigMap[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ConfigMapNodeConfigSource contains the information to reference a ConfigMap as a config source for the Node. This API is deprecated since 1.22: https://git.k8s.io/enhancements/keps/sig-node/281-dynamic-kubelet-configuration */
    interface io$k8s$api$core$v1$ConfigMapNodeConfigSource {
        /** KubeletConfigKey declares which key of the referenced ConfigMap corresponds to the KubeletConfiguration structure This field is required in all cases. */
        kubeletConfigKey: string;
        /** Name is the metadata.name of the referenced ConfigMap. This field is required in all cases. */
        name: string;
        /** Namespace is the metadata.namespace of the referenced ConfigMap. This field is required in all cases. */
        namespace: string;
        /** ResourceVersion is the metadata.ResourceVersion of the referenced ConfigMap. This field is forbidden in Node.Spec, and required in Node.Status. */
        resourceVersion?: string;
        /** UID is the metadata.UID of the referenced ConfigMap. This field is forbidden in Node.Spec, and required in Node.Status. */
        uid?: string;
    }
    /**
     * Adapts a ConfigMap into a projected volume.
     *
     * The contents of the target ConfigMap's Data field will be presented in a projected volume as files using the keys in the Data field as the file names, unless the items element is populated with specific mappings of keys to paths. Note that this is identical to a configmap volume source without the default mode.
     */
    interface io$k8s$api$core$v1$ConfigMapProjection {
        /** If unspecified, each key-value pair in the Data field of the referenced ConfigMap will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the ConfigMap, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'. */
        items?: Schemas.io$k8s$api$core$v1$KeyToPath[];
        /** Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names */
        name?: string;
        /** Specify whether the ConfigMap or its keys must be defined */
        optional?: boolean;
    }
    /**
     * Adapts a ConfigMap into a volume.
     *
     * The contents of the target ConfigMap's Data field will be presented in a volume as files using the keys in the Data field as the file names, unless the items element is populated with specific mappings of keys to paths. ConfigMap volumes support ownership management and SELinux relabeling.
     */
    interface io$k8s$api$core$v1$ConfigMapVolumeSource {
        /** Optional: mode bits used to set permissions on created files by default. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set. */
        defaultMode?: number;
        /** If unspecified, each key-value pair in the Data field of the referenced ConfigMap will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the ConfigMap, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'. */
        items?: Schemas.io$k8s$api$core$v1$KeyToPath[];
        /** Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names */
        name?: string;
        /** Specify whether the ConfigMap or its keys must be defined */
        optional?: boolean;
    }
    /** A single application container that you want to run within a pod. */
    interface io$k8s$api$core$v1$Container {
        /** Arguments to the entrypoint. The docker image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell */
        args?: string[];
        /** Entrypoint array. Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell */
        command?: string[];
        /** List of environment variables to set in the container. Cannot be updated. */
        env?: Schemas.io$k8s$api$core$v1$EnvVar[];
        /** List of sources to populate environment variables in the container. The keys defined within a source must be a C_IDENTIFIER. All invalid keys will be reported as an event when the container is starting. When a key exists in multiple sources, the value associated with the last source will take precedence. Values defined by an Env with a duplicate key will take precedence. Cannot be updated. */
        envFrom?: Schemas.io$k8s$api$core$v1$EnvFromSource[];
        /** Docker image name. More info: https://kubernetes.io/docs/concepts/containers/images This field is optional to allow higher level config management to default or override container images in workload controllers like Deployments and StatefulSets. */
        image?: string;
        /**
         * Image pull policy. One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: https://kubernetes.io/docs/concepts/containers/images#updating-images
         *
         */
        imagePullPolicy?: string;
        lifecycle?: Schemas.io$k8s$api$core$v1$Lifecycle;
        livenessProbe?: Schemas.io$k8s$api$core$v1$Probe;
        /** Name of the container specified as a DNS_LABEL. Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated. */
        name: string;
        /** List of ports to expose from the container. Exposing a port here gives the system additional information about the network connections a container uses, but is primarily informational. Not specifying a port here DOES NOT prevent that port from being exposed. Any port which is listening on the default "0.0.0.0" address inside a container will be accessible from the network. Cannot be updated. */
        ports?: Schemas.io$k8s$api$core$v1$ContainerPort[];
        readinessProbe?: Schemas.io$k8s$api$core$v1$Probe;
        resources?: Schemas.io$k8s$api$core$v1$ResourceRequirements;
        securityContext?: Schemas.io$k8s$api$core$v1$SecurityContext;
        startupProbe?: Schemas.io$k8s$api$core$v1$Probe;
        /** Whether this container should allocate a buffer for stdin in the container runtime. If this is not set, reads from stdin in the container will always result in EOF. Default is false. */
        stdin?: boolean;
        /** Whether the container runtime should close the stdin channel after it has been opened by a single attach. When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF. Default is false */
        stdinOnce?: boolean;
        /** Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem. Message written is intended to be brief final status, such as an assertion failure message. Will be truncated by the node if greater than 4096 bytes. The total message length across all containers will be limited to 12kb. Defaults to /dev/termination-log. Cannot be updated. */
        terminationMessagePath?: string;
        /**
         * Indicate how the termination message should be populated. File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
         *
         */
        terminationMessagePolicy?: string;
        /** Whether this container should allocate a TTY for itself, also requires 'stdin' to be true. Default is false. */
        tty?: boolean;
        /** volumeDevices is the list of block devices to be used by the container. */
        volumeDevices?: Schemas.io$k8s$api$core$v1$VolumeDevice[];
        /** Pod volumes to mount into the container's filesystem. Cannot be updated. */
        volumeMounts?: Schemas.io$k8s$api$core$v1$VolumeMount[];
        /** Container's working directory. If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated. */
        workingDir?: string;
    }
    /** Describe a container image */
    interface io$k8s$api$core$v1$ContainerImage {
        /** Names by which this image is known. e.g. ["k8s.gcr.io/hyperkube:v1.0.7", "dockerhub.io/google_containers/hyperkube:v1.0.7"] */
        names?: string[];
        /** The size of the image in bytes. */
        sizeBytes?: number;
    }
    /** ContainerPort represents a network port in a single container. */
    interface io$k8s$api$core$v1$ContainerPort {
        /** Number of port to expose on the pod's IP address. This must be a valid port number, 0 < x < 65536. */
        containerPort: number;
        /** What host IP to bind the external port to. */
        hostIP?: string;
        /** Number of port to expose on the host. If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this. */
        hostPort?: number;
        /** If specified, this must be an IANA_SVC_NAME and unique within the pod. Each named port in a pod must have a unique name. Name for the port that can be referred to by services. */
        name?: string;
        /**
         * Protocol for port. Must be UDP, TCP, or SCTP. Defaults to "TCP".
         *
         */
        protocol?: string;
    }
    /** ContainerState holds a possible state of container. Only one of its members may be specified. If none of them is specified, the default one is ContainerStateWaiting. */
    interface io$k8s$api$core$v1$ContainerState {
        running?: Schemas.io$k8s$api$core$v1$ContainerStateRunning;
        terminated?: Schemas.io$k8s$api$core$v1$ContainerStateTerminated;
        waiting?: Schemas.io$k8s$api$core$v1$ContainerStateWaiting;
    }
    /** ContainerStateRunning is a running state of a container. */
    interface io$k8s$api$core$v1$ContainerStateRunning {
        startedAt?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
    }
    /** ContainerStateTerminated is a terminated state of a container. */
    interface io$k8s$api$core$v1$ContainerStateTerminated {
        /** Container's ID in the format 'docker://<container_id>' */
        containerID?: string;
        /** Exit status from the last termination of the container */
        exitCode: number;
        finishedAt?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** Message regarding the last termination of the container */
        message?: string;
        /** (brief) reason from the last termination of the container */
        reason?: string;
        /** Signal from the last termination of the container */
        signal?: number;
        startedAt?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
    }
    /** ContainerStateWaiting is a waiting state of a container. */
    interface io$k8s$api$core$v1$ContainerStateWaiting {
        /** Message regarding why the container is not yet running. */
        message?: string;
        /** (brief) reason the container is not yet running. */
        reason?: string;
    }
    /** ContainerStatus contains details for the current status of this container. */
    interface io$k8s$api$core$v1$ContainerStatus {
        /** Container's ID in the format 'docker://<container_id>'. */
        containerID?: string;
        /** The image the container is running. More info: https://kubernetes.io/docs/concepts/containers/images. */
        image: string;
        /** ImageID of the container's image. */
        imageID: string;
        lastState?: Schemas.io$k8s$api$core$v1$ContainerState;
        /** This must be a DNS_LABEL. Each container in a pod must have a unique name. Cannot be updated. */
        name: string;
        /** Specifies whether the container has passed its readiness probe. */
        ready: boolean;
        /** The number of times the container has been restarted. */
        restartCount: number;
        /** Specifies whether the container has passed its startup probe. Initialized as false, becomes true after startupProbe is considered successful. Resets to false when the container is restarted, or if kubelet loses state temporarily. Is always true when no startupProbe is defined. */
        started?: boolean;
        state?: Schemas.io$k8s$api$core$v1$ContainerState;
    }
    /** DaemonEndpoint contains information about a single Daemon endpoint. */
    interface io$k8s$api$core$v1$DaemonEndpoint {
        /** Port number of the given endpoint. */
        Port: number;
    }
    /** Represents downward API info for projecting into a projected volume. Note that this is identical to a downwardAPI volume source without the default mode. */
    interface io$k8s$api$core$v1$DownwardAPIProjection {
        /** Items is a list of DownwardAPIVolume file */
        items?: Schemas.io$k8s$api$core$v1$DownwardAPIVolumeFile[];
    }
    /** DownwardAPIVolumeFile represents information to create the file containing the pod field */
    interface io$k8s$api$core$v1$DownwardAPIVolumeFile {
        fieldRef?: Schemas.io$k8s$api$core$v1$ObjectFieldSelector;
        /** Optional: mode bits used to set permissions on this file, must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set. */
        mode?: number;
        /** Required: Path is  the relative path name of the file to be created. Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..' */
        path: string;
        resourceFieldRef?: Schemas.io$k8s$api$core$v1$ResourceFieldSelector;
    }
    /** DownwardAPIVolumeSource represents a volume containing downward API info. Downward API volumes support ownership management and SELinux relabeling. */
    interface io$k8s$api$core$v1$DownwardAPIVolumeSource {
        /** Optional: mode bits to use on created files by default. Must be a Optional: mode bits used to set permissions on created files by default. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set. */
        defaultMode?: number;
        /** Items is a list of downward API volume file */
        items?: Schemas.io$k8s$api$core$v1$DownwardAPIVolumeFile[];
    }
    /** Represents an empty directory for a pod. Empty directory volumes support ownership management and SELinux relabeling. */
    interface io$k8s$api$core$v1$EmptyDirVolumeSource {
        /** What type of storage medium should back this directory. The default is "" which means to use the node's default medium. Must be an empty string (default) or Memory. More info: https://kubernetes.io/docs/concepts/storage/volumes#emptydir */
        medium?: string;
        sizeLimit?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
    }
    /** EndpointAddress is a tuple that describes single IP address. */
    interface io$k8s$api$core$v1$EndpointAddress {
        /** The Hostname of this endpoint */
        hostname?: string;
        /** The IP of this endpoint. May not be loopback (127.0.0.0/8), link-local (169.254.0.0/16), or link-local multicast ((224.0.0.0/24). IPv6 is also accepted but not fully supported on all platforms. Also, certain kubernetes components, like kube-proxy, are not IPv6 ready. */
        ip: string;
        /** Optional: Node hosting this endpoint. This can be used to determine endpoints local to a node. */
        nodeName?: string;
        targetRef?: Schemas.io$k8s$api$core$v1$ObjectReference;
    }
    /** EndpointPort is a tuple that describes a single port. */
    interface io$k8s$api$core$v1$EndpointPort {
        /** The application protocol for this port. This field follows standard Kubernetes label syntax. Un-prefixed names are reserved for IANA standard service names (as per RFC-6335 and http://www.iana.org/assignments/service-names). Non-standard protocols should use prefixed names such as mycompany.com/my-custom-protocol. */
        appProtocol?: string;
        /** The name of this port.  This must match the 'name' field in the corresponding ServicePort. Must be a DNS_LABEL. Optional only if one port is defined. */
        name?: string;
        /** The port number of the endpoint. */
        port: number;
        /**
         * The IP protocol for this port. Must be UDP, TCP, or SCTP. Default is TCP.
         *
         */
        protocol?: string;
    }
    /**
     * EndpointSubset is a group of addresses with a common set of ports. The expanded set of endpoints is the Cartesian product of Addresses x Ports. For example, given:
     *   {
     *     Addresses: [{"ip": "10.10.1.1"}, {"ip": "10.10.2.2"}],
     *     Ports:     [{"name": "a", "port": 8675}, {"name": "b", "port": 309}]
     *   }
     * The resulting set of endpoints can be viewed as:
     *     a: [ 10.10.1.1:8675, 10.10.2.2:8675 ],
     *     b: [ 10.10.1.1:309, 10.10.2.2:309 ]
     */
    interface io$k8s$api$core$v1$EndpointSubset {
        /** IP addresses which offer the related ports that are marked as ready. These endpoints should be considered safe for load balancers and clients to utilize. */
        addresses?: Schemas.io$k8s$api$core$v1$EndpointAddress[];
        /** IP addresses which offer the related ports but are not currently marked as ready because they have not yet finished starting, have recently failed a readiness check, or have recently failed a liveness check. */
        notReadyAddresses?: Schemas.io$k8s$api$core$v1$EndpointAddress[];
        /** Port numbers available on the related IP addresses. */
        ports?: Schemas.io$k8s$api$core$v1$EndpointPort[];
    }
    /**
     * Endpoints is a collection of endpoints that implement the actual service. Example:
     *   Name: "mysvc",
     *   Subsets: [
     *     {
     *       Addresses: [{"ip": "10.10.1.1"}, {"ip": "10.10.2.2"}],
     *       Ports: [{"name": "a", "port": 8675}, {"name": "b", "port": 309}]
     *     },
     *     {
     *       Addresses: [{"ip": "10.10.3.3"}],
     *       Ports: [{"name": "a", "port": 93}, {"name": "b", "port": 76}]
     *     },
     *  ]
     */
    interface io$k8s$api$core$v1$Endpoints {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** The set of all endpoints is the union of all subsets. Addresses are placed into subsets according to the IPs they share. A single address with multiple ports, some of which are ready and some of which are not (because they come from different containers) will result in the address being displayed in different subsets for the different ports. No address will appear in both Addresses and NotReadyAddresses in the same subset. Sets of addresses and ports that comprise a service. */
        subsets?: Schemas.io$k8s$api$core$v1$EndpointSubset[];
    }
    /** EndpointsList is a list of endpoints. */
    interface io$k8s$api$core$v1$EndpointsList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of endpoints. */
        items: Schemas.io$k8s$api$core$v1$Endpoints[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** EnvFromSource represents the source of a set of ConfigMaps */
    interface io$k8s$api$core$v1$EnvFromSource {
        configMapRef?: Schemas.io$k8s$api$core$v1$ConfigMapEnvSource;
        /** An optional identifier to prepend to each key in the ConfigMap. Must be a C_IDENTIFIER. */
        prefix?: string;
        secretRef?: Schemas.io$k8s$api$core$v1$SecretEnvSource;
    }
    /** EnvVar represents an environment variable present in a Container. */
    interface io$k8s$api$core$v1$EnvVar {
        /** Name of the environment variable. Must be a C_IDENTIFIER. */
        name: string;
        /** Variable references $(VAR_NAME) are expanded using the previously defined environment variables in the container and any service environment variables. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "". */
        value?: string;
        valueFrom?: Schemas.io$k8s$api$core$v1$EnvVarSource;
    }
    /** EnvVarSource represents a source for the value of an EnvVar. */
    interface io$k8s$api$core$v1$EnvVarSource {
        configMapKeyRef?: Schemas.io$k8s$api$core$v1$ConfigMapKeySelector;
        fieldRef?: Schemas.io$k8s$api$core$v1$ObjectFieldSelector;
        resourceFieldRef?: Schemas.io$k8s$api$core$v1$ResourceFieldSelector;
        secretKeyRef?: Schemas.io$k8s$api$core$v1$SecretKeySelector;
    }
    /**
     * An EphemeralContainer is a temporary container that you may add to an existing Pod for user-initiated activities such as debugging. Ephemeral containers have no resource or scheduling guarantees, and they will not be restarted when they exit or when a Pod is removed or restarted. The kubelet may evict a Pod if an ephemeral container causes the Pod to exceed its resource allocation.
     *
     * To add an ephemeral container, use the ephemeralcontainers subresource of an existing Pod. Ephemeral containers may not be removed or restarted.
     *
     * This is a beta feature available on clusters that haven't disabled the EphemeralContainers feature gate.
     */
    interface io$k8s$api$core$v1$EphemeralContainer {
        /** Arguments to the entrypoint. The docker image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell */
        args?: string[];
        /** Entrypoint array. Not executed within a shell. The docker image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell */
        command?: string[];
        /** List of environment variables to set in the container. Cannot be updated. */
        env?: Schemas.io$k8s$api$core$v1$EnvVar[];
        /** List of sources to populate environment variables in the container. The keys defined within a source must be a C_IDENTIFIER. All invalid keys will be reported as an event when the container is starting. When a key exists in multiple sources, the value associated with the last source will take precedence. Values defined by an Env with a duplicate key will take precedence. Cannot be updated. */
        envFrom?: Schemas.io$k8s$api$core$v1$EnvFromSource[];
        /** Docker image name. More info: https://kubernetes.io/docs/concepts/containers/images */
        image?: string;
        /**
         * Image pull policy. One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: https://kubernetes.io/docs/concepts/containers/images#updating-images
         *
         */
        imagePullPolicy?: string;
        lifecycle?: Schemas.io$k8s$api$core$v1$Lifecycle;
        livenessProbe?: Schemas.io$k8s$api$core$v1$Probe;
        /** Name of the ephemeral container specified as a DNS_LABEL. This name must be unique among all containers, init containers and ephemeral containers. */
        name: string;
        /** Ports are not allowed for ephemeral containers. */
        ports?: Schemas.io$k8s$api$core$v1$ContainerPort[];
        readinessProbe?: Schemas.io$k8s$api$core$v1$Probe;
        resources?: Schemas.io$k8s$api$core$v1$ResourceRequirements;
        securityContext?: Schemas.io$k8s$api$core$v1$SecurityContext;
        startupProbe?: Schemas.io$k8s$api$core$v1$Probe;
        /** Whether this container should allocate a buffer for stdin in the container runtime. If this is not set, reads from stdin in the container will always result in EOF. Default is false. */
        stdin?: boolean;
        /** Whether the container runtime should close the stdin channel after it has been opened by a single attach. When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF. Default is false */
        stdinOnce?: boolean;
        /**
         * If set, the name of the container from PodSpec that this ephemeral container targets. The ephemeral container will be run in the namespaces (IPC, PID, etc) of this container. If not set then the ephemeral container uses the namespaces configured in the Pod spec.
         *
         * The container runtime must implement support for this feature. If the runtime does not support namespace targeting then the result of setting this field is undefined.
         */
        targetContainerName?: string;
        /** Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem. Message written is intended to be brief final status, such as an assertion failure message. Will be truncated by the node if greater than 4096 bytes. The total message length across all containers will be limited to 12kb. Defaults to /dev/termination-log. Cannot be updated. */
        terminationMessagePath?: string;
        /**
         * Indicate how the termination message should be populated. File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.
         *
         */
        terminationMessagePolicy?: string;
        /** Whether this container should allocate a TTY for itself, also requires 'stdin' to be true. Default is false. */
        tty?: boolean;
        /** volumeDevices is the list of block devices to be used by the container. */
        volumeDevices?: Schemas.io$k8s$api$core$v1$VolumeDevice[];
        /** Pod volumes to mount into the container's filesystem. Subpath mounts are not allowed for ephemeral containers. Cannot be updated. */
        volumeMounts?: Schemas.io$k8s$api$core$v1$VolumeMount[];
        /** Container's working directory. If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated. */
        workingDir?: string;
    }
    /** Represents an ephemeral volume that is handled by a normal storage driver. */
    interface io$k8s$api$core$v1$EphemeralVolumeSource {
        volumeClaimTemplate?: Schemas.io$k8s$api$core$v1$PersistentVolumeClaimTemplate;
    }
    /** Event is a report of an event somewhere in the cluster.  Events have a limited retention time and triggers and messages may evolve with time.  Event consumers should not rely on the timing of an event with a given Reason reflecting a consistent underlying trigger, or the continued existence of events with that Reason.  Events should be treated as informative, best-effort, supplemental data. */
    interface io$k8s$api$core$v1$Event {
        /** What action was taken/failed regarding to the Regarding object. */
        action?: string;
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** The number of times this event has occurred. */
        count?: number;
        eventTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$MicroTime;
        firstTimestamp?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        involvedObject: Schemas.io$k8s$api$core$v1$ObjectReference;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        lastTimestamp?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** A human-readable description of the status of this operation. */
        message?: string;
        metadata: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** This should be a short, machine understandable string that gives the reason for the transition into the object's current status. */
        reason?: string;
        related?: Schemas.io$k8s$api$core$v1$ObjectReference;
        /** Name of the controller that emitted this Event, e.g. `kubernetes.io/kubelet`. */
        reportingComponent?: string;
        /** ID of the controller instance, e.g. `kubelet-xyzf`. */
        reportingInstance?: string;
        series?: Schemas.io$k8s$api$core$v1$EventSeries;
        source?: Schemas.io$k8s$api$core$v1$EventSource;
        /** Type of this event (Normal, Warning), new types could be added in the future */
        type?: string;
    }
    /** EventList is a list of events. */
    interface io$k8s$api$core$v1$EventList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of events */
        items: Schemas.io$k8s$api$core$v1$Event[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** EventSeries contain information on series of events, i.e. thing that was/is happening continuously for some time. */
    interface io$k8s$api$core$v1$EventSeries {
        /** Number of occurrences in this series up to the last heartbeat time */
        count?: number;
        lastObservedTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$MicroTime;
    }
    /** EventSource contains information for an event. */
    interface io$k8s$api$core$v1$EventSource {
        /** Component from which the event is generated. */
        component?: string;
        /** Node name on which the event is generated. */
        host?: string;
    }
    /** ExecAction describes a "run in container" action. */
    interface io$k8s$api$core$v1$ExecAction {
        /** Command is the command line to execute inside the container, the working directory for the command  is root ('/') in the container's filesystem. The command is simply exec'd, it is not run inside a shell, so traditional shell instructions ('|', etc) won't work. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy. */
        command?: string[];
    }
    /** Represents a Fibre Channel volume. Fibre Channel volumes can only be mounted as read/write once. Fibre Channel volumes support ownership management and SELinux relabeling. */
    interface io$k8s$api$core$v1$FCVolumeSource {
        /** Filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. */
        fsType?: string;
        /** Optional: FC target lun number */
        lun?: number;
        /** Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. */
        readOnly?: boolean;
        /** Optional: FC target worldwide names (WWNs) */
        targetWWNs?: string[];
        /** Optional: FC volume world wide identifiers (wwids) Either wwids or combination of targetWWNs and lun must be set, but not both simultaneously. */
        wwids?: string[];
    }
    /** FlexPersistentVolumeSource represents a generic persistent volume resource that is provisioned/attached using an exec based plugin. */
    interface io$k8s$api$core$v1$FlexPersistentVolumeSource {
        /** Driver is the name of the driver to use for this volume. */
        driver: string;
        /** Filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default filesystem depends on FlexVolume script. */
        fsType?: string;
        /** Optional: Extra command options if any. */
        options?: {
            [key: string]: string;
        };
        /** Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. */
        readOnly?: boolean;
        secretRef?: Schemas.io$k8s$api$core$v1$SecretReference;
    }
    /** FlexVolume represents a generic volume resource that is provisioned/attached using an exec based plugin. */
    interface io$k8s$api$core$v1$FlexVolumeSource {
        /** Driver is the name of the driver to use for this volume. */
        driver: string;
        /** Filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default filesystem depends on FlexVolume script. */
        fsType?: string;
        /** Optional: Extra command options if any. */
        options?: {
            [key: string]: string;
        };
        /** Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. */
        readOnly?: boolean;
        secretRef?: Schemas.io$k8s$api$core$v1$LocalObjectReference;
    }
    /** Represents a Flocker volume mounted by the Flocker agent. One and only one of datasetName and datasetUUID should be set. Flocker volumes do not support ownership management or SELinux relabeling. */
    interface io$k8s$api$core$v1$FlockerVolumeSource {
        /** Name of the dataset stored as metadata -> name on the dataset for Flocker should be considered as deprecated */
        datasetName?: string;
        /** UUID of the dataset. This is unique identifier of a Flocker dataset */
        datasetUUID?: string;
    }
    /**
     * Represents a Persistent Disk resource in Google Compute Engine.
     *
     * A GCE PD must exist before mounting to a container. The disk must also be in the same GCE project and zone as the kubelet. A GCE PD can only be mounted as read/write once or read-only many times. GCE PDs support ownership management and SELinux relabeling.
     */
    interface io$k8s$api$core$v1$GCEPersistentDiskVolumeSource {
        /** Filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk */
        fsType?: string;
        /** The partition in the volume that you want to mount. If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty). More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk */
        partition?: number;
        /** Unique name of the PD resource in GCE. Used to identify the disk in GCE. More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk */
        pdName: string;
        /** ReadOnly here will force the ReadOnly setting in VolumeMounts. Defaults to false. More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk */
        readOnly?: boolean;
    }
    interface io$k8s$api$core$v1$GRPCAction {
        /** Port number of the gRPC service. Number must be in the range 1 to 65535. */
        port: number;
        /**
         * Service is the name of the service to place in the gRPC HealthCheckRequest (see https://github.com/grpc/grpc/blob/master/doc/health-checking.md).
         *
         * If this is not specified, the default behavior is defined by gRPC.
         */
        service?: string;
    }
    /**
     * Represents a volume that is populated with the contents of a git repository. Git repo volumes do not support ownership management. Git repo volumes support SELinux relabeling.
     *
     * DEPRECATED: GitRepo is deprecated. To provision a container with a git repo, mount an EmptyDir into an InitContainer that clones the repo using git, then mount the EmptyDir into the Pod's container.
     */
    interface io$k8s$api$core$v1$GitRepoVolumeSource {
        /** Target directory name. Must not contain or start with '..'.  If '.' is supplied, the volume directory will be the git repository.  Otherwise, if specified, the volume will contain the git repository in the subdirectory with the given name. */
        directory?: string;
        /** Repository URL */
        repository: string;
        /** Commit hash for the specified revision. */
        revision?: string;
    }
    /** Represents a Glusterfs mount that lasts the lifetime of a pod. Glusterfs volumes do not support ownership management or SELinux relabeling. */
    interface io$k8s$api$core$v1$GlusterfsPersistentVolumeSource {
        /** EndpointsName is the endpoint name that details Glusterfs topology. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod */
        endpoints: string;
        /** EndpointsNamespace is the namespace that contains Glusterfs endpoint. If this field is empty, the EndpointNamespace defaults to the same namespace as the bound PVC. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod */
        endpointsNamespace?: string;
        /** Path is the Glusterfs volume path. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod */
        path: string;
        /** ReadOnly here will force the Glusterfs volume to be mounted with read-only permissions. Defaults to false. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod */
        readOnly?: boolean;
    }
    /** Represents a Glusterfs mount that lasts the lifetime of a pod. Glusterfs volumes do not support ownership management or SELinux relabeling. */
    interface io$k8s$api$core$v1$GlusterfsVolumeSource {
        /** EndpointsName is the endpoint name that details Glusterfs topology. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod */
        endpoints: string;
        /** Path is the Glusterfs volume path. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod */
        path: string;
        /** ReadOnly here will force the Glusterfs volume to be mounted with read-only permissions. Defaults to false. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod */
        readOnly?: boolean;
    }
    /** HTTPGetAction describes an action based on HTTP Get requests. */
    interface io$k8s$api$core$v1$HTTPGetAction {
        /** Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead. */
        host?: string;
        /** Custom headers to set in the request. HTTP allows repeated headers. */
        httpHeaders?: Schemas.io$k8s$api$core$v1$HTTPHeader[];
        /** Path to access on the HTTP server. */
        path?: string;
        port: Schemas.io$k8s$apimachinery$pkg$util$intstr$IntOrString;
        /**
         * Scheme to use for connecting to the host. Defaults to HTTP.
         *
         */
        scheme?: string;
    }
    /** HTTPHeader describes a custom header to be used in HTTP probes */
    interface io$k8s$api$core$v1$HTTPHeader {
        /** The header field name */
        name: string;
        /** The header field value */
        value: string;
    }
    /** HostAlias holds the mapping between IP and hostnames that will be injected as an entry in the pod's hosts file. */
    interface io$k8s$api$core$v1$HostAlias {
        /** Hostnames for the above IP address. */
        hostnames?: string[];
        /** IP address of the host file entry. */
        ip?: string;
    }
    /** Represents a host path mapped into a pod. Host path volumes do not support ownership management or SELinux relabeling. */
    interface io$k8s$api$core$v1$HostPathVolumeSource {
        /** Path of the directory on the host. If the path is a symlink, it will follow the link to the real path. More info: https://kubernetes.io/docs/concepts/storage/volumes#hostpath */
        path: string;
        /** Type for HostPath Volume Defaults to "" More info: https://kubernetes.io/docs/concepts/storage/volumes#hostpath */
        type?: string;
    }
    /** ISCSIPersistentVolumeSource represents an ISCSI disk. ISCSI volumes can only be mounted as read/write once. ISCSI volumes support ownership management and SELinux relabeling. */
    interface io$k8s$api$core$v1$ISCSIPersistentVolumeSource {
        /** whether support iSCSI Discovery CHAP authentication */
        chapAuthDiscovery?: boolean;
        /** whether support iSCSI Session CHAP authentication */
        chapAuthSession?: boolean;
        /** Filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#iscsi */
        fsType?: string;
        /** Custom iSCSI Initiator Name. If initiatorName is specified with iscsiInterface simultaneously, new iSCSI interface <target portal>:<volume name> will be created for the connection. */
        initiatorName?: string;
        /** Target iSCSI Qualified Name. */
        iqn: string;
        /** iSCSI Interface Name that uses an iSCSI transport. Defaults to 'default' (tcp). */
        iscsiInterface?: string;
        /** iSCSI Target Lun number. */
        lun: number;
        /** iSCSI Target Portal List. The Portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260). */
        portals?: string[];
        /** ReadOnly here will force the ReadOnly setting in VolumeMounts. Defaults to false. */
        readOnly?: boolean;
        secretRef?: Schemas.io$k8s$api$core$v1$SecretReference;
        /** iSCSI Target Portal. The Portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260). */
        targetPortal: string;
    }
    /** Represents an ISCSI disk. ISCSI volumes can only be mounted as read/write once. ISCSI volumes support ownership management and SELinux relabeling. */
    interface io$k8s$api$core$v1$ISCSIVolumeSource {
        /** whether support iSCSI Discovery CHAP authentication */
        chapAuthDiscovery?: boolean;
        /** whether support iSCSI Session CHAP authentication */
        chapAuthSession?: boolean;
        /** Filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#iscsi */
        fsType?: string;
        /** Custom iSCSI Initiator Name. If initiatorName is specified with iscsiInterface simultaneously, new iSCSI interface <target portal>:<volume name> will be created for the connection. */
        initiatorName?: string;
        /** Target iSCSI Qualified Name. */
        iqn: string;
        /** iSCSI Interface Name that uses an iSCSI transport. Defaults to 'default' (tcp). */
        iscsiInterface?: string;
        /** iSCSI Target Lun number. */
        lun: number;
        /** iSCSI Target Portal List. The portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260). */
        portals?: string[];
        /** ReadOnly here will force the ReadOnly setting in VolumeMounts. Defaults to false. */
        readOnly?: boolean;
        secretRef?: Schemas.io$k8s$api$core$v1$LocalObjectReference;
        /** iSCSI Target Portal. The Portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260). */
        targetPortal: string;
    }
    /** Maps a string key to a path within a volume. */
    interface io$k8s$api$core$v1$KeyToPath {
        /** The key to project. */
        key: string;
        /** Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set. */
        mode?: number;
        /** The relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'. */
        path: string;
    }
    /** Lifecycle describes actions that the management system should take in response to container lifecycle events. For the PostStart and PreStop lifecycle handlers, management of the container blocks until the action is complete, unless the container process fails, in which case the handler is aborted. */
    interface io$k8s$api$core$v1$Lifecycle {
        postStart?: Schemas.io$k8s$api$core$v1$LifecycleHandler;
        preStop?: Schemas.io$k8s$api$core$v1$LifecycleHandler;
    }
    /** LifecycleHandler defines a specific action that should be taken in a lifecycle hook. One and only one of the fields, except TCPSocket must be specified. */
    interface io$k8s$api$core$v1$LifecycleHandler {
        exec?: Schemas.io$k8s$api$core$v1$ExecAction;
        httpGet?: Schemas.io$k8s$api$core$v1$HTTPGetAction;
        tcpSocket?: Schemas.io$k8s$api$core$v1$TCPSocketAction;
    }
    /** LimitRange sets resource usage limits for each kind of resource in a Namespace. */
    interface io$k8s$api$core$v1$LimitRange {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$core$v1$LimitRangeSpec;
    }
    /** LimitRangeItem defines a min/max usage limit for any resource that matches on kind. */
    interface io$k8s$api$core$v1$LimitRangeItem {
        /** Default resource requirement limit value by resource name if resource limit is omitted. */
        default?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** DefaultRequest is the default resource requirement request value by resource name if resource request is omitted. */
        defaultRequest?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** Max usage constraints on this kind by resource name. */
        max?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** MaxLimitRequestRatio if specified, the named resource must have a request and limit that are both non-zero where limit divided by request is less than or equal to the enumerated value; this represents the max burst for the named resource. */
        maxLimitRequestRatio?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** Min usage constraints on this kind by resource name. */
        min?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** Type of resource that this limit applies to. */
        type: string;
    }
    /** LimitRangeList is a list of LimitRange items. */
    interface io$k8s$api$core$v1$LimitRangeList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is a list of LimitRange objects. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/ */
        items: Schemas.io$k8s$api$core$v1$LimitRange[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** LimitRangeSpec defines a min/max usage limit for resources that match on kind. */
    interface io$k8s$api$core$v1$LimitRangeSpec {
        /** Limits is the list of LimitRangeItem objects that are enforced. */
        limits: Schemas.io$k8s$api$core$v1$LimitRangeItem[];
    }
    /** LoadBalancerIngress represents the status of a load-balancer ingress point: traffic intended for the service should be sent to an ingress point. */
    interface io$k8s$api$core$v1$LoadBalancerIngress {
        /** Hostname is set for load-balancer ingress points that are DNS based (typically AWS load-balancers) */
        hostname?: string;
        /** IP is set for load-balancer ingress points that are IP based (typically GCE or OpenStack load-balancers) */
        ip?: string;
        /** Ports is a list of records of service ports If used, every port defined in the service should have an entry in it */
        ports?: Schemas.io$k8s$api$core$v1$PortStatus[];
    }
    /** LoadBalancerStatus represents the status of a load-balancer. */
    interface io$k8s$api$core$v1$LoadBalancerStatus {
        /** Ingress is a list containing ingress points for the load-balancer. Traffic intended for the service should be sent to these ingress points. */
        ingress?: Schemas.io$k8s$api$core$v1$LoadBalancerIngress[];
    }
    /** LocalObjectReference contains enough information to let you locate the referenced object inside the same namespace. */
    interface io$k8s$api$core$v1$LocalObjectReference {
        /** Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names */
        name?: string;
    }
    /** Local represents directly-attached storage with node affinity (Beta feature) */
    interface io$k8s$api$core$v1$LocalVolumeSource {
        /** Filesystem type to mount. It applies only when the Path is a block device. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default value is to auto-select a filesystem if unspecified. */
        fsType?: string;
        /** The full path to the volume on the node. It can be either a directory or block device (disk, partition, ...). */
        path: string;
    }
    /** Represents an NFS mount that lasts the lifetime of a pod. NFS volumes do not support ownership management or SELinux relabeling. */
    interface io$k8s$api$core$v1$NFSVolumeSource {
        /** Path that is exported by the NFS server. More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs */
        path: string;
        /** ReadOnly here will force the NFS export to be mounted with read-only permissions. Defaults to false. More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs */
        readOnly?: boolean;
        /** Server is the hostname or IP address of the NFS server. More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs */
        server: string;
    }
    /** Namespace provides a scope for Names. Use of multiple namespaces is optional. */
    interface io$k8s$api$core$v1$Namespace {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$core$v1$NamespaceSpec;
        status?: Schemas.io$k8s$api$core$v1$NamespaceStatus;
    }
    /** NamespaceCondition contains details about state of namespace. */
    interface io$k8s$api$core$v1$NamespaceCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        message?: string;
        reason?: string;
        /** Status of the condition, one of True, False, Unknown. */
        status: string;
        /** Type of namespace controller condition. */
        type: string;
    }
    /** NamespaceList is a list of Namespaces. */
    interface io$k8s$api$core$v1$NamespaceList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is the list of Namespace objects in the list. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/namespaces/ */
        items: Schemas.io$k8s$api$core$v1$Namespace[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** NamespaceSpec describes the attributes on a Namespace. */
    interface io$k8s$api$core$v1$NamespaceSpec {
        /** Finalizers is an opaque list of values that must be empty to permanently remove object from storage. More info: https://kubernetes.io/docs/tasks/administer-cluster/namespaces/ */
        finalizers?: string[];
    }
    /** NamespaceStatus is information about the current status of a Namespace. */
    interface io$k8s$api$core$v1$NamespaceStatus {
        /** Represents the latest available observations of a namespace's current state. */
        conditions?: Schemas.io$k8s$api$core$v1$NamespaceCondition[];
        /**
         * Phase is the current lifecycle phase of the namespace. More info: https://kubernetes.io/docs/tasks/administer-cluster/namespaces/
         *
         */
        phase?: string;
    }
    /** Node is a worker node in Kubernetes. Each node will have a unique identifier in the cache (i.e. in etcd). */
    interface io$k8s$api$core$v1$Node {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$core$v1$NodeSpec;
        status?: Schemas.io$k8s$api$core$v1$NodeStatus;
    }
    /** NodeAddress contains information for the node's address. */
    interface io$k8s$api$core$v1$NodeAddress {
        /** The node address. */
        address: string;
        /** Node address type, one of Hostname, ExternalIP or InternalIP. */
        type: string;
    }
    /** Node affinity is a group of node affinity scheduling rules. */
    interface io$k8s$api$core$v1$NodeAffinity {
        /** The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node matches the corresponding matchExpressions; the node(s) with the highest sum are the most preferred. */
        preferredDuringSchedulingIgnoredDuringExecution?: Schemas.io$k8s$api$core$v1$PreferredSchedulingTerm[];
        requiredDuringSchedulingIgnoredDuringExecution?: Schemas.io$k8s$api$core$v1$NodeSelector;
    }
    /** NodeCondition contains condition information for a node. */
    interface io$k8s$api$core$v1$NodeCondition {
        lastHeartbeatTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** Human readable message indicating details about last transition. */
        message?: string;
        /** (brief) reason for the condition's last transition. */
        reason?: string;
        /** Status of the condition, one of True, False, Unknown. */
        status: string;
        /** Type of node condition. */
        type: string;
    }
    /** NodeConfigSource specifies a source of node configuration. Exactly one subfield (excluding metadata) must be non-nil. This API is deprecated since 1.22 */
    interface io$k8s$api$core$v1$NodeConfigSource {
        configMap?: Schemas.io$k8s$api$core$v1$ConfigMapNodeConfigSource;
    }
    /** NodeConfigStatus describes the status of the config assigned by Node.Spec.ConfigSource. */
    interface io$k8s$api$core$v1$NodeConfigStatus {
        active?: Schemas.io$k8s$api$core$v1$NodeConfigSource;
        assigned?: Schemas.io$k8s$api$core$v1$NodeConfigSource;
        /** Error describes any problems reconciling the Spec.ConfigSource to the Active config. Errors may occur, for example, attempting to checkpoint Spec.ConfigSource to the local Assigned record, attempting to checkpoint the payload associated with Spec.ConfigSource, attempting to load or validate the Assigned config, etc. Errors may occur at different points while syncing config. Earlier errors (e.g. download or checkpointing errors) will not result in a rollback to LastKnownGood, and may resolve across Kubelet retries. Later errors (e.g. loading or validating a checkpointed config) will result in a rollback to LastKnownGood. In the latter case, it is usually possible to resolve the error by fixing the config assigned in Spec.ConfigSource. You can find additional information for debugging by searching the error message in the Kubelet log. Error is a human-readable description of the error state; machines can check whether or not Error is empty, but should not rely on the stability of the Error text across Kubelet versions. */
        error?: string;
        lastKnownGood?: Schemas.io$k8s$api$core$v1$NodeConfigSource;
    }
    /** NodeDaemonEndpoints lists ports opened by daemons running on the Node. */
    interface io$k8s$api$core$v1$NodeDaemonEndpoints {
        kubeletEndpoint?: Schemas.io$k8s$api$core$v1$DaemonEndpoint;
    }
    /** NodeList is the whole list of all Nodes which have been registered with master. */
    interface io$k8s$api$core$v1$NodeList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of nodes */
        items: Schemas.io$k8s$api$core$v1$Node[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** A node selector represents the union of the results of one or more label queries over a set of nodes; that is, it represents the OR of the selectors represented by the node selector terms. */
    interface io$k8s$api$core$v1$NodeSelector {
        /** Required. A list of node selector terms. The terms are ORed. */
        nodeSelectorTerms: Schemas.io$k8s$api$core$v1$NodeSelectorTerm[];
    }
    /** A node selector requirement is a selector that contains values, a key, and an operator that relates the key and values. */
    interface io$k8s$api$core$v1$NodeSelectorRequirement {
        /** The label key that the selector applies to. */
        key: string;
        /**
         * Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt.
         *
         */
        operator: string;
        /** An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch. */
        values?: string[];
    }
    /** A null or empty node selector term matches no objects. The requirements of them are ANDed. The TopologySelectorTerm type implements a subset of the NodeSelectorTerm. */
    interface io$k8s$api$core$v1$NodeSelectorTerm {
        /** A list of node selector requirements by node's labels. */
        matchExpressions?: Schemas.io$k8s$api$core$v1$NodeSelectorRequirement[];
        /** A list of node selector requirements by node's fields. */
        matchFields?: Schemas.io$k8s$api$core$v1$NodeSelectorRequirement[];
    }
    /** NodeSpec describes the attributes that a node is created with. */
    interface io$k8s$api$core$v1$NodeSpec {
        configSource?: Schemas.io$k8s$api$core$v1$NodeConfigSource;
        /** Deprecated. Not all kubelets will set this field. Remove field after 1.13. see: https://issues.k8s.io/61966 */
        externalID?: string;
        /** PodCIDR represents the pod IP range assigned to the node. */
        podCIDR?: string;
        /** podCIDRs represents the IP ranges assigned to the node for usage by Pods on that node. If this field is specified, the 0th entry must match the podCIDR field. It may contain at most 1 value for each of IPv4 and IPv6. */
        podCIDRs?: string[];
        /** ID of the node assigned by the cloud provider in the format: <ProviderName>://<ProviderSpecificNodeID> */
        providerID?: string;
        /** If specified, the node's taints. */
        taints?: Schemas.io$k8s$api$core$v1$Taint[];
        /** Unschedulable controls node schedulability of new pods. By default, node is schedulable. More info: https://kubernetes.io/docs/concepts/nodes/node/#manual-node-administration */
        unschedulable?: boolean;
    }
    /** NodeStatus is information about the current status of a node. */
    interface io$k8s$api$core$v1$NodeStatus {
        /** List of addresses reachable to the node. Queried from cloud provider, if available. More info: https://kubernetes.io/docs/concepts/nodes/node/#addresses Note: This field is declared as mergeable, but the merge key is not sufficiently unique, which can cause data corruption when it is merged. Callers should instead use a full-replacement patch. See http://pr.k8s.io/79391 for an example. */
        addresses?: Schemas.io$k8s$api$core$v1$NodeAddress[];
        /** Allocatable represents the resources of a node that are available for scheduling. Defaults to Capacity. */
        allocatable?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** Capacity represents the total resources of a node. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#capacity */
        capacity?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** Conditions is an array of current observed node conditions. More info: https://kubernetes.io/docs/concepts/nodes/node/#condition */
        conditions?: Schemas.io$k8s$api$core$v1$NodeCondition[];
        config?: Schemas.io$k8s$api$core$v1$NodeConfigStatus;
        daemonEndpoints?: Schemas.io$k8s$api$core$v1$NodeDaemonEndpoints;
        /** List of container images on this node */
        images?: Schemas.io$k8s$api$core$v1$ContainerImage[];
        nodeInfo?: Schemas.io$k8s$api$core$v1$NodeSystemInfo;
        /**
         * NodePhase is the recently observed lifecycle phase of the node. More info: https://kubernetes.io/docs/concepts/nodes/node/#phase The field is never populated, and now is deprecated.
         *
         */
        phase?: string;
        /** List of volumes that are attached to the node. */
        volumesAttached?: Schemas.io$k8s$api$core$v1$AttachedVolume[];
        /** List of attachable volumes in use (mounted) by the node. */
        volumesInUse?: string[];
    }
    /** NodeSystemInfo is a set of ids/uuids to uniquely identify the node. */
    interface io$k8s$api$core$v1$NodeSystemInfo {
        /** The Architecture reported by the node */
        architecture: string;
        /** Boot ID reported by the node. */
        bootID: string;
        /** ContainerRuntime Version reported by the node through runtime remote API (e.g. docker://1.5.0). */
        containerRuntimeVersion: string;
        /** Kernel Version reported by the node from 'uname -r' (e.g. 3.16.0-0.bpo.4-amd64). */
        kernelVersion: string;
        /** KubeProxy Version reported by the node. */
        kubeProxyVersion: string;
        /** Kubelet Version reported by the node. */
        kubeletVersion: string;
        /** MachineID reported by the node. For unique machine identification in the cluster this field is preferred. Learn more from man(5) machine-id: http://man7.org/linux/man-pages/man5/machine-id.5.html */
        machineID: string;
        /** The Operating System reported by the node */
        operatingSystem: string;
        /** OS Image reported by the node from /etc/os-release (e.g. Debian GNU/Linux 7 (wheezy)). */
        osImage: string;
        /** SystemUUID reported by the node. For unique machine identification MachineID is preferred. This field is specific to Red Hat hosts https://access.redhat.com/documentation/en-us/red_hat_subscription_management/1/html/rhsm/uuid */
        systemUUID: string;
    }
    /** ObjectFieldSelector selects an APIVersioned field of an object. */
    interface io$k8s$api$core$v1$ObjectFieldSelector {
        /** Version of the schema the FieldPath is written in terms of, defaults to "v1". */
        apiVersion?: string;
        /** Path of the field to select in the specified API version. */
        fieldPath: string;
    }
    /** ObjectReference contains enough information to let you inspect or modify the referred object. */
    interface io$k8s$api$core$v1$ObjectReference {
        /** API version of the referent. */
        apiVersion?: string;
        /** If referring to a piece of an object instead of an entire object, this string should contain a valid JSON/Go field access statement, such as desiredState.manifest.containers[2]. For example, if the object reference is to a container within a pod, this would take on a value like: "spec.containers{name}" (where "name" refers to the name of the container that triggered the event) or if no container name is specified "spec.containers[2]" (container with index 2 in this pod). This syntax is chosen only to have some well-defined way of referencing a part of an object. */
        fieldPath?: string;
        /** Kind of the referent. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        /** Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names */
        name?: string;
        /** Namespace of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/namespaces/ */
        namespace?: string;
        /** Specific resourceVersion to which this reference is made, if any. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#concurrency-control-and-consistency */
        resourceVersion?: string;
        /** UID of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#uids */
        uid?: string;
    }
    /** PersistentVolume (PV) is a storage resource provisioned by an administrator. It is analogous to a node. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes */
    interface io$k8s$api$core$v1$PersistentVolume {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$core$v1$PersistentVolumeSpec;
        status?: Schemas.io$k8s$api$core$v1$PersistentVolumeStatus;
    }
    /** PersistentVolumeClaim is a user's request for and claim to a persistent volume */
    interface io$k8s$api$core$v1$PersistentVolumeClaim {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$core$v1$PersistentVolumeClaimSpec;
        status?: Schemas.io$k8s$api$core$v1$PersistentVolumeClaimStatus;
    }
    /** PersistentVolumeClaimCondition contails details about state of pvc */
    interface io$k8s$api$core$v1$PersistentVolumeClaimCondition {
        lastProbeTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** Human-readable message indicating details about last transition. */
        message?: string;
        /** Unique, this should be a short, machine understandable string that gives the reason for condition's last transition. If it reports "ResizeStarted" that means the underlying persistent volume is being resized. */
        reason?: string;
        status: string;
        type: string;
    }
    /** PersistentVolumeClaimList is a list of PersistentVolumeClaim items. */
    interface io$k8s$api$core$v1$PersistentVolumeClaimList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** A list of persistent volume claims. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistentvolumeclaims */
        items: Schemas.io$k8s$api$core$v1$PersistentVolumeClaim[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** PersistentVolumeClaimSpec describes the common attributes of storage devices and allows a Source for provider-specific attributes */
    interface io$k8s$api$core$v1$PersistentVolumeClaimSpec {
        /** AccessModes contains the desired access modes the volume should have. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#access-modes-1 */
        accessModes?: string[];
        dataSource?: Schemas.io$k8s$api$core$v1$TypedLocalObjectReference;
        dataSourceRef?: Schemas.io$k8s$api$core$v1$TypedLocalObjectReference;
        resources?: Schemas.io$k8s$api$core$v1$ResourceRequirements;
        selector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        /** Name of the StorageClass required by the claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#class-1 */
        storageClassName?: string;
        /** volumeMode defines what type of volume is required by the claim. Value of Filesystem is implied when not included in claim spec. */
        volumeMode?: string;
        /** VolumeName is the binding reference to the PersistentVolume backing this claim. */
        volumeName?: string;
    }
    /** PersistentVolumeClaimStatus is the current status of a persistent volume claim. */
    interface io$k8s$api$core$v1$PersistentVolumeClaimStatus {
        /** AccessModes contains the actual access modes the volume backing the PVC has. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#access-modes-1 */
        accessModes?: string[];
        /** The storage resource within AllocatedResources tracks the capacity allocated to a PVC. It may be larger than the actual capacity when a volume expansion operation is requested. For storage quota, the larger value from allocatedResources and PVC.spec.resources is used. If allocatedResources is not set, PVC.spec.resources alone is used for quota calculation. If a volume expansion capacity request is lowered, allocatedResources is only lowered if there are no expansion operations in progress and if the actual volume capacity is equal or lower than the requested capacity. This is an alpha field and requires enabling RecoverVolumeExpansionFailure feature. */
        allocatedResources?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** Represents the actual resources of the underlying volume. */
        capacity?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** Current Condition of persistent volume claim. If underlying persistent volume is being resized then the Condition will be set to 'ResizeStarted'. */
        conditions?: Schemas.io$k8s$api$core$v1$PersistentVolumeClaimCondition[];
        /**
         * Phase represents the current phase of PersistentVolumeClaim.
         *
         */
        phase?: string;
        /** ResizeStatus stores status of resize operation. ResizeStatus is not set by default but when expansion is complete resizeStatus is set to empty string by resize controller or kubelet. This is an alpha field and requires enabling RecoverVolumeExpansionFailure feature. */
        resizeStatus?: string;
    }
    /** PersistentVolumeClaimTemplate is used to produce PersistentVolumeClaim objects as part of an EphemeralVolumeSource. */
    interface io$k8s$api$core$v1$PersistentVolumeClaimTemplate {
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$core$v1$PersistentVolumeClaimSpec;
    }
    /** PersistentVolumeClaimVolumeSource references the user's PVC in the same namespace. This volume finds the bound PV and mounts that volume for the pod. A PersistentVolumeClaimVolumeSource is, essentially, a wrapper around another type of volume that is owned by someone else (the system). */
    interface io$k8s$api$core$v1$PersistentVolumeClaimVolumeSource {
        /** ClaimName is the name of a PersistentVolumeClaim in the same namespace as the pod using this volume. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistentvolumeclaims */
        claimName: string;
        /** Will force the ReadOnly setting in VolumeMounts. Default false. */
        readOnly?: boolean;
    }
    /** PersistentVolumeList is a list of PersistentVolume items. */
    interface io$k8s$api$core$v1$PersistentVolumeList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of persistent volumes. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes */
        items: Schemas.io$k8s$api$core$v1$PersistentVolume[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** PersistentVolumeSpec is the specification of a persistent volume. */
    interface io$k8s$api$core$v1$PersistentVolumeSpec {
        /** AccessModes contains all ways the volume can be mounted. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#access-modes */
        accessModes?: string[];
        awsElasticBlockStore?: Schemas.io$k8s$api$core$v1$AWSElasticBlockStoreVolumeSource;
        azureDisk?: Schemas.io$k8s$api$core$v1$AzureDiskVolumeSource;
        azureFile?: Schemas.io$k8s$api$core$v1$AzureFilePersistentVolumeSource;
        /** A description of the persistent volume's resources and capacity. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#capacity */
        capacity?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        cephfs?: Schemas.io$k8s$api$core$v1$CephFSPersistentVolumeSource;
        cinder?: Schemas.io$k8s$api$core$v1$CinderPersistentVolumeSource;
        claimRef?: Schemas.io$k8s$api$core$v1$ObjectReference;
        csi?: Schemas.io$k8s$api$core$v1$CSIPersistentVolumeSource;
        fc?: Schemas.io$k8s$api$core$v1$FCVolumeSource;
        flexVolume?: Schemas.io$k8s$api$core$v1$FlexPersistentVolumeSource;
        flocker?: Schemas.io$k8s$api$core$v1$FlockerVolumeSource;
        gcePersistentDisk?: Schemas.io$k8s$api$core$v1$GCEPersistentDiskVolumeSource;
        glusterfs?: Schemas.io$k8s$api$core$v1$GlusterfsPersistentVolumeSource;
        hostPath?: Schemas.io$k8s$api$core$v1$HostPathVolumeSource;
        iscsi?: Schemas.io$k8s$api$core$v1$ISCSIPersistentVolumeSource;
        local?: Schemas.io$k8s$api$core$v1$LocalVolumeSource;
        /** A list of mount options, e.g. ["ro", "soft"]. Not validated - mount will simply fail if one is invalid. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes/#mount-options */
        mountOptions?: string[];
        nfs?: Schemas.io$k8s$api$core$v1$NFSVolumeSource;
        nodeAffinity?: Schemas.io$k8s$api$core$v1$VolumeNodeAffinity;
        /**
         * What happens to a persistent volume when released from its claim. Valid options are Retain (default for manually created PersistentVolumes), Delete (default for dynamically provisioned PersistentVolumes), and Recycle (deprecated). Recycle must be supported by the volume plugin underlying this PersistentVolume. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#reclaiming
         *
         */
        persistentVolumeReclaimPolicy?: string;
        photonPersistentDisk?: Schemas.io$k8s$api$core$v1$PhotonPersistentDiskVolumeSource;
        portworxVolume?: Schemas.io$k8s$api$core$v1$PortworxVolumeSource;
        quobyte?: Schemas.io$k8s$api$core$v1$QuobyteVolumeSource;
        rbd?: Schemas.io$k8s$api$core$v1$RBDPersistentVolumeSource;
        scaleIO?: Schemas.io$k8s$api$core$v1$ScaleIOPersistentVolumeSource;
        /** Name of StorageClass to which this persistent volume belongs. Empty value means that this volume does not belong to any StorageClass. */
        storageClassName?: string;
        storageos?: Schemas.io$k8s$api$core$v1$StorageOSPersistentVolumeSource;
        /** volumeMode defines if a volume is intended to be used with a formatted filesystem or to remain in raw block state. Value of Filesystem is implied when not included in spec. */
        volumeMode?: string;
        vsphereVolume?: Schemas.io$k8s$api$core$v1$VsphereVirtualDiskVolumeSource;
    }
    /** PersistentVolumeStatus is the current status of a persistent volume. */
    interface io$k8s$api$core$v1$PersistentVolumeStatus {
        /** A human-readable message indicating details about why the volume is in this state. */
        message?: string;
        /**
         * Phase indicates if a volume is available, bound to a claim, or released by a claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#phase
         *
         */
        phase?: string;
        /** Reason is a brief CamelCase string that describes any failure and is meant for machine parsing and tidy display in the CLI. */
        reason?: string;
    }
    /** Represents a Photon Controller persistent disk resource. */
    interface io$k8s$api$core$v1$PhotonPersistentDiskVolumeSource {
        /** Filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. */
        fsType?: string;
        /** ID that identifies Photon Controller persistent disk */
        pdID: string;
    }
    /** Pod is a collection of containers that can run on a host. This resource is created by clients and scheduled onto hosts. */
    interface io$k8s$api$core$v1$Pod {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$core$v1$PodSpec;
        status?: Schemas.io$k8s$api$core$v1$PodStatus;
    }
    /** Pod affinity is a group of inter pod affinity scheduling rules. */
    interface io$k8s$api$core$v1$PodAffinity {
        /** The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred. */
        preferredDuringSchedulingIgnoredDuringExecution?: Schemas.io$k8s$api$core$v1$WeightedPodAffinityTerm[];
        /** If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied. */
        requiredDuringSchedulingIgnoredDuringExecution?: Schemas.io$k8s$api$core$v1$PodAffinityTerm[];
    }
    /** Defines a set of pods (namely those matching the labelSelector relative to the given namespace(s)) that this pod should be co-located (affinity) or not co-located (anti-affinity) with, where co-located is defined as running on a node whose value of the label with key <topologyKey> matches that of any node on which a pod of the set of pods is running */
    interface io$k8s$api$core$v1$PodAffinityTerm {
        labelSelector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        namespaceSelector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        /** namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace" */
        namespaces?: string[];
        /** This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed. */
        topologyKey: string;
    }
    /** Pod anti affinity is a group of inter pod anti affinity scheduling rules. */
    interface io$k8s$api$core$v1$PodAntiAffinity {
        /** The scheduler will prefer to schedule pods to nodes that satisfy the anti-affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling anti-affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred. */
        preferredDuringSchedulingIgnoredDuringExecution?: Schemas.io$k8s$api$core$v1$WeightedPodAffinityTerm[];
        /** If the anti-affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the anti-affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied. */
        requiredDuringSchedulingIgnoredDuringExecution?: Schemas.io$k8s$api$core$v1$PodAffinityTerm[];
    }
    /** PodCondition contains details for the current condition of this pod. */
    interface io$k8s$api$core$v1$PodCondition {
        lastProbeTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** Human-readable message indicating details about last transition. */
        message?: string;
        /** Unique, one-word, CamelCase reason for the condition's last transition. */
        reason?: string;
        /** Status is the status of the condition. Can be True, False, Unknown. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-conditions */
        status: string;
        /** Type is the type of the condition. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-conditions */
        type: string;
    }
    /** PodDNSConfig defines the DNS parameters of a pod in addition to those generated from DNSPolicy. */
    interface io$k8s$api$core$v1$PodDNSConfig {
        /** A list of DNS name server IP addresses. This will be appended to the base nameservers generated from DNSPolicy. Duplicated nameservers will be removed. */
        nameservers?: string[];
        /** A list of DNS resolver options. This will be merged with the base options generated from DNSPolicy. Duplicated entries will be removed. Resolution options given in Options will override those that appear in the base DNSPolicy. */
        options?: Schemas.io$k8s$api$core$v1$PodDNSConfigOption[];
        /** A list of DNS search domains for host-name lookup. This will be appended to the base search paths generated from DNSPolicy. Duplicated search paths will be removed. */
        searches?: string[];
    }
    /** PodDNSConfigOption defines DNS resolver options of a pod. */
    interface io$k8s$api$core$v1$PodDNSConfigOption {
        /** Required. */
        name?: string;
        value?: string;
    }
    /**
     * IP address information for entries in the (plural) PodIPs field. Each entry includes:
     *    IP: An IP address allocated to the pod. Routable at least within the cluster.
     */
    interface io$k8s$api$core$v1$PodIP {
        /** ip is an IP address (IPv4 or IPv6) assigned to the pod */
        ip?: string;
    }
    /** PodList is a list of Pods. */
    interface io$k8s$api$core$v1$PodList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of pods. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md */
        items: Schemas.io$k8s$api$core$v1$Pod[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** PodOS defines the OS parameters of a pod. */
    interface io$k8s$api$core$v1$PodOS {
        /** Name is the name of the operating system. The currently supported values are linux and windows. Additional value may be defined in future and can be one of: https://github.com/opencontainers/runtime-spec/blob/master/config.md#platform-specific-configuration Clients should expect to handle additional values and treat unrecognized values in this field as os: null */
        name: string;
    }
    /** PodReadinessGate contains the reference to a pod condition */
    interface io$k8s$api$core$v1$PodReadinessGate {
        /** ConditionType refers to a condition in the pod's condition list with matching type. */
        conditionType: string;
    }
    /** PodSecurityContext holds pod-level security attributes and common container settings. Some fields are also present in container.securityContext.  Field values of container.securityContext take precedence over field values of PodSecurityContext. */
    interface io$k8s$api$core$v1$PodSecurityContext {
        /**
         * A special supplemental group that applies to all containers in a pod. Some volume types allow the Kubelet to change the ownership of that volume to be owned by the pod:
         *
         * 1. The owning GID will be the FSGroup 2. The setgid bit is set (new files created in the volume will be owned by FSGroup) 3. The permission bits are OR'd with rw-rw----
         *
         * If unset, the Kubelet will not modify the ownership and permissions of any volume. Note that this field cannot be set when spec.os.name is windows.
         */
        fsGroup?: number;
        /** fsGroupChangePolicy defines behavior of changing ownership and permission of the volume before being exposed inside Pod. This field will only apply to volume types which support fsGroup based ownership(and permissions). It will have no effect on ephemeral volume types such as: secret, configmaps and emptydir. Valid values are "OnRootMismatch" and "Always". If not specified, "Always" is used. Note that this field cannot be set when spec.os.name is windows. */
        fsGroupChangePolicy?: string;
        /** The GID to run the entrypoint of the container process. Uses runtime default if unset. May also be set in SecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container. Note that this field cannot be set when spec.os.name is windows. */
        runAsGroup?: number;
        /** Indicates that the container must run as a non-root user. If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in SecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. */
        runAsNonRoot?: boolean;
        /** The UID to run the entrypoint of the container process. Defaults to user specified in image metadata if unspecified. May also be set in SecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container. Note that this field cannot be set when spec.os.name is windows. */
        runAsUser?: number;
        seLinuxOptions?: Schemas.io$k8s$api$core$v1$SELinuxOptions;
        seccompProfile?: Schemas.io$k8s$api$core$v1$SeccompProfile;
        /** A list of groups applied to the first process run in each container, in addition to the container's primary GID.  If unspecified, no groups will be added to any container. Note that this field cannot be set when spec.os.name is windows. */
        supplementalGroups?: number[];
        /** Sysctls hold a list of namespaced sysctls used for the pod. Pods with unsupported sysctls (by the container runtime) might fail to launch. Note that this field cannot be set when spec.os.name is windows. */
        sysctls?: Schemas.io$k8s$api$core$v1$Sysctl[];
        windowsOptions?: Schemas.io$k8s$api$core$v1$WindowsSecurityContextOptions;
    }
    /** PodSpec is a description of a pod. */
    interface io$k8s$api$core$v1$PodSpec {
        /** Optional duration in seconds the pod may be active on the node relative to StartTime before the system will actively try to mark it failed and kill associated containers. Value must be a positive integer. */
        activeDeadlineSeconds?: number;
        affinity?: Schemas.io$k8s$api$core$v1$Affinity;
        /** AutomountServiceAccountToken indicates whether a service account token should be automatically mounted. */
        automountServiceAccountToken?: boolean;
        /** List of containers belonging to the pod. Containers cannot currently be added or removed. There must be at least one container in a Pod. Cannot be updated. */
        containers: Schemas.io$k8s$api$core$v1$Container[];
        dnsConfig?: Schemas.io$k8s$api$core$v1$PodDNSConfig;
        /**
         * Set DNS policy for the pod. Defaults to "ClusterFirst". Valid values are 'ClusterFirstWithHostNet', 'ClusterFirst', 'Default' or 'None'. DNS parameters given in DNSConfig will be merged with the policy selected with DNSPolicy. To have DNS options set along with hostNetwork, you have to specify DNS policy explicitly to 'ClusterFirstWithHostNet'.
         *
         */
        dnsPolicy?: string;
        /** EnableServiceLinks indicates whether information about services should be injected into pod's environment variables, matching the syntax of Docker links. Optional: Defaults to true. */
        enableServiceLinks?: boolean;
        /** List of ephemeral containers run in this pod. Ephemeral containers may be run in an existing pod to perform user-initiated actions such as debugging. This list cannot be specified when creating a pod, and it cannot be modified by updating the pod spec. In order to add an ephemeral container to an existing pod, use the pod's ephemeralcontainers subresource. This field is beta-level and available on clusters that haven't disabled the EphemeralContainers feature gate. */
        ephemeralContainers?: Schemas.io$k8s$api$core$v1$EphemeralContainer[];
        /** HostAliases is an optional list of hosts and IPs that will be injected into the pod's hosts file if specified. This is only valid for non-hostNetwork pods. */
        hostAliases?: Schemas.io$k8s$api$core$v1$HostAlias[];
        /** Use the host's ipc namespace. Optional: Default to false. */
        hostIPC?: boolean;
        /** Host networking requested for this pod. Use the host's network namespace. If this option is set, the ports that will be used must be specified. Default to false. */
        hostNetwork?: boolean;
        /** Use the host's pid namespace. Optional: Default to false. */
        hostPID?: boolean;
        /** Specifies the hostname of the Pod If not specified, the pod's hostname will be set to a system-defined value. */
        hostname?: string;
        /** ImagePullSecrets is an optional list of references to secrets in the same namespace to use for pulling any of the images used by this PodSpec. If specified, these secrets will be passed to individual puller implementations for them to use. For example, in the case of docker, only DockerConfig type secrets are honored. More info: https://kubernetes.io/docs/concepts/containers/images#specifying-imagepullsecrets-on-a-pod */
        imagePullSecrets?: Schemas.io$k8s$api$core$v1$LocalObjectReference[];
        /** List of initialization containers belonging to the pod. Init containers are executed in order prior to containers being started. If any init container fails, the pod is considered to have failed and is handled according to its restartPolicy. The name for an init container or normal container must be unique among all containers. Init containers may not have Lifecycle actions, Readiness probes, Liveness probes, or Startup probes. The resourceRequirements of an init container are taken into account during scheduling by finding the highest request/limit for each resource type, and then using the max of of that value or the sum of the normal containers. Limits are applied to init containers in a similar fashion. Init containers cannot currently be added or removed. Cannot be updated. More info: https://kubernetes.io/docs/concepts/workloads/pods/init-containers/ */
        initContainers?: Schemas.io$k8s$api$core$v1$Container[];
        /** NodeName is a request to schedule this pod onto a specific node. If it is non-empty, the scheduler simply schedules this pod onto that node, assuming that it fits resource requirements. */
        nodeName?: string;
        /** NodeSelector is a selector which must be true for the pod to fit on a node. Selector which must match a node's labels for the pod to be scheduled on that node. More info: https://kubernetes.io/docs/concepts/configuration/assign-pod-node/ */
        nodeSelector?: {
            [key: string]: string;
        };
        os?: Schemas.io$k8s$api$core$v1$PodOS;
        /** Overhead represents the resource overhead associated with running a pod for a given RuntimeClass. This field will be autopopulated at admission time by the RuntimeClass admission controller. If the RuntimeClass admission controller is enabled, overhead must not be set in Pod create requests. The RuntimeClass admission controller will reject Pod create requests which have the overhead already set. If RuntimeClass is configured and selected in the PodSpec, Overhead will be set to the value defined in the corresponding RuntimeClass, otherwise it will remain unset and treated as zero. More info: https://git.k8s.io/enhancements/keps/sig-node/688-pod-overhead/README.md This field is beta-level as of Kubernetes v1.18, and is only honored by servers that enable the PodOverhead feature. */
        overhead?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** PreemptionPolicy is the Policy for preempting pods with lower priority. One of Never, PreemptLowerPriority. Defaults to PreemptLowerPriority if unset. This field is beta-level, gated by the NonPreemptingPriority feature-gate. */
        preemptionPolicy?: string;
        /** The priority value. Various system components use this field to find the priority of the pod. When Priority Admission Controller is enabled, it prevents users from setting this field. The admission controller populates this field from PriorityClassName. The higher the value, the higher the priority. */
        priority?: number;
        /** If specified, indicates the pod's priority. "system-node-critical" and "system-cluster-critical" are two special keywords which indicate the highest priorities with the former being the highest priority. Any other name must be defined by creating a PriorityClass object with that name. If not specified, the pod priority will be default or zero if there is no default. */
        priorityClassName?: string;
        /** If specified, all readiness gates will be evaluated for pod readiness. A pod is ready when all its containers are ready AND all conditions specified in the readiness gates have status equal to "True" More info: https://git.k8s.io/enhancements/keps/sig-network/580-pod-readiness-gates */
        readinessGates?: Schemas.io$k8s$api$core$v1$PodReadinessGate[];
        /**
         * Restart policy for all containers within the pod. One of Always, OnFailure, Never. Default to Always. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle/#restart-policy
         *
         */
        restartPolicy?: string;
        /** RuntimeClassName refers to a RuntimeClass object in the node.k8s.io group, which should be used to run this pod.  If no RuntimeClass resource matches the named class, the pod will not be run. If unset or empty, the "legacy" RuntimeClass will be used, which is an implicit class with an empty definition that uses the default runtime handler. More info: https://git.k8s.io/enhancements/keps/sig-node/585-runtime-class This is a beta feature as of Kubernetes v1.14. */
        runtimeClassName?: string;
        /** If specified, the pod will be dispatched by specified scheduler. If not specified, the pod will be dispatched by default scheduler. */
        schedulerName?: string;
        securityContext?: Schemas.io$k8s$api$core$v1$PodSecurityContext;
        /** DeprecatedServiceAccount is a depreciated alias for ServiceAccountName. Deprecated: Use serviceAccountName instead. */
        serviceAccount?: string;
        /** ServiceAccountName is the name of the ServiceAccount to use to run this pod. More info: https://kubernetes.io/docs/tasks/configure-pod-container/configure-service-account/ */
        serviceAccountName?: string;
        /** If true the pod's hostname will be configured as the pod's FQDN, rather than the leaf name (the default). In Linux containers, this means setting the FQDN in the hostname field of the kernel (the nodename field of struct utsname). In Windows containers, this means setting the registry value of hostname for the registry key HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\Tcpip\Parameters to FQDN. If a pod does not have FQDN, this has no effect. Default to false. */
        setHostnameAsFQDN?: boolean;
        /** Share a single process namespace between all of the containers in a pod. When this is set containers will be able to view and signal processes from other containers in the same pod, and the first process in each container will not be assigned PID 1. HostPID and ShareProcessNamespace cannot both be set. Optional: Default to false. */
        shareProcessNamespace?: boolean;
        /** If specified, the fully qualified Pod hostname will be "<hostname>.<subdomain>.<pod namespace>.svc.<cluster domain>". If not specified, the pod will not have a domainname at all. */
        subdomain?: string;
        /** Optional duration in seconds the pod needs to terminate gracefully. May be decreased in delete request. Value must be non-negative integer. The value zero indicates stop immediately via the kill signal (no opportunity to shut down). If this value is nil, the default grace period will be used instead. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process. Defaults to 30 seconds. */
        terminationGracePeriodSeconds?: number;
        /** If specified, the pod's tolerations. */
        tolerations?: Schemas.io$k8s$api$core$v1$Toleration[];
        /** TopologySpreadConstraints describes how a group of pods ought to spread across topology domains. Scheduler will schedule pods in a way which abides by the constraints. All topologySpreadConstraints are ANDed. */
        topologySpreadConstraints?: Schemas.io$k8s$api$core$v1$TopologySpreadConstraint[];
        /** List of volumes that can be mounted by containers belonging to the pod. More info: https://kubernetes.io/docs/concepts/storage/volumes */
        volumes?: Schemas.io$k8s$api$core$v1$Volume[];
    }
    /** PodStatus represents information about the status of a pod. Status may trail the actual state of a system, especially if the node that hosts the pod cannot contact the control plane. */
    interface io$k8s$api$core$v1$PodStatus {
        /** Current service state of pod. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-conditions */
        conditions?: Schemas.io$k8s$api$core$v1$PodCondition[];
        /** The list has one entry per container in the manifest. Each entry is currently the output of `docker inspect`. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-and-container-status */
        containerStatuses?: Schemas.io$k8s$api$core$v1$ContainerStatus[];
        /** Status for any ephemeral containers that have run in this pod. This field is beta-level and available on clusters that haven't disabled the EphemeralContainers feature gate. */
        ephemeralContainerStatuses?: Schemas.io$k8s$api$core$v1$ContainerStatus[];
        /** IP address of the host to which the pod is assigned. Empty if not yet scheduled. */
        hostIP?: string;
        /** The list has one entry per init container in the manifest. The most recent successful init container will have ready = true, the most recently started container will have startTime set. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-and-container-status */
        initContainerStatuses?: Schemas.io$k8s$api$core$v1$ContainerStatus[];
        /** A human readable message indicating details about why the pod is in this condition. */
        message?: string;
        /** nominatedNodeName is set only when this pod preempts other pods on the node, but it cannot be scheduled right away as preemption victims receive their graceful termination periods. This field does not guarantee that the pod will be scheduled on this node. Scheduler may decide to place the pod elsewhere if other nodes become available sooner. Scheduler may also decide to give the resources on this node to a higher priority pod that is created after preemption. As a result, this field may be different than PodSpec.nodeName when the pod is scheduled. */
        nominatedNodeName?: string;
        /**
         * The phase of a Pod is a simple, high-level summary of where the Pod is in its lifecycle. The conditions array, the reason and message fields, and the individual container status arrays contain more detail about the pod's status. There are five possible phase values:
         *
         * Pending: The pod has been accepted by the Kubernetes system, but one or more of the container images has not been created. This includes time before being scheduled as well as time spent downloading images over the network, which could take a while. Running: The pod has been bound to a node, and all of the containers have been created. At least one container is still running, or is in the process of starting or restarting. Succeeded: All containers in the pod have terminated in success, and will not be restarted. Failed: All containers in the pod have terminated, and at least one container has terminated in failure. The container either exited with non-zero status or was terminated by the system. Unknown: For some reason the state of the pod could not be obtained, typically due to an error in communicating with the host of the pod.
         *
         * More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-phase
         *
         */
        phase?: string;
        /** IP address allocated to the pod. Routable at least within the cluster. Empty if not yet allocated. */
        podIP?: string;
        /** podIPs holds the IP addresses allocated to the pod. If this field is specified, the 0th entry must match the podIP field. Pods may be allocated at most 1 value for each of IPv4 and IPv6. This list is empty if no IPs have been allocated yet. */
        podIPs?: Schemas.io$k8s$api$core$v1$PodIP[];
        /**
         * The Quality of Service (QOS) classification assigned to the pod based on resource requirements See PodQOSClass type for available QOS classes More info: https://git.k8s.io/community/contributors/design-proposals/node/resource-qos.md
         *
         */
        qosClass?: string;
        /** A brief CamelCase message indicating details about why the pod is in this state. e.g. 'Evicted' */
        reason?: string;
        startTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
    }
    /** PodTemplate describes a template for creating copies of a predefined pod. */
    interface io$k8s$api$core$v1$PodTemplate {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        template?: Schemas.io$k8s$api$core$v1$PodTemplateSpec;
    }
    /** PodTemplateList is a list of PodTemplates. */
    interface io$k8s$api$core$v1$PodTemplateList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of pod templates */
        items: Schemas.io$k8s$api$core$v1$PodTemplate[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** PodTemplateSpec describes the data a pod should have when created from a template */
    interface io$k8s$api$core$v1$PodTemplateSpec {
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$core$v1$PodSpec;
    }
    interface io$k8s$api$core$v1$PortStatus {
        /**
         * Error is to record the problem with the service port The format of the error shall comply with the following rules: - built-in error values shall be specified in this file and those shall use
         *   CamelCase names
         * - cloud provider specific error values must have names that comply with the
         *   format foo.example.com/CamelCase.
         */
        error?: string;
        /** Port is the port number of the service port of which status is recorded here */
        port: number;
        /**
         * Protocol is the protocol of the service port of which status is recorded here The supported values are: "TCP", "UDP", "SCTP"
         *
         */
        protocol: string;
    }
    /** PortworxVolumeSource represents a Portworx volume resource. */
    interface io$k8s$api$core$v1$PortworxVolumeSource {
        /** FSType represents the filesystem type to mount Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs". Implicitly inferred to be "ext4" if unspecified. */
        fsType?: string;
        /** Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. */
        readOnly?: boolean;
        /** VolumeID uniquely identifies a Portworx volume */
        volumeID: string;
    }
    /** An empty preferred scheduling term matches all objects with implicit weight 0 (i.e. it's a no-op). A null preferred scheduling term matches no objects (i.e. is also a no-op). */
    interface io$k8s$api$core$v1$PreferredSchedulingTerm {
        preference: Schemas.io$k8s$api$core$v1$NodeSelectorTerm;
        /** Weight associated with matching the corresponding nodeSelectorTerm, in the range 1-100. */
        weight: number;
    }
    /** Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic. */
    interface io$k8s$api$core$v1$Probe {
        exec?: Schemas.io$k8s$api$core$v1$ExecAction;
        /** Minimum consecutive failures for the probe to be considered failed after having succeeded. Defaults to 3. Minimum value is 1. */
        failureThreshold?: number;
        grpc?: Schemas.io$k8s$api$core$v1$GRPCAction;
        httpGet?: Schemas.io$k8s$api$core$v1$HTTPGetAction;
        /** Number of seconds after the container has started before liveness probes are initiated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes */
        initialDelaySeconds?: number;
        /** How often (in seconds) to perform the probe. Default to 10 seconds. Minimum value is 1. */
        periodSeconds?: number;
        /** Minimum consecutive successes for the probe to be considered successful after having failed. Defaults to 1. Must be 1 for liveness and startup. Minimum value is 1. */
        successThreshold?: number;
        tcpSocket?: Schemas.io$k8s$api$core$v1$TCPSocketAction;
        /** Optional duration in seconds the pod needs to terminate gracefully upon probe failure. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process. If this value is nil, the pod's terminationGracePeriodSeconds will be used. Otherwise, this value overrides the value provided by the pod spec. Value must be non-negative integer. The value zero indicates stop immediately via the kill signal (no opportunity to shut down). This is a beta field and requires enabling ProbeTerminationGracePeriod feature gate. Minimum value is 1. spec.terminationGracePeriodSeconds is used if unset. */
        terminationGracePeriodSeconds?: number;
        /** Number of seconds after which the probe times out. Defaults to 1 second. Minimum value is 1. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes */
        timeoutSeconds?: number;
    }
    /** Represents a projected volume source */
    interface io$k8s$api$core$v1$ProjectedVolumeSource {
        /** Mode bits used to set permissions on created files by default. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set. */
        defaultMode?: number;
        /** list of volume projections */
        sources?: Schemas.io$k8s$api$core$v1$VolumeProjection[];
    }
    /** Represents a Quobyte mount that lasts the lifetime of a pod. Quobyte volumes do not support ownership management or SELinux relabeling. */
    interface io$k8s$api$core$v1$QuobyteVolumeSource {
        /** Group to map volume access to Default is no group */
        group?: string;
        /** ReadOnly here will force the Quobyte volume to be mounted with read-only permissions. Defaults to false. */
        readOnly?: boolean;
        /** Registry represents a single or multiple Quobyte Registry services specified as a string as host:port pair (multiple entries are separated with commas) which acts as the central registry for volumes */
        registry: string;
        /** Tenant owning the given Quobyte volume in the Backend Used with dynamically provisioned Quobyte volumes, value is set by the plugin */
        tenant?: string;
        /** User to map volume access to Defaults to serivceaccount user */
        user?: string;
        /** Volume is a string that references an already created Quobyte volume by name. */
        volume: string;
    }
    /** Represents a Rados Block Device mount that lasts the lifetime of a pod. RBD volumes support ownership management and SELinux relabeling. */
    interface io$k8s$api$core$v1$RBDPersistentVolumeSource {
        /** Filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#rbd */
        fsType?: string;
        /** The rados image name. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        image: string;
        /** Keyring is the path to key ring for RBDUser. Default is /etc/ceph/keyring. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        keyring?: string;
        /** A collection of Ceph monitors. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        monitors: string[];
        /** The rados pool name. Default is rbd. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        pool?: string;
        /** ReadOnly here will force the ReadOnly setting in VolumeMounts. Defaults to false. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        readOnly?: boolean;
        secretRef?: Schemas.io$k8s$api$core$v1$SecretReference;
        /** The rados user name. Default is admin. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        user?: string;
    }
    /** Represents a Rados Block Device mount that lasts the lifetime of a pod. RBD volumes support ownership management and SELinux relabeling. */
    interface io$k8s$api$core$v1$RBDVolumeSource {
        /** Filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#rbd */
        fsType?: string;
        /** The rados image name. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        image: string;
        /** Keyring is the path to key ring for RBDUser. Default is /etc/ceph/keyring. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        keyring?: string;
        /** A collection of Ceph monitors. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        monitors: string[];
        /** The rados pool name. Default is rbd. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        pool?: string;
        /** ReadOnly here will force the ReadOnly setting in VolumeMounts. Defaults to false. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        readOnly?: boolean;
        secretRef?: Schemas.io$k8s$api$core$v1$LocalObjectReference;
        /** The rados user name. Default is admin. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        user?: string;
    }
    /** ReplicationController represents the configuration of a replication controller. */
    interface io$k8s$api$core$v1$ReplicationController {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$core$v1$ReplicationControllerSpec;
        status?: Schemas.io$k8s$api$core$v1$ReplicationControllerStatus;
    }
    /** ReplicationControllerCondition describes the state of a replication controller at a certain point. */
    interface io$k8s$api$core$v1$ReplicationControllerCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** A human readable message indicating details about the transition. */
        message?: string;
        /** The reason for the condition's last transition. */
        reason?: string;
        /** Status of the condition, one of True, False, Unknown. */
        status: string;
        /** Type of replication controller condition. */
        type: string;
    }
    /** ReplicationControllerList is a collection of replication controllers. */
    interface io$k8s$api$core$v1$ReplicationControllerList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of replication controllers. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller */
        items: Schemas.io$k8s$api$core$v1$ReplicationController[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ReplicationControllerSpec is the specification of a replication controller. */
    interface io$k8s$api$core$v1$ReplicationControllerSpec {
        /** Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready) */
        minReadySeconds?: number;
        /** Replicas is the number of desired replicas. This is a pointer to distinguish between explicit zero and unspecified. Defaults to 1. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#what-is-a-replicationcontroller */
        replicas?: number;
        /** Selector is a label query over pods that should match the Replicas count. If Selector is empty, it is defaulted to the labels present on the Pod template. Label keys and values that must match in order to be controlled by this replication controller, if empty defaulted to labels on Pod template. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors */
        selector?: {
            [key: string]: string;
        };
        template?: Schemas.io$k8s$api$core$v1$PodTemplateSpec;
    }
    /** ReplicationControllerStatus represents the current status of a replication controller. */
    interface io$k8s$api$core$v1$ReplicationControllerStatus {
        /** The number of available replicas (ready for at least minReadySeconds) for this replication controller. */
        availableReplicas?: number;
        /** Represents the latest available observations of a replication controller's current state. */
        conditions?: Schemas.io$k8s$api$core$v1$ReplicationControllerCondition[];
        /** The number of pods that have labels matching the labels of the pod template of the replication controller. */
        fullyLabeledReplicas?: number;
        /** ObservedGeneration reflects the generation of the most recently observed replication controller. */
        observedGeneration?: number;
        /** The number of ready replicas for this replication controller. */
        readyReplicas?: number;
        /** Replicas is the most recently oberved number of replicas. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#what-is-a-replicationcontroller */
        replicas: number;
    }
    /** ResourceFieldSelector represents container resources (cpu, memory) and their output format */
    interface io$k8s$api$core$v1$ResourceFieldSelector {
        /** Container name: required for volumes, optional for env vars */
        containerName?: string;
        divisor?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        /** Required: resource to select */
        resource: string;
    }
    /** ResourceQuota sets aggregate quota restrictions enforced per namespace */
    interface io$k8s$api$core$v1$ResourceQuota {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$core$v1$ResourceQuotaSpec;
        status?: Schemas.io$k8s$api$core$v1$ResourceQuotaStatus;
    }
    /** ResourceQuotaList is a list of ResourceQuota items. */
    interface io$k8s$api$core$v1$ResourceQuotaList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is a list of ResourceQuota objects. More info: https://kubernetes.io/docs/concepts/policy/resource-quotas/ */
        items: Schemas.io$k8s$api$core$v1$ResourceQuota[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ResourceQuotaSpec defines the desired hard limits to enforce for Quota. */
    interface io$k8s$api$core$v1$ResourceQuotaSpec {
        /** hard is the set of desired hard limits for each named resource. More info: https://kubernetes.io/docs/concepts/policy/resource-quotas/ */
        hard?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        scopeSelector?: Schemas.io$k8s$api$core$v1$ScopeSelector;
        /** A collection of filters that must match each object tracked by a quota. If not specified, the quota matches all objects. */
        scopes?: string[];
    }
    /** ResourceQuotaStatus defines the enforced hard limits and observed use. */
    interface io$k8s$api$core$v1$ResourceQuotaStatus {
        /** Hard is the set of enforced hard limits for each named resource. More info: https://kubernetes.io/docs/concepts/policy/resource-quotas/ */
        hard?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** Used is the current observed total usage of the resource in the namespace. */
        used?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
    }
    /** ResourceRequirements describes the compute resource requirements. */
    interface io$k8s$api$core$v1$ResourceRequirements {
        /** Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/ */
        limits?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/ */
        requests?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
    }
    /** SELinuxOptions are the labels to be applied to the container */
    interface io$k8s$api$core$v1$SELinuxOptions {
        /** Level is SELinux level label that applies to the container. */
        level?: string;
        /** Role is a SELinux role label that applies to the container. */
        role?: string;
        /** Type is a SELinux type label that applies to the container. */
        type?: string;
        /** User is a SELinux user label that applies to the container. */
        user?: string;
    }
    /** ScaleIOPersistentVolumeSource represents a persistent ScaleIO volume */
    interface io$k8s$api$core$v1$ScaleIOPersistentVolumeSource {
        /** Filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Default is "xfs" */
        fsType?: string;
        /** The host address of the ScaleIO API Gateway. */
        gateway: string;
        /** The name of the ScaleIO Protection Domain for the configured storage. */
        protectionDomain?: string;
        /** Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. */
        readOnly?: boolean;
        secretRef: Schemas.io$k8s$api$core$v1$SecretReference;
        /** Flag to enable/disable SSL communication with Gateway, default false */
        sslEnabled?: boolean;
        /** Indicates whether the storage for a volume should be ThickProvisioned or ThinProvisioned. Default is ThinProvisioned. */
        storageMode?: string;
        /** The ScaleIO Storage Pool associated with the protection domain. */
        storagePool?: string;
        /** The name of the storage system as configured in ScaleIO. */
        system: string;
        /** The name of a volume already created in the ScaleIO system that is associated with this volume source. */
        volumeName?: string;
    }
    /** ScaleIOVolumeSource represents a persistent ScaleIO volume */
    interface io$k8s$api$core$v1$ScaleIOVolumeSource {
        /** Filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Default is "xfs". */
        fsType?: string;
        /** The host address of the ScaleIO API Gateway. */
        gateway: string;
        /** The name of the ScaleIO Protection Domain for the configured storage. */
        protectionDomain?: string;
        /** Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. */
        readOnly?: boolean;
        secretRef: Schemas.io$k8s$api$core$v1$LocalObjectReference;
        /** Flag to enable/disable SSL communication with Gateway, default false */
        sslEnabled?: boolean;
        /** Indicates whether the storage for a volume should be ThickProvisioned or ThinProvisioned. Default is ThinProvisioned. */
        storageMode?: string;
        /** The ScaleIO Storage Pool associated with the protection domain. */
        storagePool?: string;
        /** The name of the storage system as configured in ScaleIO. */
        system: string;
        /** The name of a volume already created in the ScaleIO system that is associated with this volume source. */
        volumeName?: string;
    }
    /** A scope selector represents the AND of the selectors represented by the scoped-resource selector requirements. */
    interface io$k8s$api$core$v1$ScopeSelector {
        /** A list of scope selector requirements by scope of the resources. */
        matchExpressions?: Schemas.io$k8s$api$core$v1$ScopedResourceSelectorRequirement[];
    }
    /** A scoped-resource selector requirement is a selector that contains values, a scope name, and an operator that relates the scope name and values. */
    interface io$k8s$api$core$v1$ScopedResourceSelectorRequirement {
        /**
         * Represents a scope's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist.
         *
         */
        operator: string;
        /**
         * The name of the scope that the selector applies to.
         *
         */
        scopeName: string;
        /** An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch. */
        values?: string[];
    }
    /** SeccompProfile defines a pod/container's seccomp profile settings. Only one profile source may be set. */
    interface io$k8s$api$core$v1$SeccompProfile {
        /** localhostProfile indicates a profile defined in a file on the node should be used. The profile must be preconfigured on the node to work. Must be a descending path, relative to the kubelet's configured seccomp profile location. Must only be set if type is "Localhost". */
        localhostProfile?: string;
        /**
         * type indicates which kind of seccomp profile will be applied. Valid options are:
         *
         * Localhost - a profile defined in a file on the node should be used. RuntimeDefault - the container runtime default profile should be used. Unconfined - no profile should be applied.
         *
         */
        type: string;
    }
    /** Secret holds secret data of a certain type. The total bytes of the values in the Data field must be less than MaxSecretSize bytes. */
    interface io$k8s$api$core$v1$Secret {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Data contains the secret data. Each key must consist of alphanumeric characters, '-', '_' or '.'. The serialized form of the secret data is a base64 encoded string, representing the arbitrary (possibly non-string) data value here. Described in https://tools.ietf.org/html/rfc4648#section-4 */
        data?: {
            [key: string]: Blob;
        };
        /** Immutable, if set to true, ensures that data stored in the Secret cannot be updated (only object metadata can be modified). If not set to true, the field can be modified at any time. Defaulted to nil. */
        immutable?: boolean;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** stringData allows specifying non-binary secret data in string form. It is provided as a write-only input field for convenience. All keys and values are merged into the data field on write, overwriting any existing values. The stringData field is never output when reading from the API. */
        stringData?: {
            [key: string]: string;
        };
        /** Used to facilitate programmatic handling of secret data. More info: https://kubernetes.io/docs/concepts/configuration/secret/#secret-types */
        type?: string;
    }
    /**
     * SecretEnvSource selects a Secret to populate the environment variables with.
     *
     * The contents of the target Secret's Data field will represent the key-value pairs as environment variables.
     */
    interface io$k8s$api$core$v1$SecretEnvSource {
        /** Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names */
        name?: string;
        /** Specify whether the Secret must be defined */
        optional?: boolean;
    }
    /** SecretKeySelector selects a key of a Secret. */
    interface io$k8s$api$core$v1$SecretKeySelector {
        /** The key of the secret to select from.  Must be a valid secret key. */
        key: string;
        /** Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names */
        name?: string;
        /** Specify whether the Secret or its key must be defined */
        optional?: boolean;
    }
    /** SecretList is a list of Secret. */
    interface io$k8s$api$core$v1$SecretList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is a list of secret objects. More info: https://kubernetes.io/docs/concepts/configuration/secret */
        items: Schemas.io$k8s$api$core$v1$Secret[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /**
     * Adapts a secret into a projected volume.
     *
     * The contents of the target Secret's Data field will be presented in a projected volume as files using the keys in the Data field as the file names. Note that this is identical to a secret volume source without the default mode.
     */
    interface io$k8s$api$core$v1$SecretProjection {
        /** If unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the Secret, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'. */
        items?: Schemas.io$k8s$api$core$v1$KeyToPath[];
        /** Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names */
        name?: string;
        /** Specify whether the Secret or its key must be defined */
        optional?: boolean;
    }
    /** SecretReference represents a Secret Reference. It has enough information to retrieve secret in any namespace */
    interface io$k8s$api$core$v1$SecretReference {
        /** Name is unique within a namespace to reference a secret resource. */
        name?: string;
        /** Namespace defines the space within which the secret name must be unique. */
        namespace?: string;
    }
    /**
     * Adapts a Secret into a volume.
     *
     * The contents of the target Secret's Data field will be presented in a volume as files using the keys in the Data field as the file names. Secret volumes support ownership management and SELinux relabeling.
     */
    interface io$k8s$api$core$v1$SecretVolumeSource {
        /** Optional: mode bits used to set permissions on created files by default. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set. */
        defaultMode?: number;
        /** If unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the Secret, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'. */
        items?: Schemas.io$k8s$api$core$v1$KeyToPath[];
        /** Specify whether the Secret or its keys must be defined */
        optional?: boolean;
        /** Name of the secret in the pod's namespace to use. More info: https://kubernetes.io/docs/concepts/storage/volumes#secret */
        secretName?: string;
    }
    /** SecurityContext holds security configuration that will be applied to a container. Some fields are present in both SecurityContext and PodSecurityContext.  When both are set, the values in SecurityContext take precedence. */
    interface io$k8s$api$core$v1$SecurityContext {
        /** AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process. This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN Note that this field cannot be set when spec.os.name is windows. */
        allowPrivilegeEscalation?: boolean;
        capabilities?: Schemas.io$k8s$api$core$v1$Capabilities;
        /** Run container in privileged mode. Processes in privileged containers are essentially equivalent to root on the host. Defaults to false. Note that this field cannot be set when spec.os.name is windows. */
        privileged?: boolean;
        /** procMount denotes the type of proc mount to use for the containers. The default is DefaultProcMount which uses the container runtime defaults for readonly paths and masked paths. This requires the ProcMountType feature flag to be enabled. Note that this field cannot be set when spec.os.name is windows. */
        procMount?: string;
        /** Whether this container has a read-only root filesystem. Default is false. Note that this field cannot be set when spec.os.name is windows. */
        readOnlyRootFilesystem?: boolean;
        /** The GID to run the entrypoint of the container process. Uses runtime default if unset. May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is windows. */
        runAsGroup?: number;
        /** Indicates that the container must run as a non-root user. If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. */
        runAsNonRoot?: boolean;
        /** The UID to run the entrypoint of the container process. Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is windows. */
        runAsUser?: number;
        seLinuxOptions?: Schemas.io$k8s$api$core$v1$SELinuxOptions;
        seccompProfile?: Schemas.io$k8s$api$core$v1$SeccompProfile;
        windowsOptions?: Schemas.io$k8s$api$core$v1$WindowsSecurityContextOptions;
    }
    /** Service is a named abstraction of software service (for example, mysql) consisting of local port (for example 3306) that the proxy listens on, and the selector that determines which pods will answer requests sent through the proxy. */
    interface io$k8s$api$core$v1$Service {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$core$v1$ServiceSpec;
        status?: Schemas.io$k8s$api$core$v1$ServiceStatus;
    }
    /** ServiceAccount binds together: * a name, understood by users, and perhaps by peripheral systems, for an identity * a principal that can be authenticated and authorized * a set of secrets */
    interface io$k8s$api$core$v1$ServiceAccount {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** AutomountServiceAccountToken indicates whether pods running as this service account should have an API token automatically mounted. Can be overridden at the pod level. */
        automountServiceAccountToken?: boolean;
        /** ImagePullSecrets is a list of references to secrets in the same namespace to use for pulling any images in pods that reference this ServiceAccount. ImagePullSecrets are distinct from Secrets because Secrets can be mounted in the pod, but ImagePullSecrets are only accessed by the kubelet. More info: https://kubernetes.io/docs/concepts/containers/images/#specifying-imagepullsecrets-on-a-pod */
        imagePullSecrets?: Schemas.io$k8s$api$core$v1$LocalObjectReference[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** Secrets is the list of secrets allowed to be used by pods running using this ServiceAccount. More info: https://kubernetes.io/docs/concepts/configuration/secret */
        secrets?: Schemas.io$k8s$api$core$v1$ObjectReference[];
    }
    /** ServiceAccountList is a list of ServiceAccount objects */
    interface io$k8s$api$core$v1$ServiceAccountList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of ServiceAccounts. More info: https://kubernetes.io/docs/tasks/configure-pod-container/configure-service-account/ */
        items: Schemas.io$k8s$api$core$v1$ServiceAccount[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ServiceAccountTokenProjection represents a projected service account token volume. This projection can be used to insert a service account token into the pods runtime filesystem for use against APIs (Kubernetes API Server or otherwise). */
    interface io$k8s$api$core$v1$ServiceAccountTokenProjection {
        /** Audience is the intended audience of the token. A recipient of a token must identify itself with an identifier specified in the audience of the token, and otherwise should reject the token. The audience defaults to the identifier of the apiserver. */
        audience?: string;
        /** ExpirationSeconds is the requested duration of validity of the service account token. As the token approaches expiration, the kubelet volume plugin will proactively rotate the service account token. The kubelet will start trying to rotate the token if the token is older than 80 percent of its time to live or if the token is older than 24 hours.Defaults to 1 hour and must be at least 10 minutes. */
        expirationSeconds?: number;
        /** Path is the path relative to the mount point of the file to project the token into. */
        path: string;
    }
    /** ServiceList holds a list of services. */
    interface io$k8s$api$core$v1$ServiceList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of services */
        items: Schemas.io$k8s$api$core$v1$Service[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ServicePort contains information on service's port. */
    interface io$k8s$api$core$v1$ServicePort {
        /** The application protocol for this port. This field follows standard Kubernetes label syntax. Un-prefixed names are reserved for IANA standard service names (as per RFC-6335 and http://www.iana.org/assignments/service-names). Non-standard protocols should use prefixed names such as mycompany.com/my-custom-protocol. */
        appProtocol?: string;
        /** The name of this port within the service. This must be a DNS_LABEL. All ports within a ServiceSpec must have unique names. When considering the endpoints for a Service, this must match the 'name' field in the EndpointPort. Optional if only one ServicePort is defined on this service. */
        name?: string;
        /** The port on each node on which this service is exposed when type is NodePort or LoadBalancer.  Usually assigned by the system. If a value is specified, in-range, and not in use it will be used, otherwise the operation will fail.  If not specified, a port will be allocated if this Service requires one.  If this field is specified when creating a Service which does not need it, creation will fail. This field will be wiped when updating a Service to no longer need it (e.g. changing type from NodePort to ClusterIP). More info: https://kubernetes.io/docs/concepts/services-networking/service/#type-nodeport */
        nodePort?: number;
        /** The port that will be exposed by this service. */
        port: number;
        /**
         * The IP protocol for this port. Supports "TCP", "UDP", and "SCTP". Default is TCP.
         *
         */
        protocol?: string;
        targetPort?: Schemas.io$k8s$apimachinery$pkg$util$intstr$IntOrString;
    }
    /** ServiceSpec describes the attributes that a user creates on a service. */
    interface io$k8s$api$core$v1$ServiceSpec {
        /** allocateLoadBalancerNodePorts defines if NodePorts will be automatically allocated for services with type LoadBalancer.  Default is "true". It may be set to "false" if the cluster load-balancer does not rely on NodePorts.  If the caller requests specific NodePorts (by specifying a value), those requests will be respected, regardless of this field. This field may only be set for services with type LoadBalancer and will be cleared if the type is changed to any other type. This field is beta-level and is only honored by servers that enable the ServiceLBNodePortControl feature. */
        allocateLoadBalancerNodePorts?: boolean;
        /** clusterIP is the IP address of the service and is usually assigned randomly. If an address is specified manually, is in-range (as per system configuration), and is not in use, it will be allocated to the service; otherwise creation of the service will fail. This field may not be changed through updates unless the type field is also being changed to ExternalName (which requires this field to be blank) or the type field is being changed from ExternalName (in which case this field may optionally be specified, as describe above).  Valid values are "None", empty string (""), or a valid IP address. Setting this to "None" makes a "headless service" (no virtual IP), which is useful when direct endpoint connections are preferred and proxying is not required.  Only applies to types ClusterIP, NodePort, and LoadBalancer. If this field is specified when creating a Service of type ExternalName, creation will fail. This field will be wiped when updating a Service to type ExternalName. More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies */
        clusterIP?: string;
        /**
         * ClusterIPs is a list of IP addresses assigned to this service, and are usually assigned randomly.  If an address is specified manually, is in-range (as per system configuration), and is not in use, it will be allocated to the service; otherwise creation of the service will fail. This field may not be changed through updates unless the type field is also being changed to ExternalName (which requires this field to be empty) or the type field is being changed from ExternalName (in which case this field may optionally be specified, as describe above).  Valid values are "None", empty string (""), or a valid IP address.  Setting this to "None" makes a "headless service" (no virtual IP), which is useful when direct endpoint connections are preferred and proxying is not required.  Only applies to types ClusterIP, NodePort, and LoadBalancer. If this field is specified when creating a Service of type ExternalName, creation will fail. This field will be wiped when updating a Service to type ExternalName.  If this field is not specified, it will be initialized from the clusterIP field.  If this field is specified, clients must ensure that clusterIPs[0] and clusterIP have the same value.
         *
         * This field may hold a maximum of two entries (dual-stack IPs, in either order). These IPs must correspond to the values of the ipFamilies field. Both clusterIPs and ipFamilies are governed by the ipFamilyPolicy field. More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies
         */
        clusterIPs?: string[];
        /** externalIPs is a list of IP addresses for which nodes in the cluster will also accept traffic for this service.  These IPs are not managed by Kubernetes.  The user is responsible for ensuring that traffic arrives at a node with this IP.  A common example is external load-balancers that are not part of the Kubernetes system. */
        externalIPs?: string[];
        /** externalName is the external reference that discovery mechanisms will return as an alias for this service (e.g. a DNS CNAME record). No proxying will be involved.  Must be a lowercase RFC-1123 hostname (https://tools.ietf.org/html/rfc1123) and requires `type` to be "ExternalName". */
        externalName?: string;
        /**
         * externalTrafficPolicy denotes if this Service desires to route external traffic to node-local or cluster-wide endpoints. "Local" preserves the client source IP and avoids a second hop for LoadBalancer and Nodeport type services, but risks potentially imbalanced traffic spreading. "Cluster" obscures the client source IP and may cause a second hop to another node, but should have good overall load-spreading.
         *
         */
        externalTrafficPolicy?: string;
        /** healthCheckNodePort specifies the healthcheck nodePort for the service. This only applies when type is set to LoadBalancer and externalTrafficPolicy is set to Local. If a value is specified, is in-range, and is not in use, it will be used.  If not specified, a value will be automatically allocated.  External systems (e.g. load-balancers) can use this port to determine if a given node holds endpoints for this service or not.  If this field is specified when creating a Service which does not need it, creation will fail. This field will be wiped when updating a Service to no longer need it (e.g. changing type). */
        healthCheckNodePort?: number;
        /** InternalTrafficPolicy specifies if the cluster internal traffic should be routed to all endpoints or node-local endpoints only. "Cluster" routes internal traffic to a Service to all endpoints. "Local" routes traffic to node-local endpoints only, traffic is dropped if no node-local endpoints are ready. The default value is "Cluster". */
        internalTrafficPolicy?: string;
        /**
         * IPFamilies is a list of IP families (e.g. IPv4, IPv6) assigned to this service. This field is usually assigned automatically based on cluster configuration and the ipFamilyPolicy field. If this field is specified manually, the requested family is available in the cluster, and ipFamilyPolicy allows it, it will be used; otherwise creation of the service will fail. This field is conditionally mutable: it allows for adding or removing a secondary IP family, but it does not allow changing the primary IP family of the Service. Valid values are "IPv4" and "IPv6".  This field only applies to Services of types ClusterIP, NodePort, and LoadBalancer, and does apply to "headless" services. This field will be wiped when updating a Service to type ExternalName.
         *
         * This field may hold a maximum of two entries (dual-stack families, in either order).  These families must correspond to the values of the clusterIPs field, if specified. Both clusterIPs and ipFamilies are governed by the ipFamilyPolicy field.
         */
        ipFamilies?: string[];
        /** IPFamilyPolicy represents the dual-stack-ness requested or required by this Service. If there is no value provided, then this field will be set to SingleStack. Services can be "SingleStack" (a single IP family), "PreferDualStack" (two IP families on dual-stack configured clusters or a single IP family on single-stack clusters), or "RequireDualStack" (two IP families on dual-stack configured clusters, otherwise fail). The ipFamilies and clusterIPs fields depend on the value of this field. This field will be wiped when updating a service to type ExternalName. */
        ipFamilyPolicy?: string;
        /** loadBalancerClass is the class of the load balancer implementation this Service belongs to. If specified, the value of this field must be a label-style identifier, with an optional prefix, e.g. "internal-vip" or "example.com/internal-vip". Unprefixed names are reserved for end-users. This field can only be set when the Service type is 'LoadBalancer'. If not set, the default load balancer implementation is used, today this is typically done through the cloud provider integration, but should apply for any default implementation. If set, it is assumed that a load balancer implementation is watching for Services with a matching class. Any default load balancer implementation (e.g. cloud providers) should ignore Services that set this field. This field can only be set when creating or updating a Service to type 'LoadBalancer'. Once set, it can not be changed. This field will be wiped when a service is updated to a non 'LoadBalancer' type. */
        loadBalancerClass?: string;
        /** Only applies to Service Type: LoadBalancer LoadBalancer will get created with the IP specified in this field. This feature depends on whether the underlying cloud-provider supports specifying the loadBalancerIP when a load balancer is created. This field will be ignored if the cloud-provider does not support the feature. */
        loadBalancerIP?: string;
        /** If specified and supported by the platform, this will restrict traffic through the cloud-provider load-balancer will be restricted to the specified client IPs. This field will be ignored if the cloud-provider does not support the feature." More info: https://kubernetes.io/docs/tasks/access-application-cluster/create-external-load-balancer/ */
        loadBalancerSourceRanges?: string[];
        /** The list of ports that are exposed by this service. More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies */
        ports?: Schemas.io$k8s$api$core$v1$ServicePort[];
        /** publishNotReadyAddresses indicates that any agent which deals with endpoints for this Service should disregard any indications of ready/not-ready. The primary use case for setting this field is for a StatefulSet's Headless Service to propagate SRV DNS records for its Pods for the purpose of peer discovery. The Kubernetes controllers that generate Endpoints and EndpointSlice resources for Services interpret this to mean that all endpoints are considered "ready" even if the Pods themselves are not. Agents which consume only Kubernetes generated endpoints through the Endpoints or EndpointSlice resources can safely assume this behavior. */
        publishNotReadyAddresses?: boolean;
        /** Route service traffic to pods with label keys and values matching this selector. If empty or not present, the service is assumed to have an external process managing its endpoints, which Kubernetes will not modify. Only applies to types ClusterIP, NodePort, and LoadBalancer. Ignored if type is ExternalName. More info: https://kubernetes.io/docs/concepts/services-networking/service/ */
        selector?: {
            [key: string]: string;
        };
        /**
         * Supports "ClientIP" and "None". Used to maintain session affinity. Enable client IP based session affinity. Must be ClientIP or None. Defaults to None. More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies
         *
         */
        sessionAffinity?: string;
        sessionAffinityConfig?: Schemas.io$k8s$api$core$v1$SessionAffinityConfig;
        /**
         * type determines how the Service is exposed. Defaults to ClusterIP. Valid options are ExternalName, ClusterIP, NodePort, and LoadBalancer. "ClusterIP" allocates a cluster-internal IP address for load-balancing to endpoints. Endpoints are determined by the selector or if that is not specified, by manual construction of an Endpoints object or EndpointSlice objects. If clusterIP is "None", no virtual IP is allocated and the endpoints are published as a set of endpoints rather than a virtual IP. "NodePort" builds on ClusterIP and allocates a port on every node which routes to the same endpoints as the clusterIP. "LoadBalancer" builds on NodePort and creates an external load-balancer (if supported in the current cloud) which routes to the same endpoints as the clusterIP. "ExternalName" aliases this service to the specified externalName. Several other fields do not apply to ExternalName services. More info: https://kubernetes.io/docs/concepts/services-networking/service/#publishing-services-service-types
         *
         */
        type?: string;
    }
    /** ServiceStatus represents the current status of a service. */
    interface io$k8s$api$core$v1$ServiceStatus {
        /** Current service state */
        conditions?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Condition[];
        loadBalancer?: Schemas.io$k8s$api$core$v1$LoadBalancerStatus;
    }
    /** SessionAffinityConfig represents the configurations of session affinity. */
    interface io$k8s$api$core$v1$SessionAffinityConfig {
        clientIP?: Schemas.io$k8s$api$core$v1$ClientIPConfig;
    }
    /** Represents a StorageOS persistent volume resource. */
    interface io$k8s$api$core$v1$StorageOSPersistentVolumeSource {
        /** Filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. */
        fsType?: string;
        /** Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. */
        readOnly?: boolean;
        secretRef?: Schemas.io$k8s$api$core$v1$ObjectReference;
        /** VolumeName is the human-readable name of the StorageOS volume.  Volume names are only unique within a namespace. */
        volumeName?: string;
        /** VolumeNamespace specifies the scope of the volume within StorageOS.  If no namespace is specified then the Pod's namespace will be used.  This allows the Kubernetes name scoping to be mirrored within StorageOS for tighter integration. Set VolumeName to any name to override the default behaviour. Set to "default" if you are not using namespaces within StorageOS. Namespaces that do not pre-exist within StorageOS will be created. */
        volumeNamespace?: string;
    }
    /** Represents a StorageOS persistent volume resource. */
    interface io$k8s$api$core$v1$StorageOSVolumeSource {
        /** Filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. */
        fsType?: string;
        /** Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. */
        readOnly?: boolean;
        secretRef?: Schemas.io$k8s$api$core$v1$LocalObjectReference;
        /** VolumeName is the human-readable name of the StorageOS volume.  Volume names are only unique within a namespace. */
        volumeName?: string;
        /** VolumeNamespace specifies the scope of the volume within StorageOS.  If no namespace is specified then the Pod's namespace will be used.  This allows the Kubernetes name scoping to be mirrored within StorageOS for tighter integration. Set VolumeName to any name to override the default behaviour. Set to "default" if you are not using namespaces within StorageOS. Namespaces that do not pre-exist within StorageOS will be created. */
        volumeNamespace?: string;
    }
    /** Sysctl defines a kernel parameter to be set */
    interface io$k8s$api$core$v1$Sysctl {
        /** Name of a property to set */
        name: string;
        /** Value of a property to set */
        value: string;
    }
    /** TCPSocketAction describes an action based on opening a socket */
    interface io$k8s$api$core$v1$TCPSocketAction {
        /** Optional: Host name to connect to, defaults to the pod IP. */
        host?: string;
        port: Schemas.io$k8s$apimachinery$pkg$util$intstr$IntOrString;
    }
    /** The node this Taint is attached to has the "effect" on any pod that does not tolerate the Taint. */
    interface io$k8s$api$core$v1$Taint {
        /**
         * Required. The effect of the taint on pods that do not tolerate the taint. Valid effects are NoSchedule, PreferNoSchedule and NoExecute.
         *
         */
        effect: string;
        /** Required. The taint key to be applied to a node. */
        key: string;
        timeAdded?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** The taint value corresponding to the taint key. */
        value?: string;
    }
    /** The pod this Toleration is attached to tolerates any taint that matches the triple <key,value,effect> using the matching operator <operator>. */
    interface io$k8s$api$core$v1$Toleration {
        /**
         * Effect indicates the taint effect to match. Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute.
         *
         */
        effect?: string;
        /** Key is the taint key that the toleration applies to. Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys. */
        key?: string;
        /**
         * Operator represents a key's relationship to the value. Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category.
         *
         */
        operator?: string;
        /** TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint. By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system. */
        tolerationSeconds?: number;
        /** Value is the taint value the toleration matches to. If the operator is Exists, the value should be empty, otherwise just a regular string. */
        value?: string;
    }
    /** A topology selector requirement is a selector that matches given label. This is an alpha feature and may change in the future. */
    interface io$k8s$api$core$v1$TopologySelectorLabelRequirement {
        /** The label key that the selector applies to. */
        key: string;
        /** An array of string values. One value must match the label to be selected. Each entry in Values is ORed. */
        values: string[];
    }
    /** A topology selector term represents the result of label queries. A null or empty topology selector term matches no objects. The requirements of them are ANDed. It provides a subset of functionality as NodeSelectorTerm. This is an alpha feature and may change in the future. */
    interface io$k8s$api$core$v1$TopologySelectorTerm {
        /** A list of topology selector requirements by labels. */
        matchLabelExpressions?: Schemas.io$k8s$api$core$v1$TopologySelectorLabelRequirement[];
    }
    /** TopologySpreadConstraint specifies how to spread matching pods among the given topology. */
    interface io$k8s$api$core$v1$TopologySpreadConstraint {
        labelSelector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        /** MaxSkew describes the degree to which pods may be unevenly distributed. When `whenUnsatisfiable=DoNotSchedule`, it is the maximum permitted difference between the number of matching pods in the target topology and the global minimum. For example, in a 3-zone cluster, MaxSkew is set to 1, and pods with the same labelSelector spread as 1/1/0: | zone1 | zone2 | zone3 | |   P   |   P   |       | - if MaxSkew is 1, incoming pod can only be scheduled to zone3 to become 1/1/1; scheduling it onto zone1(zone2) would make the ActualSkew(2-0) on zone1(zone2) violate MaxSkew(1). - if MaxSkew is 2, incoming pod can be scheduled onto any zone. When `whenUnsatisfiable=ScheduleAnyway`, it is used to give higher precedence to topologies that satisfy it. It's a required field. Default value is 1 and 0 is not allowed. */
        maxSkew: number;
        /** TopologyKey is the key of node labels. Nodes that have a label with this key and identical values are considered to be in the same topology. We consider each <key, value> as a "bucket", and try to put balanced number of pods into each bucket. It's a required field. */
        topologyKey: string;
        /**
         * WhenUnsatisfiable indicates how to deal with a pod if it doesn't satisfy the spread constraint. - DoNotSchedule (default) tells the scheduler not to schedule it. - ScheduleAnyway tells the scheduler to schedule the pod in any location,
         *   but giving higher precedence to topologies that would help reduce the
         *   skew.
         * A constraint is considered "Unsatisfiable" for an incoming pod if and only if every possible node assignment for that pod would violate "MaxSkew" on some topology. For example, in a 3-zone cluster, MaxSkew is set to 1, and pods with the same labelSelector spread as 3/1/1: | zone1 | zone2 | zone3 | | P P P |   P   |   P   | If WhenUnsatisfiable is set to DoNotSchedule, incoming pod can only be scheduled to zone2(zone3) to become 3/2/1(3/1/2) as ActualSkew(2-1) on zone2(zone3) satisfies MaxSkew(1). In other words, the cluster can still be imbalanced, but scheduler won't make it *more* imbalanced. It's a required field.
         *
         */
        whenUnsatisfiable: string;
    }
    /** TypedLocalObjectReference contains enough information to let you locate the typed referenced object inside the same namespace. */
    interface io$k8s$api$core$v1$TypedLocalObjectReference {
        /** APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required. */
        apiGroup?: string;
        /** Kind is the type of resource being referenced */
        kind: string;
        /** Name is the name of resource being referenced */
        name: string;
    }
    /** Volume represents a named volume in a pod that may be accessed by any container in the pod. */
    interface io$k8s$api$core$v1$Volume {
        awsElasticBlockStore?: Schemas.io$k8s$api$core$v1$AWSElasticBlockStoreVolumeSource;
        azureDisk?: Schemas.io$k8s$api$core$v1$AzureDiskVolumeSource;
        azureFile?: Schemas.io$k8s$api$core$v1$AzureFileVolumeSource;
        cephfs?: Schemas.io$k8s$api$core$v1$CephFSVolumeSource;
        cinder?: Schemas.io$k8s$api$core$v1$CinderVolumeSource;
        configMap?: Schemas.io$k8s$api$core$v1$ConfigMapVolumeSource;
        csi?: Schemas.io$k8s$api$core$v1$CSIVolumeSource;
        downwardAPI?: Schemas.io$k8s$api$core$v1$DownwardAPIVolumeSource;
        emptyDir?: Schemas.io$k8s$api$core$v1$EmptyDirVolumeSource;
        ephemeral?: Schemas.io$k8s$api$core$v1$EphemeralVolumeSource;
        fc?: Schemas.io$k8s$api$core$v1$FCVolumeSource;
        flexVolume?: Schemas.io$k8s$api$core$v1$FlexVolumeSource;
        flocker?: Schemas.io$k8s$api$core$v1$FlockerVolumeSource;
        gcePersistentDisk?: Schemas.io$k8s$api$core$v1$GCEPersistentDiskVolumeSource;
        gitRepo?: Schemas.io$k8s$api$core$v1$GitRepoVolumeSource;
        glusterfs?: Schemas.io$k8s$api$core$v1$GlusterfsVolumeSource;
        hostPath?: Schemas.io$k8s$api$core$v1$HostPathVolumeSource;
        iscsi?: Schemas.io$k8s$api$core$v1$ISCSIVolumeSource;
        /** Volume's name. Must be a DNS_LABEL and unique within the pod. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names */
        name: string;
        nfs?: Schemas.io$k8s$api$core$v1$NFSVolumeSource;
        persistentVolumeClaim?: Schemas.io$k8s$api$core$v1$PersistentVolumeClaimVolumeSource;
        photonPersistentDisk?: Schemas.io$k8s$api$core$v1$PhotonPersistentDiskVolumeSource;
        portworxVolume?: Schemas.io$k8s$api$core$v1$PortworxVolumeSource;
        projected?: Schemas.io$k8s$api$core$v1$ProjectedVolumeSource;
        quobyte?: Schemas.io$k8s$api$core$v1$QuobyteVolumeSource;
        rbd?: Schemas.io$k8s$api$core$v1$RBDVolumeSource;
        scaleIO?: Schemas.io$k8s$api$core$v1$ScaleIOVolumeSource;
        secret?: Schemas.io$k8s$api$core$v1$SecretVolumeSource;
        storageos?: Schemas.io$k8s$api$core$v1$StorageOSVolumeSource;
        vsphereVolume?: Schemas.io$k8s$api$core$v1$VsphereVirtualDiskVolumeSource;
    }
    /** volumeDevice describes a mapping of a raw block device within a container. */
    interface io$k8s$api$core$v1$VolumeDevice {
        /** devicePath is the path inside of the container that the device will be mapped to. */
        devicePath: string;
        /** name must match the name of a persistentVolumeClaim in the pod */
        name: string;
    }
    /** VolumeMount describes a mounting of a Volume within a container. */
    interface io$k8s$api$core$v1$VolumeMount {
        /** Path within the container at which the volume should be mounted.  Must not contain ':'. */
        mountPath: string;
        /** mountPropagation determines how mounts are propagated from the host to container and the other way around. When not set, MountPropagationNone is used. This field is beta in 1.10. */
        mountPropagation?: string;
        /** This must match the Name of a Volume. */
        name: string;
        /** Mounted read-only if true, read-write otherwise (false or unspecified). Defaults to false. */
        readOnly?: boolean;
        /** Path within the volume from which the container's volume should be mounted. Defaults to "" (volume's root). */
        subPath?: string;
        /** Expanded path within the volume from which the container's volume should be mounted. Behaves similarly to SubPath but environment variable references $(VAR_NAME) are expanded using the container's environment. Defaults to "" (volume's root). SubPathExpr and SubPath are mutually exclusive. */
        subPathExpr?: string;
    }
    /** VolumeNodeAffinity defines constraints that limit what nodes this volume can be accessed from. */
    interface io$k8s$api$core$v1$VolumeNodeAffinity {
        required?: Schemas.io$k8s$api$core$v1$NodeSelector;
    }
    /** Projection that may be projected along with other supported volume types */
    interface io$k8s$api$core$v1$VolumeProjection {
        configMap?: Schemas.io$k8s$api$core$v1$ConfigMapProjection;
        downwardAPI?: Schemas.io$k8s$api$core$v1$DownwardAPIProjection;
        secret?: Schemas.io$k8s$api$core$v1$SecretProjection;
        serviceAccountToken?: Schemas.io$k8s$api$core$v1$ServiceAccountTokenProjection;
    }
    /** Represents a vSphere volume resource. */
    interface io$k8s$api$core$v1$VsphereVirtualDiskVolumeSource {
        /** Filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. */
        fsType?: string;
        /** Storage Policy Based Management (SPBM) profile ID associated with the StoragePolicyName. */
        storagePolicyID?: string;
        /** Storage Policy Based Management (SPBM) profile name. */
        storagePolicyName?: string;
        /** Path that identifies vSphere volume vmdk */
        volumePath: string;
    }
    /** The weights of all of the matched WeightedPodAffinityTerm fields are added per-node to find the most preferred node(s) */
    interface io$k8s$api$core$v1$WeightedPodAffinityTerm {
        podAffinityTerm: Schemas.io$k8s$api$core$v1$PodAffinityTerm;
        /** weight associated with matching the corresponding podAffinityTerm, in the range 1-100. */
        weight: number;
    }
    /** WindowsSecurityContextOptions contain Windows-specific options and credentials. */
    interface io$k8s$api$core$v1$WindowsSecurityContextOptions {
        /** GMSACredentialSpec is where the GMSA admission webhook (https://github.com/kubernetes-sigs/windows-gmsa) inlines the contents of the GMSA credential spec named by the GMSACredentialSpecName field. */
        gmsaCredentialSpec?: string;
        /** GMSACredentialSpecName is the name of the GMSA credential spec to use. */
        gmsaCredentialSpecName?: string;
        /** HostProcess determines if a container should be run as a 'Host Process' container. This field is alpha-level and will only be honored by components that enable the WindowsHostProcessContainers feature flag. Setting this field without the feature flag will result in errors when validating the Pod. All of a Pod's containers must have the same effective HostProcess value (it is not allowed to have a mix of HostProcess containers and non-HostProcess containers).  In addition, if HostProcess is true then HostNetwork must also be set to true. */
        hostProcess?: boolean;
        /** The UserName in Windows to run the entrypoint of the container process. Defaults to the user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. */
        runAsUserName?: string;
    }
    /** Endpoint represents a single logical "backend" implementing a service. */
    interface io$k8s$api$discovery$v1$Endpoint {
        /** addresses of this endpoint. The contents of this field are interpreted according to the corresponding EndpointSlice addressType field. Consumers must handle different types of addresses in the context of their own capabilities. This must contain at least one address but no more than 100. */
        addresses: string[];
        conditions?: Schemas.io$k8s$api$discovery$v1$EndpointConditions;
        /** deprecatedTopology contains topology information part of the v1beta1 API. This field is deprecated, and will be removed when the v1beta1 API is removed (no sooner than kubernetes v1.24).  While this field can hold values, it is not writable through the v1 API, and any attempts to write to it will be silently ignored. Topology information can be found in the zone and nodeName fields instead. */
        deprecatedTopology?: {
            [key: string]: string;
        };
        hints?: Schemas.io$k8s$api$discovery$v1$EndpointHints;
        /** hostname of this endpoint. This field may be used by consumers of endpoints to distinguish endpoints from each other (e.g. in DNS names). Multiple endpoints which use the same hostname should be considered fungible (e.g. multiple A values in DNS). Must be lowercase and pass DNS Label (RFC 1123) validation. */
        hostname?: string;
        /** nodeName represents the name of the Node hosting this endpoint. This can be used to determine endpoints local to a Node. This field can be enabled with the EndpointSliceNodeName feature gate. */
        nodeName?: string;
        targetRef?: Schemas.io$k8s$api$core$v1$ObjectReference;
        /** zone is the name of the Zone this endpoint exists in. */
        zone?: string;
    }
    /** EndpointConditions represents the current condition of an endpoint. */
    interface io$k8s$api$discovery$v1$EndpointConditions {
        /** ready indicates that this endpoint is prepared to receive traffic, according to whatever system is managing the endpoint. A nil value indicates an unknown state. In most cases consumers should interpret this unknown state as ready. For compatibility reasons, ready should never be "true" for terminating endpoints. */
        ready?: boolean;
        /** serving is identical to ready except that it is set regardless of the terminating state of endpoints. This condition should be set to true for a ready endpoint that is terminating. If nil, consumers should defer to the ready condition. This field can be enabled with the EndpointSliceTerminatingCondition feature gate. */
        serving?: boolean;
        /** terminating indicates that this endpoint is terminating. A nil value indicates an unknown state. Consumers should interpret this unknown state to mean that the endpoint is not terminating. This field can be enabled with the EndpointSliceTerminatingCondition feature gate. */
        terminating?: boolean;
    }
    /** EndpointHints provides hints describing how an endpoint should be consumed. */
    interface io$k8s$api$discovery$v1$EndpointHints {
        /** forZones indicates the zone(s) this endpoint should be consumed by to enable topology aware routing. */
        forZones?: Schemas.io$k8s$api$discovery$v1$ForZone[];
    }
    /** EndpointPort represents a Port used by an EndpointSlice */
    interface io$k8s$api$discovery$v1$EndpointPort {
        /** The application protocol for this port. This field follows standard Kubernetes label syntax. Un-prefixed names are reserved for IANA standard service names (as per RFC-6335 and http://www.iana.org/assignments/service-names). Non-standard protocols should use prefixed names such as mycompany.com/my-custom-protocol. */
        appProtocol?: string;
        /** The name of this port. All ports in an EndpointSlice must have a unique name. If the EndpointSlice is dervied from a Kubernetes service, this corresponds to the Service.ports[].name. Name must either be an empty string or pass DNS_LABEL validation: * must be no more than 63 characters long. * must consist of lower case alphanumeric characters or '-'. * must start and end with an alphanumeric character. Default is empty string. */
        name?: string;
        /** The port number of the endpoint. If this is not specified, ports are not restricted and must be interpreted in the context of the specific consumer. */
        port?: number;
        /** The IP protocol for this port. Must be UDP, TCP, or SCTP. Default is TCP. */
        protocol?: string;
    }
    /** EndpointSlice represents a subset of the endpoints that implement a service. For a given service there may be multiple EndpointSlice objects, selected by labels, which must be joined to produce the full set of endpoints. */
    interface io$k8s$api$discovery$v1$EndpointSlice {
        /**
         * addressType specifies the type of address carried by this EndpointSlice. All addresses in this slice must be the same type. This field is immutable after creation. The following address types are currently supported: * IPv4: Represents an IPv4 Address. * IPv6: Represents an IPv6 Address. * FQDN: Represents a Fully Qualified Domain Name.
         *
         */
        addressType: string;
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** endpoints is a list of unique endpoints in this slice. Each slice may include a maximum of 1000 endpoints. */
        endpoints: Schemas.io$k8s$api$discovery$v1$Endpoint[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** ports specifies the list of network ports exposed by each endpoint in this slice. Each port must have a unique name. When ports is empty, it indicates that there are no defined ports. When a port is defined with a nil port value, it indicates "all ports". Each slice may include a maximum of 100 ports. */
        ports?: Schemas.io$k8s$api$discovery$v1$EndpointPort[];
    }
    /** EndpointSliceList represents a list of endpoint slices */
    interface io$k8s$api$discovery$v1$EndpointSliceList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of endpoint slices */
        items: Schemas.io$k8s$api$discovery$v1$EndpointSlice[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ForZone provides information about which zones should consume this endpoint. */
    interface io$k8s$api$discovery$v1$ForZone {
        /** name represents the name of the zone. */
        name: string;
    }
    /** Endpoint represents a single logical "backend" implementing a service. */
    interface io$k8s$api$discovery$v1beta1$Endpoint {
        /** addresses of this endpoint. The contents of this field are interpreted according to the corresponding EndpointSlice addressType field. Consumers must handle different types of addresses in the context of their own capabilities. This must contain at least one address but no more than 100. */
        addresses: string[];
        conditions?: Schemas.io$k8s$api$discovery$v1beta1$EndpointConditions;
        hints?: Schemas.io$k8s$api$discovery$v1beta1$EndpointHints;
        /** hostname of this endpoint. This field may be used by consumers of endpoints to distinguish endpoints from each other (e.g. in DNS names). Multiple endpoints which use the same hostname should be considered fungible (e.g. multiple A values in DNS). Must be lowercase and pass DNS Label (RFC 1123) validation. */
        hostname?: string;
        /** nodeName represents the name of the Node hosting this endpoint. This can be used to determine endpoints local to a Node. This field can be enabled with the EndpointSliceNodeName feature gate. */
        nodeName?: string;
        targetRef?: Schemas.io$k8s$api$core$v1$ObjectReference;
        /**
         * topology contains arbitrary topology information associated with the endpoint. These key/value pairs must conform with the label format. https://kubernetes.io/docs/concepts/overview/working-with-objects/labels Topology may include a maximum of 16 key/value pairs. This includes, but is not limited to the following well known keys: * kubernetes.io/hostname: the value indicates the hostname of the node
         *   where the endpoint is located. This should match the corresponding
         *   node label.
         * * topology.kubernetes.io/zone: the value indicates the zone where the
         *   endpoint is located. This should match the corresponding node label.
         * * topology.kubernetes.io/region: the value indicates the region where the
         *   endpoint is located. This should match the corresponding node label.
         * This field is deprecated and will be removed in future api versions.
         */
        topology?: {
            [key: string]: string;
        };
    }
    /** EndpointConditions represents the current condition of an endpoint. */
    interface io$k8s$api$discovery$v1beta1$EndpointConditions {
        /** ready indicates that this endpoint is prepared to receive traffic, according to whatever system is managing the endpoint. A nil value indicates an unknown state. In most cases consumers should interpret this unknown state as ready. For compatibility reasons, ready should never be "true" for terminating endpoints. */
        ready?: boolean;
        /** serving is identical to ready except that it is set regardless of the terminating state of endpoints. This condition should be set to true for a ready endpoint that is terminating. If nil, consumers should defer to the ready condition. This field can be enabled with the EndpointSliceTerminatingCondition feature gate. */
        serving?: boolean;
        /** terminating indicates that this endpoint is terminating. A nil value indicates an unknown state. Consumers should interpret this unknown state to mean that the endpoint is not terminating. This field can be enabled with the EndpointSliceTerminatingCondition feature gate. */
        terminating?: boolean;
    }
    /** EndpointHints provides hints describing how an endpoint should be consumed. */
    interface io$k8s$api$discovery$v1beta1$EndpointHints {
        /** forZones indicates the zone(s) this endpoint should be consumed by to enable topology aware routing. May contain a maximum of 8 entries. */
        forZones?: Schemas.io$k8s$api$discovery$v1beta1$ForZone[];
    }
    /** EndpointPort represents a Port used by an EndpointSlice */
    interface io$k8s$api$discovery$v1beta1$EndpointPort {
        /** The application protocol for this port. This field follows standard Kubernetes label syntax. Un-prefixed names are reserved for IANA standard service names (as per RFC-6335 and http://www.iana.org/assignments/service-names). Non-standard protocols should use prefixed names such as mycompany.com/my-custom-protocol. */
        appProtocol?: string;
        /** The name of this port. All ports in an EndpointSlice must have a unique name. If the EndpointSlice is dervied from a Kubernetes service, this corresponds to the Service.ports[].name. Name must either be an empty string or pass DNS_LABEL validation: * must be no more than 63 characters long. * must consist of lower case alphanumeric characters or '-'. * must start and end with an alphanumeric character. Default is empty string. */
        name?: string;
        /** The port number of the endpoint. If this is not specified, ports are not restricted and must be interpreted in the context of the specific consumer. */
        port?: number;
        /** The IP protocol for this port. Must be UDP, TCP, or SCTP. Default is TCP. */
        protocol?: string;
    }
    /** EndpointSlice represents a subset of the endpoints that implement a service. For a given service there may be multiple EndpointSlice objects, selected by labels, which must be joined to produce the full set of endpoints. */
    interface io$k8s$api$discovery$v1beta1$EndpointSlice {
        /** addressType specifies the type of address carried by this EndpointSlice. All addresses in this slice must be the same type. This field is immutable after creation. The following address types are currently supported: * IPv4: Represents an IPv4 Address. * IPv6: Represents an IPv6 Address. * FQDN: Represents a Fully Qualified Domain Name. */
        addressType: string;
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** endpoints is a list of unique endpoints in this slice. Each slice may include a maximum of 1000 endpoints. */
        endpoints: Schemas.io$k8s$api$discovery$v1beta1$Endpoint[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** ports specifies the list of network ports exposed by each endpoint in this slice. Each port must have a unique name. When ports is empty, it indicates that there are no defined ports. When a port is defined with a nil port value, it indicates "all ports". Each slice may include a maximum of 100 ports. */
        ports?: Schemas.io$k8s$api$discovery$v1beta1$EndpointPort[];
    }
    /** EndpointSliceList represents a list of endpoint slices */
    interface io$k8s$api$discovery$v1beta1$EndpointSliceList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of endpoint slices */
        items: Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ForZone provides information about which zones should consume this endpoint. */
    interface io$k8s$api$discovery$v1beta1$ForZone {
        /** name represents the name of the zone. */
        name: string;
    }
    /** Event is a report of an event somewhere in the cluster. It generally denotes some state change in the system. Events have a limited retention time and triggers and messages may evolve with time.  Event consumers should not rely on the timing of an event with a given Reason reflecting a consistent underlying trigger, or the continued existence of events with that Reason.  Events should be treated as informative, best-effort, supplemental data. */
    interface io$k8s$api$events$v1$Event {
        /** action is what action was taken/failed regarding to the regarding object. It is machine-readable. This field cannot be empty for new Events and it can have at most 128 characters. */
        action?: string;
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** deprecatedCount is the deprecated field assuring backward compatibility with core.v1 Event type. */
        deprecatedCount?: number;
        deprecatedFirstTimestamp?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        deprecatedLastTimestamp?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        deprecatedSource?: Schemas.io$k8s$api$core$v1$EventSource;
        eventTime: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$MicroTime;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** note is a human-readable description of the status of this operation. Maximal length of the note is 1kB, but libraries should be prepared to handle values up to 64kB. */
        note?: string;
        /** reason is why the action was taken. It is human-readable. This field cannot be empty for new Events and it can have at most 128 characters. */
        reason?: string;
        regarding?: Schemas.io$k8s$api$core$v1$ObjectReference;
        related?: Schemas.io$k8s$api$core$v1$ObjectReference;
        /** reportingController is the name of the controller that emitted this Event, e.g. `kubernetes.io/kubelet`. This field cannot be empty for new Events. */
        reportingController?: string;
        /** reportingInstance is the ID of the controller instance, e.g. `kubelet-xyzf`. This field cannot be empty for new Events and it can have at most 128 characters. */
        reportingInstance?: string;
        series?: Schemas.io$k8s$api$events$v1$EventSeries;
        /** type is the type of this event (Normal, Warning), new types could be added in the future. It is machine-readable. This field cannot be empty for new Events. */
        type?: string;
    }
    /** EventList is a list of Event objects. */
    interface io$k8s$api$events$v1$EventList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is a list of schema objects. */
        items: Schemas.io$k8s$api$events$v1$Event[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** EventSeries contain information on series of events, i.e. thing that was/is happening continuously for some time. How often to update the EventSeries is up to the event reporters. The default event reporter in "k8s.io/client-go/tools/events/event_broadcaster.go" shows how this struct is updated on heartbeats and can guide customized reporter implementations. */
    interface io$k8s$api$events$v1$EventSeries {
        /** count is the number of occurrences in this series up to the last heartbeat time. */
        count: number;
        lastObservedTime: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$MicroTime;
    }
    /** Event is a report of an event somewhere in the cluster. It generally denotes some state change in the system. Events have a limited retention time and triggers and messages may evolve with time.  Event consumers should not rely on the timing of an event with a given Reason reflecting a consistent underlying trigger, or the continued existence of events with that Reason.  Events should be treated as informative, best-effort, supplemental data. */
    interface io$k8s$api$events$v1beta1$Event {
        /** action is what action was taken/failed regarding to the regarding object. It is machine-readable. This field can have at most 128 characters. */
        action?: string;
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** deprecatedCount is the deprecated field assuring backward compatibility with core.v1 Event type. */
        deprecatedCount?: number;
        deprecatedFirstTimestamp?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        deprecatedLastTimestamp?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        deprecatedSource?: Schemas.io$k8s$api$core$v1$EventSource;
        eventTime: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$MicroTime;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** note is a human-readable description of the status of this operation. Maximal length of the note is 1kB, but libraries should be prepared to handle values up to 64kB. */
        note?: string;
        /** reason is why the action was taken. It is human-readable. This field can have at most 128 characters. */
        reason?: string;
        regarding?: Schemas.io$k8s$api$core$v1$ObjectReference;
        related?: Schemas.io$k8s$api$core$v1$ObjectReference;
        /** reportingController is the name of the controller that emitted this Event, e.g. `kubernetes.io/kubelet`. This field cannot be empty for new Events. */
        reportingController?: string;
        /** reportingInstance is the ID of the controller instance, e.g. `kubelet-xyzf`. This field cannot be empty for new Events and it can have at most 128 characters. */
        reportingInstance?: string;
        series?: Schemas.io$k8s$api$events$v1beta1$EventSeries;
        /** type is the type of this event (Normal, Warning), new types could be added in the future. It is machine-readable. */
        type?: string;
    }
    /** EventList is a list of Event objects. */
    interface io$k8s$api$events$v1beta1$EventList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is a list of schema objects. */
        items: Schemas.io$k8s$api$events$v1beta1$Event[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** EventSeries contain information on series of events, i.e. thing that was/is happening continuously for some time. */
    interface io$k8s$api$events$v1beta1$EventSeries {
        /** count is the number of occurrences in this series up to the last heartbeat time. */
        count: number;
        lastObservedTime: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$MicroTime;
    }
    /** FlowDistinguisherMethod specifies the method of a flow distinguisher. */
    interface io$k8s$api$flowcontrol$v1beta1$FlowDistinguisherMethod {
        /** `type` is the type of flow distinguisher method The supported types are "ByUser" and "ByNamespace". Required. */
        type: string;
    }
    /** FlowSchema defines the schema of a group of flows. Note that a flow is made up of a set of inbound API requests with similar attributes and is identified by a pair of strings: the name of the FlowSchema and a "flow distinguisher". */
    interface io$k8s$api$flowcontrol$v1beta1$FlowSchema {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchemaSpec;
        status?: Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchemaStatus;
    }
    /** FlowSchemaCondition describes conditions for a FlowSchema. */
    interface io$k8s$api$flowcontrol$v1beta1$FlowSchemaCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** `message` is a human-readable message indicating details about last transition. */
        message?: string;
        /** `reason` is a unique, one-word, CamelCase reason for the condition's last transition. */
        reason?: string;
        /** `status` is the status of the condition. Can be True, False, Unknown. Required. */
        status?: string;
        /** `type` is the type of the condition. Required. */
        type?: string;
    }
    /** FlowSchemaList is a list of FlowSchema objects. */
    interface io$k8s$api$flowcontrol$v1beta1$FlowSchemaList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** `items` is a list of FlowSchemas. */
        items: Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** FlowSchemaSpec describes how the FlowSchema's specification looks like. */
    interface io$k8s$api$flowcontrol$v1beta1$FlowSchemaSpec {
        distinguisherMethod?: Schemas.io$k8s$api$flowcontrol$v1beta1$FlowDistinguisherMethod;
        /** `matchingPrecedence` is used to choose among the FlowSchemas that match a given request. The chosen FlowSchema is among those with the numerically lowest (which we take to be logically highest) MatchingPrecedence.  Each MatchingPrecedence value must be ranged in [1,10000]. Note that if the precedence is not specified, it will be set to 1000 as default. */
        matchingPrecedence?: number;
        priorityLevelConfiguration: Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfigurationReference;
        /** `rules` describes which requests will match this flow schema. This FlowSchema matches a request if and only if at least one member of rules matches the request. if it is an empty slice, there will be no requests matching the FlowSchema. */
        rules?: Schemas.io$k8s$api$flowcontrol$v1beta1$PolicyRulesWithSubjects[];
    }
    /** FlowSchemaStatus represents the current state of a FlowSchema. */
    interface io$k8s$api$flowcontrol$v1beta1$FlowSchemaStatus {
        /** `conditions` is a list of the current states of FlowSchema. */
        conditions?: Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchemaCondition[];
    }
    /** GroupSubject holds detailed information for group-kind subject. */
    interface io$k8s$api$flowcontrol$v1beta1$GroupSubject {
        /** name is the user group that matches, or "*" to match all user groups. See https://github.com/kubernetes/apiserver/blob/master/pkg/authentication/user/user.go for some well-known group names. Required. */
        name: string;
    }
    /** LimitResponse defines how to handle requests that can not be executed right now. */
    interface io$k8s$api$flowcontrol$v1beta1$LimitResponse {
        queuing?: Schemas.io$k8s$api$flowcontrol$v1beta1$QueuingConfiguration;
        /** `type` is "Queue" or "Reject". "Queue" means that requests that can not be executed upon arrival are held in a queue until they can be executed or a queuing limit is reached. "Reject" means that requests that can not be executed upon arrival are rejected. Required. */
        type: string;
    }
    /**
     * LimitedPriorityLevelConfiguration specifies how to handle requests that are subject to limits. It addresses two issues:
     *  * How are requests for this priority level limited?
     *  * What should be done with requests that exceed the limit?
     */
    interface io$k8s$api$flowcontrol$v1beta1$LimitedPriorityLevelConfiguration {
        /**
         * `assuredConcurrencyShares` (ACS) configures the execution limit, which is a limit on the number of requests of this priority level that may be exeucting at a given time.  ACS must be a positive number. The server's concurrency limit (SCL) is divided among the concurrency-controlled priority levels in proportion to their assured concurrency shares. This produces the assured concurrency value (ACV) --- the number of requests that may be executing at a time --- for each such priority level:
         *
         *             ACV(l) = ceil( SCL * ACS(l) / ( sum[priority levels k] ACS(k) ) )
         *
         * bigger numbers of ACS mean more reserved concurrent requests (at the expense of every other PL). This field has a default value of 30.
         */
        assuredConcurrencyShares?: number;
        limitResponse?: Schemas.io$k8s$api$flowcontrol$v1beta1$LimitResponse;
    }
    /** NonResourcePolicyRule is a predicate that matches non-resource requests according to their verb and the target non-resource URL. A NonResourcePolicyRule matches a request if and only if both (a) at least one member of verbs matches the request and (b) at least one member of nonResourceURLs matches the request. */
    interface io$k8s$api$flowcontrol$v1beta1$NonResourcePolicyRule {
        /**
         * `nonResourceURLs` is a set of url prefixes that a user should have access to and may not be empty. For example:
         *   - "/healthz" is legal
         *   - "/hea*" is illegal
         *   - "/hea" is legal but matches nothing
         *   - "/hea/\\*" also matches nothing
         *   - "/healthz/*" matches all per-component health checks.
         * "*" matches all non-resource urls. if it is present, it must be the only entry. Required.
         */
        nonResourceURLs: string[];
        /** `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs. If it is present, it must be the only entry. Required. */
        verbs: string[];
    }
    /** PolicyRulesWithSubjects prescribes a test that applies to a request to an apiserver. The test considers the subject making the request, the verb being requested, and the resource to be acted upon. This PolicyRulesWithSubjects matches a request if and only if both (a) at least one member of subjects matches the request and (b) at least one member of resourceRules or nonResourceRules matches the request. */
    interface io$k8s$api$flowcontrol$v1beta1$PolicyRulesWithSubjects {
        /** `nonResourceRules` is a list of NonResourcePolicyRules that identify matching requests according to their verb and the target non-resource URL. */
        nonResourceRules?: Schemas.io$k8s$api$flowcontrol$v1beta1$NonResourcePolicyRule[];
        /** `resourceRules` is a slice of ResourcePolicyRules that identify matching requests according to their verb and the target resource. At least one of `resourceRules` and `nonResourceRules` has to be non-empty. */
        resourceRules?: Schemas.io$k8s$api$flowcontrol$v1beta1$ResourcePolicyRule[];
        /** subjects is the list of normal user, serviceaccount, or group that this rule cares about. There must be at least one member in this slice. A slice that includes both the system:authenticated and system:unauthenticated user groups matches every request. Required. */
        subjects: Schemas.io$k8s$api$flowcontrol$v1beta1$Subject[];
    }
    /** PriorityLevelConfiguration represents the configuration of a priority level. */
    interface io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfigurationSpec;
        status?: Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfigurationStatus;
    }
    /** PriorityLevelConfigurationCondition defines the condition of priority level. */
    interface io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfigurationCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** `message` is a human-readable message indicating details about last transition. */
        message?: string;
        /** `reason` is a unique, one-word, CamelCase reason for the condition's last transition. */
        reason?: string;
        /** `status` is the status of the condition. Can be True, False, Unknown. Required. */
        status?: string;
        /** `type` is the type of the condition. Required. */
        type?: string;
    }
    /** PriorityLevelConfigurationList is a list of PriorityLevelConfiguration objects. */
    interface io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfigurationList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** `items` is a list of request-priorities. */
        items: Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** PriorityLevelConfigurationReference contains information that points to the "request-priority" being used. */
    interface io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfigurationReference {
        /** `name` is the name of the priority level configuration being referenced Required. */
        name: string;
    }
    /** PriorityLevelConfigurationSpec specifies the configuration of a priority level. */
    interface io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfigurationSpec {
        limited?: Schemas.io$k8s$api$flowcontrol$v1beta1$LimitedPriorityLevelConfiguration;
        /** `type` indicates whether this priority level is subject to limitation on request execution.  A value of `"Exempt"` means that requests of this priority level are not subject to a limit (and thus are never queued) and do not detract from the capacity made available to other priority levels.  A value of `"Limited"` means that (a) requests of this priority level _are_ subject to limits and (b) some of the server's limited capacity is made available exclusively to this priority level. Required. */
        type: string;
    }
    /** PriorityLevelConfigurationStatus represents the current state of a "request-priority". */
    interface io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfigurationStatus {
        /** `conditions` is the current state of "request-priority". */
        conditions?: Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfigurationCondition[];
    }
    /** QueuingConfiguration holds the configuration parameters for queuing */
    interface io$k8s$api$flowcontrol$v1beta1$QueuingConfiguration {
        /** `handSize` is a small positive number that configures the shuffle sharding of requests into queues.  When enqueuing a request at this priority level the request's flow identifier (a string pair) is hashed and the hash value is used to shuffle the list of queues and deal a hand of the size specified here.  The request is put into one of the shortest queues in that hand. `handSize` must be no larger than `queues`, and should be significantly smaller (so that a few heavy flows do not saturate most of the queues).  See the user-facing documentation for more extensive guidance on setting this field.  This field has a default value of 8. */
        handSize?: number;
        /** `queueLengthLimit` is the maximum number of requests allowed to be waiting in a given queue of this priority level at a time; excess requests are rejected.  This value must be positive.  If not specified, it will be defaulted to 50. */
        queueLengthLimit?: number;
        /** `queues` is the number of queues for this priority level. The queues exist independently at each apiserver. The value must be positive.  Setting it to 1 effectively precludes shufflesharding and thus makes the distinguisher method of associated flow schemas irrelevant.  This field has a default value of 64. */
        queues?: number;
    }
    /** ResourcePolicyRule is a predicate that matches some resource requests, testing the request's verb and the target resource. A ResourcePolicyRule matches a resource request if and only if: (a) at least one member of verbs matches the request, (b) at least one member of apiGroups matches the request, (c) at least one member of resources matches the request, and (d) either (d1) the request does not specify a namespace (i.e., `Namespace==""`) and clusterScope is true or (d2) the request specifies a namespace and least one member of namespaces matches the request's namespace. */
    interface io$k8s$api$flowcontrol$v1beta1$ResourcePolicyRule {
        /** `apiGroups` is a list of matching API groups and may not be empty. "*" matches all API groups and, if present, must be the only entry. Required. */
        apiGroups: string[];
        /** `clusterScope` indicates whether to match requests that do not specify a namespace (which happens either because the resource is not namespaced or the request targets all namespaces). If this field is omitted or false then the `namespaces` field must contain a non-empty list. */
        clusterScope?: boolean;
        /** `namespaces` is a list of target namespaces that restricts matches.  A request that specifies a target namespace matches only if either (a) this list contains that target namespace or (b) this list contains "*".  Note that "*" matches any specified namespace but does not match a request that _does not specify_ a namespace (see the `clusterScope` field for that). This list may be empty, but only if `clusterScope` is true. */
        namespaces?: string[];
        /** `resources` is a list of matching resources (i.e., lowercase and plural) with, if desired, subresource.  For example, [ "services", "nodes/status" ].  This list may not be empty. "*" matches all resources and, if present, must be the only entry. Required. */
        resources: string[];
        /** `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs and, if present, must be the only entry. Required. */
        verbs: string[];
    }
    /** ServiceAccountSubject holds detailed information for service-account-kind subject. */
    interface io$k8s$api$flowcontrol$v1beta1$ServiceAccountSubject {
        /** `name` is the name of matching ServiceAccount objects, or "*" to match regardless of name. Required. */
        name: string;
        /** `namespace` is the namespace of matching ServiceAccount objects. Required. */
        namespace: string;
    }
    /** Subject matches the originator of a request, as identified by the request authentication system. There are three ways of matching an originator; by user, group, or service account. */
    interface io$k8s$api$flowcontrol$v1beta1$Subject {
        group?: Schemas.io$k8s$api$flowcontrol$v1beta1$GroupSubject;
        /** `kind` indicates which one of the other fields is non-empty. Required */
        kind: string;
        serviceAccount?: Schemas.io$k8s$api$flowcontrol$v1beta1$ServiceAccountSubject;
        user?: Schemas.io$k8s$api$flowcontrol$v1beta1$UserSubject;
    }
    /** UserSubject holds detailed information for user-kind subject. */
    interface io$k8s$api$flowcontrol$v1beta1$UserSubject {
        /** `name` is the username that matches, or "*" to match all usernames. Required. */
        name: string;
    }
    /** FlowDistinguisherMethod specifies the method of a flow distinguisher. */
    interface io$k8s$api$flowcontrol$v1beta2$FlowDistinguisherMethod {
        /** `type` is the type of flow distinguisher method The supported types are "ByUser" and "ByNamespace". Required. */
        type: string;
    }
    /** FlowSchema defines the schema of a group of flows. Note that a flow is made up of a set of inbound API requests with similar attributes and is identified by a pair of strings: the name of the FlowSchema and a "flow distinguisher". */
    interface io$k8s$api$flowcontrol$v1beta2$FlowSchema {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchemaSpec;
        status?: Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchemaStatus;
    }
    /** FlowSchemaCondition describes conditions for a FlowSchema. */
    interface io$k8s$api$flowcontrol$v1beta2$FlowSchemaCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** `message` is a human-readable message indicating details about last transition. */
        message?: string;
        /** `reason` is a unique, one-word, CamelCase reason for the condition's last transition. */
        reason?: string;
        /** `status` is the status of the condition. Can be True, False, Unknown. Required. */
        status?: string;
        /** `type` is the type of the condition. Required. */
        type?: string;
    }
    /** FlowSchemaList is a list of FlowSchema objects. */
    interface io$k8s$api$flowcontrol$v1beta2$FlowSchemaList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** `items` is a list of FlowSchemas. */
        items: Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** FlowSchemaSpec describes how the FlowSchema's specification looks like. */
    interface io$k8s$api$flowcontrol$v1beta2$FlowSchemaSpec {
        distinguisherMethod?: Schemas.io$k8s$api$flowcontrol$v1beta2$FlowDistinguisherMethod;
        /** `matchingPrecedence` is used to choose among the FlowSchemas that match a given request. The chosen FlowSchema is among those with the numerically lowest (which we take to be logically highest) MatchingPrecedence.  Each MatchingPrecedence value must be ranged in [1,10000]. Note that if the precedence is not specified, it will be set to 1000 as default. */
        matchingPrecedence?: number;
        priorityLevelConfiguration: Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationReference;
        /** `rules` describes which requests will match this flow schema. This FlowSchema matches a request if and only if at least one member of rules matches the request. if it is an empty slice, there will be no requests matching the FlowSchema. */
        rules?: Schemas.io$k8s$api$flowcontrol$v1beta2$PolicyRulesWithSubjects[];
    }
    /** FlowSchemaStatus represents the current state of a FlowSchema. */
    interface io$k8s$api$flowcontrol$v1beta2$FlowSchemaStatus {
        /** `conditions` is a list of the current states of FlowSchema. */
        conditions?: Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchemaCondition[];
    }
    /** GroupSubject holds detailed information for group-kind subject. */
    interface io$k8s$api$flowcontrol$v1beta2$GroupSubject {
        /** name is the user group that matches, or "*" to match all user groups. See https://github.com/kubernetes/apiserver/blob/master/pkg/authentication/user/user.go for some well-known group names. Required. */
        name: string;
    }
    /** LimitResponse defines how to handle requests that can not be executed right now. */
    interface io$k8s$api$flowcontrol$v1beta2$LimitResponse {
        queuing?: Schemas.io$k8s$api$flowcontrol$v1beta2$QueuingConfiguration;
        /** `type` is "Queue" or "Reject". "Queue" means that requests that can not be executed upon arrival are held in a queue until they can be executed or a queuing limit is reached. "Reject" means that requests that can not be executed upon arrival are rejected. Required. */
        type: string;
    }
    /**
     * LimitedPriorityLevelConfiguration specifies how to handle requests that are subject to limits. It addresses two issues:
     *  * How are requests for this priority level limited?
     *  * What should be done with requests that exceed the limit?
     */
    interface io$k8s$api$flowcontrol$v1beta2$LimitedPriorityLevelConfiguration {
        /**
         * `assuredConcurrencyShares` (ACS) configures the execution limit, which is a limit on the number of requests of this priority level that may be exeucting at a given time.  ACS must be a positive number. The server's concurrency limit (SCL) is divided among the concurrency-controlled priority levels in proportion to their assured concurrency shares. This produces the assured concurrency value (ACV) --- the number of requests that may be executing at a time --- for each such priority level:
         *
         *             ACV(l) = ceil( SCL * ACS(l) / ( sum[priority levels k] ACS(k) ) )
         *
         * bigger numbers of ACS mean more reserved concurrent requests (at the expense of every other PL). This field has a default value of 30.
         */
        assuredConcurrencyShares?: number;
        limitResponse?: Schemas.io$k8s$api$flowcontrol$v1beta2$LimitResponse;
    }
    /** NonResourcePolicyRule is a predicate that matches non-resource requests according to their verb and the target non-resource URL. A NonResourcePolicyRule matches a request if and only if both (a) at least one member of verbs matches the request and (b) at least one member of nonResourceURLs matches the request. */
    interface io$k8s$api$flowcontrol$v1beta2$NonResourcePolicyRule {
        /**
         * `nonResourceURLs` is a set of url prefixes that a user should have access to and may not be empty. For example:
         *   - "/healthz" is legal
         *   - "/hea*" is illegal
         *   - "/hea" is legal but matches nothing
         *   - "/hea/\\*" also matches nothing
         *   - "/healthz/*" matches all per-component health checks.
         * "*" matches all non-resource urls. if it is present, it must be the only entry. Required.
         */
        nonResourceURLs: string[];
        /** `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs. If it is present, it must be the only entry. Required. */
        verbs: string[];
    }
    /** PolicyRulesWithSubjects prescribes a test that applies to a request to an apiserver. The test considers the subject making the request, the verb being requested, and the resource to be acted upon. This PolicyRulesWithSubjects matches a request if and only if both (a) at least one member of subjects matches the request and (b) at least one member of resourceRules or nonResourceRules matches the request. */
    interface io$k8s$api$flowcontrol$v1beta2$PolicyRulesWithSubjects {
        /** `nonResourceRules` is a list of NonResourcePolicyRules that identify matching requests according to their verb and the target non-resource URL. */
        nonResourceRules?: Schemas.io$k8s$api$flowcontrol$v1beta2$NonResourcePolicyRule[];
        /** `resourceRules` is a slice of ResourcePolicyRules that identify matching requests according to their verb and the target resource. At least one of `resourceRules` and `nonResourceRules` has to be non-empty. */
        resourceRules?: Schemas.io$k8s$api$flowcontrol$v1beta2$ResourcePolicyRule[];
        /** subjects is the list of normal user, serviceaccount, or group that this rule cares about. There must be at least one member in this slice. A slice that includes both the system:authenticated and system:unauthenticated user groups matches every request. Required. */
        subjects: Schemas.io$k8s$api$flowcontrol$v1beta2$Subject[];
    }
    /** PriorityLevelConfiguration represents the configuration of a priority level. */
    interface io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationSpec;
        status?: Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationStatus;
    }
    /** PriorityLevelConfigurationCondition defines the condition of priority level. */
    interface io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** `message` is a human-readable message indicating details about last transition. */
        message?: string;
        /** `reason` is a unique, one-word, CamelCase reason for the condition's last transition. */
        reason?: string;
        /** `status` is the status of the condition. Can be True, False, Unknown. Required. */
        status?: string;
        /** `type` is the type of the condition. Required. */
        type?: string;
    }
    /** PriorityLevelConfigurationList is a list of PriorityLevelConfiguration objects. */
    interface io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** `items` is a list of request-priorities. */
        items: Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** PriorityLevelConfigurationReference contains information that points to the "request-priority" being used. */
    interface io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationReference {
        /** `name` is the name of the priority level configuration being referenced Required. */
        name: string;
    }
    /** PriorityLevelConfigurationSpec specifies the configuration of a priority level. */
    interface io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationSpec {
        limited?: Schemas.io$k8s$api$flowcontrol$v1beta2$LimitedPriorityLevelConfiguration;
        /** `type` indicates whether this priority level is subject to limitation on request execution.  A value of `"Exempt"` means that requests of this priority level are not subject to a limit (and thus are never queued) and do not detract from the capacity made available to other priority levels.  A value of `"Limited"` means that (a) requests of this priority level _are_ subject to limits and (b) some of the server's limited capacity is made available exclusively to this priority level. Required. */
        type: string;
    }
    /** PriorityLevelConfigurationStatus represents the current state of a "request-priority". */
    interface io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationStatus {
        /** `conditions` is the current state of "request-priority". */
        conditions?: Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationCondition[];
    }
    /** QueuingConfiguration holds the configuration parameters for queuing */
    interface io$k8s$api$flowcontrol$v1beta2$QueuingConfiguration {
        /** `handSize` is a small positive number that configures the shuffle sharding of requests into queues.  When enqueuing a request at this priority level the request's flow identifier (a string pair) is hashed and the hash value is used to shuffle the list of queues and deal a hand of the size specified here.  The request is put into one of the shortest queues in that hand. `handSize` must be no larger than `queues`, and should be significantly smaller (so that a few heavy flows do not saturate most of the queues).  See the user-facing documentation for more extensive guidance on setting this field.  This field has a default value of 8. */
        handSize?: number;
        /** `queueLengthLimit` is the maximum number of requests allowed to be waiting in a given queue of this priority level at a time; excess requests are rejected.  This value must be positive.  If not specified, it will be defaulted to 50. */
        queueLengthLimit?: number;
        /** `queues` is the number of queues for this priority level. The queues exist independently at each apiserver. The value must be positive.  Setting it to 1 effectively precludes shufflesharding and thus makes the distinguisher method of associated flow schemas irrelevant.  This field has a default value of 64. */
        queues?: number;
    }
    /** ResourcePolicyRule is a predicate that matches some resource requests, testing the request's verb and the target resource. A ResourcePolicyRule matches a resource request if and only if: (a) at least one member of verbs matches the request, (b) at least one member of apiGroups matches the request, (c) at least one member of resources matches the request, and (d) either (d1) the request does not specify a namespace (i.e., `Namespace==""`) and clusterScope is true or (d2) the request specifies a namespace and least one member of namespaces matches the request's namespace. */
    interface io$k8s$api$flowcontrol$v1beta2$ResourcePolicyRule {
        /** `apiGroups` is a list of matching API groups and may not be empty. "*" matches all API groups and, if present, must be the only entry. Required. */
        apiGroups: string[];
        /** `clusterScope` indicates whether to match requests that do not specify a namespace (which happens either because the resource is not namespaced or the request targets all namespaces). If this field is omitted or false then the `namespaces` field must contain a non-empty list. */
        clusterScope?: boolean;
        /** `namespaces` is a list of target namespaces that restricts matches.  A request that specifies a target namespace matches only if either (a) this list contains that target namespace or (b) this list contains "*".  Note that "*" matches any specified namespace but does not match a request that _does not specify_ a namespace (see the `clusterScope` field for that). This list may be empty, but only if `clusterScope` is true. */
        namespaces?: string[];
        /** `resources` is a list of matching resources (i.e., lowercase and plural) with, if desired, subresource.  For example, [ "services", "nodes/status" ].  This list may not be empty. "*" matches all resources and, if present, must be the only entry. Required. */
        resources: string[];
        /** `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs and, if present, must be the only entry. Required. */
        verbs: string[];
    }
    /** ServiceAccountSubject holds detailed information for service-account-kind subject. */
    interface io$k8s$api$flowcontrol$v1beta2$ServiceAccountSubject {
        /** `name` is the name of matching ServiceAccount objects, or "*" to match regardless of name. Required. */
        name: string;
        /** `namespace` is the namespace of matching ServiceAccount objects. Required. */
        namespace: string;
    }
    /** Subject matches the originator of a request, as identified by the request authentication system. There are three ways of matching an originator; by user, group, or service account. */
    interface io$k8s$api$flowcontrol$v1beta2$Subject {
        group?: Schemas.io$k8s$api$flowcontrol$v1beta2$GroupSubject;
        /** `kind` indicates which one of the other fields is non-empty. Required */
        kind: string;
        serviceAccount?: Schemas.io$k8s$api$flowcontrol$v1beta2$ServiceAccountSubject;
        user?: Schemas.io$k8s$api$flowcontrol$v1beta2$UserSubject;
    }
    /** UserSubject holds detailed information for user-kind subject. */
    interface io$k8s$api$flowcontrol$v1beta2$UserSubject {
        /** `name` is the username that matches, or "*" to match all usernames. Required. */
        name: string;
    }
    /** HTTPIngressPath associates a path with a backend. Incoming urls matching the path are forwarded to the backend. */
    interface io$k8s$api$networking$v1$HTTPIngressPath {
        backend: Schemas.io$k8s$api$networking$v1$IngressBackend;
        /** Path is matched against the path of an incoming request. Currently it can contain characters disallowed from the conventional "path" part of a URL as defined by RFC 3986. Paths must begin with a '/' and must be present when using PathType with value "Exact" or "Prefix". */
        path?: string;
        /**
         * PathType determines the interpretation of the Path matching. PathType can be one of the following values: * Exact: Matches the URL path exactly. * Prefix: Matches based on a URL path prefix split by '/'. Matching is
         *   done on a path element by element basis. A path element refers is the
         *   list of labels in the path split by the '/' separator. A request is a
         *   match for path p if every p is an element-wise prefix of p of the
         *   request path. Note that if the last element of the path is a substring
         *   of the last element in request path, it is not a match (e.g. /foo/bar
         *   matches /foo/bar/baz, but does not match /foo/barbaz).
         * * ImplementationSpecific: Interpretation of the Path matching is up to
         *   the IngressClass. Implementations can treat this as a separate PathType
         *   or treat it identically to Prefix or Exact path types.
         * Implementations are required to support all path types.
         */
        pathType: string;
    }
    /** HTTPIngressRuleValue is a list of http selectors pointing to backends. In the example: http://<host>/<path>?<searchpart> -> backend where where parts of the url correspond to RFC 3986, this resource will be used to match against everything after the last '/' and before the first '?' or '#'. */
    interface io$k8s$api$networking$v1$HTTPIngressRuleValue {
        /** A collection of paths that map requests to backends. */
        paths: Schemas.io$k8s$api$networking$v1$HTTPIngressPath[];
    }
    /** IPBlock describes a particular CIDR (Ex. "192.168.1.1/24","2001:db9::/64") that is allowed to the pods matched by a NetworkPolicySpec's podSelector. The except entry describes CIDRs that should not be included within this rule. */
    interface io$k8s$api$networking$v1$IPBlock {
        /** CIDR is a string representing the IP Block Valid examples are "192.168.1.1/24" or "2001:db9::/64" */
        cidr: string;
        /** Except is a slice of CIDRs that should not be included within an IP Block Valid examples are "192.168.1.1/24" or "2001:db9::/64" Except values will be rejected if they are outside the CIDR range */
        except?: string[];
    }
    /** Ingress is a collection of rules that allow inbound connections to reach the endpoints defined by a backend. An Ingress can be configured to give services externally-reachable urls, load balance traffic, terminate SSL, offer name based virtual hosting etc. */
    interface io$k8s$api$networking$v1$Ingress {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$networking$v1$IngressSpec;
        status?: Schemas.io$k8s$api$networking$v1$IngressStatus;
    }
    /** IngressBackend describes all endpoints for a given service and port. */
    interface io$k8s$api$networking$v1$IngressBackend {
        resource?: Schemas.io$k8s$api$core$v1$TypedLocalObjectReference;
        service?: Schemas.io$k8s$api$networking$v1$IngressServiceBackend;
    }
    /** IngressClass represents the class of the Ingress, referenced by the Ingress Spec. The `ingressclass.kubernetes.io/is-default-class` annotation can be used to indicate that an IngressClass should be considered default. When a single IngressClass resource has this annotation set to true, new Ingress resources without a class specified will be assigned this default class. */
    interface io$k8s$api$networking$v1$IngressClass {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$networking$v1$IngressClassSpec;
    }
    /** IngressClassList is a collection of IngressClasses. */
    interface io$k8s$api$networking$v1$IngressClassList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is the list of IngressClasses. */
        items: Schemas.io$k8s$api$networking$v1$IngressClass[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** IngressClassParametersReference identifies an API object. This can be used to specify a cluster or namespace-scoped resource. */
    interface io$k8s$api$networking$v1$IngressClassParametersReference {
        /** APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required. */
        apiGroup?: string;
        /** Kind is the type of resource being referenced. */
        kind: string;
        /** Name is the name of resource being referenced. */
        name: string;
        /** Namespace is the namespace of the resource being referenced. This field is required when scope is set to "Namespace" and must be unset when scope is set to "Cluster". */
        namespace?: string;
        /** Scope represents if this refers to a cluster or namespace scoped resource. This may be set to "Cluster" (default) or "Namespace". */
        scope?: string;
    }
    /** IngressClassSpec provides information about the class of an Ingress. */
    interface io$k8s$api$networking$v1$IngressClassSpec {
        /** Controller refers to the name of the controller that should handle this class. This allows for different "flavors" that are controlled by the same controller. For example, you may have different Parameters for the same implementing controller. This should be specified as a domain-prefixed path no more than 250 characters in length, e.g. "acme.io/ingress-controller". This field is immutable. */
        controller?: string;
        parameters?: Schemas.io$k8s$api$networking$v1$IngressClassParametersReference;
    }
    /** IngressList is a collection of Ingress. */
    interface io$k8s$api$networking$v1$IngressList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is the list of Ingress. */
        items: Schemas.io$k8s$api$networking$v1$Ingress[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** IngressRule represents the rules mapping the paths under a specified host to the related backend services. Incoming requests are first evaluated for a host match, then routed to the backend associated with the matching IngressRuleValue. */
    interface io$k8s$api$networking$v1$IngressRule {
        /**
         * Host is the fully qualified domain name of a network host, as defined by RFC 3986. Note the following deviations from the "host" part of the URI as defined in RFC 3986: 1. IPs are not allowed. Currently an IngressRuleValue can only apply to
         *    the IP in the Spec of the parent Ingress.
         * 2. The `:` delimiter is not respected because ports are not allowed.
         * 	  Currently the port of an Ingress is implicitly :80 for http and
         * 	  :443 for https.
         * Both these may change in the future. Incoming requests are matched against the host before the IngressRuleValue. If the host is unspecified, the Ingress routes all traffic based on the specified IngressRuleValue.
         *
         * Host can be "precise" which is a domain name without the terminating dot of a network host (e.g. "foo.bar.com") or "wildcard", which is a domain name prefixed with a single wildcard label (e.g. "*.foo.com"). The wildcard character '*' must appear by itself as the first DNS label and matches only a single label. You cannot have a wildcard label by itself (e.g. Host == "*"). Requests will be matched against the Host field in the following way: 1. If Host is precise, the request matches this rule if the http host header is equal to Host. 2. If Host is a wildcard, then the request matches this rule if the http host header is to equal to the suffix (removing the first label) of the wildcard rule.
         */
        host?: string;
        http?: Schemas.io$k8s$api$networking$v1$HTTPIngressRuleValue;
    }
    /** IngressServiceBackend references a Kubernetes Service as a Backend. */
    interface io$k8s$api$networking$v1$IngressServiceBackend {
        /** Name is the referenced service. The service must exist in the same namespace as the Ingress object. */
        name: string;
        port?: Schemas.io$k8s$api$networking$v1$ServiceBackendPort;
    }
    /** IngressSpec describes the Ingress the user wishes to exist. */
    interface io$k8s$api$networking$v1$IngressSpec {
        defaultBackend?: Schemas.io$k8s$api$networking$v1$IngressBackend;
        /** IngressClassName is the name of the IngressClass cluster resource. The associated IngressClass defines which controller will implement the resource. This replaces the deprecated `kubernetes.io/ingress.class` annotation. For backwards compatibility, when that annotation is set, it must be given precedence over this field. The controller may emit a warning if the field and annotation have different values. Implementations of this API should ignore Ingresses without a class specified. An IngressClass resource may be marked as default, which can be used to set a default value for this field. For more information, refer to the IngressClass documentation. */
        ingressClassName?: string;
        /** A list of host rules used to configure the Ingress. If unspecified, or no rule matches, all traffic is sent to the default backend. */
        rules?: Schemas.io$k8s$api$networking$v1$IngressRule[];
        /** TLS configuration. Currently the Ingress only supports a single TLS port, 443. If multiple members of this list specify different hosts, they will be multiplexed on the same port according to the hostname specified through the SNI TLS extension, if the ingress controller fulfilling the ingress supports SNI. */
        tls?: Schemas.io$k8s$api$networking$v1$IngressTLS[];
    }
    /** IngressStatus describe the current state of the Ingress. */
    interface io$k8s$api$networking$v1$IngressStatus {
        loadBalancer?: Schemas.io$k8s$api$core$v1$LoadBalancerStatus;
    }
    /** IngressTLS describes the transport layer security associated with an Ingress. */
    interface io$k8s$api$networking$v1$IngressTLS {
        /** Hosts are a list of hosts included in the TLS certificate. The values in this list must match the name/s used in the tlsSecret. Defaults to the wildcard host setting for the loadbalancer controller fulfilling this Ingress, if left unspecified. */
        hosts?: string[];
        /** SecretName is the name of the secret used to terminate TLS traffic on port 443. Field is left optional to allow TLS routing based on SNI hostname alone. If the SNI host in a listener conflicts with the "Host" header field used by an IngressRule, the SNI host is used for termination and value of the Host header is used for routing. */
        secretName?: string;
    }
    /** NetworkPolicy describes what network traffic is allowed for a set of Pods */
    interface io$k8s$api$networking$v1$NetworkPolicy {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$networking$v1$NetworkPolicySpec;
    }
    /** NetworkPolicyEgressRule describes a particular set of traffic that is allowed out of pods matched by a NetworkPolicySpec's podSelector. The traffic must match both ports and to. This type is beta-level in 1.8 */
    interface io$k8s$api$networking$v1$NetworkPolicyEgressRule {
        /** List of destination ports for outgoing traffic. Each item in this list is combined using a logical OR. If this field is empty or missing, this rule matches all ports (traffic not restricted by port). If this field is present and contains at least one item, then this rule allows traffic only if the traffic matches at least one port in the list. */
        ports?: Schemas.io$k8s$api$networking$v1$NetworkPolicyPort[];
        /** List of destinations for outgoing traffic of pods selected for this rule. Items in this list are combined using a logical OR operation. If this field is empty or missing, this rule matches all destinations (traffic not restricted by destination). If this field is present and contains at least one item, this rule allows traffic only if the traffic matches at least one item in the to list. */
        to?: Schemas.io$k8s$api$networking$v1$NetworkPolicyPeer[];
    }
    /** NetworkPolicyIngressRule describes a particular set of traffic that is allowed to the pods matched by a NetworkPolicySpec's podSelector. The traffic must match both ports and from. */
    interface io$k8s$api$networking$v1$NetworkPolicyIngressRule {
        /** List of sources which should be able to access the pods selected for this rule. Items in this list are combined using a logical OR operation. If this field is empty or missing, this rule matches all sources (traffic not restricted by source). If this field is present and contains at least one item, this rule allows traffic only if the traffic matches at least one item in the from list. */
        from?: Schemas.io$k8s$api$networking$v1$NetworkPolicyPeer[];
        /** List of ports which should be made accessible on the pods selected for this rule. Each item in this list is combined using a logical OR. If this field is empty or missing, this rule matches all ports (traffic not restricted by port). If this field is present and contains at least one item, then this rule allows traffic only if the traffic matches at least one port in the list. */
        ports?: Schemas.io$k8s$api$networking$v1$NetworkPolicyPort[];
    }
    /** NetworkPolicyList is a list of NetworkPolicy objects. */
    interface io$k8s$api$networking$v1$NetworkPolicyList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is a list of schema objects. */
        items: Schemas.io$k8s$api$networking$v1$NetworkPolicy[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** NetworkPolicyPeer describes a peer to allow traffic to/from. Only certain combinations of fields are allowed */
    interface io$k8s$api$networking$v1$NetworkPolicyPeer {
        ipBlock?: Schemas.io$k8s$api$networking$v1$IPBlock;
        namespaceSelector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        podSelector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
    }
    /** NetworkPolicyPort describes a port to allow traffic on */
    interface io$k8s$api$networking$v1$NetworkPolicyPort {
        /** If set, indicates that the range of ports from port to endPort, inclusive, should be allowed by the policy. This field cannot be defined if the port field is not defined or if the port field is defined as a named (string) port. The endPort must be equal or greater than port. This feature is in Beta state and is enabled by default. It can be disabled using the Feature Gate "NetworkPolicyEndPort". */
        endPort?: number;
        port?: Schemas.io$k8s$apimachinery$pkg$util$intstr$IntOrString;
        /** The protocol (TCP, UDP, or SCTP) which traffic must match. If not specified, this field defaults to TCP. */
        protocol?: string;
    }
    /** NetworkPolicySpec provides the specification of a NetworkPolicy */
    interface io$k8s$api$networking$v1$NetworkPolicySpec {
        /** List of egress rules to be applied to the selected pods. Outgoing traffic is allowed if there are no NetworkPolicies selecting the pod (and cluster policy otherwise allows the traffic), OR if the traffic matches at least one egress rule across all of the NetworkPolicy objects whose podSelector matches the pod. If this field is empty then this NetworkPolicy limits all outgoing traffic (and serves solely to ensure that the pods it selects are isolated by default). This field is beta-level in 1.8 */
        egress?: Schemas.io$k8s$api$networking$v1$NetworkPolicyEgressRule[];
        /** List of ingress rules to be applied to the selected pods. Traffic is allowed to a pod if there are no NetworkPolicies selecting the pod (and cluster policy otherwise allows the traffic), OR if the traffic source is the pod's local node, OR if the traffic matches at least one ingress rule across all of the NetworkPolicy objects whose podSelector matches the pod. If this field is empty then this NetworkPolicy does not allow any traffic (and serves solely to ensure that the pods it selects are isolated by default) */
        ingress?: Schemas.io$k8s$api$networking$v1$NetworkPolicyIngressRule[];
        podSelector: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        /** List of rule types that the NetworkPolicy relates to. Valid options are ["Ingress"], ["Egress"], or ["Ingress", "Egress"]. If this field is not specified, it will default based on the existence of Ingress or Egress rules; policies that contain an Egress section are assumed to affect Egress, and all policies (whether or not they contain an Ingress section) are assumed to affect Ingress. If you want to write an egress-only policy, you must explicitly specify policyTypes [ "Egress" ]. Likewise, if you want to write a policy that specifies that no egress is allowed, you must specify a policyTypes value that include "Egress" (since such a policy would not include an Egress section and would otherwise default to just [ "Ingress" ]). This field is beta-level in 1.8 */
        policyTypes?: string[];
    }
    /** ServiceBackendPort is the service port being referenced. */
    interface io$k8s$api$networking$v1$ServiceBackendPort {
        /** Name is the name of the port on the Service. This is a mutually exclusive setting with "Number". */
        name?: string;
        /** Number is the numerical port number (e.g. 80) on the Service. This is a mutually exclusive setting with "Name". */
        number?: number;
    }
    /** Overhead structure represents the resource overhead associated with running a pod. */
    interface io$k8s$api$node$v1$Overhead {
        /** PodFixed represents the fixed resource overhead associated with running a pod. */
        podFixed?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
    }
    /** RuntimeClass defines a class of container runtime supported in the cluster. The RuntimeClass is used to determine which container runtime is used to run all containers in a pod. RuntimeClasses are manually defined by a user or cluster provisioner, and referenced in the PodSpec. The Kubelet is responsible for resolving the RuntimeClassName reference before running the pod.  For more details, see https://kubernetes.io/docs/concepts/containers/runtime-class/ */
    interface io$k8s$api$node$v1$RuntimeClass {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Handler specifies the underlying runtime and configuration that the CRI implementation will use to handle pods of this class. The possible values are specific to the node & CRI configuration.  It is assumed that all handlers are available on every node, and handlers of the same name are equivalent on every node. For example, a handler called "runc" might specify that the runc OCI runtime (using native Linux containers) will be used to run the containers in a pod. The Handler must be lowercase, conform to the DNS Label (RFC 1123) requirements, and is immutable. */
        handler: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        overhead?: Schemas.io$k8s$api$node$v1$Overhead;
        scheduling?: Schemas.io$k8s$api$node$v1$Scheduling;
    }
    /** RuntimeClassList is a list of RuntimeClass objects. */
    interface io$k8s$api$node$v1$RuntimeClassList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is a list of schema objects. */
        items: Schemas.io$k8s$api$node$v1$RuntimeClass[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** Scheduling specifies the scheduling constraints for nodes supporting a RuntimeClass. */
    interface io$k8s$api$node$v1$Scheduling {
        /** nodeSelector lists labels that must be present on nodes that support this RuntimeClass. Pods using this RuntimeClass can only be scheduled to a node matched by this selector. The RuntimeClass nodeSelector is merged with a pod's existing nodeSelector. Any conflicts will cause the pod to be rejected in admission. */
        nodeSelector?: {
            [key: string]: string;
        };
        /** tolerations are appended (excluding duplicates) to pods running with this RuntimeClass during admission, effectively unioning the set of nodes tolerated by the pod and the RuntimeClass. */
        tolerations?: Schemas.io$k8s$api$core$v1$Toleration[];
    }
    /** Overhead structure represents the resource overhead associated with running a pod. */
    interface io$k8s$api$node$v1alpha1$Overhead {
        /** PodFixed represents the fixed resource overhead associated with running a pod. */
        podFixed?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
    }
    /** RuntimeClass defines a class of container runtime supported in the cluster. The RuntimeClass is used to determine which container runtime is used to run all containers in a pod. RuntimeClasses are (currently) manually defined by a user or cluster provisioner, and referenced in the PodSpec. The Kubelet is responsible for resolving the RuntimeClassName reference before running the pod.  For more details, see https://git.k8s.io/enhancements/keps/sig-node/585-runtime-class */
    interface io$k8s$api$node$v1alpha1$RuntimeClass {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$node$v1alpha1$RuntimeClassSpec;
    }
    /** RuntimeClassList is a list of RuntimeClass objects. */
    interface io$k8s$api$node$v1alpha1$RuntimeClassList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is a list of schema objects. */
        items: Schemas.io$k8s$api$node$v1alpha1$RuntimeClass[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** RuntimeClassSpec is a specification of a RuntimeClass. It contains parameters that are required to describe the RuntimeClass to the Container Runtime Interface (CRI) implementation, as well as any other components that need to understand how the pod will be run. The RuntimeClassSpec is immutable. */
    interface io$k8s$api$node$v1alpha1$RuntimeClassSpec {
        overhead?: Schemas.io$k8s$api$node$v1alpha1$Overhead;
        /** RuntimeHandler specifies the underlying runtime and configuration that the CRI implementation will use to handle pods of this class. The possible values are specific to the node & CRI configuration.  It is assumed that all handlers are available on every node, and handlers of the same name are equivalent on every node. For example, a handler called "runc" might specify that the runc OCI runtime (using native Linux containers) will be used to run the containers in a pod. The RuntimeHandler must be lowercase, conform to the DNS Label (RFC 1123) requirements, and is immutable. */
        runtimeHandler: string;
        scheduling?: Schemas.io$k8s$api$node$v1alpha1$Scheduling;
    }
    /** Scheduling specifies the scheduling constraints for nodes supporting a RuntimeClass. */
    interface io$k8s$api$node$v1alpha1$Scheduling {
        /** nodeSelector lists labels that must be present on nodes that support this RuntimeClass. Pods using this RuntimeClass can only be scheduled to a node matched by this selector. The RuntimeClass nodeSelector is merged with a pod's existing nodeSelector. Any conflicts will cause the pod to be rejected in admission. */
        nodeSelector?: {
            [key: string]: string;
        };
        /** tolerations are appended (excluding duplicates) to pods running with this RuntimeClass during admission, effectively unioning the set of nodes tolerated by the pod and the RuntimeClass. */
        tolerations?: Schemas.io$k8s$api$core$v1$Toleration[];
    }
    /** Overhead structure represents the resource overhead associated with running a pod. */
    interface io$k8s$api$node$v1beta1$Overhead {
        /** PodFixed represents the fixed resource overhead associated with running a pod. */
        podFixed?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
    }
    /** RuntimeClass defines a class of container runtime supported in the cluster. The RuntimeClass is used to determine which container runtime is used to run all containers in a pod. RuntimeClasses are (currently) manually defined by a user or cluster provisioner, and referenced in the PodSpec. The Kubelet is responsible for resolving the RuntimeClassName reference before running the pod.  For more details, see https://git.k8s.io/enhancements/keps/sig-node/585-runtime-class */
    interface io$k8s$api$node$v1beta1$RuntimeClass {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Handler specifies the underlying runtime and configuration that the CRI implementation will use to handle pods of this class. The possible values are specific to the node & CRI configuration.  It is assumed that all handlers are available on every node, and handlers of the same name are equivalent on every node. For example, a handler called "runc" might specify that the runc OCI runtime (using native Linux containers) will be used to run the containers in a pod. The Handler must be lowercase, conform to the DNS Label (RFC 1123) requirements, and is immutable. */
        handler: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        overhead?: Schemas.io$k8s$api$node$v1beta1$Overhead;
        scheduling?: Schemas.io$k8s$api$node$v1beta1$Scheduling;
    }
    /** RuntimeClassList is a list of RuntimeClass objects. */
    interface io$k8s$api$node$v1beta1$RuntimeClassList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is a list of schema objects. */
        items: Schemas.io$k8s$api$node$v1beta1$RuntimeClass[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** Scheduling specifies the scheduling constraints for nodes supporting a RuntimeClass. */
    interface io$k8s$api$node$v1beta1$Scheduling {
        /** nodeSelector lists labels that must be present on nodes that support this RuntimeClass. Pods using this RuntimeClass can only be scheduled to a node matched by this selector. The RuntimeClass nodeSelector is merged with a pod's existing nodeSelector. Any conflicts will cause the pod to be rejected in admission. */
        nodeSelector?: {
            [key: string]: string;
        };
        /** tolerations are appended (excluding duplicates) to pods running with this RuntimeClass during admission, effectively unioning the set of nodes tolerated by the pod and the RuntimeClass. */
        tolerations?: Schemas.io$k8s$api$core$v1$Toleration[];
    }
    /** Eviction evicts a pod from its node subject to certain policies and safety constraints. This is a subresource of Pod.  A request to cause such an eviction is created by POSTing to .../pods/<pod name>/evictions. */
    interface io$k8s$api$policy$v1$Eviction {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        deleteOptions?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
    }
    /** PodDisruptionBudget is an object to define the max disruption that can be caused to a collection of pods */
    interface io$k8s$api$policy$v1$PodDisruptionBudget {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetSpec;
        status?: Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetStatus;
    }
    /** PodDisruptionBudgetList is a collection of PodDisruptionBudgets. */
    interface io$k8s$api$policy$v1$PodDisruptionBudgetList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is a list of PodDisruptionBudgets */
        items: Schemas.io$k8s$api$policy$v1$PodDisruptionBudget[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** PodDisruptionBudgetSpec is a description of a PodDisruptionBudget. */
    interface io$k8s$api$policy$v1$PodDisruptionBudgetSpec {
        maxUnavailable?: Schemas.io$k8s$apimachinery$pkg$util$intstr$IntOrString;
        minAvailable?: Schemas.io$k8s$apimachinery$pkg$util$intstr$IntOrString;
        selector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
    }
    /** PodDisruptionBudgetStatus represents information about the status of a PodDisruptionBudget. Status may trail the actual state of a system. */
    interface io$k8s$api$policy$v1$PodDisruptionBudgetStatus {
        /**
         * Conditions contain conditions for PDB. The disruption controller sets the DisruptionAllowed condition. The following are known values for the reason field (additional reasons could be added in the future): - SyncFailed: The controller encountered an error and wasn't able to compute
         *               the number of allowed disruptions. Therefore no disruptions are
         *               allowed and the status of the condition will be False.
         * - InsufficientPods: The number of pods are either at or below the number
         *                     required by the PodDisruptionBudget. No disruptions are
         *                     allowed and the status of the condition will be False.
         * - SufficientPods: There are more pods than required by the PodDisruptionBudget.
         *                   The condition will be True, and the number of allowed
         *                   disruptions are provided by the disruptionsAllowed property.
         */
        conditions?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Condition[];
        /** current number of healthy pods */
        currentHealthy: number;
        /** minimum desired number of healthy pods */
        desiredHealthy: number;
        /** DisruptedPods contains information about pods whose eviction was processed by the API server eviction subresource handler but has not yet been observed by the PodDisruptionBudget controller. A pod will be in this map from the time when the API server processed the eviction request to the time when the pod is seen by PDB controller as having been marked for deletion (or after a timeout). The key in the map is the name of the pod and the value is the time when the API server processed the eviction request. If the deletion didn't occur and a pod is still there it will be removed from the list automatically by PodDisruptionBudget controller after some time. If everything goes smooth this map should be empty for the most of the time. Large number of entries in the map may indicate problems with pod deletions. */
        disruptedPods?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        };
        /** Number of pod disruptions that are currently allowed. */
        disruptionsAllowed: number;
        /** total number of pods counted by this disruption budget */
        expectedPods: number;
        /** Most recent generation observed when updating this PDB status. DisruptionsAllowed and other status information is valid only if observedGeneration equals to PDB's object generation. */
        observedGeneration?: number;
    }
    /** AllowedCSIDriver represents a single inline CSI Driver that is allowed to be used. */
    interface io$k8s$api$policy$v1beta1$AllowedCSIDriver {
        /** Name is the registered name of the CSI driver */
        name: string;
    }
    /** AllowedFlexVolume represents a single Flexvolume that is allowed to be used. */
    interface io$k8s$api$policy$v1beta1$AllowedFlexVolume {
        /** driver is the name of the Flexvolume driver. */
        driver: string;
    }
    /** AllowedHostPath defines the host volume conditions that will be enabled by a policy for pods to use. It requires the path prefix to be defined. */
    interface io$k8s$api$policy$v1beta1$AllowedHostPath {
        /**
         * pathPrefix is the path prefix that the host volume must match. It does not support `*`. Trailing slashes are trimmed when validating the path prefix with a host path.
         *
         * Examples: `/foo` would allow `/foo`, `/foo/` and `/foo/bar` `/foo` would not allow `/food` or `/etc/foo`
         */
        pathPrefix?: string;
        /** when set to true, will allow host volumes matching the pathPrefix only if all volume mounts are readOnly. */
        readOnly?: boolean;
    }
    /** FSGroupStrategyOptions defines the strategy type and options used to create the strategy. */
    interface io$k8s$api$policy$v1beta1$FSGroupStrategyOptions {
        /** ranges are the allowed ranges of fs groups.  If you would like to force a single fs group then supply a single range with the same start and end. Required for MustRunAs. */
        ranges?: Schemas.io$k8s$api$policy$v1beta1$IDRange[];
        /** rule is the strategy that will dictate what FSGroup is used in the SecurityContext. */
        rule?: string;
    }
    /** HostPortRange defines a range of host ports that will be enabled by a policy for pods to use.  It requires both the start and end to be defined. */
    interface io$k8s$api$policy$v1beta1$HostPortRange {
        /** max is the end of the range, inclusive. */
        max: number;
        /** min is the start of the range, inclusive. */
        min: number;
    }
    /** IDRange provides a min/max of an allowed range of IDs. */
    interface io$k8s$api$policy$v1beta1$IDRange {
        /** max is the end of the range, inclusive. */
        max: number;
        /** min is the start of the range, inclusive. */
        min: number;
    }
    /** PodDisruptionBudget is an object to define the max disruption that can be caused to a collection of pods */
    interface io$k8s$api$policy$v1beta1$PodDisruptionBudget {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudgetSpec;
        status?: Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudgetStatus;
    }
    /** PodDisruptionBudgetList is a collection of PodDisruptionBudgets. */
    interface io$k8s$api$policy$v1beta1$PodDisruptionBudgetList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items list individual PodDisruptionBudget objects */
        items: Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** PodDisruptionBudgetSpec is a description of a PodDisruptionBudget. */
    interface io$k8s$api$policy$v1beta1$PodDisruptionBudgetSpec {
        maxUnavailable?: Schemas.io$k8s$apimachinery$pkg$util$intstr$IntOrString;
        minAvailable?: Schemas.io$k8s$apimachinery$pkg$util$intstr$IntOrString;
        selector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
    }
    /** PodDisruptionBudgetStatus represents information about the status of a PodDisruptionBudget. Status may trail the actual state of a system. */
    interface io$k8s$api$policy$v1beta1$PodDisruptionBudgetStatus {
        /**
         * Conditions contain conditions for PDB. The disruption controller sets the DisruptionAllowed condition. The following are known values for the reason field (additional reasons could be added in the future): - SyncFailed: The controller encountered an error and wasn't able to compute
         *               the number of allowed disruptions. Therefore no disruptions are
         *               allowed and the status of the condition will be False.
         * - InsufficientPods: The number of pods are either at or below the number
         *                     required by the PodDisruptionBudget. No disruptions are
         *                     allowed and the status of the condition will be False.
         * - SufficientPods: There are more pods than required by the PodDisruptionBudget.
         *                   The condition will be True, and the number of allowed
         *                   disruptions are provided by the disruptionsAllowed property.
         */
        conditions?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Condition[];
        /** current number of healthy pods */
        currentHealthy: number;
        /** minimum desired number of healthy pods */
        desiredHealthy: number;
        /** DisruptedPods contains information about pods whose eviction was processed by the API server eviction subresource handler but has not yet been observed by the PodDisruptionBudget controller. A pod will be in this map from the time when the API server processed the eviction request to the time when the pod is seen by PDB controller as having been marked for deletion (or after a timeout). The key in the map is the name of the pod and the value is the time when the API server processed the eviction request. If the deletion didn't occur and a pod is still there it will be removed from the list automatically by PodDisruptionBudget controller after some time. If everything goes smooth this map should be empty for the most of the time. Large number of entries in the map may indicate problems with pod deletions. */
        disruptedPods?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        };
        /** Number of pod disruptions that are currently allowed. */
        disruptionsAllowed: number;
        /** total number of pods counted by this disruption budget */
        expectedPods: number;
        /** Most recent generation observed when updating this PDB status. DisruptionsAllowed and other status information is valid only if observedGeneration equals to PDB's object generation. */
        observedGeneration?: number;
    }
    /** PodSecurityPolicy governs the ability to make requests that affect the Security Context that will be applied to a pod and container. Deprecated in 1.21. */
    interface io$k8s$api$policy$v1beta1$PodSecurityPolicy {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicySpec;
    }
    /** PodSecurityPolicyList is a list of PodSecurityPolicy objects. */
    interface io$k8s$api$policy$v1beta1$PodSecurityPolicyList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is a list of schema objects. */
        items: Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** PodSecurityPolicySpec defines the policy enforced. */
    interface io$k8s$api$policy$v1beta1$PodSecurityPolicySpec {
        /** allowPrivilegeEscalation determines if a pod can request to allow privilege escalation. If unspecified, defaults to true. */
        allowPrivilegeEscalation?: boolean;
        /** AllowedCSIDrivers is an allowlist of inline CSI drivers that must be explicitly set to be embedded within a pod spec. An empty value indicates that any CSI driver can be used for inline ephemeral volumes. This is a beta field, and is only honored if the API server enables the CSIInlineVolume feature gate. */
        allowedCSIDrivers?: Schemas.io$k8s$api$policy$v1beta1$AllowedCSIDriver[];
        /** allowedCapabilities is a list of capabilities that can be requested to add to the container. Capabilities in this field may be added at the pod author's discretion. You must not list a capability in both allowedCapabilities and requiredDropCapabilities. */
        allowedCapabilities?: string[];
        /** allowedFlexVolumes is an allowlist of Flexvolumes.  Empty or nil indicates that all Flexvolumes may be used.  This parameter is effective only when the usage of the Flexvolumes is allowed in the "volumes" field. */
        allowedFlexVolumes?: Schemas.io$k8s$api$policy$v1beta1$AllowedFlexVolume[];
        /** allowedHostPaths is an allowlist of host paths. Empty indicates that all host paths may be used. */
        allowedHostPaths?: Schemas.io$k8s$api$policy$v1beta1$AllowedHostPath[];
        /** AllowedProcMountTypes is an allowlist of allowed ProcMountTypes. Empty or nil indicates that only the DefaultProcMountType may be used. This requires the ProcMountType feature flag to be enabled. */
        allowedProcMountTypes?: string[];
        /**
         * allowedUnsafeSysctls is a list of explicitly allowed unsafe sysctls, defaults to none. Each entry is either a plain sysctl name or ends in "*" in which case it is considered as a prefix of allowed sysctls. Single * means all unsafe sysctls are allowed. Kubelet has to allowlist all allowed unsafe sysctls explicitly to avoid rejection.
         *
         * Examples: e.g. "foo/\\*" allows "foo/bar", "foo/baz", etc. e.g. "foo.*" allows "foo.bar", "foo.baz", etc.
         */
        allowedUnsafeSysctls?: string[];
        /** defaultAddCapabilities is the default set of capabilities that will be added to the container unless the pod spec specifically drops the capability.  You may not list a capability in both defaultAddCapabilities and requiredDropCapabilities. Capabilities added here are implicitly allowed, and need not be included in the allowedCapabilities list. */
        defaultAddCapabilities?: string[];
        /** defaultAllowPrivilegeEscalation controls the default setting for whether a process can gain more privileges than its parent process. */
        defaultAllowPrivilegeEscalation?: boolean;
        /**
         * forbiddenSysctls is a list of explicitly forbidden sysctls, defaults to none. Each entry is either a plain sysctl name or ends in "*" in which case it is considered as a prefix of forbidden sysctls. Single * means all sysctls are forbidden.
         *
         * Examples: e.g. "foo/\\*" forbids "foo/bar", "foo/baz", etc. e.g. "foo.*" forbids "foo.bar", "foo.baz", etc.
         */
        forbiddenSysctls?: string[];
        fsGroup: Schemas.io$k8s$api$policy$v1beta1$FSGroupStrategyOptions;
        /** hostIPC determines if the policy allows the use of HostIPC in the pod spec. */
        hostIPC?: boolean;
        /** hostNetwork determines if the policy allows the use of HostNetwork in the pod spec. */
        hostNetwork?: boolean;
        /** hostPID determines if the policy allows the use of HostPID in the pod spec. */
        hostPID?: boolean;
        /** hostPorts determines which host port ranges are allowed to be exposed. */
        hostPorts?: Schemas.io$k8s$api$policy$v1beta1$HostPortRange[];
        /** privileged determines if a pod can request to be run as privileged. */
        privileged?: boolean;
        /** readOnlyRootFilesystem when set to true will force containers to run with a read only root file system.  If the container specifically requests to run with a non-read only root file system the PSP should deny the pod. If set to false the container may run with a read only root file system if it wishes but it will not be forced to. */
        readOnlyRootFilesystem?: boolean;
        /** requiredDropCapabilities are the capabilities that will be dropped from the container.  These are required to be dropped and cannot be added. */
        requiredDropCapabilities?: string[];
        runAsGroup?: Schemas.io$k8s$api$policy$v1beta1$RunAsGroupStrategyOptions;
        runAsUser: Schemas.io$k8s$api$policy$v1beta1$RunAsUserStrategyOptions;
        runtimeClass?: Schemas.io$k8s$api$policy$v1beta1$RuntimeClassStrategyOptions;
        seLinux: Schemas.io$k8s$api$policy$v1beta1$SELinuxStrategyOptions;
        supplementalGroups: Schemas.io$k8s$api$policy$v1beta1$SupplementalGroupsStrategyOptions;
        /** volumes is an allowlist of volume plugins. Empty indicates that no volumes may be used. To allow all volumes you may use '*'. */
        volumes?: string[];
    }
    /** RunAsGroupStrategyOptions defines the strategy type and any options used to create the strategy. */
    interface io$k8s$api$policy$v1beta1$RunAsGroupStrategyOptions {
        /** ranges are the allowed ranges of gids that may be used. If you would like to force a single gid then supply a single range with the same start and end. Required for MustRunAs. */
        ranges?: Schemas.io$k8s$api$policy$v1beta1$IDRange[];
        /** rule is the strategy that will dictate the allowable RunAsGroup values that may be set. */
        rule: string;
    }
    /** RunAsUserStrategyOptions defines the strategy type and any options used to create the strategy. */
    interface io$k8s$api$policy$v1beta1$RunAsUserStrategyOptions {
        /** ranges are the allowed ranges of uids that may be used. If you would like to force a single uid then supply a single range with the same start and end. Required for MustRunAs. */
        ranges?: Schemas.io$k8s$api$policy$v1beta1$IDRange[];
        /** rule is the strategy that will dictate the allowable RunAsUser values that may be set. */
        rule: string;
    }
    /** RuntimeClassStrategyOptions define the strategy that will dictate the allowable RuntimeClasses for a pod. */
    interface io$k8s$api$policy$v1beta1$RuntimeClassStrategyOptions {
        /** allowedRuntimeClassNames is an allowlist of RuntimeClass names that may be specified on a pod. A value of "*" means that any RuntimeClass name is allowed, and must be the only item in the list. An empty list requires the RuntimeClassName field to be unset. */
        allowedRuntimeClassNames: string[];
        /** defaultRuntimeClassName is the default RuntimeClassName to set on the pod. The default MUST be allowed by the allowedRuntimeClassNames list. A value of nil does not mutate the Pod. */
        defaultRuntimeClassName?: string;
    }
    /** SELinuxStrategyOptions defines the strategy type and any options used to create the strategy. */
    interface io$k8s$api$policy$v1beta1$SELinuxStrategyOptions {
        /** rule is the strategy that will dictate the allowable labels that may be set. */
        rule: string;
        seLinuxOptions?: Schemas.io$k8s$api$core$v1$SELinuxOptions;
    }
    /** SupplementalGroupsStrategyOptions defines the strategy type and options used to create the strategy. */
    interface io$k8s$api$policy$v1beta1$SupplementalGroupsStrategyOptions {
        /** ranges are the allowed ranges of supplemental groups.  If you would like to force a single supplemental group then supply a single range with the same start and end. Required for MustRunAs. */
        ranges?: Schemas.io$k8s$api$policy$v1beta1$IDRange[];
        /** rule is the strategy that will dictate what supplemental groups is used in the SecurityContext. */
        rule?: string;
    }
    /** AggregationRule describes how to locate ClusterRoles to aggregate into the ClusterRole */
    interface io$k8s$api$rbac$v1$AggregationRule {
        /** ClusterRoleSelectors holds a list of selectors which will be used to find ClusterRoles and create the rules. If any of the selectors match, then the ClusterRole's permissions will be added */
        clusterRoleSelectors?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector[];
    }
    /** ClusterRole is a cluster level, logical grouping of PolicyRules that can be referenced as a unit by a RoleBinding or ClusterRoleBinding. */
    interface io$k8s$api$rbac$v1$ClusterRole {
        aggregationRule?: Schemas.io$k8s$api$rbac$v1$AggregationRule;
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** Rules holds all the PolicyRules for this ClusterRole */
        rules?: Schemas.io$k8s$api$rbac$v1$PolicyRule[];
    }
    /** ClusterRoleBinding references a ClusterRole, but not contain it.  It can reference a ClusterRole in the global namespace, and adds who information via Subject. */
    interface io$k8s$api$rbac$v1$ClusterRoleBinding {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        roleRef: Schemas.io$k8s$api$rbac$v1$RoleRef;
        /** Subjects holds references to the objects the role applies to. */
        subjects?: Schemas.io$k8s$api$rbac$v1$Subject[];
    }
    /** ClusterRoleBindingList is a collection of ClusterRoleBindings */
    interface io$k8s$api$rbac$v1$ClusterRoleBindingList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is a list of ClusterRoleBindings */
        items: Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ClusterRoleList is a collection of ClusterRoles */
    interface io$k8s$api$rbac$v1$ClusterRoleList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is a list of ClusterRoles */
        items: Schemas.io$k8s$api$rbac$v1$ClusterRole[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** PolicyRule holds information that describes a policy rule, but does not contain information about who the rule applies to or which namespace the rule applies to. */
    interface io$k8s$api$rbac$v1$PolicyRule {
        /** APIGroups is the name of the APIGroup that contains the resources.  If multiple API groups are specified, any action requested against one of the enumerated resources in any API group will be allowed. */
        apiGroups?: string[];
        /** NonResourceURLs is a set of partial urls that a user should have access to.  *s are allowed, but only as the full, final step in the path Since non-resource URLs are not namespaced, this field is only applicable for ClusterRoles referenced from a ClusterRoleBinding. Rules can either apply to API resources (such as "pods" or "secrets") or non-resource URL paths (such as "/api"),  but not both. */
        nonResourceURLs?: string[];
        /** ResourceNames is an optional white list of names that the rule applies to.  An empty set means that everything is allowed. */
        resourceNames?: string[];
        /** Resources is a list of resources this rule applies to. '*' represents all resources. */
        resources?: string[];
        /** Verbs is a list of Verbs that apply to ALL the ResourceKinds contained in this rule. '*' represents all verbs. */
        verbs: string[];
    }
    /** Role is a namespaced, logical grouping of PolicyRules that can be referenced as a unit by a RoleBinding. */
    interface io$k8s$api$rbac$v1$Role {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** Rules holds all the PolicyRules for this Role */
        rules?: Schemas.io$k8s$api$rbac$v1$PolicyRule[];
    }
    /** RoleBinding references a role, but does not contain it.  It can reference a Role in the same namespace or a ClusterRole in the global namespace. It adds who information via Subjects and namespace information by which namespace it exists in.  RoleBindings in a given namespace only have effect in that namespace. */
    interface io$k8s$api$rbac$v1$RoleBinding {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        roleRef: Schemas.io$k8s$api$rbac$v1$RoleRef;
        /** Subjects holds references to the objects the role applies to. */
        subjects?: Schemas.io$k8s$api$rbac$v1$Subject[];
    }
    /** RoleBindingList is a collection of RoleBindings */
    interface io$k8s$api$rbac$v1$RoleBindingList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is a list of RoleBindings */
        items: Schemas.io$k8s$api$rbac$v1$RoleBinding[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** RoleList is a collection of Roles */
    interface io$k8s$api$rbac$v1$RoleList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is a list of Roles */
        items: Schemas.io$k8s$api$rbac$v1$Role[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** RoleRef contains information that points to the role being used */
    interface io$k8s$api$rbac$v1$RoleRef {
        /** APIGroup is the group for the resource being referenced */
        apiGroup: string;
        /** Kind is the type of resource being referenced */
        kind: string;
        /** Name is the name of resource being referenced */
        name: string;
    }
    /** Subject contains a reference to the object or user identities a role binding applies to.  This can either hold a direct API object reference, or a value for non-objects such as user and group names. */
    interface io$k8s$api$rbac$v1$Subject {
        /** APIGroup holds the API group of the referenced subject. Defaults to "" for ServiceAccount subjects. Defaults to "rbac.authorization.k8s.io" for User and Group subjects. */
        apiGroup?: string;
        /** Kind of object being referenced. Values defined by this API group are "User", "Group", and "ServiceAccount". If the Authorizer does not recognized the kind value, the Authorizer should report an error. */
        kind: string;
        /** Name of the object being referenced. */
        name: string;
        /** Namespace of the referenced object.  If the object kind is non-namespace, such as "User" or "Group", and this value is not empty the Authorizer should report an error. */
        namespace?: string;
    }
    /** PriorityClass defines mapping from a priority class name to the priority integer value. The value can be any valid integer. */
    interface io$k8s$api$scheduling$v1$PriorityClass {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** description is an arbitrary string that usually provides guidelines on when this priority class should be used. */
        description?: string;
        /** globalDefault specifies whether this PriorityClass should be considered as the default priority for pods that do not have any priority class. Only one PriorityClass can be marked as `globalDefault`. However, if more than one PriorityClasses exists with their `globalDefault` field set to true, the smallest value of such global default PriorityClasses will be used as the default priority. */
        globalDefault?: boolean;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** PreemptionPolicy is the Policy for preempting pods with lower priority. One of Never, PreemptLowerPriority. Defaults to PreemptLowerPriority if unset. This field is beta-level, gated by the NonPreemptingPriority feature-gate. */
        preemptionPolicy?: string;
        /** The value of this priority class. This is the actual priority that pods receive when they have the name of this class in their pod spec. */
        value: number;
    }
    /** PriorityClassList is a collection of priority classes. */
    interface io$k8s$api$scheduling$v1$PriorityClassList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of PriorityClasses */
        items: Schemas.io$k8s$api$scheduling$v1$PriorityClass[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** CSIDriver captures information about a Container Storage Interface (CSI) volume driver deployed on the cluster. Kubernetes attach detach controller uses this object to determine whether attach is required. Kubelet uses this object to determine whether pod information needs to be passed on mount. CSIDriver objects are non-namespaced. */
    interface io$k8s$api$storage$v1$CSIDriver {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$storage$v1$CSIDriverSpec;
    }
    /** CSIDriverList is a collection of CSIDriver objects. */
    interface io$k8s$api$storage$v1$CSIDriverList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of CSIDriver */
        items: Schemas.io$k8s$api$storage$v1$CSIDriver[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** CSIDriverSpec is the specification of a CSIDriver. */
    interface io$k8s$api$storage$v1$CSIDriverSpec {
        /**
         * attachRequired indicates this CSI volume driver requires an attach operation (because it implements the CSI ControllerPublishVolume() method), and that the Kubernetes attach detach controller should call the attach volume interface which checks the volumeattachment status and waits until the volume is attached before proceeding to mounting. The CSI external-attacher coordinates with CSI volume driver and updates the volumeattachment status when the attach operation is complete. If the CSIDriverRegistry feature gate is enabled and the value is specified to false, the attach operation will be skipped. Otherwise the attach operation will be called.
         *
         * This field is immutable.
         */
        attachRequired?: boolean;
        /**
         * Defines if the underlying volume supports changing ownership and permission of the volume before being mounted. Refer to the specific FSGroupPolicy values for additional details.
         *
         * This field is immutable.
         *
         * Defaults to ReadWriteOnceWithFSType, which will examine each volume to determine if Kubernetes should modify ownership and permissions of the volume. With the default policy the defined fsGroup will only be applied if a fstype is defined and the volume's access mode contains ReadWriteOnce.
         */
        fsGroupPolicy?: string;
        /**
         * If set to true, podInfoOnMount indicates this CSI volume driver requires additional pod information (like podName, podUID, etc.) during mount operations. If set to false, pod information will not be passed on mount. Default is false. The CSI driver specifies podInfoOnMount as part of driver deployment. If true, Kubelet will pass pod information as VolumeContext in the CSI NodePublishVolume() calls. The CSI driver is responsible for parsing and validating the information passed in as VolumeContext. The following VolumeConext will be passed if podInfoOnMount is set to true. This list might grow, but the prefix will be used. "csi.storage.k8s.io/pod.name": pod.Name "csi.storage.k8s.io/pod.namespace": pod.Namespace "csi.storage.k8s.io/pod.uid": string(pod.UID) "csi.storage.k8s.io/ephemeral": "true" if the volume is an ephemeral inline volume
         *                                 defined by a CSIVolumeSource, otherwise "false"
         *
         * "csi.storage.k8s.io/ephemeral" is a new feature in Kubernetes 1.16. It is only required for drivers which support both the "Persistent" and "Ephemeral" VolumeLifecycleMode. Other drivers can leave pod info disabled and/or ignore this field. As Kubernetes 1.15 doesn't support this field, drivers can only support one mode when deployed on such a cluster and the deployment determines which mode that is, for example via a command line parameter of the driver.
         *
         * This field is immutable.
         */
        podInfoOnMount?: boolean;
        /**
         * RequiresRepublish indicates the CSI driver wants `NodePublishVolume` being periodically called to reflect any possible change in the mounted volume. This field defaults to false.
         *
         * Note: After a successful initial NodePublishVolume call, subsequent calls to NodePublishVolume should only update the contents of the volume. New mount points will not be seen by a running container.
         */
        requiresRepublish?: boolean;
        /**
         * If set to true, storageCapacity indicates that the CSI volume driver wants pod scheduling to consider the storage capacity that the driver deployment will report by creating CSIStorageCapacity objects with capacity information.
         *
         * The check can be enabled immediately when deploying a driver. In that case, provisioning new volumes with late binding will pause until the driver deployment has published some suitable CSIStorageCapacity object.
         *
         * Alternatively, the driver can be deployed with the field unset or false and it can be flipped later when storage capacity information has been published.
         *
         * This field was immutable in Kubernetes <= 1.22 and now is mutable.
         *
         * This is a beta field and only available when the CSIStorageCapacity feature is enabled. The default is false.
         */
        storageCapacity?: boolean;
        /**
         * TokenRequests indicates the CSI driver needs pods' service account tokens it is mounting volume for to do necessary authentication. Kubelet will pass the tokens in VolumeContext in the CSI NodePublishVolume calls. The CSI driver should parse and validate the following VolumeContext: "csi.storage.k8s.io/serviceAccount.tokens": {
         *   "<audience>": {
         *     "token": <token>,
         *     "expirationTimestamp": <expiration timestamp in RFC3339>,
         *   },
         *   ...
         * }
         *
         * Note: Audience in each TokenRequest should be different and at most one token is empty string. To receive a new token after expiry, RequiresRepublish can be used to trigger NodePublishVolume periodically.
         */
        tokenRequests?: Schemas.io$k8s$api$storage$v1$TokenRequest[];
        /**
         * volumeLifecycleModes defines what kind of volumes this CSI volume driver supports. The default if the list is empty is "Persistent", which is the usage defined by the CSI specification and implemented in Kubernetes via the usual PV/PVC mechanism. The other mode is "Ephemeral". In this mode, volumes are defined inline inside the pod spec with CSIVolumeSource and their lifecycle is tied to the lifecycle of that pod. A driver has to be aware of this because it is only going to get a NodePublishVolume call for such a volume. For more information about implementing this mode, see https://kubernetes-csi.github.io/docs/ephemeral-local-volumes.html A driver can support one or more of these modes and more modes may be added in the future. This field is beta.
         *
         * This field is immutable.
         */
        volumeLifecycleModes?: string[];
    }
    /** CSINode holds information about all CSI drivers installed on a node. CSI drivers do not need to create the CSINode object directly. As long as they use the node-driver-registrar sidecar container, the kubelet will automatically populate the CSINode object for the CSI driver as part of kubelet plugin registration. CSINode has the same name as a node. If the object is missing, it means either there are no CSI Drivers available on the node, or the Kubelet version is low enough that it doesn't create this object. CSINode has an OwnerReference that points to the corresponding node object. */
    interface io$k8s$api$storage$v1$CSINode {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$storage$v1$CSINodeSpec;
    }
    /** CSINodeDriver holds information about the specification of one CSI driver installed on a node */
    interface io$k8s$api$storage$v1$CSINodeDriver {
        allocatable?: Schemas.io$k8s$api$storage$v1$VolumeNodeResources;
        /** This is the name of the CSI driver that this object refers to. This MUST be the same name returned by the CSI GetPluginName() call for that driver. */
        name: string;
        /** nodeID of the node from the driver point of view. This field enables Kubernetes to communicate with storage systems that do not share the same nomenclature for nodes. For example, Kubernetes may refer to a given node as "node1", but the storage system may refer to the same node as "nodeA". When Kubernetes issues a command to the storage system to attach a volume to a specific node, it can use this field to refer to the node name using the ID that the storage system will understand, e.g. "nodeA" instead of "node1". This field is required. */
        nodeID: string;
        /** topologyKeys is the list of keys supported by the driver. When a driver is initialized on a cluster, it provides a set of topology keys that it understands (e.g. "company.com/zone", "company.com/region"). When a driver is initialized on a node, it provides the same topology keys along with values. Kubelet will expose these topology keys as labels on its own node object. When Kubernetes does topology aware provisioning, it can use this list to determine which labels it should retrieve from the node object and pass back to the driver. It is possible for different nodes to use different topology keys. This can be empty if driver does not support topology. */
        topologyKeys?: string[];
    }
    /** CSINodeList is a collection of CSINode objects. */
    interface io$k8s$api$storage$v1$CSINodeList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of CSINode */
        items: Schemas.io$k8s$api$storage$v1$CSINode[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** CSINodeSpec holds information about the specification of all CSI drivers installed on a node */
    interface io$k8s$api$storage$v1$CSINodeSpec {
        /** drivers is a list of information of all CSI Drivers existing on a node. If all drivers in the list are uninstalled, this can become empty. */
        drivers: Schemas.io$k8s$api$storage$v1$CSINodeDriver[];
    }
    /**
     * StorageClass describes the parameters for a class of storage for which PersistentVolumes can be dynamically provisioned.
     *
     * StorageClasses are non-namespaced; the name of the storage class according to etcd is in ObjectMeta.Name.
     */
    interface io$k8s$api$storage$v1$StorageClass {
        /** AllowVolumeExpansion shows whether the storage class allow volume expand */
        allowVolumeExpansion?: boolean;
        /** Restrict the node topologies where volumes can be dynamically provisioned. Each volume plugin defines its own supported topology specifications. An empty TopologySelectorTerm list means there is no topology restriction. This field is only honored by servers that enable the VolumeScheduling feature. */
        allowedTopologies?: Schemas.io$k8s$api$core$v1$TopologySelectorTerm[];
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** Dynamically provisioned PersistentVolumes of this storage class are created with these mountOptions, e.g. ["ro", "soft"]. Not validated - mount of the PVs will simply fail if one is invalid. */
        mountOptions?: string[];
        /** Parameters holds the parameters for the provisioner that should create volumes of this storage class. */
        parameters?: {
            [key: string]: string;
        };
        /** Provisioner indicates the type of the provisioner. */
        provisioner: string;
        /** Dynamically provisioned PersistentVolumes of this storage class are created with this reclaimPolicy. Defaults to Delete. */
        reclaimPolicy?: string;
        /** VolumeBindingMode indicates how PersistentVolumeClaims should be provisioned and bound.  When unset, VolumeBindingImmediate is used. This field is only honored by servers that enable the VolumeScheduling feature. */
        volumeBindingMode?: string;
    }
    /** StorageClassList is a collection of storage classes. */
    interface io$k8s$api$storage$v1$StorageClassList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is the list of StorageClasses */
        items: Schemas.io$k8s$api$storage$v1$StorageClass[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** TokenRequest contains parameters of a service account token. */
    interface io$k8s$api$storage$v1$TokenRequest {
        /** Audience is the intended audience of the token in "TokenRequestSpec". It will default to the audiences of kube apiserver. */
        audience: string;
        /** ExpirationSeconds is the duration of validity of the token in "TokenRequestSpec". It has the same default value of "ExpirationSeconds" in "TokenRequestSpec". */
        expirationSeconds?: number;
    }
    /**
     * VolumeAttachment captures the intent to attach or detach the specified volume to/from the specified node.
     *
     * VolumeAttachment objects are non-namespaced.
     */
    interface io$k8s$api$storage$v1$VolumeAttachment {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$storage$v1$VolumeAttachmentSpec;
        status?: Schemas.io$k8s$api$storage$v1$VolumeAttachmentStatus;
    }
    /** VolumeAttachmentList is a collection of VolumeAttachment objects. */
    interface io$k8s$api$storage$v1$VolumeAttachmentList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is the list of VolumeAttachments */
        items: Schemas.io$k8s$api$storage$v1$VolumeAttachment[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** VolumeAttachmentSource represents a volume that should be attached. Right now only PersistenVolumes can be attached via external attacher, in future we may allow also inline volumes in pods. Exactly one member can be set. */
    interface io$k8s$api$storage$v1$VolumeAttachmentSource {
        inlineVolumeSpec?: Schemas.io$k8s$api$core$v1$PersistentVolumeSpec;
        /** Name of the persistent volume to attach. */
        persistentVolumeName?: string;
    }
    /** VolumeAttachmentSpec is the specification of a VolumeAttachment request. */
    interface io$k8s$api$storage$v1$VolumeAttachmentSpec {
        /** Attacher indicates the name of the volume driver that MUST handle this request. This is the name returned by GetPluginName(). */
        attacher: string;
        /** The node that the volume should be attached to. */
        nodeName: string;
        source: Schemas.io$k8s$api$storage$v1$VolumeAttachmentSource;
    }
    /** VolumeAttachmentStatus is the status of a VolumeAttachment request. */
    interface io$k8s$api$storage$v1$VolumeAttachmentStatus {
        attachError?: Schemas.io$k8s$api$storage$v1$VolumeError;
        /** Indicates the volume is successfully attached. This field must only be set by the entity completing the attach operation, i.e. the external-attacher. */
        attached: boolean;
        /** Upon successful attach, this field is populated with any information returned by the attach operation that must be passed into subsequent WaitForAttach or Mount calls. This field must only be set by the entity completing the attach operation, i.e. the external-attacher. */
        attachmentMetadata?: {
            [key: string]: string;
        };
        detachError?: Schemas.io$k8s$api$storage$v1$VolumeError;
    }
    /** VolumeError captures an error encountered during a volume operation. */
    interface io$k8s$api$storage$v1$VolumeError {
        /** String detailing the error encountered during Attach or Detach operation. This string may be logged, so it should not contain sensitive information. */
        message?: string;
        time?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
    }
    /** VolumeNodeResources is a set of resource limits for scheduling of volumes. */
    interface io$k8s$api$storage$v1$VolumeNodeResources {
        /** Maximum number of unique volumes managed by the CSI driver that can be used on a node. A volume that is both attached and mounted on a node is considered to be used once, not twice. The same rule applies for a unique volume that is shared among multiple pods on the same node. If this field is not specified, then the supported number of volumes on this node is unbounded. */
        count?: number;
    }
    /**
     * CSIStorageCapacity stores the result of one CSI GetCapacity call. For a given StorageClass, this describes the available capacity in a particular topology segment.  This can be used when considering where to instantiate new PersistentVolumes.
     *
     * For example this can express things like: - StorageClass "standard" has "1234 GiB" available in "topology.kubernetes.io/zone=us-east1" - StorageClass "localssd" has "10 GiB" available in "kubernetes.io/hostname=knode-abc123"
     *
     * The following three cases all imply that no capacity is available for a certain combination: - no object exists with suitable topology and storage class name - such an object exists, but the capacity is unset - such an object exists, but the capacity is zero
     *
     * The producer of these objects can decide which approach is more suitable.
     *
     * They are consumed by the kube-scheduler if the CSIStorageCapacity beta feature gate is enabled there and a CSI driver opts into capacity-aware scheduling with CSIDriver.StorageCapacity.
     */
    interface io$k8s$api$storage$v1alpha1$CSIStorageCapacity {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        capacity?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        maximumVolumeSize?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        nodeTopology?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        /** The name of the StorageClass that the reported capacity applies to. It must meet the same requirements as the name of a StorageClass object (non-empty, DNS subdomain). If that object no longer exists, the CSIStorageCapacity object is obsolete and should be removed by its creator. This field is immutable. */
        storageClassName: string;
    }
    /** CSIStorageCapacityList is a collection of CSIStorageCapacity objects. */
    interface io$k8s$api$storage$v1alpha1$CSIStorageCapacityList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is the list of CSIStorageCapacity objects. */
        items: Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /**
     * CSIStorageCapacity stores the result of one CSI GetCapacity call. For a given StorageClass, this describes the available capacity in a particular topology segment.  This can be used when considering where to instantiate new PersistentVolumes.
     *
     * For example this can express things like: - StorageClass "standard" has "1234 GiB" available in "topology.kubernetes.io/zone=us-east1" - StorageClass "localssd" has "10 GiB" available in "kubernetes.io/hostname=knode-abc123"
     *
     * The following three cases all imply that no capacity is available for a certain combination: - no object exists with suitable topology and storage class name - such an object exists, but the capacity is unset - such an object exists, but the capacity is zero
     *
     * The producer of these objects can decide which approach is more suitable.
     *
     * They are consumed by the kube-scheduler if the CSIStorageCapacity beta feature gate is enabled there and a CSI driver opts into capacity-aware scheduling with CSIDriver.StorageCapacity.
     */
    interface io$k8s$api$storage$v1beta1$CSIStorageCapacity {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        capacity?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        maximumVolumeSize?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        nodeTopology?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        /** The name of the StorageClass that the reported capacity applies to. It must meet the same requirements as the name of a StorageClass object (non-empty, DNS subdomain). If that object no longer exists, the CSIStorageCapacity object is obsolete and should be removed by its creator. This field is immutable. */
        storageClassName: string;
    }
    /** CSIStorageCapacityList is a collection of CSIStorageCapacity objects. */
    interface io$k8s$api$storage$v1beta1$CSIStorageCapacityList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is the list of CSIStorageCapacity objects. */
        items: Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** CustomResourceColumnDefinition specifies a column for server side printing. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceColumnDefinition {
        /** description is a human readable description of this column. */
        description?: string;
        /** format is an optional OpenAPI type definition for this column. The 'name' format is applied to the primary identifier column to assist in clients identifying column is the resource name. See https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#data-types for details. */
        format?: string;
        /** jsonPath is a simple JSON path (i.e. with array notation) which is evaluated against each custom resource to produce the value for this column. */
        jsonPath: string;
        /** name is a human readable name for the column. */
        name: string;
        /** priority is an integer defining the relative importance of this column compared to others. Lower numbers are considered higher priority. Columns that may be omitted in limited space scenarios should be given a priority greater than 0. */
        priority?: number;
        /** type is an OpenAPI type definition for this column. See https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#data-types for details. */
        type: string;
    }
    /** CustomResourceConversion describes how to convert different versions of a CR. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceConversion {
        /**
         * strategy specifies how custom resources are converted between versions. Allowed values are: - `None`: The converter only change the apiVersion and would not touch any other field in the custom resource. - `Webhook`: API Server will call to an external webhook to do the conversion. Additional information
         *   is needed for this option. This requires spec.preserveUnknownFields to be false, and spec.conversion.webhook to be set.
         */
        strategy: string;
        webhook?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$WebhookConversion;
    }
    /** CustomResourceDefinition represents a resource that should be exposed on the API server.  Its name MUST be in the format <.spec.name>.<.spec.group>. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionSpec;
        status?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionStatus;
    }
    /** CustomResourceDefinitionCondition contains details for the current condition of this pod. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** message is a human-readable message indicating details about last transition. */
        message?: string;
        /** reason is a unique, one-word, CamelCase reason for the condition's last transition. */
        reason?: string;
        /** status is the status of the condition. Can be True, False, Unknown. */
        status: string;
        /** type is the type of the condition. Types include Established, NamesAccepted and Terminating. */
        type: string;
    }
    /** CustomResourceDefinitionList is a list of CustomResourceDefinition objects. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items list individual CustomResourceDefinition objects */
        items: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** CustomResourceDefinitionNames indicates the names to serve this CustomResourceDefinition */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionNames {
        /** categories is a list of grouped resources this custom resource belongs to (e.g. 'all'). This is published in API discovery documents, and used by clients to support invocations like `kubectl get all`. */
        categories?: string[];
        /** kind is the serialized kind of the resource. It is normally CamelCase and singular. Custom resource instances will use this value as the `kind` attribute in API calls. */
        kind: string;
        /** listKind is the serialized kind of the list for this resource. Defaults to "`kind`List". */
        listKind?: string;
        /** plural is the plural name of the resource to serve. The custom resources are served under `/apis/<group>/<version>/.../<plural>`. Must match the name of the CustomResourceDefinition (in the form `<names.plural>.<group>`). Must be all lowercase. */
        plural: string;
        /** shortNames are short names for the resource, exposed in API discovery documents, and used by clients to support invocations like `kubectl get <shortname>`. It must be all lowercase. */
        shortNames?: string[];
        /** singular is the singular name of the resource. It must be all lowercase. Defaults to lowercased `kind`. */
        singular?: string;
    }
    /** CustomResourceDefinitionSpec describes how a user wants their resource to appear */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionSpec {
        conversion?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceConversion;
        /** group is the API group of the defined custom resource. The custom resources are served under `/apis/<group>/...`. Must match the name of the CustomResourceDefinition (in the form `<names.plural>.<group>`). */
        group: string;
        names: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionNames;
        /** preserveUnknownFields indicates that object fields which are not specified in the OpenAPI schema should be preserved when persisting to storage. apiVersion, kind, metadata and known fields inside metadata are always preserved. This field is deprecated in favor of setting `x-preserve-unknown-fields` to true in `spec.versions[*].schema.openAPIV3Schema`. See https://kubernetes.io/docs/tasks/access-kubernetes-api/custom-resources/custom-resource-definitions/#pruning-versus-preserving-unknown-fields for details. */
        preserveUnknownFields?: boolean;
        /** scope indicates whether the defined custom resource is cluster- or namespace-scoped. Allowed values are `Cluster` and `Namespaced`. */
        scope: string;
        /** versions is the list of all API versions of the defined custom resource. Version names are used to compute the order in which served versions are listed in API discovery. If the version string is "kube-like", it will sort above non "kube-like" version strings, which are ordered lexicographically. "Kube-like" versions start with a "v", then are followed by a number (the major version), then optionally the string "alpha" or "beta" and another number (the minor version). These are sorted first by GA > beta > alpha (where GA is a version with no suffix such as beta or alpha), and then by comparing major version, then minor version. An example sorted list of versions: v10, v2, v1, v11beta2, v10beta3, v3beta1, v12alpha1, v11alpha2, foo1, foo10. */
        versions: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionVersion[];
    }
    /** CustomResourceDefinitionStatus indicates the state of the CustomResourceDefinition */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionStatus {
        acceptedNames?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionNames;
        /** conditions indicate state for particular aspects of a CustomResourceDefinition */
        conditions?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionCondition[];
        /** storedVersions lists all versions of CustomResources that were ever persisted. Tracking these versions allows a migration path for stored versions in etcd. The field is mutable so a migration controller can finish a migration to another version (ensuring no old objects are left in storage), and then remove the rest of the versions from this list. Versions may not be removed from `spec.versions` while they exist in this list. */
        storedVersions?: string[];
    }
    /** CustomResourceDefinitionVersion describes a version for CRD. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionVersion {
        /** additionalPrinterColumns specifies additional columns returned in Table output. See https://kubernetes.io/docs/reference/using-api/api-concepts/#receiving-resources-as-tables for details. If no columns are specified, a single column displaying the age of the custom resource is used. */
        additionalPrinterColumns?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceColumnDefinition[];
        /** deprecated indicates this version of the custom resource API is deprecated. When set to true, API requests to this version receive a warning header in the server response. Defaults to false. */
        deprecated?: boolean;
        /** deprecationWarning overrides the default warning returned to API clients. May only be set when `deprecated` is true. The default warning indicates this version is deprecated and recommends use of the newest served version of equal or greater stability, if one exists. */
        deprecationWarning?: string;
        /** name is the version name, e.g. “v1”, “v2beta1”, etc. The custom resources are served under this version at `/apis/<group>/<version>/...` if `served` is true. */
        name: string;
        schema?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceValidation;
        /** served is a flag enabling/disabling this version from being served via REST APIs */
        served: boolean;
        /** storage indicates this version should be used when persisting custom resources to storage. There must be exactly one version with storage=true. */
        storage: boolean;
        subresources?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceSubresources;
    }
    /** CustomResourceSubresourceScale defines how to serve the scale subresource for CustomResources. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceSubresourceScale {
        /** labelSelectorPath defines the JSON path inside of a custom resource that corresponds to Scale `status.selector`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.status` or `.spec`. Must be set to work with HorizontalPodAutoscaler. The field pointed by this JSON path must be a string field (not a complex selector struct) which contains a serialized label selector in string form. More info: https://kubernetes.io/docs/tasks/access-kubernetes-api/custom-resources/custom-resource-definitions#scale-subresource If there is no value under the given path in the custom resource, the `status.selector` value in the `/scale` subresource will default to the empty string. */
        labelSelectorPath?: string;
        /** specReplicasPath defines the JSON path inside of a custom resource that corresponds to Scale `spec.replicas`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.spec`. If there is no value under the given path in the custom resource, the `/scale` subresource will return an error on GET. */
        specReplicasPath: string;
        /** statusReplicasPath defines the JSON path inside of a custom resource that corresponds to Scale `status.replicas`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.status`. If there is no value under the given path in the custom resource, the `status.replicas` value in the `/scale` subresource will default to 0. */
        statusReplicasPath: string;
    }
    /** CustomResourceSubresourceStatus defines how to serve the status subresource for CustomResources. Status is represented by the `.status` JSON path inside of a CustomResource. When set, * exposes a /status subresource for the custom resource * PUT requests to the /status subresource take a custom resource object, and ignore changes to anything except the status stanza * PUT/POST/PATCH requests to the custom resource ignore changes to the status stanza */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceSubresourceStatus {
    }
    /** CustomResourceSubresources defines the status and scale subresources for CustomResources. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceSubresources {
        scale?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceSubresourceScale;
        status?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceSubresourceStatus;
    }
    /** CustomResourceValidation is a list of validation methods for CustomResources. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceValidation {
        openAPIV3Schema?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaProps;
    }
    /** ExternalDocumentation allows referencing an external resource for extended documentation. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$ExternalDocumentation {
        description?: string;
        url?: string;
    }
    /** JSON represents any valid JSON value. These types are supported: bool, int64, float64, string, []interface{}, map[string]interface{} and nil. */
    type io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSON = any;
    /** JSONSchemaProps is a JSON-Schema following Specification Draft 4 (http://json-schema.org/). */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaProps {
        "$ref"?: string;
        "$schema"?: string;
        additionalItems?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaPropsOrBool;
        additionalProperties?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaPropsOrBool;
        allOf?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaProps[];
        anyOf?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaProps[];
        default?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSON;
        definitions?: {
            [key: string]: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaProps;
        };
        dependencies?: {
            [key: string]: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaPropsOrStringArray;
        };
        description?: string;
        enum?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSON[];
        example?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSON;
        exclusiveMaximum?: boolean;
        exclusiveMinimum?: boolean;
        externalDocs?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$ExternalDocumentation;
        /**
         * format is an OpenAPI v3 format string. Unknown formats are ignored. The following formats are validated:
         *
         * - bsonobjectid: a bson object ID, i.e. a 24 characters hex string - uri: an URI as parsed by Golang net/url.ParseRequestURI - email: an email address as parsed by Golang net/mail.ParseAddress - hostname: a valid representation for an Internet host name, as defined by RFC 1034, section 3.1 [RFC1034]. - ipv4: an IPv4 IP as parsed by Golang net.ParseIP - ipv6: an IPv6 IP as parsed by Golang net.ParseIP - cidr: a CIDR as parsed by Golang net.ParseCIDR - mac: a MAC address as parsed by Golang net.ParseMAC - uuid: an UUID that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?[0-9a-f]{4}-?[0-9a-f]{4}-?[0-9a-f]{12}$ - uuid3: an UUID3 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?3[0-9a-f]{3}-?[0-9a-f]{4}-?[0-9a-f]{12}$ - uuid4: an UUID4 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?4[0-9a-f]{3}-?[89ab][0-9a-f]{3}-?[0-9a-f]{12}$ - uuid5: an UUID5 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?5[0-9a-f]{3}-?[89ab][0-9a-f]{3}-?[0-9a-f]{12}$ - isbn: an ISBN10 or ISBN13 number string like "0321751043" or "978-0321751041" - isbn10: an ISBN10 number string like "0321751043" - isbn13: an ISBN13 number string like "978-0321751041" - creditcard: a credit card number defined by the regex ^(?:4[0-9]{12}(?:[0-9]{3})?|5[1-5][0-9]{14}|6(?:011|5[0-9][0-9])[0-9]{12}|3[47][0-9]{13}|3(?:0[0-5]|[68][0-9])[0-9]{11}|(?:2131|1800|35\d{3})\d{11})$ with any non digit characters mixed in - ssn: a U.S. social security number following the regex ^\d{3}[- ]?\d{2}[- ]?\d{4}$ - hexcolor: an hexadecimal color code like "#FFFFFF: following the regex ^#?([0-9a-fA-F]{3}|[0-9a-fA-F]{6})$ - rgbcolor: an RGB color code like rgb like "rgb(255,255,2559" - byte: base64 encoded binary data - password: any kind of string - date: a date string like "2006-01-02" as defined by full-date in RFC3339 - duration: a duration string like "22 ns" as parsed by Golang time.ParseDuration or compatible with Scala duration format - datetime: a date time string like "2014-12-15T19:30:20.000Z" as defined by date-time in RFC3339.
         */
        format?: string;
        id?: string;
        items?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaPropsOrArray;
        maxItems?: number;
        maxLength?: number;
        maxProperties?: number;
        maximum?: number;
        minItems?: number;
        minLength?: number;
        minProperties?: number;
        minimum?: number;
        multipleOf?: number;
        not?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaProps;
        nullable?: boolean;
        oneOf?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaProps[];
        pattern?: string;
        patternProperties?: {
            [key: string]: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaProps;
        };
        properties?: {
            [key: string]: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaProps;
        };
        required?: string[];
        title?: string;
        type?: string;
        uniqueItems?: boolean;
        /** x-kubernetes-embedded-resource defines that the value is an embedded Kubernetes runtime.Object, with TypeMeta and ObjectMeta. The type must be object. It is allowed to further restrict the embedded object. kind, apiVersion and metadata are validated automatically. x-kubernetes-preserve-unknown-fields is allowed to be true, but does not have to be if the object is fully specified (up to kind, apiVersion, metadata). */
        "x-kubernetes-embedded-resource"?: boolean;
        /**
         * x-kubernetes-int-or-string specifies that this value is either an integer or a string. If this is true, an empty type is allowed and type as child of anyOf is permitted if following one of the following patterns:
         *
         * 1) anyOf:
         *    - type: integer
         *    - type: string
         * 2) allOf:
         *    - anyOf:
         *      - type: integer
         *      - type: string
         *    - ... zero or more
         */
        "x-kubernetes-int-or-string"?: boolean;
        /**
         * x-kubernetes-list-map-keys annotates an array with the x-kubernetes-list-type `map` by specifying the keys used as the index of the map.
         *
         * This tag MUST only be used on lists that have the "x-kubernetes-list-type" extension set to "map". Also, the values specified for this attribute must be a scalar typed field of the child structure (no nesting is supported).
         *
         * The properties specified must either be required or have a default value, to ensure those properties are present for all list items.
         */
        "x-kubernetes-list-map-keys"?: string[];
        /**
         * x-kubernetes-list-type annotates an array to further describe its topology. This extension must only be used on lists and may have 3 possible values:
         *
         * 1) `atomic`: the list is treated as a single entity, like a scalar.
         *      Atomic lists will be entirely replaced when updated. This extension
         *      may be used on any type of list (struct, scalar, ...).
         * 2) `set`:
         *      Sets are lists that must not have multiple items with the same value. Each
         *      value must be a scalar, an object with x-kubernetes-map-type `atomic` or an
         *      array with x-kubernetes-list-type `atomic`.
         * 3) `map`:
         *      These lists are like maps in that their elements have a non-index key
         *      used to identify them. Order is preserved upon merge. The map tag
         *      must only be used on a list with elements of type object.
         * Defaults to atomic for arrays.
         */
        "x-kubernetes-list-type"?: string;
        /**
         * x-kubernetes-map-type annotates an object to further describe its topology. This extension must only be used when type is object and may have 2 possible values:
         *
         * 1) `granular`:
         *      These maps are actual maps (key-value pairs) and each fields are independent
         *      from each other (they can each be manipulated by separate actors). This is
         *      the default behaviour for all maps.
         * 2) `atomic`: the list is treated as a single entity, like a scalar.
         *      Atomic maps will be entirely replaced when updated.
         */
        "x-kubernetes-map-type"?: string;
        /** x-kubernetes-preserve-unknown-fields stops the API server decoding step from pruning fields which are not specified in the validation schema. This affects fields recursively, but switches back to normal pruning behaviour if nested properties or additionalProperties are specified in the schema. This can either be true or undefined. False is forbidden. */
        "x-kubernetes-preserve-unknown-fields"?: boolean;
        /** x-kubernetes-validations describes a list of validation rules written in the CEL expression language. This field is an alpha-level. Using this field requires the feature gate `CustomResourceValidationExpressions` to be enabled. */
        "x-kubernetes-validations"?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$ValidationRule[];
    }
    /** JSONSchemaPropsOrArray represents a value that can either be a JSONSchemaProps or an array of JSONSchemaProps. Mainly here for serialization purposes. */
    type io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaPropsOrArray = any;
    /** JSONSchemaPropsOrBool represents JSONSchemaProps or a boolean value. Defaults to true for the boolean property. */
    type io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaPropsOrBool = any;
    /** JSONSchemaPropsOrStringArray represents a JSONSchemaProps or a string array. */
    type io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaPropsOrStringArray = any;
    /** ServiceReference holds a reference to Service.legacy.k8s.io */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$ServiceReference {
        /** name is the name of the service. Required */
        name: string;
        /** namespace is the namespace of the service. Required */
        namespace: string;
        /** path is an optional URL path at which the webhook will be contacted. */
        path?: string;
        /** port is an optional service port at which the webhook will be contacted. `port` should be a valid port number (1-65535, inclusive). Defaults to 443 for backward compatibility. */
        port?: number;
    }
    /** ValidationRule describes a validation rule written in the CEL expression language. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$ValidationRule {
        /** Message represents the message displayed when validation fails. The message is required if the Rule contains line breaks. The message must not contain line breaks. If unset, the message is "failed rule: {Rule}". e.g. "must be a URL with the host matching spec.host" */
        message?: string;
        /**
         * Rule represents the expression which will be evaluated by CEL. ref: https://github.com/google/cel-spec The Rule is scoped to the location of the x-kubernetes-validations extension in the schema. The `self` variable in the CEL expression is bound to the scoped value. Example: - Rule scoped to the root of a resource with a status subresource: {"rule": "self.status.actual <= self.spec.maxDesired"}
         *
         * If the Rule is scoped to an object with properties, the accessible properties of the object are field selectable via `self.field` and field presence can be checked via `has(self.field)`. Null valued fields are treated as absent fields in CEL expressions. If the Rule is scoped to an object with additionalProperties (i.e. a map) the value of the map are accessible via `self[mapKey]`, map containment can be checked via `mapKey in self` and all entries of the map are accessible via CEL macros and functions such as `self.all(...)`. If the Rule is scoped to an array, the elements of the array are accessible via `self[i]` and also by macros and functions. If the Rule is scoped to a scalar, `self` is bound to the scalar value. Examples: - Rule scoped to a map of objects: {"rule": "self.components['Widget'].priority < 10"} - Rule scoped to a list of integers: {"rule": "self.values.all(value, value >= 0 && value < 100)"} - Rule scoped to a string value: {"rule": "self.startsWith('kube')"}
         *
         * The `apiVersion`, `kind`, `metadata.name` and `metadata.generateName` are always accessible from the root of the object and from any x-kubernetes-embedded-resource annotated objects. No other metadata properties are accessible.
         *
         * Unknown data preserved in custom resources via x-kubernetes-preserve-unknown-fields is not accessible in CEL expressions. This includes: - Unknown field values that are preserved by object schemas with x-kubernetes-preserve-unknown-fields. - Object properties where the property schema is of an "unknown type". An "unknown type" is recursively defined as:
         *   - A schema with no type and x-kubernetes-preserve-unknown-fields set to true
         *   - An array where the items schema is of an "unknown type"
         *   - An object where the additionalProperties schema is of an "unknown type"
         *
         * Only property names of the form `[a-zA-Z_.-/][a-zA-Z0-9_.-/]*` are accessible. Accessible property names are escaped according to the following rules when accessed in the expression: - '__' escapes to '__underscores__' - '.' escapes to '__dot__' - '-' escapes to '__dash__' - '/' escapes to '__slash__' - Property names that exactly match a CEL RESERVED keyword escape to '__{keyword}__'. The keywords are:
         * 	  "true", "false", "null", "in", "as", "break", "const", "continue", "else", "for", "function", "if",
         * 	  "import", "let", "loop", "package", "namespace", "return".
         * Examples:
         *   - Rule accessing a property named "namespace": {"rule": "self.__namespace__ > 0"}
         *   - Rule accessing a property named "x-prop": {"rule": "self.x__dash__prop > 0"}
         *   - Rule accessing a property named "redact__d": {"rule": "self.redact__underscores__d > 0"}
         *
         * Equality on arrays with x-kubernetes-list-type of 'set' or 'map' ignores element order, i.e. [1, 2] == [2, 1]. Concatenation on arrays with x-kubernetes-list-type use the semantics of the list type:
         *   - 'set': `X + Y` performs a union where the array positions of all elements in `X` are preserved and
         *     non-intersecting elements in `Y` are appended, retaining their partial order.
         *   - 'map': `X + Y` performs a merge where the array positions of all keys in `X` are preserved but the values
         *     are overwritten by values in `Y` when the key sets of `X` and `Y` intersect. Elements in `Y` with
         *     non-intersecting keys are appended, retaining their partial order.
         */
        rule: string;
    }
    /** WebhookClientConfig contains the information to make a TLS connection with the webhook. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$WebhookClientConfig {
        /** caBundle is a PEM encoded CA bundle which will be used to validate the webhook's server certificate. If unspecified, system trust roots on the apiserver are used. */
        caBundle?: Blob;
        service?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$ServiceReference;
        /**
         * url gives the location of the webhook, in standard URL form (`scheme://host:port/path`). Exactly one of `url` or `service` must be specified.
         *
         * The `host` should not refer to a service running in the cluster; use the `service` field instead. The host might be resolved via external DNS in some apiservers (e.g., `kube-apiserver` cannot resolve in-cluster DNS as that would be a layering violation). `host` may also be an IP address.
         *
         * Please note that using `localhost` or `127.0.0.1` as a `host` is risky unless you take great care to run this webhook on all hosts which run an apiserver which might need to make calls to this webhook. Such installs are likely to be non-portable, i.e., not easy to turn up in a new cluster.
         *
         * The scheme must be "https"; the URL must begin with "https://".
         *
         * A path is optional, and if present may be any string permissible in a URL. You may use the path to pass an arbitrary string to the webhook, for example, a cluster identifier.
         *
         * Attempting to use a user or basic auth e.g. "user:password@" is not allowed. Fragments ("#...") and query parameters ("?...") are not allowed, either.
         */
        url?: string;
    }
    /** WebhookConversion describes how to call a conversion webhook */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$WebhookConversion {
        clientConfig?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$WebhookClientConfig;
        /** conversionReviewVersions is an ordered list of preferred `ConversionReview` versions the Webhook expects. The API server will use the first version in the list which it supports. If none of the versions specified in this list are supported by API server, conversion will fail for the custom resource. If a persisted Webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail. */
        conversionReviewVersions: string[];
    }
    /**
     * Quantity is a fixed-point representation of a number. It provides convenient marshaling/unmarshaling in JSON and YAML, in addition to String() and AsInt64() accessors.
     *
     * The serialization format is:
     *
     * <quantity>        ::= <signedNumber><suffix>
     *   (Note that <suffix> may be empty, from the "" case in <decimalSI>.)
     * <digit>           ::= 0 | 1 | ... | 9 <digits>          ::= <digit> | <digit><digits> <number>          ::= <digits> | <digits>.<digits> | <digits>. | .<digits> <sign>            ::= "+" | "-" <signedNumber>    ::= <number> | <sign><number> <suffix>          ::= <binarySI> | <decimalExponent> | <decimalSI> <binarySI>        ::= Ki | Mi | Gi | Ti | Pi | Ei
     *   (International System of units; See: http://physics.nist.gov/cuu/Units/binary.html)
     * <decimalSI>       ::= m | "" | k | M | G | T | P | E
     *   (Note that 1024 = 1Ki but 1000 = 1k; I didn't choose the capitalization.)
     * <decimalExponent> ::= "e" <signedNumber> | "E" <signedNumber>
     *
     * No matter which of the three exponent forms is used, no quantity may represent a number greater than 2^63-1 in magnitude, nor may it have more than 3 decimal places. Numbers larger or more precise will be capped or rounded up. (E.g.: 0.1m will rounded up to 1m.) This may be extended in the future if we require larger or smaller quantities.
     *
     * When a Quantity is parsed from a string, it will remember the type of suffix it had, and will use the same type again when it is serialized.
     *
     * Before serializing, Quantity will be put in "canonical form". This means that Exponent/suffix will be adjusted up or down (with a corresponding increase or decrease in Mantissa) such that:
     *   a. No precision is lost
     *   b. No fractional digits will be emitted
     *   c. The exponent (or suffix) is as large as possible.
     * The sign will be omitted unless the number is negative.
     *
     * Examples:
     *   1.5 will be serialized as "1500m"
     *   1.5Gi will be serialized as "1536Mi"
     *
     * Note that the quantity will NEVER be internally represented by a floating point number. That is the whole point of this exercise.
     *
     * Non-canonical values will still parse as long as they are well formed, but will be re-emitted in their canonical form. (So always use canonical form, or don't diff.)
     *
     * This format is intended to make it difficult to use these numbers without writing some sort of special handling code in the hopes that that will cause implementors to also use a fixed point implementation.
     */
    type io$k8s$apimachinery$pkg$api$resource$Quantity = string;
    /** APIGroup contains the name, the supported versions, and the preferred version of a group. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        /** name is the name of the group. */
        name: string;
        preferredVersion?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$GroupVersionForDiscovery;
        /** a map of client CIDR to server address that is serving this group. This is to help clients reach servers in the most network-efficient way possible. Clients can use the appropriate server address as per the CIDR that they match. In case of multiple matches, clients should use the longest matching CIDR. The server returns only those CIDRs that it thinks that the client can match. For example: the master will return an internal IP CIDR only, if the client reaches the server using an internal IP. Server looks at X-Forwarded-For header or X-Real-Ip header or request.RemoteAddr (in that order) to get the client IP. */
        serverAddressByClientCIDRs?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ServerAddressByClientCIDR[];
        /** versions are the versions supported in this group. */
        versions: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$GroupVersionForDiscovery[];
    }
    /** APIGroupList is a list of APIGroup, to allow clients to discover the API at /apis. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$APIGroupList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** groups is a list of APIGroup. */
        groups: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
    }
    /** APIResource specifies the name of a resource and whether it is namespaced. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$APIResource {
        /** categories is a list of the grouped resources this resource belongs to (e.g. 'all') */
        categories?: string[];
        /** group is the preferred group of the resource.  Empty implies the group of the containing resource list. For subresources, this may have a different value, for example: Scale". */
        group?: string;
        /** kind is the kind for the resource (e.g. 'Foo' is the kind for a resource 'foo') */
        kind: string;
        /** name is the plural name of the resource. */
        name: string;
        /** namespaced indicates if a resource is namespaced or not. */
        namespaced: boolean;
        /** shortNames is a list of suggested short names of the resource. */
        shortNames?: string[];
        /** singularName is the singular name of the resource.  This allows clients to handle plural and singular opaquely. The singularName is more correct for reporting status on a single item and both singular and plural are allowed from the kubectl CLI interface. */
        singularName: string;
        /** The hash value of the storage version, the version this resource is converted to when written to the data store. Value must be treated as opaque by clients. Only equality comparison on the value is valid. This is an alpha feature and may change or be removed in the future. The field is populated by the apiserver only if the StorageVersionHash feature gate is enabled. This field will remain optional even if it graduates. */
        storageVersionHash?: string;
        /** verbs is a list of supported kube verbs (this includes get, list, watch, create, update, patch, delete, deletecollection, and proxy) */
        verbs: string[];
        /** version is the preferred version of the resource.  Empty implies the version of the containing resource list For subresources, this may have a different value, for example: v1 (while inside a v1beta1 version of the core resource's group)". */
        version?: string;
    }
    /** APIResourceList is a list of APIResource, it is used to expose the name of the resources supported in a specific group and version, and if the resource is namespaced. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** groupVersion is the group and version this APIResourceList is for. */
        groupVersion: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        /** resources contains the name of the resources and if they are namespaced. */
        resources: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResource[];
    }
    /** APIVersions lists the versions that are available, to allow clients to discover the API at /api, which is the root path of the legacy v1 API. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$APIVersions {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        /** a map of client CIDR to server address that is serving this group. This is to help clients reach servers in the most network-efficient way possible. Clients can use the appropriate server address as per the CIDR that they match. In case of multiple matches, clients should use the longest matching CIDR. The server returns only those CIDRs that it thinks that the client can match. For example: the master will return an internal IP CIDR only, if the client reaches the server using an internal IP. Server looks at X-Forwarded-For header or X-Real-Ip header or request.RemoteAddr (in that order) to get the client IP. */
        serverAddressByClientCIDRs: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ServerAddressByClientCIDR[];
        /** versions are the api versions that are available. */
        versions: string[];
    }
    /** Condition contains details for one aspect of the current state of this API Resource. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$Condition {
        lastTransitionTime: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** message is a human readable message indicating details about the transition. This may be an empty string. */
        message: string;
        /** observedGeneration represents the .metadata.generation that the condition was set based upon. For instance, if .metadata.generation is currently 12, but the .status.conditions[x].observedGeneration is 9, the condition is out of date with respect to the current state of the instance. */
        observedGeneration?: number;
        /** reason contains a programmatic identifier indicating the reason for the condition's last transition. Producers of specific condition types may define expected values and meanings for this field, and whether the values are considered a guaranteed API. The value should be a CamelCase string. This field may not be empty. */
        reason: string;
        /** status of the condition, one of True, False, Unknown. */
        status: string;
        /** type of condition in CamelCase or in foo.example.com/CamelCase. */
        type: string;
    }
    /** DeleteOptions may be provided when deleting an API object. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
        dryRun?: string[];
        /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
        gracePeriodSeconds?: number;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
        orphanDependents?: boolean;
        preconditions?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Preconditions;
        /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
        propagationPolicy?: string;
    }
    /**
     * FieldsV1 stores a set of fields in a data structure like a Trie, in JSON format.
     *
     * Each key is either a '.' representing the field itself, and will always map to an empty set, or a string representing a sub-field or item. The string will follow one of these four formats: 'f:<name>', where <name> is the name of a field in a struct, or key in a map 'v:<value>', where <value> is the exact json formatted value of a list item 'i:<index>', where <index> is position of a item in a list 'k:<keys>', where <keys> is a map of  a list item's key fields to their unique values If a key maps to an empty Fields value, the field that key represents is part of the set.
     *
     * The exact format is defined in sigs.k8s.io/structured-merge-diff
     */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$FieldsV1 {
    }
    /** GroupVersion contains the "group/version" and "version" string of a version. It is made a struct to keep extensibility. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$GroupVersionForDiscovery {
        /** groupVersion specifies the API group and version in the form "group/version" */
        groupVersion: string;
        /** version specifies the version in the form of "version". This is to save the clients the trouble of splitting the GroupVersion. */
        version: string;
    }
    /** A label selector is a label query over a set of resources. The result of matchLabels and matchExpressions are ANDed. An empty label selector matches all objects. A null label selector matches no objects. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector {
        /** matchExpressions is a list of label selector requirements. The requirements are ANDed. */
        matchExpressions?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelectorRequirement[];
        /** matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed. */
        matchLabels?: {
            [key: string]: string;
        };
    }
    /** A label selector requirement is a selector that contains values, a key, and an operator that relates the key and values. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelectorRequirement {
        /** key is the label key that the selector applies to. */
        key: string;
        /** operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist. */
        operator: string;
        /** values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch. */
        values?: string[];
    }
    /** ListMeta describes metadata that synthetic resources must have, including lists and various status objects. A resource may have only one of {ObjectMeta, ListMeta}. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta {
        /** continue may be set if the user set a limit on the number of items returned, and indicates that the server has more data available. The value is opaque and may be used to issue another request to the endpoint that served this list to retrieve the next set of available objects. Continuing a consistent list may not be possible if the server configuration has changed or more than a few minutes have passed. The resourceVersion field returned when using this continue value will be identical to the value in the first response, unless you have received this token from an error message. */
        continue?: string;
        /** remainingItemCount is the number of subsequent items in the list which are not included in this list response. If the list request contained label or field selectors, then the number of remaining items is unknown and the field will be left unset and omitted during serialization. If the list is complete (either because it is not chunking or because this is the last chunk), then there are no more remaining items and this field will be left unset and omitted during serialization. Servers older than v1.15 do not set this field. The intended use of the remainingItemCount is *estimating* the size of a collection. Clients should not rely on the remainingItemCount to be set or to be exact. */
        remainingItemCount?: number;
        /** String that identifies the server's internal version of this object that can be used by clients to determine when objects have changed. Value must be treated as opaque by clients and passed unmodified back to the server. Populated by the system. Read-only. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#concurrency-control-and-consistency */
        resourceVersion?: string;
        /**
         * selfLink is a URL representing this object. Populated by the system. Read-only.
         *
         * DEPRECATED Kubernetes will stop propagating this field in 1.20 release and the field is planned to be removed in 1.21 release.
         */
        selfLink?: string;
    }
    /** ManagedFieldsEntry is a workflow-id, a FieldSet and the group version of the resource that the fieldset applies to. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$ManagedFieldsEntry {
        /** APIVersion defines the version of this resource that this field set applies to. The format is "group/version" just like the top-level APIVersion field. It is necessary to track the version of a field set because it cannot be automatically converted. */
        apiVersion?: string;
        /** FieldsType is the discriminator for the different fields format and version. There is currently only one possible value: "FieldsV1" */
        fieldsType?: string;
        fieldsV1?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$FieldsV1;
        /** Manager is an identifier of the workflow managing these fields. */
        manager?: string;
        /** Operation is the type of operation which lead to this ManagedFieldsEntry being created. The only valid values for this field are 'Apply' and 'Update'. */
        operation?: string;
        /** Subresource is the name of the subresource used to update that object, or empty string if the object was updated through the main resource. The value of this field is used to distinguish between managers, even if they share the same name. For example, a status update will be distinct from a regular update using the same manager name. Note that the APIVersion field is not related to the Subresource field and it always corresponds to the version of the main resource. */
        subresource?: string;
        time?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
    }
    /** MicroTime is version of Time with microsecond level precision. */
    type io$k8s$apimachinery$pkg$apis$meta$v1$MicroTime = string;
    /** ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta {
        /** Annotations is an unstructured key value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: http://kubernetes.io/docs/user-guide/annotations */
        annotations?: {
            [key: string]: string;
        };
        /** The name of the cluster which the object belongs to. This is used to distinguish resources with same name and namespace in different clusters. This field is not set anywhere right now and apiserver is going to ignore it if set in create or update request. */
        clusterName?: string;
        creationTimestamp?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** Number of seconds allowed for this object to gracefully terminate before it will be removed from the system. Only set when deletionTimestamp is also set. May only be shortened. Read-only. */
        deletionGracePeriodSeconds?: number;
        deletionTimestamp?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** Must be empty before the object is deleted from the registry. Each entry is an identifier for the responsible component that will remove the entry from the list. If the deletionTimestamp of the object is non-nil, entries in this list can only be removed. Finalizers may be processed and removed in any order.  Order is NOT enforced because it introduces significant risk of stuck finalizers. finalizers is a shared field, any actor with permission can reorder it. If the finalizer list is processed in order, then this can lead to a situation in which the component responsible for the first finalizer in the list is waiting for a signal (field value, external system, or other) produced by a component responsible for a finalizer later in the list, resulting in a deadlock. Without enforced ordering finalizers are free to order amongst themselves and are not vulnerable to ordering changes in the list. */
        finalizers?: string[];
        /**
         * GenerateName is an optional prefix, used by the server, to generate a unique name ONLY IF the Name field has not been provided. If this field is used, the name returned to the client will be different than the name passed. This value will also be combined with a unique suffix. The provided value has the same validation rules as the Name field, and may be truncated by the length of the suffix required to make the value unique on the server.
         *
         * If this field is specified and the generated name exists, the server will NOT return a 409 - instead, it will either return 201 Created or 500 with Reason ServerTimeout indicating a unique name could not be found in the time allotted, and the client should retry (optionally after the time indicated in the Retry-After header).
         *
         * Applied only if Name is not specified. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#idempotency
         */
        generateName?: string;
        /** A sequence number representing a specific generation of the desired state. Populated by the system. Read-only. */
        generation?: number;
        /** Map of string keys and values that can be used to organize and categorize (scope and select) objects. May match selectors of replication controllers and services. More info: http://kubernetes.io/docs/user-guide/labels */
        labels?: {
            [key: string]: string;
        };
        /** ManagedFields maps workflow-id and version to the set of fields that are managed by that workflow. This is mostly for internal housekeeping, and users typically shouldn't need to set or understand this field. A workflow can be the user's name, a controller's name, or the name of a specific apply path like "ci-cd". The set of fields is always in the version that the workflow used when modifying the object. */
        managedFields?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ManagedFieldsEntry[];
        /** Name must be unique within a namespace. Is required when creating resources, although some resources may allow a client to request the generation of an appropriate name automatically. Name is primarily intended for creation idempotence and configuration definition. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/identifiers#names */
        name?: string;
        /**
         * Namespace defines the space within which each name must be unique. An empty namespace is equivalent to the "default" namespace, but "default" is the canonical representation. Not all objects are required to be scoped to a namespace - the value of this field for those objects will be empty.
         *
         * Must be a DNS_LABEL. Cannot be updated. More info: http://kubernetes.io/docs/user-guide/namespaces
         */
        namespace?: string;
        /** List of objects depended by this object. If ALL objects in the list have been deleted, this object will be garbage collected. If this object is managed by a controller, then an entry in this list will point to this controller, with the controller field set to true. There cannot be more than one managing controller. */
        ownerReferences?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$OwnerReference[];
        /**
         * An opaque value that represents the internal version of this object that can be used by clients to determine when objects have changed. May be used for optimistic concurrency, change detection, and the watch operation on a resource or set of resources. Clients must treat these values as opaque and passed unmodified back to the server. They may only be valid for a particular resource or set of resources.
         *
         * Populated by the system. Read-only. Value must be treated as opaque by clients and . More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#concurrency-control-and-consistency
         */
        resourceVersion?: string;
        /**
         * SelfLink is a URL representing this object. Populated by the system. Read-only.
         *
         * DEPRECATED Kubernetes will stop propagating this field in 1.20 release and the field is planned to be removed in 1.21 release.
         */
        selfLink?: string;
        /**
         * UID is the unique in time and space value for this object. It is typically generated by the server on successful creation of a resource and is not allowed to change on PUT operations.
         *
         * Populated by the system. Read-only. More info: http://kubernetes.io/docs/user-guide/identifiers#uids
         */
        uid?: string;
    }
    /** OwnerReference contains enough information to let you identify an owning object. An owning object must be in the same namespace as the dependent, or be cluster-scoped, so there is no namespace field. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$OwnerReference {
        /** API version of the referent. */
        apiVersion: string;
        /** If true, AND if the owner has the "foregroundDeletion" finalizer, then the owner cannot be deleted from the key-value store until this reference is removed. Defaults to false. To set this field, a user needs "delete" permission of the owner, otherwise 422 (Unprocessable Entity) will be returned. */
        blockOwnerDeletion?: boolean;
        /** If true, this reference points to the managing controller. */
        controller?: boolean;
        /** Kind of the referent. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind: string;
        /** Name of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#names */
        name: string;
        /** UID of the referent. More info: http://kubernetes.io/docs/user-guide/identifiers#uids */
        uid: string;
    }
    /** Patch is provided to give a concrete name and type to the Kubernetes PATCH request body. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$Patch {
    }
    /** Preconditions must be fulfilled before an operation (update, delete, etc.) is carried out. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$Preconditions {
        /** Specifies the target ResourceVersion */
        resourceVersion?: string;
        /** Specifies the target UID. */
        uid?: string;
    }
    /** ServerAddressByClientCIDR helps the client to determine the server address that they should use, depending on the clientCIDR that they match. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$ServerAddressByClientCIDR {
        /** The CIDR with which clients can match their IP to figure out the server address that they should use. */
        clientCIDR: string;
        /** Address of this server, suitable for a client that matches the above CIDR. This can be a hostname, hostname:port, IP or IP:port. */
        serverAddress: string;
    }
    /** Status is a return value for calls that don't return other objects. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$Status {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Suggested HTTP return code for this status, 0 if not set. */
        code?: number;
        details?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$StatusDetails;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        /** A human-readable description of the status of this operation. */
        message?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
        /** A machine-readable description of why this operation is in the "Failure" status. If this value is empty there is no information available. A Reason clarifies an HTTP status code but does not override it. */
        reason?: string;
        /** Status of the operation. One of: "Success" or "Failure". More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status */
        status?: string;
    }
    /** StatusCause provides more information about an api.Status failure, including cases when multiple errors are encountered. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$StatusCause {
        /**
         * The field of the resource that has caused this error, as named by its JSON serialization. May include dot and postfix notation for nested attributes. Arrays are zero-indexed.  Fields may appear more than once in an array of causes due to fields having multiple errors. Optional.
         *
         * Examples:
         *   "name" - the field "name" on the current resource
         *   "items[0].name" - the field "name" on the first array entry in "items"
         */
        field?: string;
        /** A human-readable description of the cause of the error.  This field may be presented as-is to a reader. */
        message?: string;
        /** A machine-readable description of the cause of the error. If this value is empty there is no information available. */
        reason?: string;
    }
    /** StatusDetails is a set of additional properties that MAY be set by the server to provide additional information about a response. The Reason field of a Status object defines what attributes will be set. Clients must ignore fields that do not match the defined type of each attribute, and should assume that any attribute may be empty, invalid, or under defined. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$StatusDetails {
        /** The Causes array includes more details associated with the StatusReason failure. Not all StatusReasons may provide detailed causes. */
        causes?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$StatusCause[];
        /** The group attribute of the resource associated with the status StatusReason. */
        group?: string;
        /** The kind attribute of the resource associated with the status StatusReason. On some operations may differ from the requested resource Kind. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        /** The name attribute of the resource associated with the status StatusReason (when there is a single name which can be described). */
        name?: string;
        /** If specified, the time in seconds before the operation should be retried. Some errors may indicate the client must take an alternate action - for those errors this field may indicate how long to wait before taking the alternate action. */
        retryAfterSeconds?: number;
        /** UID of the resource. (when there is a single resource which can be described). More info: http://kubernetes.io/docs/user-guide/identifiers#uids */
        uid?: string;
    }
    /** Time is a wrapper around time.Time which supports correct marshaling to YAML and JSON.  Wrappers are provided for many of the factory methods that the time package offers. */
    type io$k8s$apimachinery$pkg$apis$meta$v1$Time = string;
    /** Event represents a single event to a watched resource. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent {
        object: Schemas.io$k8s$apimachinery$pkg$runtime$RawExtension;
        type: string;
    }
    /**
     * RawExtension is used to hold extensions in external versions.
     *
     * To use this, make a field which has RawExtension as its type in your external, versioned struct, and Object in your internal struct. You also need to register your various plugin types.
     *
     * // Internal package: type MyAPIObject struct {
     * 	runtime.TypeMeta `json:",inline"`
     * 	MyPlugin runtime.Object `json:"myPlugin"`
     * } type PluginA struct {
     * 	AOption string `json:"aOption"`
     * }
     *
     * // External package: type MyAPIObject struct {
     * 	runtime.TypeMeta `json:",inline"`
     * 	MyPlugin runtime.RawExtension `json:"myPlugin"`
     * } type PluginA struct {
     * 	AOption string `json:"aOption"`
     * }
     *
     * // On the wire, the JSON will look something like this: {
     * 	"kind":"MyAPIObject",
     * 	"apiVersion":"v1",
     * 	"myPlugin": {
     * 		"kind":"PluginA",
     * 		"aOption":"foo",
     * 	},
     * }
     *
     * So what happens? Decode first uses json or yaml to unmarshal the serialized data into your external MyAPIObject. That causes the raw JSON to be stored, but not unpacked. The next step is to copy (using pkg/conversion) into the internal struct. The runtime package's DefaultScheme has conversion functions installed which will unpack the JSON stored in RawExtension, turning it into the correct object type, and storing it in the Object. (TODO: In the case where the object is of an unknown type, a runtime.Unknown object will be created and stored.)
     */
    interface io$k8s$apimachinery$pkg$runtime$RawExtension {
    }
    /** IntOrString is a type that can hold an int32 or a string.  When used in JSON or YAML marshalling and unmarshalling, it produces or consumes the inner type.  This allows you to have, for example, a JSON field that can accept a name or number. */
    type io$k8s$apimachinery$pkg$util$intstr$IntOrString = number | string;
    /** Info contains versioning information. how we'll want to distribute that information. */
    interface io$k8s$apimachinery$pkg$version$Info {
        buildDate: string;
        compiler: string;
        gitCommit: string;
        gitTreeState: string;
        gitVersion: string;
        goVersion: string;
        major: string;
        minor: string;
        platform: string;
    }
    /** APIService represents a server for a particular GroupVersion. Name must be "version.group". */
    interface io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceSpec;
        status?: Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceStatus;
    }
    /** APIServiceCondition describes the state of an APIService at a particular point */
    interface io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** Human-readable message indicating details about last transition. */
        message?: string;
        /** Unique, one-word, CamelCase reason for the condition's last transition. */
        reason?: string;
        /** Status is the status of the condition. Can be True, False, Unknown. */
        status: string;
        /** Type is the type of the condition. */
        type: string;
    }
    /** APIServiceList is a list of APIService objects. */
    interface io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is the list of APIService */
        items: Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** APIServiceSpec contains information for locating and communicating with a server. Only https is supported, though you are able to disable certificate verification. */
    interface io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceSpec {
        /** CABundle is a PEM encoded CA bundle which will be used to validate an API server's serving certificate. If unspecified, system trust roots on the apiserver are used. */
        caBundle?: Blob;
        /** Group is the API group name this server hosts */
        group?: string;
        /** GroupPriorityMininum is the priority this group should have at least. Higher priority means that the group is preferred by clients over lower priority ones. Note that other versions of this group might specify even higher GroupPriorityMininum values such that the whole group gets a higher priority. The primary sort is based on GroupPriorityMinimum, ordered highest number to lowest (20 before 10). The secondary sort is based on the alphabetical comparison of the name of the object.  (v1.bar before v1.foo) We'd recommend something like: *.k8s.io (except extensions) at 18000 and PaaSes (OpenShift, Deis) are recommended to be in the 2000s */
        groupPriorityMinimum: number;
        /** InsecureSkipTLSVerify disables TLS certificate verification when communicating with this server. This is strongly discouraged.  You should use the CABundle instead. */
        insecureSkipTLSVerify?: boolean;
        service?: Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$ServiceReference;
        /** Version is the API version this server hosts.  For example, "v1" */
        version?: string;
        /** VersionPriority controls the ordering of this API version inside of its group.  Must be greater than zero. The primary sort is based on VersionPriority, ordered highest to lowest (20 before 10). Since it's inside of a group, the number can be small, probably in the 10s. In case of equal version priorities, the version string will be used to compute the order inside a group. If the version string is "kube-like", it will sort above non "kube-like" version strings, which are ordered lexicographically. "Kube-like" versions start with a "v", then are followed by a number (the major version), then optionally the string "alpha" or "beta" and another number (the minor version). These are sorted first by GA > beta > alpha (where GA is a version with no suffix such as beta or alpha), and then by comparing major version, then minor version. An example sorted list of versions: v10, v2, v1, v11beta2, v10beta3, v3beta1, v12alpha1, v11alpha2, foo1, foo10. */
        versionPriority: number;
    }
    /** APIServiceStatus contains derived information about an API server */
    interface io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceStatus {
        /** Current service state of apiService. */
        conditions?: Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceCondition[];
    }
    /** ServiceReference holds a reference to Service.legacy.k8s.io */
    interface io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$ServiceReference {
        /** Name is the name of the service */
        name?: string;
        /** Namespace is the namespace of the service */
        namespace?: string;
        /** If specified, the port on the service that hosting webhook. Default to 443 for backward compatibility. `port` should be a valid port number (1-65535, inclusive). */
        port?: number;
    }
}
export declare namespace RequestBodies {
    namespace io$k8s$api$core$v1$Secret {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$Secret;
        }
    }
    namespace io$k8s$api$core$v1$LimitRange {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$LimitRange;
        }
    }
    namespace io$k8s$api$storage$v1$VolumeAttachment {
        interface Content {
            "*/*": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
        }
    }
    namespace io$k8s$api$node$v1$RuntimeClass {
        interface Content {
            "*/*": Schemas.io$k8s$api$node$v1$RuntimeClass;
        }
    }
    namespace io$k8s$api$flowcontrol$v1beta1$FlowSchema {
        interface Content {
            "*/*": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
        }
    }
    namespace io$k8s$api$apps$v1$Deployment {
        interface Content {
            "*/*": Schemas.io$k8s$api$apps$v1$Deployment;
        }
    }
    namespace io$k8s$api$core$v1$ServiceAccount {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$ServiceAccount;
        }
    }
    namespace io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration {
        interface Content {
            "*/*": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
        }
    }
    namespace io$k8s$api$apps$v1$DaemonSet {
        interface Content {
            "*/*": Schemas.io$k8s$api$apps$v1$DaemonSet;
        }
    }
    namespace io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService {
        interface Content {
            "*/*": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
        }
    }
    namespace io$k8s$api$core$v1$Service {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$Service;
        }
    }
    namespace io$k8s$api$rbac$v1$RoleBinding {
        interface Content {
            "*/*": Schemas.io$k8s$api$rbac$v1$RoleBinding;
        }
    }
    namespace io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration {
        interface Content {
            "*/*": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
        }
    }
    namespace io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration {
        interface Content {
            "*/*": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
        }
    }
    namespace io$k8s$api$apps$v1$ReplicaSet {
        interface Content {
            "*/*": Schemas.io$k8s$api$apps$v1$ReplicaSet;
        }
    }
    namespace io$k8s$api$core$v1$Namespace {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$Namespace;
        }
    }
    namespace io$k8s$api$batch$v1$Job {
        interface Content {
            "*/*": Schemas.io$k8s$api$batch$v1$Job;
        }
    }
    namespace io$k8s$api$core$v1$Node {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$Node;
        }
    }
    namespace io$k8s$api$core$v1$ReplicationController {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$ReplicationController;
        }
    }
    namespace io$k8s$api$discovery$v1beta1$EndpointSlice {
        interface Content {
            "*/*": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
        }
    }
    namespace io$k8s$api$events$v1$Event {
        interface Content {
            "*/*": Schemas.io$k8s$api$events$v1$Event;
        }
    }
    namespace io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions {
        interface Content {
            "*/*": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions;
        }
    }
    namespace io$k8s$api$storage$v1$CSIDriver {
        interface Content {
            "*/*": Schemas.io$k8s$api$storage$v1$CSIDriver;
        }
    }
    namespace io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler {
        interface Content {
            "*/*": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
        }
    }
    namespace io$k8s$api$autoscaling$v1$Scale {
        interface Content {
            "*/*": Schemas.io$k8s$api$autoscaling$v1$Scale;
        }
    }
    namespace io$k8s$api$batch$v1beta1$CronJob {
        interface Content {
            "*/*": Schemas.io$k8s$api$batch$v1beta1$CronJob;
        }
    }
    namespace io$k8s$api$rbac$v1$ClusterRole {
        interface Content {
            "*/*": Schemas.io$k8s$api$rbac$v1$ClusterRole;
        }
    }
    namespace io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler {
        interface Content {
            "*/*": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
        }
    }
    namespace io$k8s$api$node$v1alpha1$RuntimeClass {
        interface Content {
            "*/*": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
        }
    }
    namespace io$k8s$api$discovery$v1$EndpointSlice {
        interface Content {
            "*/*": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
        }
    }
    namespace io$k8s$api$coordination$v1$Lease {
        interface Content {
            "*/*": Schemas.io$k8s$api$coordination$v1$Lease;
        }
    }
    namespace io$k8s$api$core$v1$ConfigMap {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$ConfigMap;
        }
    }
    namespace io$k8s$api$core$v1$Binding {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$Binding;
        }
    }
    namespace io$k8s$apimachinery$pkg$apis$meta$v1$Patch {
        interface Content {
            "application/json-patch+json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Patch;
            "application/merge-patch+json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Patch;
            "application/strategic-merge-patch+json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Patch;
            "application/apply-patch+yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Patch;
        }
    }
    namespace io$k8s$api$core$v1$Endpoints {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$Endpoints;
        }
    }
    namespace io$k8s$api$core$v1$Event {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$Event;
        }
    }
    namespace io$k8s$api$core$v1$PersistentVolumeClaim {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
        }
    }
    namespace io$k8s$api$core$v1$Pod {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$Pod;
        }
    }
    namespace io$k8s$api$core$v1$PodTemplate {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$PodTemplate;
        }
    }
    namespace io$k8s$api$core$v1$ResourceQuota {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$ResourceQuota;
        }
    }
    namespace io$k8s$api$core$v1$PersistentVolume {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$PersistentVolume;
        }
    }
    namespace io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration {
        interface Content {
            "*/*": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
        }
    }
    namespace io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition {
        interface Content {
            "*/*": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
        }
    }
    namespace io$k8s$api$apps$v1$ControllerRevision {
        interface Content {
            "*/*": Schemas.io$k8s$api$apps$v1$ControllerRevision;
        }
    }
    namespace io$k8s$api$apps$v1$StatefulSet {
        interface Content {
            "*/*": Schemas.io$k8s$api$apps$v1$StatefulSet;
        }
    }
    namespace io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler {
        interface Content {
            "*/*": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
        }
    }
    namespace io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler {
        interface Content {
            "*/*": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
        }
    }
    namespace io$k8s$api$batch$v1$CronJob {
        interface Content {
            "*/*": Schemas.io$k8s$api$batch$v1$CronJob;
        }
    }
    namespace io$k8s$api$certificates$v1$CertificateSigningRequest {
        interface Content {
            "*/*": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
        }
    }
    namespace io$k8s$api$events$v1beta1$Event {
        interface Content {
            "*/*": Schemas.io$k8s$api$events$v1beta1$Event;
        }
    }
    namespace io$k8s$api$flowcontrol$v1beta2$FlowSchema {
        interface Content {
            "*/*": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
        }
    }
    namespace io$k8s$api$apiserverinternal$v1alpha1$StorageVersion {
        interface Content {
            "*/*": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
        }
    }
    namespace io$k8s$api$networking$v1$IngressClass {
        interface Content {
            "*/*": Schemas.io$k8s$api$networking$v1$IngressClass;
        }
    }
    namespace io$k8s$api$networking$v1$Ingress {
        interface Content {
            "*/*": Schemas.io$k8s$api$networking$v1$Ingress;
        }
    }
    namespace io$k8s$api$networking$v1$NetworkPolicy {
        interface Content {
            "*/*": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
        }
    }
    namespace io$k8s$api$node$v1beta1$RuntimeClass {
        interface Content {
            "*/*": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
        }
    }
    namespace io$k8s$api$policy$v1$PodDisruptionBudget {
        interface Content {
            "*/*": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
        }
    }
    namespace io$k8s$api$policy$v1beta1$PodDisruptionBudget {
        interface Content {
            "*/*": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
        }
    }
    namespace io$k8s$api$policy$v1beta1$PodSecurityPolicy {
        interface Content {
            "*/*": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
        }
    }
    namespace io$k8s$api$rbac$v1$ClusterRoleBinding {
        interface Content {
            "*/*": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
        }
    }
    namespace io$k8s$api$rbac$v1$Role {
        interface Content {
            "*/*": Schemas.io$k8s$api$rbac$v1$Role;
        }
    }
    namespace io$k8s$api$scheduling$v1$PriorityClass {
        interface Content {
            "*/*": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
        }
    }
    namespace io$k8s$api$storage$v1$CSINode {
        interface Content {
            "*/*": Schemas.io$k8s$api$storage$v1$CSINode;
        }
    }
    namespace io$k8s$api$storage$v1$StorageClass {
        interface Content {
            "*/*": Schemas.io$k8s$api$storage$v1$StorageClass;
        }
    }
    namespace io$k8s$api$storage$v1alpha1$CSIStorageCapacity {
        interface Content {
            "*/*": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
        }
    }
    namespace io$k8s$api$storage$v1beta1$CSIStorageCapacity {
        interface Content {
            "*/*": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
        }
    }
}
export interface Response$getServiceAccountIssuerOpenIDConfiguration$Status$200 {
    "application/json": string;
}
export interface Response$getCoreAPIVersions$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIVersions;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIVersions;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIVersions;
}
export interface Response$getCoreV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listCoreV1ComponentStatus {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1ComponentStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ComponentStatusList;
    "application/yaml": Schemas.io$k8s$api$core$v1$ComponentStatusList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ComponentStatusList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$ComponentStatusList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$ComponentStatusList;
}
export interface Parameter$readCoreV1ComponentStatus {
    /** name of the ComponentStatus */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1ComponentStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ComponentStatus;
    "application/yaml": Schemas.io$k8s$api$core$v1$ComponentStatus;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ComponentStatus;
}
export interface Parameter$listCoreV1ConfigMapForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1ConfigMapForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ConfigMapList;
    "application/yaml": Schemas.io$k8s$api$core$v1$ConfigMapList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ConfigMapList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$ConfigMapList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$ConfigMapList;
}
export interface Parameter$listCoreV1EndpointsForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1EndpointsForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$EndpointsList;
    "application/yaml": Schemas.io$k8s$api$core$v1$EndpointsList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$EndpointsList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$EndpointsList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$EndpointsList;
}
export interface Parameter$listCoreV1EventForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1EventForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$EventList;
    "application/yaml": Schemas.io$k8s$api$core$v1$EventList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$EventList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$EventList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$EventList;
}
export interface Parameter$listCoreV1LimitRangeForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1LimitRangeForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$LimitRangeList;
    "application/yaml": Schemas.io$k8s$api$core$v1$LimitRangeList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$LimitRangeList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$LimitRangeList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$LimitRangeList;
}
export interface Parameter$listCoreV1Namespace {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1Namespace$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$NamespaceList;
    "application/yaml": Schemas.io$k8s$api$core$v1$NamespaceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$NamespaceList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$NamespaceList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$NamespaceList;
}
export interface Parameter$createCoreV1Namespace {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createCoreV1Namespace = RequestBodies.io$k8s$api$core$v1$Namespace.Content;
export interface Response$createCoreV1Namespace$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
export interface Response$createCoreV1Namespace$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
export interface Response$createCoreV1Namespace$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
export interface Parameter$createCoreV1NamespacedBinding {
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export declare type RequestBody$createCoreV1NamespacedBinding = RequestBodies.io$k8s$api$core$v1$Binding.Content;
export interface Response$createCoreV1NamespacedBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Binding;
    "application/yaml": Schemas.io$k8s$api$core$v1$Binding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Binding;
}
export interface Response$createCoreV1NamespacedBinding$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Binding;
    "application/yaml": Schemas.io$k8s$api$core$v1$Binding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Binding;
}
export interface Response$createCoreV1NamespacedBinding$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$Binding;
    "application/yaml": Schemas.io$k8s$api$core$v1$Binding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Binding;
}
export interface Parameter$listCoreV1NamespacedConfigMap {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1NamespacedConfigMap$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ConfigMapList;
    "application/yaml": Schemas.io$k8s$api$core$v1$ConfigMapList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ConfigMapList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$ConfigMapList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$ConfigMapList;
}
export interface Parameter$createCoreV1NamespacedConfigMap {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createCoreV1NamespacedConfigMap = RequestBodies.io$k8s$api$core$v1$ConfigMap.Content;
export interface Response$createCoreV1NamespacedConfigMap$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/yaml": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ConfigMap;
}
export interface Response$createCoreV1NamespacedConfigMap$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/yaml": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ConfigMap;
}
export interface Response$createCoreV1NamespacedConfigMap$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/yaml": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ConfigMap;
}
export interface Parameter$deleteCoreV1CollectionNamespacedConfigMap {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteCoreV1CollectionNamespacedConfigMap = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1CollectionNamespacedConfigMap$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readCoreV1NamespacedConfigMap {
    /** name of the ConfigMap */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1NamespacedConfigMap$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/yaml": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ConfigMap;
}
export interface Parameter$replaceCoreV1NamespacedConfigMap {
    /** name of the ConfigMap */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1NamespacedConfigMap = RequestBodies.io$k8s$api$core$v1$ConfigMap.Content;
export interface Response$replaceCoreV1NamespacedConfigMap$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/yaml": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ConfigMap;
}
export interface Response$replaceCoreV1NamespacedConfigMap$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/yaml": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ConfigMap;
}
export interface Parameter$deleteCoreV1NamespacedConfigMap {
    /** name of the ConfigMap */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteCoreV1NamespacedConfigMap = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1NamespacedConfigMap$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteCoreV1NamespacedConfigMap$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchCoreV1NamespacedConfigMap {
    /** name of the ConfigMap */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1NamespacedConfigMap = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1NamespacedConfigMap$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/yaml": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ConfigMap;
}
export interface Response$patchCoreV1NamespacedConfigMap$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/yaml": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ConfigMap;
}
export interface Parameter$listCoreV1NamespacedEndpoints {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1NamespacedEndpoints$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$EndpointsList;
    "application/yaml": Schemas.io$k8s$api$core$v1$EndpointsList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$EndpointsList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$EndpointsList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$EndpointsList;
}
export interface Parameter$createCoreV1NamespacedEndpoints {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createCoreV1NamespacedEndpoints = RequestBodies.io$k8s$api$core$v1$Endpoints.Content;
export interface Response$createCoreV1NamespacedEndpoints$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/yaml": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Endpoints;
}
export interface Response$createCoreV1NamespacedEndpoints$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/yaml": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Endpoints;
}
export interface Response$createCoreV1NamespacedEndpoints$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/yaml": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Endpoints;
}
export interface Parameter$deleteCoreV1CollectionNamespacedEndpoints {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteCoreV1CollectionNamespacedEndpoints = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1CollectionNamespacedEndpoints$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readCoreV1NamespacedEndpoints {
    /** name of the Endpoints */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1NamespacedEndpoints$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/yaml": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Endpoints;
}
export interface Parameter$replaceCoreV1NamespacedEndpoints {
    /** name of the Endpoints */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1NamespacedEndpoints = RequestBodies.io$k8s$api$core$v1$Endpoints.Content;
export interface Response$replaceCoreV1NamespacedEndpoints$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/yaml": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Endpoints;
}
export interface Response$replaceCoreV1NamespacedEndpoints$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/yaml": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Endpoints;
}
export interface Parameter$deleteCoreV1NamespacedEndpoints {
    /** name of the Endpoints */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteCoreV1NamespacedEndpoints = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1NamespacedEndpoints$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteCoreV1NamespacedEndpoints$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchCoreV1NamespacedEndpoints {
    /** name of the Endpoints */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1NamespacedEndpoints = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1NamespacedEndpoints$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/yaml": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Endpoints;
}
export interface Response$patchCoreV1NamespacedEndpoints$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/yaml": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Endpoints;
}
export interface Parameter$listCoreV1NamespacedEvent {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$EventList;
    "application/yaml": Schemas.io$k8s$api$core$v1$EventList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$EventList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$EventList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$EventList;
}
export interface Parameter$createCoreV1NamespacedEvent {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createCoreV1NamespacedEvent = RequestBodies.io$k8s$api$core$v1$Event.Content;
export interface Response$createCoreV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Event;
    "application/yaml": Schemas.io$k8s$api$core$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Event;
}
export interface Response$createCoreV1NamespacedEvent$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Event;
    "application/yaml": Schemas.io$k8s$api$core$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Event;
}
export interface Response$createCoreV1NamespacedEvent$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$Event;
    "application/yaml": Schemas.io$k8s$api$core$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Event;
}
export interface Parameter$deleteCoreV1CollectionNamespacedEvent {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteCoreV1CollectionNamespacedEvent = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1CollectionNamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readCoreV1NamespacedEvent {
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Event;
    "application/yaml": Schemas.io$k8s$api$core$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Event;
}
export interface Parameter$replaceCoreV1NamespacedEvent {
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1NamespacedEvent = RequestBodies.io$k8s$api$core$v1$Event.Content;
export interface Response$replaceCoreV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Event;
    "application/yaml": Schemas.io$k8s$api$core$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Event;
}
export interface Response$replaceCoreV1NamespacedEvent$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Event;
    "application/yaml": Schemas.io$k8s$api$core$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Event;
}
export interface Parameter$deleteCoreV1NamespacedEvent {
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteCoreV1NamespacedEvent = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteCoreV1NamespacedEvent$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchCoreV1NamespacedEvent {
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1NamespacedEvent = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Event;
    "application/yaml": Schemas.io$k8s$api$core$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Event;
}
export interface Response$patchCoreV1NamespacedEvent$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Event;
    "application/yaml": Schemas.io$k8s$api$core$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Event;
}
export interface Parameter$listCoreV1NamespacedLimitRange {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1NamespacedLimitRange$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$LimitRangeList;
    "application/yaml": Schemas.io$k8s$api$core$v1$LimitRangeList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$LimitRangeList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$LimitRangeList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$LimitRangeList;
}
export interface Parameter$createCoreV1NamespacedLimitRange {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createCoreV1NamespacedLimitRange = RequestBodies.io$k8s$api$core$v1$LimitRange.Content;
export interface Response$createCoreV1NamespacedLimitRange$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/yaml": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$LimitRange;
}
export interface Response$createCoreV1NamespacedLimitRange$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/yaml": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$LimitRange;
}
export interface Response$createCoreV1NamespacedLimitRange$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/yaml": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$LimitRange;
}
export interface Parameter$deleteCoreV1CollectionNamespacedLimitRange {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteCoreV1CollectionNamespacedLimitRange = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1CollectionNamespacedLimitRange$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readCoreV1NamespacedLimitRange {
    /** name of the LimitRange */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1NamespacedLimitRange$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/yaml": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$LimitRange;
}
export interface Parameter$replaceCoreV1NamespacedLimitRange {
    /** name of the LimitRange */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1NamespacedLimitRange = RequestBodies.io$k8s$api$core$v1$LimitRange.Content;
export interface Response$replaceCoreV1NamespacedLimitRange$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/yaml": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$LimitRange;
}
export interface Response$replaceCoreV1NamespacedLimitRange$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/yaml": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$LimitRange;
}
export interface Parameter$deleteCoreV1NamespacedLimitRange {
    /** name of the LimitRange */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteCoreV1NamespacedLimitRange = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1NamespacedLimitRange$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteCoreV1NamespacedLimitRange$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchCoreV1NamespacedLimitRange {
    /** name of the LimitRange */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1NamespacedLimitRange = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1NamespacedLimitRange$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/yaml": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$LimitRange;
}
export interface Response$patchCoreV1NamespacedLimitRange$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/yaml": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$LimitRange;
}
export interface Parameter$listCoreV1NamespacedPersistentVolumeClaim {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1NamespacedPersistentVolumeClaim$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaimList;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaimList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaimList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$PersistentVolumeClaimList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$PersistentVolumeClaimList;
}
export interface Parameter$createCoreV1NamespacedPersistentVolumeClaim {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createCoreV1NamespacedPersistentVolumeClaim = RequestBodies.io$k8s$api$core$v1$PersistentVolumeClaim.Content;
export interface Response$createCoreV1NamespacedPersistentVolumeClaim$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
export interface Response$createCoreV1NamespacedPersistentVolumeClaim$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
export interface Response$createCoreV1NamespacedPersistentVolumeClaim$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
export interface Parameter$deleteCoreV1CollectionNamespacedPersistentVolumeClaim {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteCoreV1CollectionNamespacedPersistentVolumeClaim = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1CollectionNamespacedPersistentVolumeClaim$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readCoreV1NamespacedPersistentVolumeClaim {
    /** name of the PersistentVolumeClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1NamespacedPersistentVolumeClaim$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
export interface Parameter$replaceCoreV1NamespacedPersistentVolumeClaim {
    /** name of the PersistentVolumeClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1NamespacedPersistentVolumeClaim = RequestBodies.io$k8s$api$core$v1$PersistentVolumeClaim.Content;
export interface Response$replaceCoreV1NamespacedPersistentVolumeClaim$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
export interface Response$replaceCoreV1NamespacedPersistentVolumeClaim$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
export interface Parameter$deleteCoreV1NamespacedPersistentVolumeClaim {
    /** name of the PersistentVolumeClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteCoreV1NamespacedPersistentVolumeClaim = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1NamespacedPersistentVolumeClaim$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
export interface Response$deleteCoreV1NamespacedPersistentVolumeClaim$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
export interface Parameter$patchCoreV1NamespacedPersistentVolumeClaim {
    /** name of the PersistentVolumeClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1NamespacedPersistentVolumeClaim = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1NamespacedPersistentVolumeClaim$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
export interface Response$patchCoreV1NamespacedPersistentVolumeClaim$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
export interface Parameter$readCoreV1NamespacedPersistentVolumeClaimStatus {
    /** name of the PersistentVolumeClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1NamespacedPersistentVolumeClaimStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
export interface Parameter$replaceCoreV1NamespacedPersistentVolumeClaimStatus {
    /** name of the PersistentVolumeClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1NamespacedPersistentVolumeClaimStatus = RequestBodies.io$k8s$api$core$v1$PersistentVolumeClaim.Content;
export interface Response$replaceCoreV1NamespacedPersistentVolumeClaimStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
export interface Response$replaceCoreV1NamespacedPersistentVolumeClaimStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
export interface Parameter$patchCoreV1NamespacedPersistentVolumeClaimStatus {
    /** name of the PersistentVolumeClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1NamespacedPersistentVolumeClaimStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1NamespacedPersistentVolumeClaimStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
export interface Response$patchCoreV1NamespacedPersistentVolumeClaimStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
export interface Parameter$listCoreV1NamespacedPod {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1NamespacedPod$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PodList;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$PodList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$PodList;
}
export interface Parameter$createCoreV1NamespacedPod {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createCoreV1NamespacedPod = RequestBodies.io$k8s$api$core$v1$Pod.Content;
export interface Response$createCoreV1NamespacedPod$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
export interface Response$createCoreV1NamespacedPod$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
export interface Response$createCoreV1NamespacedPod$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
export interface Parameter$deleteCoreV1CollectionNamespacedPod {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteCoreV1CollectionNamespacedPod = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1CollectionNamespacedPod$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readCoreV1NamespacedPod {
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1NamespacedPod$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
export interface Parameter$replaceCoreV1NamespacedPod {
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1NamespacedPod = RequestBodies.io$k8s$api$core$v1$Pod.Content;
export interface Response$replaceCoreV1NamespacedPod$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
export interface Response$replaceCoreV1NamespacedPod$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
export interface Parameter$deleteCoreV1NamespacedPod {
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteCoreV1NamespacedPod = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1NamespacedPod$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
export interface Response$deleteCoreV1NamespacedPod$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
export interface Parameter$patchCoreV1NamespacedPod {
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1NamespacedPod = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1NamespacedPod$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
export interface Response$patchCoreV1NamespacedPod$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
export interface Parameter$connectCoreV1GetNamespacedPodAttach {
    /** The container in which to execute the command. Defaults to only container if there is only one container in the pod. */
    container?: string;
    /** name of the PodAttachOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Stderr if true indicates that stderr is to be redirected for the attach call. Defaults to true. */
    stderr?: boolean;
    /** Stdin if true, redirects the standard input stream of the pod for this call. Defaults to false. */
    stdin?: boolean;
    /** Stdout if true indicates that stdout is to be redirected for the attach call. Defaults to true. */
    stdout?: boolean;
    /** TTY if true indicates that a tty will be allocated for the attach call. This is passed through the container runtime so the tty is allocated on the worker node by the container runtime. Defaults to false. */
    tty?: boolean;
}
export interface Response$connectCoreV1GetNamespacedPodAttach$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1PostNamespacedPodAttach {
    /** The container in which to execute the command. Defaults to only container if there is only one container in the pod. */
    container?: string;
    /** name of the PodAttachOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Stderr if true indicates that stderr is to be redirected for the attach call. Defaults to true. */
    stderr?: boolean;
    /** Stdin if true, redirects the standard input stream of the pod for this call. Defaults to false. */
    stdin?: boolean;
    /** Stdout if true indicates that stdout is to be redirected for the attach call. Defaults to true. */
    stdout?: boolean;
    /** TTY if true indicates that a tty will be allocated for the attach call. This is passed through the container runtime so the tty is allocated on the worker node by the container runtime. Defaults to false. */
    tty?: boolean;
}
export interface Response$connectCoreV1PostNamespacedPodAttach$Status$200 {
    "*/*": string;
}
export interface Parameter$createCoreV1NamespacedPodBinding {
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** name of the Binding */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export declare type RequestBody$createCoreV1NamespacedPodBinding = RequestBodies.io$k8s$api$core$v1$Binding.Content;
export interface Response$createCoreV1NamespacedPodBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Binding;
    "application/yaml": Schemas.io$k8s$api$core$v1$Binding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Binding;
}
export interface Response$createCoreV1NamespacedPodBinding$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Binding;
    "application/yaml": Schemas.io$k8s$api$core$v1$Binding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Binding;
}
export interface Response$createCoreV1NamespacedPodBinding$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$Binding;
    "application/yaml": Schemas.io$k8s$api$core$v1$Binding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Binding;
}
export interface Parameter$readCoreV1NamespacedPodEphemeralcontainers {
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1NamespacedPodEphemeralcontainers$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
export interface Parameter$replaceCoreV1NamespacedPodEphemeralcontainers {
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1NamespacedPodEphemeralcontainers = RequestBodies.io$k8s$api$core$v1$Pod.Content;
export interface Response$replaceCoreV1NamespacedPodEphemeralcontainers$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
export interface Response$replaceCoreV1NamespacedPodEphemeralcontainers$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
export interface Parameter$patchCoreV1NamespacedPodEphemeralcontainers {
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1NamespacedPodEphemeralcontainers = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1NamespacedPodEphemeralcontainers$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
export interface Response$patchCoreV1NamespacedPodEphemeralcontainers$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
export interface Parameter$createCoreV1NamespacedPodEviction {
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** name of the Eviction */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface RequestBody$createCoreV1NamespacedPodEviction {
    "*/*": Schemas.io$k8s$api$policy$v1$Eviction;
}
export interface Response$createCoreV1NamespacedPodEviction$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1$Eviction;
    "application/yaml": Schemas.io$k8s$api$policy$v1$Eviction;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$Eviction;
}
export interface Response$createCoreV1NamespacedPodEviction$Status$201 {
    "application/json": Schemas.io$k8s$api$policy$v1$Eviction;
    "application/yaml": Schemas.io$k8s$api$policy$v1$Eviction;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$Eviction;
}
export interface Response$createCoreV1NamespacedPodEviction$Status$202 {
    "application/json": Schemas.io$k8s$api$policy$v1$Eviction;
    "application/yaml": Schemas.io$k8s$api$policy$v1$Eviction;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$Eviction;
}
export interface Parameter$connectCoreV1GetNamespacedPodExec {
    /** Command is the remote command to execute. argv array. Not executed within a shell. */
    command?: string;
    /** Container in which to execute the command. Defaults to only container if there is only one container in the pod. */
    container?: string;
    /** name of the PodExecOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Redirect the standard error stream of the pod for this call. */
    stderr?: boolean;
    /** Redirect the standard input stream of the pod for this call. Defaults to false. */
    stdin?: boolean;
    /** Redirect the standard output stream of the pod for this call. */
    stdout?: boolean;
    /** TTY if true indicates that a tty will be allocated for the exec call. Defaults to false. */
    tty?: boolean;
}
export interface Response$connectCoreV1GetNamespacedPodExec$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1PostNamespacedPodExec {
    /** Command is the remote command to execute. argv array. Not executed within a shell. */
    command?: string;
    /** Container in which to execute the command. Defaults to only container if there is only one container in the pod. */
    container?: string;
    /** name of the PodExecOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Redirect the standard error stream of the pod for this call. */
    stderr?: boolean;
    /** Redirect the standard input stream of the pod for this call. Defaults to false. */
    stdin?: boolean;
    /** Redirect the standard output stream of the pod for this call. */
    stdout?: boolean;
    /** TTY if true indicates that a tty will be allocated for the exec call. Defaults to false. */
    tty?: boolean;
}
export interface Response$connectCoreV1PostNamespacedPodExec$Status$200 {
    "*/*": string;
}
export interface Parameter$readCoreV1NamespacedPodLog {
    /** The container for which to stream logs. Defaults to only container if there is one container in the pod. */
    container?: string;
    /** Follow the log stream of the pod. Defaults to false. */
    follow?: boolean;
    /** insecureSkipTLSVerifyBackend indicates that the apiserver should not confirm the validity of the serving certificate of the backend it is connecting to.  This will make the HTTPS connection between the apiserver and the backend insecure. This means the apiserver cannot verify the log data it is receiving came from the real kubelet.  If the kubelet is configured to verify the apiserver's TLS credentials, it does not mean the connection to the real kubelet is vulnerable to a man in the middle attack (e.g. an attacker could not intercept the actual log data coming from the real kubelet). */
    insecureSkipTLSVerifyBackend?: boolean;
    /** If set, the number of bytes to read from the server before terminating the log output. This may not display a complete final line of logging, and may return slightly more or slightly less than the specified limit. */
    limitBytes?: number;
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** Return previous terminated container logs. Defaults to false. */
    previous?: boolean;
    /** A relative time in seconds before the current time from which to show logs. If this value precedes the time a pod was started, only logs since the pod start will be returned. If this value is in the future, no logs will be returned. Only one of sinceSeconds or sinceTime may be specified. */
    sinceSeconds?: number;
    /** If set, the number of lines from the end of the logs to show. If not specified, logs are shown from the creation of the container or sinceSeconds or sinceTime */
    tailLines?: number;
    /** If true, add an RFC3339 or RFC3339Nano timestamp at the beginning of every line of log output. Defaults to false. */
    timestamps?: boolean;
}
export interface Response$readCoreV1NamespacedPodLog$Status$200 {
    "text/plain": string;
    "application/json": string;
    "application/yaml": string;
    "application/vnd.kubernetes.protobuf": string;
}
export interface Parameter$connectCoreV1GetNamespacedPodPortforward {
    /** name of the PodPortForwardOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** List of ports to forward Required when using WebSockets */
    ports?: number;
}
export interface Response$connectCoreV1GetNamespacedPodPortforward$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1PostNamespacedPodPortforward {
    /** name of the PodPortForwardOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** List of ports to forward Required when using WebSockets */
    ports?: number;
}
export interface Response$connectCoreV1PostNamespacedPodPortforward$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1GetNamespacedPodProxy {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
export interface Response$connectCoreV1GetNamespacedPodProxy$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1PutNamespacedPodProxy {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
export interface Response$connectCoreV1PutNamespacedPodProxy$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1PostNamespacedPodProxy {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
export interface Response$connectCoreV1PostNamespacedPodProxy$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1DeleteNamespacedPodProxy {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
export interface Response$connectCoreV1DeleteNamespacedPodProxy$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1OptionsNamespacedPodProxy {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
export interface Response$connectCoreV1OptionsNamespacedPodProxy$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1HeadNamespacedPodProxy {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
export interface Response$connectCoreV1HeadNamespacedPodProxy$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1PatchNamespacedPodProxy {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
export interface Response$connectCoreV1PatchNamespacedPodProxy$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1GetNamespacedPodProxyWithPath {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
export interface Response$connectCoreV1GetNamespacedPodProxyWithPath$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1PutNamespacedPodProxyWithPath {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
export interface Response$connectCoreV1PutNamespacedPodProxyWithPath$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1PostNamespacedPodProxyWithPath {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
export interface Response$connectCoreV1PostNamespacedPodProxyWithPath$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1DeleteNamespacedPodProxyWithPath {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
export interface Response$connectCoreV1DeleteNamespacedPodProxyWithPath$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1OptionsNamespacedPodProxyWithPath {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
export interface Response$connectCoreV1OptionsNamespacedPodProxyWithPath$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1HeadNamespacedPodProxyWithPath {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
export interface Response$connectCoreV1HeadNamespacedPodProxyWithPath$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1PatchNamespacedPodProxyWithPath {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
export interface Response$connectCoreV1PatchNamespacedPodProxyWithPath$Status$200 {
    "*/*": string;
}
export interface Parameter$readCoreV1NamespacedPodStatus {
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1NamespacedPodStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
export interface Parameter$replaceCoreV1NamespacedPodStatus {
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1NamespacedPodStatus = RequestBodies.io$k8s$api$core$v1$Pod.Content;
export interface Response$replaceCoreV1NamespacedPodStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
export interface Response$replaceCoreV1NamespacedPodStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
export interface Parameter$patchCoreV1NamespacedPodStatus {
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1NamespacedPodStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1NamespacedPodStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
export interface Response$patchCoreV1NamespacedPodStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
export interface Parameter$listCoreV1NamespacedPodTemplate {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1NamespacedPodTemplate$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplateList;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplateList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplateList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$PodTemplateList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$PodTemplateList;
}
export interface Parameter$createCoreV1NamespacedPodTemplate {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createCoreV1NamespacedPodTemplate = RequestBodies.io$k8s$api$core$v1$PodTemplate.Content;
export interface Response$createCoreV1NamespacedPodTemplate$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplate;
}
export interface Response$createCoreV1NamespacedPodTemplate$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplate;
}
export interface Response$createCoreV1NamespacedPodTemplate$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplate;
}
export interface Parameter$deleteCoreV1CollectionNamespacedPodTemplate {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteCoreV1CollectionNamespacedPodTemplate = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1CollectionNamespacedPodTemplate$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readCoreV1NamespacedPodTemplate {
    /** name of the PodTemplate */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1NamespacedPodTemplate$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplate;
}
export interface Parameter$replaceCoreV1NamespacedPodTemplate {
    /** name of the PodTemplate */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1NamespacedPodTemplate = RequestBodies.io$k8s$api$core$v1$PodTemplate.Content;
export interface Response$replaceCoreV1NamespacedPodTemplate$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplate;
}
export interface Response$replaceCoreV1NamespacedPodTemplate$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplate;
}
export interface Parameter$deleteCoreV1NamespacedPodTemplate {
    /** name of the PodTemplate */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteCoreV1NamespacedPodTemplate = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1NamespacedPodTemplate$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplate;
}
export interface Response$deleteCoreV1NamespacedPodTemplate$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplate;
}
export interface Parameter$patchCoreV1NamespacedPodTemplate {
    /** name of the PodTemplate */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1NamespacedPodTemplate = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1NamespacedPodTemplate$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplate;
}
export interface Response$patchCoreV1NamespacedPodTemplate$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplate;
}
export interface Parameter$listCoreV1NamespacedReplicationController {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1NamespacedReplicationController$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationControllerList;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationControllerList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationControllerList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$ReplicationControllerList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$ReplicationControllerList;
}
export interface Parameter$createCoreV1NamespacedReplicationController {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createCoreV1NamespacedReplicationController = RequestBodies.io$k8s$api$core$v1$ReplicationController.Content;
export interface Response$createCoreV1NamespacedReplicationController$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
export interface Response$createCoreV1NamespacedReplicationController$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
export interface Response$createCoreV1NamespacedReplicationController$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
export interface Parameter$deleteCoreV1CollectionNamespacedReplicationController {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteCoreV1CollectionNamespacedReplicationController = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1CollectionNamespacedReplicationController$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readCoreV1NamespacedReplicationController {
    /** name of the ReplicationController */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1NamespacedReplicationController$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
export interface Parameter$replaceCoreV1NamespacedReplicationController {
    /** name of the ReplicationController */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1NamespacedReplicationController = RequestBodies.io$k8s$api$core$v1$ReplicationController.Content;
export interface Response$replaceCoreV1NamespacedReplicationController$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
export interface Response$replaceCoreV1NamespacedReplicationController$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
export interface Parameter$deleteCoreV1NamespacedReplicationController {
    /** name of the ReplicationController */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteCoreV1NamespacedReplicationController = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1NamespacedReplicationController$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteCoreV1NamespacedReplicationController$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchCoreV1NamespacedReplicationController {
    /** name of the ReplicationController */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1NamespacedReplicationController = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1NamespacedReplicationController$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
export interface Response$patchCoreV1NamespacedReplicationController$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
export interface Parameter$readCoreV1NamespacedReplicationControllerScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1NamespacedReplicationControllerScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
export interface Parameter$replaceCoreV1NamespacedReplicationControllerScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1NamespacedReplicationControllerScale = RequestBodies.io$k8s$api$autoscaling$v1$Scale.Content;
export interface Response$replaceCoreV1NamespacedReplicationControllerScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
export interface Response$replaceCoreV1NamespacedReplicationControllerScale$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
export interface Parameter$patchCoreV1NamespacedReplicationControllerScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1NamespacedReplicationControllerScale = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1NamespacedReplicationControllerScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
export interface Response$patchCoreV1NamespacedReplicationControllerScale$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
export interface Parameter$readCoreV1NamespacedReplicationControllerStatus {
    /** name of the ReplicationController */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1NamespacedReplicationControllerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
export interface Parameter$replaceCoreV1NamespacedReplicationControllerStatus {
    /** name of the ReplicationController */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1NamespacedReplicationControllerStatus = RequestBodies.io$k8s$api$core$v1$ReplicationController.Content;
export interface Response$replaceCoreV1NamespacedReplicationControllerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
export interface Response$replaceCoreV1NamespacedReplicationControllerStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
export interface Parameter$patchCoreV1NamespacedReplicationControllerStatus {
    /** name of the ReplicationController */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1NamespacedReplicationControllerStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1NamespacedReplicationControllerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
export interface Response$patchCoreV1NamespacedReplicationControllerStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
export interface Parameter$listCoreV1NamespacedResourceQuota {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1NamespacedResourceQuota$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuotaList;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuotaList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuotaList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$ResourceQuotaList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$ResourceQuotaList;
}
export interface Parameter$createCoreV1NamespacedResourceQuota {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createCoreV1NamespacedResourceQuota = RequestBodies.io$k8s$api$core$v1$ResourceQuota.Content;
export interface Response$createCoreV1NamespacedResourceQuota$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
export interface Response$createCoreV1NamespacedResourceQuota$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
export interface Response$createCoreV1NamespacedResourceQuota$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
export interface Parameter$deleteCoreV1CollectionNamespacedResourceQuota {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteCoreV1CollectionNamespacedResourceQuota = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1CollectionNamespacedResourceQuota$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readCoreV1NamespacedResourceQuota {
    /** name of the ResourceQuota */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1NamespacedResourceQuota$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
export interface Parameter$replaceCoreV1NamespacedResourceQuota {
    /** name of the ResourceQuota */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1NamespacedResourceQuota = RequestBodies.io$k8s$api$core$v1$ResourceQuota.Content;
export interface Response$replaceCoreV1NamespacedResourceQuota$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
export interface Response$replaceCoreV1NamespacedResourceQuota$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
export interface Parameter$deleteCoreV1NamespacedResourceQuota {
    /** name of the ResourceQuota */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteCoreV1NamespacedResourceQuota = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1NamespacedResourceQuota$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
export interface Response$deleteCoreV1NamespacedResourceQuota$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
export interface Parameter$patchCoreV1NamespacedResourceQuota {
    /** name of the ResourceQuota */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1NamespacedResourceQuota = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1NamespacedResourceQuota$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
export interface Response$patchCoreV1NamespacedResourceQuota$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
export interface Parameter$readCoreV1NamespacedResourceQuotaStatus {
    /** name of the ResourceQuota */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1NamespacedResourceQuotaStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
export interface Parameter$replaceCoreV1NamespacedResourceQuotaStatus {
    /** name of the ResourceQuota */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1NamespacedResourceQuotaStatus = RequestBodies.io$k8s$api$core$v1$ResourceQuota.Content;
export interface Response$replaceCoreV1NamespacedResourceQuotaStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
export interface Response$replaceCoreV1NamespacedResourceQuotaStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
export interface Parameter$patchCoreV1NamespacedResourceQuotaStatus {
    /** name of the ResourceQuota */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1NamespacedResourceQuotaStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1NamespacedResourceQuotaStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
export interface Response$patchCoreV1NamespacedResourceQuotaStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
export interface Parameter$listCoreV1NamespacedSecret {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1NamespacedSecret$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$SecretList;
    "application/yaml": Schemas.io$k8s$api$core$v1$SecretList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$SecretList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$SecretList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$SecretList;
}
export interface Parameter$createCoreV1NamespacedSecret {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createCoreV1NamespacedSecret = RequestBodies.io$k8s$api$core$v1$Secret.Content;
export interface Response$createCoreV1NamespacedSecret$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Secret;
    "application/yaml": Schemas.io$k8s$api$core$v1$Secret;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Secret;
}
export interface Response$createCoreV1NamespacedSecret$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Secret;
    "application/yaml": Schemas.io$k8s$api$core$v1$Secret;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Secret;
}
export interface Response$createCoreV1NamespacedSecret$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$Secret;
    "application/yaml": Schemas.io$k8s$api$core$v1$Secret;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Secret;
}
export interface Parameter$deleteCoreV1CollectionNamespacedSecret {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteCoreV1CollectionNamespacedSecret = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1CollectionNamespacedSecret$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readCoreV1NamespacedSecret {
    /** name of the Secret */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1NamespacedSecret$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Secret;
    "application/yaml": Schemas.io$k8s$api$core$v1$Secret;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Secret;
}
export interface Parameter$replaceCoreV1NamespacedSecret {
    /** name of the Secret */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1NamespacedSecret = RequestBodies.io$k8s$api$core$v1$Secret.Content;
export interface Response$replaceCoreV1NamespacedSecret$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Secret;
    "application/yaml": Schemas.io$k8s$api$core$v1$Secret;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Secret;
}
export interface Response$replaceCoreV1NamespacedSecret$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Secret;
    "application/yaml": Schemas.io$k8s$api$core$v1$Secret;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Secret;
}
export interface Parameter$deleteCoreV1NamespacedSecret {
    /** name of the Secret */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteCoreV1NamespacedSecret = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1NamespacedSecret$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteCoreV1NamespacedSecret$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchCoreV1NamespacedSecret {
    /** name of the Secret */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1NamespacedSecret = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1NamespacedSecret$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Secret;
    "application/yaml": Schemas.io$k8s$api$core$v1$Secret;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Secret;
}
export interface Response$patchCoreV1NamespacedSecret$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Secret;
    "application/yaml": Schemas.io$k8s$api$core$v1$Secret;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Secret;
}
export interface Parameter$listCoreV1NamespacedServiceAccount {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1NamespacedServiceAccount$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccountList;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccountList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccountList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$ServiceAccountList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$ServiceAccountList;
}
export interface Parameter$createCoreV1NamespacedServiceAccount {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createCoreV1NamespacedServiceAccount = RequestBodies.io$k8s$api$core$v1$ServiceAccount.Content;
export interface Response$createCoreV1NamespacedServiceAccount$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccount;
}
export interface Response$createCoreV1NamespacedServiceAccount$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccount;
}
export interface Response$createCoreV1NamespacedServiceAccount$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccount;
}
export interface Parameter$deleteCoreV1CollectionNamespacedServiceAccount {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteCoreV1CollectionNamespacedServiceAccount = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1CollectionNamespacedServiceAccount$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readCoreV1NamespacedServiceAccount {
    /** name of the ServiceAccount */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1NamespacedServiceAccount$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccount;
}
export interface Parameter$replaceCoreV1NamespacedServiceAccount {
    /** name of the ServiceAccount */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1NamespacedServiceAccount = RequestBodies.io$k8s$api$core$v1$ServiceAccount.Content;
export interface Response$replaceCoreV1NamespacedServiceAccount$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccount;
}
export interface Response$replaceCoreV1NamespacedServiceAccount$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccount;
}
export interface Parameter$deleteCoreV1NamespacedServiceAccount {
    /** name of the ServiceAccount */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteCoreV1NamespacedServiceAccount = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1NamespacedServiceAccount$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccount;
}
export interface Response$deleteCoreV1NamespacedServiceAccount$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccount;
}
export interface Parameter$patchCoreV1NamespacedServiceAccount {
    /** name of the ServiceAccount */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1NamespacedServiceAccount = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1NamespacedServiceAccount$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccount;
}
export interface Response$patchCoreV1NamespacedServiceAccount$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccount;
}
export interface Parameter$createCoreV1NamespacedServiceAccountToken {
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** name of the TokenRequest */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface RequestBody$createCoreV1NamespacedServiceAccountToken {
    "*/*": Schemas.io$k8s$api$authentication$v1$TokenRequest;
}
export interface Response$createCoreV1NamespacedServiceAccountToken$Status$200 {
    "application/json": Schemas.io$k8s$api$authentication$v1$TokenRequest;
    "application/yaml": Schemas.io$k8s$api$authentication$v1$TokenRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authentication$v1$TokenRequest;
}
export interface Response$createCoreV1NamespacedServiceAccountToken$Status$201 {
    "application/json": Schemas.io$k8s$api$authentication$v1$TokenRequest;
    "application/yaml": Schemas.io$k8s$api$authentication$v1$TokenRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authentication$v1$TokenRequest;
}
export interface Response$createCoreV1NamespacedServiceAccountToken$Status$202 {
    "application/json": Schemas.io$k8s$api$authentication$v1$TokenRequest;
    "application/yaml": Schemas.io$k8s$api$authentication$v1$TokenRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authentication$v1$TokenRequest;
}
export interface Parameter$listCoreV1NamespacedService {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1NamespacedService$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceList;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$ServiceList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$ServiceList;
}
export interface Parameter$createCoreV1NamespacedService {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createCoreV1NamespacedService = RequestBodies.io$k8s$api$core$v1$Service.Content;
export interface Response$createCoreV1NamespacedService$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
export interface Response$createCoreV1NamespacedService$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
export interface Response$createCoreV1NamespacedService$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
export interface Parameter$deleteCoreV1CollectionNamespacedService {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteCoreV1CollectionNamespacedService = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1CollectionNamespacedService$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readCoreV1NamespacedService {
    /** name of the Service */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1NamespacedService$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
export interface Parameter$replaceCoreV1NamespacedService {
    /** name of the Service */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1NamespacedService = RequestBodies.io$k8s$api$core$v1$Service.Content;
export interface Response$replaceCoreV1NamespacedService$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
export interface Response$replaceCoreV1NamespacedService$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
export interface Parameter$deleteCoreV1NamespacedService {
    /** name of the Service */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteCoreV1NamespacedService = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1NamespacedService$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
export interface Response$deleteCoreV1NamespacedService$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
export interface Parameter$patchCoreV1NamespacedService {
    /** name of the Service */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1NamespacedService = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1NamespacedService$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
export interface Response$patchCoreV1NamespacedService$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
export interface Parameter$connectCoreV1GetNamespacedServiceProxy {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
export interface Response$connectCoreV1GetNamespacedServiceProxy$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1PutNamespacedServiceProxy {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
export interface Response$connectCoreV1PutNamespacedServiceProxy$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1PostNamespacedServiceProxy {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
export interface Response$connectCoreV1PostNamespacedServiceProxy$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1DeleteNamespacedServiceProxy {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
export interface Response$connectCoreV1DeleteNamespacedServiceProxy$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1OptionsNamespacedServiceProxy {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
export interface Response$connectCoreV1OptionsNamespacedServiceProxy$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1HeadNamespacedServiceProxy {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
export interface Response$connectCoreV1HeadNamespacedServiceProxy$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1PatchNamespacedServiceProxy {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
export interface Response$connectCoreV1PatchNamespacedServiceProxy$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1GetNamespacedServiceProxyWithPath {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
export interface Response$connectCoreV1GetNamespacedServiceProxyWithPath$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1PutNamespacedServiceProxyWithPath {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
export interface Response$connectCoreV1PutNamespacedServiceProxyWithPath$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1PostNamespacedServiceProxyWithPath {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
export interface Response$connectCoreV1PostNamespacedServiceProxyWithPath$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1DeleteNamespacedServiceProxyWithPath {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
export interface Response$connectCoreV1DeleteNamespacedServiceProxyWithPath$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1OptionsNamespacedServiceProxyWithPath {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
export interface Response$connectCoreV1OptionsNamespacedServiceProxyWithPath$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1HeadNamespacedServiceProxyWithPath {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
export interface Response$connectCoreV1HeadNamespacedServiceProxyWithPath$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1PatchNamespacedServiceProxyWithPath {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
export interface Response$connectCoreV1PatchNamespacedServiceProxyWithPath$Status$200 {
    "*/*": string;
}
export interface Parameter$readCoreV1NamespacedServiceStatus {
    /** name of the Service */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1NamespacedServiceStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
export interface Parameter$replaceCoreV1NamespacedServiceStatus {
    /** name of the Service */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1NamespacedServiceStatus = RequestBodies.io$k8s$api$core$v1$Service.Content;
export interface Response$replaceCoreV1NamespacedServiceStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
export interface Response$replaceCoreV1NamespacedServiceStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
export interface Parameter$patchCoreV1NamespacedServiceStatus {
    /** name of the Service */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1NamespacedServiceStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1NamespacedServiceStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
export interface Response$patchCoreV1NamespacedServiceStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
export interface Parameter$readCoreV1Namespace {
    /** name of the Namespace */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1Namespace$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
export interface Parameter$replaceCoreV1Namespace {
    /** name of the Namespace */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1Namespace = RequestBodies.io$k8s$api$core$v1$Namespace.Content;
export interface Response$replaceCoreV1Namespace$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
export interface Response$replaceCoreV1Namespace$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
export interface Parameter$deleteCoreV1Namespace {
    /** name of the Namespace */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteCoreV1Namespace = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1Namespace$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteCoreV1Namespace$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchCoreV1Namespace {
    /** name of the Namespace */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1Namespace = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1Namespace$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
export interface Response$patchCoreV1Namespace$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
export interface Parameter$replaceCoreV1NamespaceFinalize {
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** name of the Namespace */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export declare type RequestBody$replaceCoreV1NamespaceFinalize = RequestBodies.io$k8s$api$core$v1$Namespace.Content;
export interface Response$replaceCoreV1NamespaceFinalize$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
export interface Response$replaceCoreV1NamespaceFinalize$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
export interface Parameter$readCoreV1NamespaceStatus {
    /** name of the Namespace */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1NamespaceStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
export interface Parameter$replaceCoreV1NamespaceStatus {
    /** name of the Namespace */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1NamespaceStatus = RequestBodies.io$k8s$api$core$v1$Namespace.Content;
export interface Response$replaceCoreV1NamespaceStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
export interface Response$replaceCoreV1NamespaceStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
export interface Parameter$patchCoreV1NamespaceStatus {
    /** name of the Namespace */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1NamespaceStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1NamespaceStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
export interface Response$patchCoreV1NamespaceStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
export interface Parameter$listCoreV1Node {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1Node$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$NodeList;
    "application/yaml": Schemas.io$k8s$api$core$v1$NodeList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$NodeList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$NodeList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$NodeList;
}
export interface Parameter$createCoreV1Node {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createCoreV1Node = RequestBodies.io$k8s$api$core$v1$Node.Content;
export interface Response$createCoreV1Node$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
export interface Response$createCoreV1Node$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
export interface Response$createCoreV1Node$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
export interface Parameter$deleteCoreV1CollectionNode {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteCoreV1CollectionNode = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1CollectionNode$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readCoreV1Node {
    /** name of the Node */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1Node$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
export interface Parameter$replaceCoreV1Node {
    /** name of the Node */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1Node = RequestBodies.io$k8s$api$core$v1$Node.Content;
export interface Response$replaceCoreV1Node$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
export interface Response$replaceCoreV1Node$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
export interface Parameter$deleteCoreV1Node {
    /** name of the Node */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteCoreV1Node = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1Node$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteCoreV1Node$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchCoreV1Node {
    /** name of the Node */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1Node = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1Node$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
export interface Response$patchCoreV1Node$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
export interface Parameter$connectCoreV1GetNodeProxy {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
export interface Response$connectCoreV1GetNodeProxy$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1PutNodeProxy {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
export interface Response$connectCoreV1PutNodeProxy$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1PostNodeProxy {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
export interface Response$connectCoreV1PostNodeProxy$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1DeleteNodeProxy {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
export interface Response$connectCoreV1DeleteNodeProxy$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1OptionsNodeProxy {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
export interface Response$connectCoreV1OptionsNodeProxy$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1HeadNodeProxy {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
export interface Response$connectCoreV1HeadNodeProxy$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1PatchNodeProxy {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
export interface Response$connectCoreV1PatchNodeProxy$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1GetNodeProxyWithPath {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
export interface Response$connectCoreV1GetNodeProxyWithPath$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1PutNodeProxyWithPath {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
export interface Response$connectCoreV1PutNodeProxyWithPath$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1PostNodeProxyWithPath {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
export interface Response$connectCoreV1PostNodeProxyWithPath$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1DeleteNodeProxyWithPath {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
export interface Response$connectCoreV1DeleteNodeProxyWithPath$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1OptionsNodeProxyWithPath {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
export interface Response$connectCoreV1OptionsNodeProxyWithPath$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1HeadNodeProxyWithPath {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
export interface Response$connectCoreV1HeadNodeProxyWithPath$Status$200 {
    "*/*": string;
}
export interface Parameter$connectCoreV1PatchNodeProxyWithPath {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
export interface Response$connectCoreV1PatchNodeProxyWithPath$Status$200 {
    "*/*": string;
}
export interface Parameter$readCoreV1NodeStatus {
    /** name of the Node */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1NodeStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
export interface Parameter$replaceCoreV1NodeStatus {
    /** name of the Node */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1NodeStatus = RequestBodies.io$k8s$api$core$v1$Node.Content;
export interface Response$replaceCoreV1NodeStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
export interface Response$replaceCoreV1NodeStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
export interface Parameter$patchCoreV1NodeStatus {
    /** name of the Node */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1NodeStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1NodeStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
export interface Response$patchCoreV1NodeStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
export interface Parameter$listCoreV1PersistentVolumeClaimForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1PersistentVolumeClaimForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaimList;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaimList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaimList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$PersistentVolumeClaimList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$PersistentVolumeClaimList;
}
export interface Parameter$listCoreV1PersistentVolume {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1PersistentVolume$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeList;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$PersistentVolumeList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$PersistentVolumeList;
}
export interface Parameter$createCoreV1PersistentVolume {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createCoreV1PersistentVolume = RequestBodies.io$k8s$api$core$v1$PersistentVolume.Content;
export interface Response$createCoreV1PersistentVolume$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
export interface Response$createCoreV1PersistentVolume$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
export interface Response$createCoreV1PersistentVolume$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
export interface Parameter$deleteCoreV1CollectionPersistentVolume {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteCoreV1CollectionPersistentVolume = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1CollectionPersistentVolume$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readCoreV1PersistentVolume {
    /** name of the PersistentVolume */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1PersistentVolume$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
export interface Parameter$replaceCoreV1PersistentVolume {
    /** name of the PersistentVolume */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1PersistentVolume = RequestBodies.io$k8s$api$core$v1$PersistentVolume.Content;
export interface Response$replaceCoreV1PersistentVolume$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
export interface Response$replaceCoreV1PersistentVolume$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
export interface Parameter$deleteCoreV1PersistentVolume {
    /** name of the PersistentVolume */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteCoreV1PersistentVolume = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoreV1PersistentVolume$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
export interface Response$deleteCoreV1PersistentVolume$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
export interface Parameter$patchCoreV1PersistentVolume {
    /** name of the PersistentVolume */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1PersistentVolume = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1PersistentVolume$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
export interface Response$patchCoreV1PersistentVolume$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
export interface Parameter$readCoreV1PersistentVolumeStatus {
    /** name of the PersistentVolume */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoreV1PersistentVolumeStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
export interface Parameter$replaceCoreV1PersistentVolumeStatus {
    /** name of the PersistentVolume */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoreV1PersistentVolumeStatus = RequestBodies.io$k8s$api$core$v1$PersistentVolume.Content;
export interface Response$replaceCoreV1PersistentVolumeStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
export interface Response$replaceCoreV1PersistentVolumeStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
export interface Parameter$patchCoreV1PersistentVolumeStatus {
    /** name of the PersistentVolume */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoreV1PersistentVolumeStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoreV1PersistentVolumeStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
export interface Response$patchCoreV1PersistentVolumeStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
export interface Parameter$listCoreV1PodForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1PodForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PodList;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$PodList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$PodList;
}
export interface Parameter$listCoreV1PodTemplateForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1PodTemplateForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplateList;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplateList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplateList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$PodTemplateList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$PodTemplateList;
}
export interface Parameter$listCoreV1ReplicationControllerForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1ReplicationControllerForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationControllerList;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationControllerList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationControllerList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$ReplicationControllerList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$ReplicationControllerList;
}
export interface Parameter$listCoreV1ResourceQuotaForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1ResourceQuotaForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuotaList;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuotaList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuotaList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$ResourceQuotaList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$ResourceQuotaList;
}
export interface Parameter$listCoreV1SecretForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1SecretForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$SecretList;
    "application/yaml": Schemas.io$k8s$api$core$v1$SecretList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$SecretList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$SecretList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$SecretList;
}
export interface Parameter$listCoreV1ServiceAccountForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1ServiceAccountForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccountList;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccountList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccountList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$ServiceAccountList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$ServiceAccountList;
}
export interface Parameter$listCoreV1ServiceForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoreV1ServiceForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceList;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$ServiceList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$ServiceList;
}
export interface Parameter$watchCoreV1ConfigMapListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1ConfigMapListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1EndpointsListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1EndpointsListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1EventListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1EventListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1LimitRangeListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1LimitRangeListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespaceList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespaceList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedConfigMapList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedConfigMapList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedConfigMap {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ConfigMap */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedConfigMap$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedEndpointsList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedEndpointsList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedEndpoints {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Endpoints */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedEndpoints$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedEventList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedEventList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedEvent {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedLimitRangeList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedLimitRangeList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedLimitRange {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the LimitRange */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedLimitRange$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedPersistentVolumeClaimList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedPersistentVolumeClaimList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedPersistentVolumeClaim {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the PersistentVolumeClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedPersistentVolumeClaim$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedPodList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedPodList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedPod {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedPod$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedPodTemplateList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedPodTemplateList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedPodTemplate {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the PodTemplate */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedPodTemplate$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedReplicationControllerList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedReplicationControllerList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedReplicationController {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ReplicationController */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedReplicationController$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedResourceQuotaList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedResourceQuotaList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedResourceQuota {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ResourceQuota */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedResourceQuota$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedSecretList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedSecretList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedSecret {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Secret */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedSecret$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedServiceAccountList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedServiceAccountList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedServiceAccount {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ServiceAccount */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedServiceAccount$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedServiceList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedServiceList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NamespacedService {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Service */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NamespacedService$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1Namespace {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Namespace */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1Namespace$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1NodeList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1NodeList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1Node {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Node */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1Node$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1PersistentVolumeClaimListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1PersistentVolumeClaimListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1PersistentVolumeList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1PersistentVolumeList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1PersistentVolume {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the PersistentVolume */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1PersistentVolume$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1PodListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1PodListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1PodTemplateListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1PodTemplateListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1ReplicationControllerListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1ReplicationControllerListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1ResourceQuotaListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1ResourceQuotaListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1SecretListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1SecretListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1ServiceAccountListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1ServiceAccountListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoreV1ServiceListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoreV1ServiceListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getAPIVersions$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroupList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroupList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroupList;
}
export interface Response$getAdmissionregistrationAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
export interface Response$getAdmissionregistrationV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listAdmissionregistrationV1MutatingWebhookConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfigurationList;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfigurationList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfigurationList;
    "application/json;stream=watch": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfigurationList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfigurationList;
}
export interface Parameter$createAdmissionregistrationV1MutatingWebhookConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createAdmissionregistrationV1MutatingWebhookConfiguration = RequestBodies.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration.Content;
export interface Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
}
export interface Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
}
export interface Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$202 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
}
export interface Parameter$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readAdmissionregistrationV1MutatingWebhookConfiguration {
    /** name of the MutatingWebhookConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
}
export interface Parameter$replaceAdmissionregistrationV1MutatingWebhookConfiguration {
    /** name of the MutatingWebhookConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceAdmissionregistrationV1MutatingWebhookConfiguration = RequestBodies.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration.Content;
export interface Response$replaceAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
}
export interface Response$replaceAdmissionregistrationV1MutatingWebhookConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
}
export interface Parameter$deleteAdmissionregistrationV1MutatingWebhookConfiguration {
    /** name of the MutatingWebhookConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteAdmissionregistrationV1MutatingWebhookConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteAdmissionregistrationV1MutatingWebhookConfiguration$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchAdmissionregistrationV1MutatingWebhookConfiguration {
    /** name of the MutatingWebhookConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchAdmissionregistrationV1MutatingWebhookConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
}
export interface Response$patchAdmissionregistrationV1MutatingWebhookConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
}
export interface Parameter$listAdmissionregistrationV1ValidatingWebhookConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfigurationList;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfigurationList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfigurationList;
    "application/json;stream=watch": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfigurationList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfigurationList;
}
export interface Parameter$createAdmissionregistrationV1ValidatingWebhookConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createAdmissionregistrationV1ValidatingWebhookConfiguration = RequestBodies.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration.Content;
export interface Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
}
export interface Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
}
export interface Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$202 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
}
export interface Parameter$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readAdmissionregistrationV1ValidatingWebhookConfiguration {
    /** name of the ValidatingWebhookConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
}
export interface Parameter$replaceAdmissionregistrationV1ValidatingWebhookConfiguration {
    /** name of the ValidatingWebhookConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceAdmissionregistrationV1ValidatingWebhookConfiguration = RequestBodies.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration.Content;
export interface Response$replaceAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
}
export interface Response$replaceAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
}
export interface Parameter$deleteAdmissionregistrationV1ValidatingWebhookConfiguration {
    /** name of the ValidatingWebhookConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteAdmissionregistrationV1ValidatingWebhookConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteAdmissionregistrationV1ValidatingWebhookConfiguration$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchAdmissionregistrationV1ValidatingWebhookConfiguration {
    /** name of the ValidatingWebhookConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchAdmissionregistrationV1ValidatingWebhookConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
}
export interface Response$patchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
}
export interface Parameter$watchAdmissionregistrationV1MutatingWebhookConfigurationList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAdmissionregistrationV1MutatingWebhookConfigurationList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAdmissionregistrationV1MutatingWebhookConfiguration {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the MutatingWebhookConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAdmissionregistrationV1ValidatingWebhookConfigurationList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAdmissionregistrationV1ValidatingWebhookConfigurationList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAdmissionregistrationV1ValidatingWebhookConfiguration {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ValidatingWebhookConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getApiextensionsAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
export interface Response$getApiextensionsV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listApiextensionsV1CustomResourceDefinition {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listApiextensionsV1CustomResourceDefinition$Status$200 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionList;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionList;
    "application/json;stream=watch": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionList;
}
export interface Parameter$createApiextensionsV1CustomResourceDefinition {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createApiextensionsV1CustomResourceDefinition = RequestBodies.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition.Content;
export interface Response$createApiextensionsV1CustomResourceDefinition$Status$200 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
export interface Response$createApiextensionsV1CustomResourceDefinition$Status$201 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
export interface Response$createApiextensionsV1CustomResourceDefinition$Status$202 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
export interface Parameter$deleteApiextensionsV1CollectionCustomResourceDefinition {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteApiextensionsV1CollectionCustomResourceDefinition = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteApiextensionsV1CollectionCustomResourceDefinition$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readApiextensionsV1CustomResourceDefinition {
    /** name of the CustomResourceDefinition */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readApiextensionsV1CustomResourceDefinition$Status$200 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
export interface Parameter$replaceApiextensionsV1CustomResourceDefinition {
    /** name of the CustomResourceDefinition */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceApiextensionsV1CustomResourceDefinition = RequestBodies.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition.Content;
export interface Response$replaceApiextensionsV1CustomResourceDefinition$Status$200 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
export interface Response$replaceApiextensionsV1CustomResourceDefinition$Status$201 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
export interface Parameter$deleteApiextensionsV1CustomResourceDefinition {
    /** name of the CustomResourceDefinition */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteApiextensionsV1CustomResourceDefinition = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteApiextensionsV1CustomResourceDefinition$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteApiextensionsV1CustomResourceDefinition$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchApiextensionsV1CustomResourceDefinition {
    /** name of the CustomResourceDefinition */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchApiextensionsV1CustomResourceDefinition = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchApiextensionsV1CustomResourceDefinition$Status$200 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
export interface Response$patchApiextensionsV1CustomResourceDefinition$Status$201 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
export interface Parameter$readApiextensionsV1CustomResourceDefinitionStatus {
    /** name of the CustomResourceDefinition */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readApiextensionsV1CustomResourceDefinitionStatus$Status$200 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
export interface Parameter$replaceApiextensionsV1CustomResourceDefinitionStatus {
    /** name of the CustomResourceDefinition */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceApiextensionsV1CustomResourceDefinitionStatus = RequestBodies.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition.Content;
export interface Response$replaceApiextensionsV1CustomResourceDefinitionStatus$Status$200 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
export interface Response$replaceApiextensionsV1CustomResourceDefinitionStatus$Status$201 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
export interface Parameter$patchApiextensionsV1CustomResourceDefinitionStatus {
    /** name of the CustomResourceDefinition */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchApiextensionsV1CustomResourceDefinitionStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchApiextensionsV1CustomResourceDefinitionStatus$Status$200 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
export interface Response$patchApiextensionsV1CustomResourceDefinitionStatus$Status$201 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
export interface Parameter$watchApiextensionsV1CustomResourceDefinitionList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchApiextensionsV1CustomResourceDefinitionList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchApiextensionsV1CustomResourceDefinition {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the CustomResourceDefinition */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchApiextensionsV1CustomResourceDefinition$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getApiregistrationAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
export interface Response$getApiregistrationV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listApiregistrationV1APIService {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listApiregistrationV1APIService$Status$200 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceList;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceList;
    "application/json;stream=watch": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceList;
}
export interface Parameter$createApiregistrationV1APIService {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createApiregistrationV1APIService = RequestBodies.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService.Content;
export interface Response$createApiregistrationV1APIService$Status$200 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
export interface Response$createApiregistrationV1APIService$Status$201 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
export interface Response$createApiregistrationV1APIService$Status$202 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
export interface Parameter$deleteApiregistrationV1CollectionAPIService {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteApiregistrationV1CollectionAPIService = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteApiregistrationV1CollectionAPIService$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readApiregistrationV1APIService {
    /** name of the APIService */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readApiregistrationV1APIService$Status$200 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
export interface Parameter$replaceApiregistrationV1APIService {
    /** name of the APIService */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceApiregistrationV1APIService = RequestBodies.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService.Content;
export interface Response$replaceApiregistrationV1APIService$Status$200 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
export interface Response$replaceApiregistrationV1APIService$Status$201 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
export interface Parameter$deleteApiregistrationV1APIService {
    /** name of the APIService */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteApiregistrationV1APIService = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteApiregistrationV1APIService$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteApiregistrationV1APIService$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchApiregistrationV1APIService {
    /** name of the APIService */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchApiregistrationV1APIService = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchApiregistrationV1APIService$Status$200 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
export interface Response$patchApiregistrationV1APIService$Status$201 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
export interface Parameter$readApiregistrationV1APIServiceStatus {
    /** name of the APIService */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readApiregistrationV1APIServiceStatus$Status$200 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
export interface Parameter$replaceApiregistrationV1APIServiceStatus {
    /** name of the APIService */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceApiregistrationV1APIServiceStatus = RequestBodies.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService.Content;
export interface Response$replaceApiregistrationV1APIServiceStatus$Status$200 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
export interface Response$replaceApiregistrationV1APIServiceStatus$Status$201 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
export interface Parameter$patchApiregistrationV1APIServiceStatus {
    /** name of the APIService */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchApiregistrationV1APIServiceStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchApiregistrationV1APIServiceStatus$Status$200 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
export interface Response$patchApiregistrationV1APIServiceStatus$Status$201 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
export interface Parameter$watchApiregistrationV1APIServiceList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchApiregistrationV1APIServiceList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchApiregistrationV1APIService {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the APIService */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchApiregistrationV1APIService$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getAppsAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
export interface Response$getAppsV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listAppsV1ControllerRevisionForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listAppsV1ControllerRevisionForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ControllerRevisionList;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ControllerRevisionList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ControllerRevisionList;
    "application/json;stream=watch": Schemas.io$k8s$api$apps$v1$ControllerRevisionList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$apps$v1$ControllerRevisionList;
}
export interface Parameter$listAppsV1DaemonSetForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listAppsV1DaemonSetForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSetList;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSetList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSetList;
    "application/json;stream=watch": Schemas.io$k8s$api$apps$v1$DaemonSetList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$apps$v1$DaemonSetList;
}
export interface Parameter$listAppsV1DeploymentForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listAppsV1DeploymentForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$DeploymentList;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DeploymentList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DeploymentList;
    "application/json;stream=watch": Schemas.io$k8s$api$apps$v1$DeploymentList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$apps$v1$DeploymentList;
}
export interface Parameter$listAppsV1NamespacedControllerRevision {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listAppsV1NamespacedControllerRevision$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ControllerRevisionList;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ControllerRevisionList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ControllerRevisionList;
    "application/json;stream=watch": Schemas.io$k8s$api$apps$v1$ControllerRevisionList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$apps$v1$ControllerRevisionList;
}
export interface Parameter$createAppsV1NamespacedControllerRevision {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createAppsV1NamespacedControllerRevision = RequestBodies.io$k8s$api$apps$v1$ControllerRevision.Content;
export interface Response$createAppsV1NamespacedControllerRevision$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ControllerRevision;
}
export interface Response$createAppsV1NamespacedControllerRevision$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ControllerRevision;
}
export interface Response$createAppsV1NamespacedControllerRevision$Status$202 {
    "application/json": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ControllerRevision;
}
export interface Parameter$deleteAppsV1CollectionNamespacedControllerRevision {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteAppsV1CollectionNamespacedControllerRevision = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteAppsV1CollectionNamespacedControllerRevision$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readAppsV1NamespacedControllerRevision {
    /** name of the ControllerRevision */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readAppsV1NamespacedControllerRevision$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ControllerRevision;
}
export interface Parameter$replaceAppsV1NamespacedControllerRevision {
    /** name of the ControllerRevision */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceAppsV1NamespacedControllerRevision = RequestBodies.io$k8s$api$apps$v1$ControllerRevision.Content;
export interface Response$replaceAppsV1NamespacedControllerRevision$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ControllerRevision;
}
export interface Response$replaceAppsV1NamespacedControllerRevision$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ControllerRevision;
}
export interface Parameter$deleteAppsV1NamespacedControllerRevision {
    /** name of the ControllerRevision */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteAppsV1NamespacedControllerRevision = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteAppsV1NamespacedControllerRevision$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteAppsV1NamespacedControllerRevision$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchAppsV1NamespacedControllerRevision {
    /** name of the ControllerRevision */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchAppsV1NamespacedControllerRevision = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchAppsV1NamespacedControllerRevision$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ControllerRevision;
}
export interface Response$patchAppsV1NamespacedControllerRevision$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ControllerRevision;
}
export interface Parameter$listAppsV1NamespacedDaemonSet {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listAppsV1NamespacedDaemonSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSetList;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSetList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSetList;
    "application/json;stream=watch": Schemas.io$k8s$api$apps$v1$DaemonSetList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$apps$v1$DaemonSetList;
}
export interface Parameter$createAppsV1NamespacedDaemonSet {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createAppsV1NamespacedDaemonSet = RequestBodies.io$k8s$api$apps$v1$DaemonSet.Content;
export interface Response$createAppsV1NamespacedDaemonSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
export interface Response$createAppsV1NamespacedDaemonSet$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
export interface Response$createAppsV1NamespacedDaemonSet$Status$202 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
export interface Parameter$deleteAppsV1CollectionNamespacedDaemonSet {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteAppsV1CollectionNamespacedDaemonSet = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteAppsV1CollectionNamespacedDaemonSet$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readAppsV1NamespacedDaemonSet {
    /** name of the DaemonSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readAppsV1NamespacedDaemonSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
export interface Parameter$replaceAppsV1NamespacedDaemonSet {
    /** name of the DaemonSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceAppsV1NamespacedDaemonSet = RequestBodies.io$k8s$api$apps$v1$DaemonSet.Content;
export interface Response$replaceAppsV1NamespacedDaemonSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
export interface Response$replaceAppsV1NamespacedDaemonSet$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
export interface Parameter$deleteAppsV1NamespacedDaemonSet {
    /** name of the DaemonSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteAppsV1NamespacedDaemonSet = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteAppsV1NamespacedDaemonSet$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteAppsV1NamespacedDaemonSet$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchAppsV1NamespacedDaemonSet {
    /** name of the DaemonSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchAppsV1NamespacedDaemonSet = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchAppsV1NamespacedDaemonSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
export interface Response$patchAppsV1NamespacedDaemonSet$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
export interface Parameter$readAppsV1NamespacedDaemonSetStatus {
    /** name of the DaemonSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readAppsV1NamespacedDaemonSetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
export interface Parameter$replaceAppsV1NamespacedDaemonSetStatus {
    /** name of the DaemonSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceAppsV1NamespacedDaemonSetStatus = RequestBodies.io$k8s$api$apps$v1$DaemonSet.Content;
export interface Response$replaceAppsV1NamespacedDaemonSetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
export interface Response$replaceAppsV1NamespacedDaemonSetStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
export interface Parameter$patchAppsV1NamespacedDaemonSetStatus {
    /** name of the DaemonSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchAppsV1NamespacedDaemonSetStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchAppsV1NamespacedDaemonSetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
export interface Response$patchAppsV1NamespacedDaemonSetStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
export interface Parameter$listAppsV1NamespacedDeployment {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listAppsV1NamespacedDeployment$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$DeploymentList;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DeploymentList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DeploymentList;
    "application/json;stream=watch": Schemas.io$k8s$api$apps$v1$DeploymentList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$apps$v1$DeploymentList;
}
export interface Parameter$createAppsV1NamespacedDeployment {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createAppsV1NamespacedDeployment = RequestBodies.io$k8s$api$apps$v1$Deployment.Content;
export interface Response$createAppsV1NamespacedDeployment$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
export interface Response$createAppsV1NamespacedDeployment$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
export interface Response$createAppsV1NamespacedDeployment$Status$202 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
export interface Parameter$deleteAppsV1CollectionNamespacedDeployment {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteAppsV1CollectionNamespacedDeployment = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteAppsV1CollectionNamespacedDeployment$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readAppsV1NamespacedDeployment {
    /** name of the Deployment */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readAppsV1NamespacedDeployment$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
export interface Parameter$replaceAppsV1NamespacedDeployment {
    /** name of the Deployment */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceAppsV1NamespacedDeployment = RequestBodies.io$k8s$api$apps$v1$Deployment.Content;
export interface Response$replaceAppsV1NamespacedDeployment$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
export interface Response$replaceAppsV1NamespacedDeployment$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
export interface Parameter$deleteAppsV1NamespacedDeployment {
    /** name of the Deployment */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteAppsV1NamespacedDeployment = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteAppsV1NamespacedDeployment$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteAppsV1NamespacedDeployment$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchAppsV1NamespacedDeployment {
    /** name of the Deployment */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchAppsV1NamespacedDeployment = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchAppsV1NamespacedDeployment$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
export interface Response$patchAppsV1NamespacedDeployment$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
export interface Parameter$readAppsV1NamespacedDeploymentScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readAppsV1NamespacedDeploymentScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
export interface Parameter$replaceAppsV1NamespacedDeploymentScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceAppsV1NamespacedDeploymentScale = RequestBodies.io$k8s$api$autoscaling$v1$Scale.Content;
export interface Response$replaceAppsV1NamespacedDeploymentScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
export interface Response$replaceAppsV1NamespacedDeploymentScale$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
export interface Parameter$patchAppsV1NamespacedDeploymentScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchAppsV1NamespacedDeploymentScale = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchAppsV1NamespacedDeploymentScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
export interface Response$patchAppsV1NamespacedDeploymentScale$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
export interface Parameter$readAppsV1NamespacedDeploymentStatus {
    /** name of the Deployment */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readAppsV1NamespacedDeploymentStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
export interface Parameter$replaceAppsV1NamespacedDeploymentStatus {
    /** name of the Deployment */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceAppsV1NamespacedDeploymentStatus = RequestBodies.io$k8s$api$apps$v1$Deployment.Content;
export interface Response$replaceAppsV1NamespacedDeploymentStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
export interface Response$replaceAppsV1NamespacedDeploymentStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
export interface Parameter$patchAppsV1NamespacedDeploymentStatus {
    /** name of the Deployment */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchAppsV1NamespacedDeploymentStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchAppsV1NamespacedDeploymentStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
export interface Response$patchAppsV1NamespacedDeploymentStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
export interface Parameter$listAppsV1NamespacedReplicaSet {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listAppsV1NamespacedReplicaSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSetList;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSetList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSetList;
    "application/json;stream=watch": Schemas.io$k8s$api$apps$v1$ReplicaSetList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$apps$v1$ReplicaSetList;
}
export interface Parameter$createAppsV1NamespacedReplicaSet {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createAppsV1NamespacedReplicaSet = RequestBodies.io$k8s$api$apps$v1$ReplicaSet.Content;
export interface Response$createAppsV1NamespacedReplicaSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
export interface Response$createAppsV1NamespacedReplicaSet$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
export interface Response$createAppsV1NamespacedReplicaSet$Status$202 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
export interface Parameter$deleteAppsV1CollectionNamespacedReplicaSet {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteAppsV1CollectionNamespacedReplicaSet = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteAppsV1CollectionNamespacedReplicaSet$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readAppsV1NamespacedReplicaSet {
    /** name of the ReplicaSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readAppsV1NamespacedReplicaSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
export interface Parameter$replaceAppsV1NamespacedReplicaSet {
    /** name of the ReplicaSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceAppsV1NamespacedReplicaSet = RequestBodies.io$k8s$api$apps$v1$ReplicaSet.Content;
export interface Response$replaceAppsV1NamespacedReplicaSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
export interface Response$replaceAppsV1NamespacedReplicaSet$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
export interface Parameter$deleteAppsV1NamespacedReplicaSet {
    /** name of the ReplicaSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteAppsV1NamespacedReplicaSet = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteAppsV1NamespacedReplicaSet$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteAppsV1NamespacedReplicaSet$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchAppsV1NamespacedReplicaSet {
    /** name of the ReplicaSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchAppsV1NamespacedReplicaSet = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchAppsV1NamespacedReplicaSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
export interface Response$patchAppsV1NamespacedReplicaSet$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
export interface Parameter$readAppsV1NamespacedReplicaSetScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readAppsV1NamespacedReplicaSetScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
export interface Parameter$replaceAppsV1NamespacedReplicaSetScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceAppsV1NamespacedReplicaSetScale = RequestBodies.io$k8s$api$autoscaling$v1$Scale.Content;
export interface Response$replaceAppsV1NamespacedReplicaSetScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
export interface Response$replaceAppsV1NamespacedReplicaSetScale$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
export interface Parameter$patchAppsV1NamespacedReplicaSetScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchAppsV1NamespacedReplicaSetScale = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchAppsV1NamespacedReplicaSetScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
export interface Response$patchAppsV1NamespacedReplicaSetScale$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
export interface Parameter$readAppsV1NamespacedReplicaSetStatus {
    /** name of the ReplicaSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readAppsV1NamespacedReplicaSetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
export interface Parameter$replaceAppsV1NamespacedReplicaSetStatus {
    /** name of the ReplicaSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceAppsV1NamespacedReplicaSetStatus = RequestBodies.io$k8s$api$apps$v1$ReplicaSet.Content;
export interface Response$replaceAppsV1NamespacedReplicaSetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
export interface Response$replaceAppsV1NamespacedReplicaSetStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
export interface Parameter$patchAppsV1NamespacedReplicaSetStatus {
    /** name of the ReplicaSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchAppsV1NamespacedReplicaSetStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchAppsV1NamespacedReplicaSetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
export interface Response$patchAppsV1NamespacedReplicaSetStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
export interface Parameter$listAppsV1NamespacedStatefulSet {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listAppsV1NamespacedStatefulSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSetList;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSetList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSetList;
    "application/json;stream=watch": Schemas.io$k8s$api$apps$v1$StatefulSetList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$apps$v1$StatefulSetList;
}
export interface Parameter$createAppsV1NamespacedStatefulSet {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createAppsV1NamespacedStatefulSet = RequestBodies.io$k8s$api$apps$v1$StatefulSet.Content;
export interface Response$createAppsV1NamespacedStatefulSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
export interface Response$createAppsV1NamespacedStatefulSet$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
export interface Response$createAppsV1NamespacedStatefulSet$Status$202 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
export interface Parameter$deleteAppsV1CollectionNamespacedStatefulSet {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteAppsV1CollectionNamespacedStatefulSet = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteAppsV1CollectionNamespacedStatefulSet$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readAppsV1NamespacedStatefulSet {
    /** name of the StatefulSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readAppsV1NamespacedStatefulSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
export interface Parameter$replaceAppsV1NamespacedStatefulSet {
    /** name of the StatefulSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceAppsV1NamespacedStatefulSet = RequestBodies.io$k8s$api$apps$v1$StatefulSet.Content;
export interface Response$replaceAppsV1NamespacedStatefulSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
export interface Response$replaceAppsV1NamespacedStatefulSet$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
export interface Parameter$deleteAppsV1NamespacedStatefulSet {
    /** name of the StatefulSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteAppsV1NamespacedStatefulSet = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteAppsV1NamespacedStatefulSet$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteAppsV1NamespacedStatefulSet$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchAppsV1NamespacedStatefulSet {
    /** name of the StatefulSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchAppsV1NamespacedStatefulSet = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchAppsV1NamespacedStatefulSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
export interface Response$patchAppsV1NamespacedStatefulSet$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
export interface Parameter$readAppsV1NamespacedStatefulSetScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readAppsV1NamespacedStatefulSetScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
export interface Parameter$replaceAppsV1NamespacedStatefulSetScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceAppsV1NamespacedStatefulSetScale = RequestBodies.io$k8s$api$autoscaling$v1$Scale.Content;
export interface Response$replaceAppsV1NamespacedStatefulSetScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
export interface Response$replaceAppsV1NamespacedStatefulSetScale$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
export interface Parameter$patchAppsV1NamespacedStatefulSetScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchAppsV1NamespacedStatefulSetScale = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchAppsV1NamespacedStatefulSetScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
export interface Response$patchAppsV1NamespacedStatefulSetScale$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
export interface Parameter$readAppsV1NamespacedStatefulSetStatus {
    /** name of the StatefulSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readAppsV1NamespacedStatefulSetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
export interface Parameter$replaceAppsV1NamespacedStatefulSetStatus {
    /** name of the StatefulSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceAppsV1NamespacedStatefulSetStatus = RequestBodies.io$k8s$api$apps$v1$StatefulSet.Content;
export interface Response$replaceAppsV1NamespacedStatefulSetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
export interface Response$replaceAppsV1NamespacedStatefulSetStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
export interface Parameter$patchAppsV1NamespacedStatefulSetStatus {
    /** name of the StatefulSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchAppsV1NamespacedStatefulSetStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchAppsV1NamespacedStatefulSetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
export interface Response$patchAppsV1NamespacedStatefulSetStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
export interface Parameter$listAppsV1ReplicaSetForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listAppsV1ReplicaSetForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSetList;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSetList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSetList;
    "application/json;stream=watch": Schemas.io$k8s$api$apps$v1$ReplicaSetList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$apps$v1$ReplicaSetList;
}
export interface Parameter$listAppsV1StatefulSetForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listAppsV1StatefulSetForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSetList;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSetList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSetList;
    "application/json;stream=watch": Schemas.io$k8s$api$apps$v1$StatefulSetList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$apps$v1$StatefulSetList;
}
export interface Parameter$watchAppsV1ControllerRevisionListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAppsV1ControllerRevisionListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAppsV1DaemonSetListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAppsV1DaemonSetListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAppsV1DeploymentListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAppsV1DeploymentListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAppsV1NamespacedControllerRevisionList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAppsV1NamespacedControllerRevisionList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAppsV1NamespacedControllerRevision {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ControllerRevision */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAppsV1NamespacedControllerRevision$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAppsV1NamespacedDaemonSetList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAppsV1NamespacedDaemonSetList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAppsV1NamespacedDaemonSet {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the DaemonSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAppsV1NamespacedDaemonSet$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAppsV1NamespacedDeploymentList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAppsV1NamespacedDeploymentList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAppsV1NamespacedDeployment {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Deployment */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAppsV1NamespacedDeployment$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAppsV1NamespacedReplicaSetList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAppsV1NamespacedReplicaSetList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAppsV1NamespacedReplicaSet {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ReplicaSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAppsV1NamespacedReplicaSet$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAppsV1NamespacedStatefulSetList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAppsV1NamespacedStatefulSetList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAppsV1NamespacedStatefulSet {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the StatefulSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAppsV1NamespacedStatefulSet$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAppsV1ReplicaSetListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAppsV1ReplicaSetListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAppsV1StatefulSetListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAppsV1StatefulSetListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getAuthenticationAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
export interface Response$getAuthenticationV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$createAuthenticationV1TokenReview {
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface RequestBody$createAuthenticationV1TokenReview {
    "*/*": Schemas.io$k8s$api$authentication$v1$TokenReview;
}
export interface Response$createAuthenticationV1TokenReview$Status$200 {
    "application/json": Schemas.io$k8s$api$authentication$v1$TokenReview;
    "application/yaml": Schemas.io$k8s$api$authentication$v1$TokenReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authentication$v1$TokenReview;
}
export interface Response$createAuthenticationV1TokenReview$Status$201 {
    "application/json": Schemas.io$k8s$api$authentication$v1$TokenReview;
    "application/yaml": Schemas.io$k8s$api$authentication$v1$TokenReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authentication$v1$TokenReview;
}
export interface Response$createAuthenticationV1TokenReview$Status$202 {
    "application/json": Schemas.io$k8s$api$authentication$v1$TokenReview;
    "application/yaml": Schemas.io$k8s$api$authentication$v1$TokenReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authentication$v1$TokenReview;
}
export interface Response$getAuthorizationAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
export interface Response$getAuthorizationV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$createAuthorizationV1NamespacedLocalSubjectAccessReview {
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface RequestBody$createAuthorizationV1NamespacedLocalSubjectAccessReview {
    "*/*": Schemas.io$k8s$api$authorization$v1$LocalSubjectAccessReview;
}
export interface Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$200 {
    "application/json": Schemas.io$k8s$api$authorization$v1$LocalSubjectAccessReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$LocalSubjectAccessReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$LocalSubjectAccessReview;
}
export interface Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$201 {
    "application/json": Schemas.io$k8s$api$authorization$v1$LocalSubjectAccessReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$LocalSubjectAccessReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$LocalSubjectAccessReview;
}
export interface Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$202 {
    "application/json": Schemas.io$k8s$api$authorization$v1$LocalSubjectAccessReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$LocalSubjectAccessReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$LocalSubjectAccessReview;
}
export interface Parameter$createAuthorizationV1SelfSubjectAccessReview {
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface RequestBody$createAuthorizationV1SelfSubjectAccessReview {
    "*/*": Schemas.io$k8s$api$authorization$v1$SelfSubjectAccessReview;
}
export interface Response$createAuthorizationV1SelfSubjectAccessReview$Status$200 {
    "application/json": Schemas.io$k8s$api$authorization$v1$SelfSubjectAccessReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$SelfSubjectAccessReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$SelfSubjectAccessReview;
}
export interface Response$createAuthorizationV1SelfSubjectAccessReview$Status$201 {
    "application/json": Schemas.io$k8s$api$authorization$v1$SelfSubjectAccessReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$SelfSubjectAccessReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$SelfSubjectAccessReview;
}
export interface Response$createAuthorizationV1SelfSubjectAccessReview$Status$202 {
    "application/json": Schemas.io$k8s$api$authorization$v1$SelfSubjectAccessReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$SelfSubjectAccessReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$SelfSubjectAccessReview;
}
export interface Parameter$createAuthorizationV1SelfSubjectRulesReview {
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface RequestBody$createAuthorizationV1SelfSubjectRulesReview {
    "*/*": Schemas.io$k8s$api$authorization$v1$SelfSubjectRulesReview;
}
export interface Response$createAuthorizationV1SelfSubjectRulesReview$Status$200 {
    "application/json": Schemas.io$k8s$api$authorization$v1$SelfSubjectRulesReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$SelfSubjectRulesReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$SelfSubjectRulesReview;
}
export interface Response$createAuthorizationV1SelfSubjectRulesReview$Status$201 {
    "application/json": Schemas.io$k8s$api$authorization$v1$SelfSubjectRulesReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$SelfSubjectRulesReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$SelfSubjectRulesReview;
}
export interface Response$createAuthorizationV1SelfSubjectRulesReview$Status$202 {
    "application/json": Schemas.io$k8s$api$authorization$v1$SelfSubjectRulesReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$SelfSubjectRulesReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$SelfSubjectRulesReview;
}
export interface Parameter$createAuthorizationV1SubjectAccessReview {
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface RequestBody$createAuthorizationV1SubjectAccessReview {
    "*/*": Schemas.io$k8s$api$authorization$v1$SubjectAccessReview;
}
export interface Response$createAuthorizationV1SubjectAccessReview$Status$200 {
    "application/json": Schemas.io$k8s$api$authorization$v1$SubjectAccessReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$SubjectAccessReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$SubjectAccessReview;
}
export interface Response$createAuthorizationV1SubjectAccessReview$Status$201 {
    "application/json": Schemas.io$k8s$api$authorization$v1$SubjectAccessReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$SubjectAccessReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$SubjectAccessReview;
}
export interface Response$createAuthorizationV1SubjectAccessReview$Status$202 {
    "application/json": Schemas.io$k8s$api$authorization$v1$SubjectAccessReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$SubjectAccessReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$SubjectAccessReview;
}
export interface Response$getAutoscalingAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
export interface Response$getAutoscalingV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerList;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerList;
    "application/json;stream=watch": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerList;
}
export interface Parameter$listAutoscalingV1NamespacedHorizontalPodAutoscaler {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerList;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerList;
    "application/json;stream=watch": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerList;
}
export interface Parameter$createAutoscalingV1NamespacedHorizontalPodAutoscaler {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createAutoscalingV1NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler.Content;
export interface Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
export interface Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
export interface Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$202 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
export interface Parameter$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readAutoscalingV1NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
export interface Parameter$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler.Content;
export interface Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
export interface Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
export interface Parameter$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchAutoscalingV1NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchAutoscalingV1NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
export interface Response$patchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
export interface Parameter$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
export interface Parameter$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus = RequestBodies.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler.Content;
export interface Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
export interface Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
export interface Parameter$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
export interface Response$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
export interface Parameter$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAutoscalingV1NamespacedHorizontalPodAutoscaler {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getAutoscalingV2APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerList;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerList;
    "application/json;stream=watch": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerList;
}
export interface Parameter$listAutoscalingV2NamespacedHorizontalPodAutoscaler {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerList;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerList;
    "application/json;stream=watch": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerList;
}
export interface Parameter$createAutoscalingV2NamespacedHorizontalPodAutoscaler {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createAutoscalingV2NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler.Content;
export interface Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
export interface Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
export interface Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$202 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
export interface Parameter$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readAutoscalingV2NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
export interface Parameter$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler.Content;
export interface Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
export interface Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
export interface Parameter$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchAutoscalingV2NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchAutoscalingV2NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
export interface Response$patchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
export interface Parameter$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
export interface Parameter$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus = RequestBodies.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler.Content;
export interface Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
export interface Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
export interface Parameter$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
export interface Response$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
export interface Parameter$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAutoscalingV2NamespacedHorizontalPodAutoscaler {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getAutoscalingV2beta1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listAutoscalingV2beta1HorizontalPodAutoscalerForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listAutoscalingV2beta1HorizontalPodAutoscalerForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscalerList;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscalerList;
    "application/json;stream=watch": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscalerList;
}
export interface Parameter$listAutoscalingV2beta1NamespacedHorizontalPodAutoscaler {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscalerList;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscalerList;
    "application/json;stream=watch": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscalerList;
}
export interface Parameter$createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler.Content;
export interface Response$createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
}
export interface Response$createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
}
export interface Response$createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$202 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
}
export interface Parameter$deleteAutoscalingV2beta1CollectionNamespacedHorizontalPodAutoscaler {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteAutoscalingV2beta1CollectionNamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteAutoscalingV2beta1CollectionNamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readAutoscalingV2beta1NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
}
export interface Parameter$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler.Content;
export interface Response$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
}
export interface Response$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
}
export interface Parameter$deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
}
export interface Response$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
}
export interface Parameter$readAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
}
export interface Parameter$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus = RequestBodies.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler.Content;
export interface Response$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
}
export interface Response$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
}
export interface Parameter$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
}
export interface Response$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta1$HorizontalPodAutoscaler;
}
export interface Parameter$watchAutoscalingV2beta1HorizontalPodAutoscalerListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAutoscalingV2beta1HorizontalPodAutoscalerListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getAutoscalingV2beta2APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listAutoscalingV2beta2HorizontalPodAutoscalerForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listAutoscalingV2beta2HorizontalPodAutoscalerForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscalerList;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscalerList;
    "application/json;stream=watch": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscalerList;
}
export interface Parameter$listAutoscalingV2beta2NamespacedHorizontalPodAutoscaler {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscalerList;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscalerList;
    "application/json;stream=watch": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscalerList;
}
export interface Parameter$createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler.Content;
export interface Response$createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
}
export interface Response$createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
}
export interface Response$createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$202 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
}
export interface Parameter$deleteAutoscalingV2beta2CollectionNamespacedHorizontalPodAutoscaler {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteAutoscalingV2beta2CollectionNamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteAutoscalingV2beta2CollectionNamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readAutoscalingV2beta2NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
}
export interface Parameter$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler.Content;
export interface Response$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
}
export interface Response$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
}
export interface Parameter$deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
}
export interface Response$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
}
export interface Parameter$readAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
}
export interface Parameter$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus = RequestBodies.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler.Content;
export interface Response$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
}
export interface Response$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
}
export interface Parameter$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
}
export interface Response$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2beta2$HorizontalPodAutoscaler;
}
export interface Parameter$watchAutoscalingV2beta2HorizontalPodAutoscalerListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAutoscalingV2beta2HorizontalPodAutoscalerListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getBatchAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
export interface Response$getBatchV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listBatchV1CronJobForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listBatchV1CronJobForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJobList;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJobList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJobList;
    "application/json;stream=watch": Schemas.io$k8s$api$batch$v1$CronJobList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$batch$v1$CronJobList;
}
export interface Parameter$listBatchV1JobForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listBatchV1JobForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$JobList;
    "application/yaml": Schemas.io$k8s$api$batch$v1$JobList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$JobList;
    "application/json;stream=watch": Schemas.io$k8s$api$batch$v1$JobList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$batch$v1$JobList;
}
export interface Parameter$listBatchV1NamespacedCronJob {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listBatchV1NamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJobList;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJobList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJobList;
    "application/json;stream=watch": Schemas.io$k8s$api$batch$v1$CronJobList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$batch$v1$CronJobList;
}
export interface Parameter$createBatchV1NamespacedCronJob {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createBatchV1NamespacedCronJob = RequestBodies.io$k8s$api$batch$v1$CronJob.Content;
export interface Response$createBatchV1NamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
export interface Response$createBatchV1NamespacedCronJob$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
export interface Response$createBatchV1NamespacedCronJob$Status$202 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
export interface Parameter$deleteBatchV1CollectionNamespacedCronJob {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteBatchV1CollectionNamespacedCronJob = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteBatchV1CollectionNamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readBatchV1NamespacedCronJob {
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readBatchV1NamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
export interface Parameter$replaceBatchV1NamespacedCronJob {
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceBatchV1NamespacedCronJob = RequestBodies.io$k8s$api$batch$v1$CronJob.Content;
export interface Response$replaceBatchV1NamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
export interface Response$replaceBatchV1NamespacedCronJob$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
export interface Parameter$deleteBatchV1NamespacedCronJob {
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteBatchV1NamespacedCronJob = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteBatchV1NamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteBatchV1NamespacedCronJob$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchBatchV1NamespacedCronJob {
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchBatchV1NamespacedCronJob = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchBatchV1NamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
export interface Response$patchBatchV1NamespacedCronJob$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
export interface Parameter$readBatchV1NamespacedCronJobStatus {
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readBatchV1NamespacedCronJobStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
export interface Parameter$replaceBatchV1NamespacedCronJobStatus {
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceBatchV1NamespacedCronJobStatus = RequestBodies.io$k8s$api$batch$v1$CronJob.Content;
export interface Response$replaceBatchV1NamespacedCronJobStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
export interface Response$replaceBatchV1NamespacedCronJobStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
export interface Parameter$patchBatchV1NamespacedCronJobStatus {
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchBatchV1NamespacedCronJobStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchBatchV1NamespacedCronJobStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
export interface Response$patchBatchV1NamespacedCronJobStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
export interface Parameter$listBatchV1NamespacedJob {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listBatchV1NamespacedJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$JobList;
    "application/yaml": Schemas.io$k8s$api$batch$v1$JobList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$JobList;
    "application/json;stream=watch": Schemas.io$k8s$api$batch$v1$JobList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$batch$v1$JobList;
}
export interface Parameter$createBatchV1NamespacedJob {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createBatchV1NamespacedJob = RequestBodies.io$k8s$api$batch$v1$Job.Content;
export interface Response$createBatchV1NamespacedJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
export interface Response$createBatchV1NamespacedJob$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
export interface Response$createBatchV1NamespacedJob$Status$202 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
export interface Parameter$deleteBatchV1CollectionNamespacedJob {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteBatchV1CollectionNamespacedJob = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteBatchV1CollectionNamespacedJob$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readBatchV1NamespacedJob {
    /** name of the Job */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readBatchV1NamespacedJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
export interface Parameter$replaceBatchV1NamespacedJob {
    /** name of the Job */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceBatchV1NamespacedJob = RequestBodies.io$k8s$api$batch$v1$Job.Content;
export interface Response$replaceBatchV1NamespacedJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
export interface Response$replaceBatchV1NamespacedJob$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
export interface Parameter$deleteBatchV1NamespacedJob {
    /** name of the Job */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteBatchV1NamespacedJob = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteBatchV1NamespacedJob$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteBatchV1NamespacedJob$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchBatchV1NamespacedJob {
    /** name of the Job */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchBatchV1NamespacedJob = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchBatchV1NamespacedJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
export interface Response$patchBatchV1NamespacedJob$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
export interface Parameter$readBatchV1NamespacedJobStatus {
    /** name of the Job */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readBatchV1NamespacedJobStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
export interface Parameter$replaceBatchV1NamespacedJobStatus {
    /** name of the Job */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceBatchV1NamespacedJobStatus = RequestBodies.io$k8s$api$batch$v1$Job.Content;
export interface Response$replaceBatchV1NamespacedJobStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
export interface Response$replaceBatchV1NamespacedJobStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
export interface Parameter$patchBatchV1NamespacedJobStatus {
    /** name of the Job */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchBatchV1NamespacedJobStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchBatchV1NamespacedJobStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
export interface Response$patchBatchV1NamespacedJobStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
export interface Parameter$watchBatchV1CronJobListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchBatchV1CronJobListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchBatchV1JobListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchBatchV1JobListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchBatchV1NamespacedCronJobList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchBatchV1NamespacedCronJobList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchBatchV1NamespacedCronJob {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchBatchV1NamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchBatchV1NamespacedJobList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchBatchV1NamespacedJobList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchBatchV1NamespacedJob {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Job */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchBatchV1NamespacedJob$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getBatchV1beta1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listBatchV1beta1CronJobForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listBatchV1beta1CronJobForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1beta1$CronJobList;
    "application/yaml": Schemas.io$k8s$api$batch$v1beta1$CronJobList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1beta1$CronJobList;
    "application/json;stream=watch": Schemas.io$k8s$api$batch$v1beta1$CronJobList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$batch$v1beta1$CronJobList;
}
export interface Parameter$listBatchV1beta1NamespacedCronJob {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listBatchV1beta1NamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1beta1$CronJobList;
    "application/yaml": Schemas.io$k8s$api$batch$v1beta1$CronJobList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1beta1$CronJobList;
    "application/json;stream=watch": Schemas.io$k8s$api$batch$v1beta1$CronJobList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$batch$v1beta1$CronJobList;
}
export interface Parameter$createBatchV1beta1NamespacedCronJob {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createBatchV1beta1NamespacedCronJob = RequestBodies.io$k8s$api$batch$v1beta1$CronJob.Content;
export interface Response$createBatchV1beta1NamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1beta1$CronJob;
}
export interface Response$createBatchV1beta1NamespacedCronJob$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1beta1$CronJob;
}
export interface Response$createBatchV1beta1NamespacedCronJob$Status$202 {
    "application/json": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1beta1$CronJob;
}
export interface Parameter$deleteBatchV1beta1CollectionNamespacedCronJob {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteBatchV1beta1CollectionNamespacedCronJob = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteBatchV1beta1CollectionNamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readBatchV1beta1NamespacedCronJob {
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readBatchV1beta1NamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1beta1$CronJob;
}
export interface Parameter$replaceBatchV1beta1NamespacedCronJob {
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceBatchV1beta1NamespacedCronJob = RequestBodies.io$k8s$api$batch$v1beta1$CronJob.Content;
export interface Response$replaceBatchV1beta1NamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1beta1$CronJob;
}
export interface Response$replaceBatchV1beta1NamespacedCronJob$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1beta1$CronJob;
}
export interface Parameter$deleteBatchV1beta1NamespacedCronJob {
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteBatchV1beta1NamespacedCronJob = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteBatchV1beta1NamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteBatchV1beta1NamespacedCronJob$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchBatchV1beta1NamespacedCronJob {
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchBatchV1beta1NamespacedCronJob = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchBatchV1beta1NamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1beta1$CronJob;
}
export interface Response$patchBatchV1beta1NamespacedCronJob$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1beta1$CronJob;
}
export interface Parameter$readBatchV1beta1NamespacedCronJobStatus {
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readBatchV1beta1NamespacedCronJobStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1beta1$CronJob;
}
export interface Parameter$replaceBatchV1beta1NamespacedCronJobStatus {
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceBatchV1beta1NamespacedCronJobStatus = RequestBodies.io$k8s$api$batch$v1beta1$CronJob.Content;
export interface Response$replaceBatchV1beta1NamespacedCronJobStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1beta1$CronJob;
}
export interface Response$replaceBatchV1beta1NamespacedCronJobStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1beta1$CronJob;
}
export interface Parameter$patchBatchV1beta1NamespacedCronJobStatus {
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchBatchV1beta1NamespacedCronJobStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchBatchV1beta1NamespacedCronJobStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1beta1$CronJob;
}
export interface Response$patchBatchV1beta1NamespacedCronJobStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1beta1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1beta1$CronJob;
}
export interface Parameter$watchBatchV1beta1CronJobListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchBatchV1beta1CronJobListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchBatchV1beta1NamespacedCronJobList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchBatchV1beta1NamespacedCronJobList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchBatchV1beta1NamespacedCronJob {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchBatchV1beta1NamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getCertificatesAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
export interface Response$getCertificatesV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listCertificatesV1CertificateSigningRequest {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCertificatesV1CertificateSigningRequest$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequestList;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequestList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequestList;
    "application/json;stream=watch": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequestList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequestList;
}
export interface Parameter$createCertificatesV1CertificateSigningRequest {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createCertificatesV1CertificateSigningRequest = RequestBodies.io$k8s$api$certificates$v1$CertificateSigningRequest.Content;
export interface Response$createCertificatesV1CertificateSigningRequest$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
export interface Response$createCertificatesV1CertificateSigningRequest$Status$201 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
export interface Response$createCertificatesV1CertificateSigningRequest$Status$202 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
export interface Parameter$deleteCertificatesV1CollectionCertificateSigningRequest {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteCertificatesV1CollectionCertificateSigningRequest = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCertificatesV1CollectionCertificateSigningRequest$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readCertificatesV1CertificateSigningRequest {
    /** name of the CertificateSigningRequest */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCertificatesV1CertificateSigningRequest$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
export interface Parameter$replaceCertificatesV1CertificateSigningRequest {
    /** name of the CertificateSigningRequest */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCertificatesV1CertificateSigningRequest = RequestBodies.io$k8s$api$certificates$v1$CertificateSigningRequest.Content;
export interface Response$replaceCertificatesV1CertificateSigningRequest$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
export interface Response$replaceCertificatesV1CertificateSigningRequest$Status$201 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
export interface Parameter$deleteCertificatesV1CertificateSigningRequest {
    /** name of the CertificateSigningRequest */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteCertificatesV1CertificateSigningRequest = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCertificatesV1CertificateSigningRequest$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteCertificatesV1CertificateSigningRequest$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchCertificatesV1CertificateSigningRequest {
    /** name of the CertificateSigningRequest */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCertificatesV1CertificateSigningRequest = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCertificatesV1CertificateSigningRequest$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
export interface Response$patchCertificatesV1CertificateSigningRequest$Status$201 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
export interface Parameter$readCertificatesV1CertificateSigningRequestApproval {
    /** name of the CertificateSigningRequest */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCertificatesV1CertificateSigningRequestApproval$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
export interface Parameter$replaceCertificatesV1CertificateSigningRequestApproval {
    /** name of the CertificateSigningRequest */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCertificatesV1CertificateSigningRequestApproval = RequestBodies.io$k8s$api$certificates$v1$CertificateSigningRequest.Content;
export interface Response$replaceCertificatesV1CertificateSigningRequestApproval$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
export interface Response$replaceCertificatesV1CertificateSigningRequestApproval$Status$201 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
export interface Parameter$patchCertificatesV1CertificateSigningRequestApproval {
    /** name of the CertificateSigningRequest */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCertificatesV1CertificateSigningRequestApproval = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCertificatesV1CertificateSigningRequestApproval$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
export interface Response$patchCertificatesV1CertificateSigningRequestApproval$Status$201 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
export interface Parameter$readCertificatesV1CertificateSigningRequestStatus {
    /** name of the CertificateSigningRequest */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCertificatesV1CertificateSigningRequestStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
export interface Parameter$replaceCertificatesV1CertificateSigningRequestStatus {
    /** name of the CertificateSigningRequest */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCertificatesV1CertificateSigningRequestStatus = RequestBodies.io$k8s$api$certificates$v1$CertificateSigningRequest.Content;
export interface Response$replaceCertificatesV1CertificateSigningRequestStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
export interface Response$replaceCertificatesV1CertificateSigningRequestStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
export interface Parameter$patchCertificatesV1CertificateSigningRequestStatus {
    /** name of the CertificateSigningRequest */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCertificatesV1CertificateSigningRequestStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCertificatesV1CertificateSigningRequestStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
export interface Response$patchCertificatesV1CertificateSigningRequestStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
export interface Parameter$watchCertificatesV1CertificateSigningRequestList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCertificatesV1CertificateSigningRequestList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCertificatesV1CertificateSigningRequest {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the CertificateSigningRequest */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCertificatesV1CertificateSigningRequest$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getCoordinationAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
export interface Response$getCoordinationV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listCoordinationV1LeaseForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoordinationV1LeaseForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$coordination$v1$LeaseList;
    "application/yaml": Schemas.io$k8s$api$coordination$v1$LeaseList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$coordination$v1$LeaseList;
    "application/json;stream=watch": Schemas.io$k8s$api$coordination$v1$LeaseList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$coordination$v1$LeaseList;
}
export interface Parameter$listCoordinationV1NamespacedLease {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listCoordinationV1NamespacedLease$Status$200 {
    "application/json": Schemas.io$k8s$api$coordination$v1$LeaseList;
    "application/yaml": Schemas.io$k8s$api$coordination$v1$LeaseList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$coordination$v1$LeaseList;
    "application/json;stream=watch": Schemas.io$k8s$api$coordination$v1$LeaseList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$coordination$v1$LeaseList;
}
export interface Parameter$createCoordinationV1NamespacedLease {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createCoordinationV1NamespacedLease = RequestBodies.io$k8s$api$coordination$v1$Lease.Content;
export interface Response$createCoordinationV1NamespacedLease$Status$200 {
    "application/json": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/yaml": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$coordination$v1$Lease;
}
export interface Response$createCoordinationV1NamespacedLease$Status$201 {
    "application/json": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/yaml": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$coordination$v1$Lease;
}
export interface Response$createCoordinationV1NamespacedLease$Status$202 {
    "application/json": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/yaml": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$coordination$v1$Lease;
}
export interface Parameter$deleteCoordinationV1CollectionNamespacedLease {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteCoordinationV1CollectionNamespacedLease = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoordinationV1CollectionNamespacedLease$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readCoordinationV1NamespacedLease {
    /** name of the Lease */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readCoordinationV1NamespacedLease$Status$200 {
    "application/json": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/yaml": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$coordination$v1$Lease;
}
export interface Parameter$replaceCoordinationV1NamespacedLease {
    /** name of the Lease */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceCoordinationV1NamespacedLease = RequestBodies.io$k8s$api$coordination$v1$Lease.Content;
export interface Response$replaceCoordinationV1NamespacedLease$Status$200 {
    "application/json": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/yaml": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$coordination$v1$Lease;
}
export interface Response$replaceCoordinationV1NamespacedLease$Status$201 {
    "application/json": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/yaml": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$coordination$v1$Lease;
}
export interface Parameter$deleteCoordinationV1NamespacedLease {
    /** name of the Lease */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteCoordinationV1NamespacedLease = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteCoordinationV1NamespacedLease$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteCoordinationV1NamespacedLease$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchCoordinationV1NamespacedLease {
    /** name of the Lease */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchCoordinationV1NamespacedLease = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchCoordinationV1NamespacedLease$Status$200 {
    "application/json": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/yaml": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$coordination$v1$Lease;
}
export interface Response$patchCoordinationV1NamespacedLease$Status$201 {
    "application/json": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/yaml": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$coordination$v1$Lease;
}
export interface Parameter$watchCoordinationV1LeaseListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoordinationV1LeaseListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoordinationV1NamespacedLeaseList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoordinationV1NamespacedLeaseList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchCoordinationV1NamespacedLease {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Lease */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchCoordinationV1NamespacedLease$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getDiscoveryAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
export interface Response$getDiscoveryV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listDiscoveryV1EndpointSliceForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listDiscoveryV1EndpointSliceForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$discovery$v1$EndpointSliceList;
    "application/yaml": Schemas.io$k8s$api$discovery$v1$EndpointSliceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1$EndpointSliceList;
    "application/json;stream=watch": Schemas.io$k8s$api$discovery$v1$EndpointSliceList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$discovery$v1$EndpointSliceList;
}
export interface Parameter$listDiscoveryV1NamespacedEndpointSlice {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listDiscoveryV1NamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$api$discovery$v1$EndpointSliceList;
    "application/yaml": Schemas.io$k8s$api$discovery$v1$EndpointSliceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1$EndpointSliceList;
    "application/json;stream=watch": Schemas.io$k8s$api$discovery$v1$EndpointSliceList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$discovery$v1$EndpointSliceList;
}
export interface Parameter$createDiscoveryV1NamespacedEndpointSlice {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createDiscoveryV1NamespacedEndpointSlice = RequestBodies.io$k8s$api$discovery$v1$EndpointSlice.Content;
export interface Response$createDiscoveryV1NamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
}
export interface Response$createDiscoveryV1NamespacedEndpointSlice$Status$201 {
    "application/json": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
}
export interface Response$createDiscoveryV1NamespacedEndpointSlice$Status$202 {
    "application/json": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
}
export interface Parameter$deleteDiscoveryV1CollectionNamespacedEndpointSlice {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteDiscoveryV1CollectionNamespacedEndpointSlice = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteDiscoveryV1CollectionNamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readDiscoveryV1NamespacedEndpointSlice {
    /** name of the EndpointSlice */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readDiscoveryV1NamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
}
export interface Parameter$replaceDiscoveryV1NamespacedEndpointSlice {
    /** name of the EndpointSlice */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceDiscoveryV1NamespacedEndpointSlice = RequestBodies.io$k8s$api$discovery$v1$EndpointSlice.Content;
export interface Response$replaceDiscoveryV1NamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
}
export interface Response$replaceDiscoveryV1NamespacedEndpointSlice$Status$201 {
    "application/json": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
}
export interface Parameter$deleteDiscoveryV1NamespacedEndpointSlice {
    /** name of the EndpointSlice */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteDiscoveryV1NamespacedEndpointSlice = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteDiscoveryV1NamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteDiscoveryV1NamespacedEndpointSlice$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchDiscoveryV1NamespacedEndpointSlice {
    /** name of the EndpointSlice */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchDiscoveryV1NamespacedEndpointSlice = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchDiscoveryV1NamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
}
export interface Response$patchDiscoveryV1NamespacedEndpointSlice$Status$201 {
    "application/json": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
}
export interface Parameter$watchDiscoveryV1EndpointSliceListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchDiscoveryV1EndpointSliceListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchDiscoveryV1NamespacedEndpointSliceList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchDiscoveryV1NamespacedEndpointSliceList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchDiscoveryV1NamespacedEndpointSlice {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the EndpointSlice */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchDiscoveryV1NamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getDiscoveryV1beta1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listDiscoveryV1beta1EndpointSliceForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listDiscoveryV1beta1EndpointSliceForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$discovery$v1beta1$EndpointSliceList;
    "application/yaml": Schemas.io$k8s$api$discovery$v1beta1$EndpointSliceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1beta1$EndpointSliceList;
    "application/json;stream=watch": Schemas.io$k8s$api$discovery$v1beta1$EndpointSliceList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$discovery$v1beta1$EndpointSliceList;
}
export interface Parameter$listDiscoveryV1beta1NamespacedEndpointSlice {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listDiscoveryV1beta1NamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$api$discovery$v1beta1$EndpointSliceList;
    "application/yaml": Schemas.io$k8s$api$discovery$v1beta1$EndpointSliceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1beta1$EndpointSliceList;
    "application/json;stream=watch": Schemas.io$k8s$api$discovery$v1beta1$EndpointSliceList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$discovery$v1beta1$EndpointSliceList;
}
export interface Parameter$createDiscoveryV1beta1NamespacedEndpointSlice {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createDiscoveryV1beta1NamespacedEndpointSlice = RequestBodies.io$k8s$api$discovery$v1beta1$EndpointSlice.Content;
export interface Response$createDiscoveryV1beta1NamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
}
export interface Response$createDiscoveryV1beta1NamespacedEndpointSlice$Status$201 {
    "application/json": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
}
export interface Response$createDiscoveryV1beta1NamespacedEndpointSlice$Status$202 {
    "application/json": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
}
export interface Parameter$deleteDiscoveryV1beta1CollectionNamespacedEndpointSlice {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteDiscoveryV1beta1CollectionNamespacedEndpointSlice = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteDiscoveryV1beta1CollectionNamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readDiscoveryV1beta1NamespacedEndpointSlice {
    /** name of the EndpointSlice */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readDiscoveryV1beta1NamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
}
export interface Parameter$replaceDiscoveryV1beta1NamespacedEndpointSlice {
    /** name of the EndpointSlice */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceDiscoveryV1beta1NamespacedEndpointSlice = RequestBodies.io$k8s$api$discovery$v1beta1$EndpointSlice.Content;
export interface Response$replaceDiscoveryV1beta1NamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
}
export interface Response$replaceDiscoveryV1beta1NamespacedEndpointSlice$Status$201 {
    "application/json": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
}
export interface Parameter$deleteDiscoveryV1beta1NamespacedEndpointSlice {
    /** name of the EndpointSlice */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteDiscoveryV1beta1NamespacedEndpointSlice = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteDiscoveryV1beta1NamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteDiscoveryV1beta1NamespacedEndpointSlice$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchDiscoveryV1beta1NamespacedEndpointSlice {
    /** name of the EndpointSlice */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchDiscoveryV1beta1NamespacedEndpointSlice = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchDiscoveryV1beta1NamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
}
export interface Response$patchDiscoveryV1beta1NamespacedEndpointSlice$Status$201 {
    "application/json": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1beta1$EndpointSlice;
}
export interface Parameter$watchDiscoveryV1beta1EndpointSliceListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchDiscoveryV1beta1EndpointSliceListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchDiscoveryV1beta1NamespacedEndpointSliceList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchDiscoveryV1beta1NamespacedEndpointSliceList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchDiscoveryV1beta1NamespacedEndpointSlice {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the EndpointSlice */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchDiscoveryV1beta1NamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getEventsAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
export interface Response$getEventsV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listEventsV1EventForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listEventsV1EventForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$events$v1$EventList;
    "application/yaml": Schemas.io$k8s$api$events$v1$EventList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1$EventList;
    "application/json;stream=watch": Schemas.io$k8s$api$events$v1$EventList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$events$v1$EventList;
}
export interface Parameter$listEventsV1NamespacedEvent {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listEventsV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$events$v1$EventList;
    "application/yaml": Schemas.io$k8s$api$events$v1$EventList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1$EventList;
    "application/json;stream=watch": Schemas.io$k8s$api$events$v1$EventList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$events$v1$EventList;
}
export interface Parameter$createEventsV1NamespacedEvent {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createEventsV1NamespacedEvent = RequestBodies.io$k8s$api$events$v1$Event.Content;
export interface Response$createEventsV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$events$v1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1$Event;
}
export interface Response$createEventsV1NamespacedEvent$Status$201 {
    "application/json": Schemas.io$k8s$api$events$v1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1$Event;
}
export interface Response$createEventsV1NamespacedEvent$Status$202 {
    "application/json": Schemas.io$k8s$api$events$v1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1$Event;
}
export interface Parameter$deleteEventsV1CollectionNamespacedEvent {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteEventsV1CollectionNamespacedEvent = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteEventsV1CollectionNamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readEventsV1NamespacedEvent {
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readEventsV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$events$v1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1$Event;
}
export interface Parameter$replaceEventsV1NamespacedEvent {
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceEventsV1NamespacedEvent = RequestBodies.io$k8s$api$events$v1$Event.Content;
export interface Response$replaceEventsV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$events$v1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1$Event;
}
export interface Response$replaceEventsV1NamespacedEvent$Status$201 {
    "application/json": Schemas.io$k8s$api$events$v1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1$Event;
}
export interface Parameter$deleteEventsV1NamespacedEvent {
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteEventsV1NamespacedEvent = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteEventsV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteEventsV1NamespacedEvent$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchEventsV1NamespacedEvent {
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchEventsV1NamespacedEvent = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchEventsV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$events$v1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1$Event;
}
export interface Response$patchEventsV1NamespacedEvent$Status$201 {
    "application/json": Schemas.io$k8s$api$events$v1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1$Event;
}
export interface Parameter$watchEventsV1EventListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchEventsV1EventListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchEventsV1NamespacedEventList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchEventsV1NamespacedEventList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchEventsV1NamespacedEvent {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchEventsV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getEventsV1beta1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listEventsV1beta1EventForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listEventsV1beta1EventForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$events$v1beta1$EventList;
    "application/yaml": Schemas.io$k8s$api$events$v1beta1$EventList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1beta1$EventList;
    "application/json;stream=watch": Schemas.io$k8s$api$events$v1beta1$EventList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$events$v1beta1$EventList;
}
export interface Parameter$listEventsV1beta1NamespacedEvent {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listEventsV1beta1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$events$v1beta1$EventList;
    "application/yaml": Schemas.io$k8s$api$events$v1beta1$EventList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1beta1$EventList;
    "application/json;stream=watch": Schemas.io$k8s$api$events$v1beta1$EventList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$events$v1beta1$EventList;
}
export interface Parameter$createEventsV1beta1NamespacedEvent {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createEventsV1beta1NamespacedEvent = RequestBodies.io$k8s$api$events$v1beta1$Event.Content;
export interface Response$createEventsV1beta1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$events$v1beta1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1beta1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1beta1$Event;
}
export interface Response$createEventsV1beta1NamespacedEvent$Status$201 {
    "application/json": Schemas.io$k8s$api$events$v1beta1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1beta1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1beta1$Event;
}
export interface Response$createEventsV1beta1NamespacedEvent$Status$202 {
    "application/json": Schemas.io$k8s$api$events$v1beta1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1beta1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1beta1$Event;
}
export interface Parameter$deleteEventsV1beta1CollectionNamespacedEvent {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteEventsV1beta1CollectionNamespacedEvent = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteEventsV1beta1CollectionNamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readEventsV1beta1NamespacedEvent {
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readEventsV1beta1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$events$v1beta1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1beta1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1beta1$Event;
}
export interface Parameter$replaceEventsV1beta1NamespacedEvent {
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceEventsV1beta1NamespacedEvent = RequestBodies.io$k8s$api$events$v1beta1$Event.Content;
export interface Response$replaceEventsV1beta1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$events$v1beta1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1beta1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1beta1$Event;
}
export interface Response$replaceEventsV1beta1NamespacedEvent$Status$201 {
    "application/json": Schemas.io$k8s$api$events$v1beta1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1beta1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1beta1$Event;
}
export interface Parameter$deleteEventsV1beta1NamespacedEvent {
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteEventsV1beta1NamespacedEvent = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteEventsV1beta1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteEventsV1beta1NamespacedEvent$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchEventsV1beta1NamespacedEvent {
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchEventsV1beta1NamespacedEvent = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchEventsV1beta1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$events$v1beta1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1beta1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1beta1$Event;
}
export interface Response$patchEventsV1beta1NamespacedEvent$Status$201 {
    "application/json": Schemas.io$k8s$api$events$v1beta1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1beta1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1beta1$Event;
}
export interface Parameter$watchEventsV1beta1EventListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchEventsV1beta1EventListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchEventsV1beta1NamespacedEventList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchEventsV1beta1NamespacedEventList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchEventsV1beta1NamespacedEvent {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchEventsV1beta1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getFlowcontrolApiserverAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
export interface Response$getFlowcontrolApiserverV1beta1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listFlowcontrolApiserverV1beta1FlowSchema {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listFlowcontrolApiserverV1beta1FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchemaList;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchemaList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchemaList;
    "application/json;stream=watch": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchemaList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchemaList;
}
export interface Parameter$createFlowcontrolApiserverV1beta1FlowSchema {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createFlowcontrolApiserverV1beta1FlowSchema = RequestBodies.io$k8s$api$flowcontrol$v1beta1$FlowSchema.Content;
export interface Response$createFlowcontrolApiserverV1beta1FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
}
export interface Response$createFlowcontrolApiserverV1beta1FlowSchema$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
}
export interface Response$createFlowcontrolApiserverV1beta1FlowSchema$Status$202 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
}
export interface Parameter$deleteFlowcontrolApiserverV1beta1CollectionFlowSchema {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteFlowcontrolApiserverV1beta1CollectionFlowSchema = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteFlowcontrolApiserverV1beta1CollectionFlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readFlowcontrolApiserverV1beta1FlowSchema {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readFlowcontrolApiserverV1beta1FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
}
export interface Parameter$replaceFlowcontrolApiserverV1beta1FlowSchema {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceFlowcontrolApiserverV1beta1FlowSchema = RequestBodies.io$k8s$api$flowcontrol$v1beta1$FlowSchema.Content;
export interface Response$replaceFlowcontrolApiserverV1beta1FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
}
export interface Response$replaceFlowcontrolApiserverV1beta1FlowSchema$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
}
export interface Parameter$deleteFlowcontrolApiserverV1beta1FlowSchema {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteFlowcontrolApiserverV1beta1FlowSchema = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteFlowcontrolApiserverV1beta1FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteFlowcontrolApiserverV1beta1FlowSchema$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchFlowcontrolApiserverV1beta1FlowSchema {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchFlowcontrolApiserverV1beta1FlowSchema = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchFlowcontrolApiserverV1beta1FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
}
export interface Response$patchFlowcontrolApiserverV1beta1FlowSchema$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
}
export interface Parameter$readFlowcontrolApiserverV1beta1FlowSchemaStatus {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readFlowcontrolApiserverV1beta1FlowSchemaStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
}
export interface Parameter$replaceFlowcontrolApiserverV1beta1FlowSchemaStatus {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceFlowcontrolApiserverV1beta1FlowSchemaStatus = RequestBodies.io$k8s$api$flowcontrol$v1beta1$FlowSchema.Content;
export interface Response$replaceFlowcontrolApiserverV1beta1FlowSchemaStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
}
export interface Response$replaceFlowcontrolApiserverV1beta1FlowSchemaStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
}
export interface Parameter$patchFlowcontrolApiserverV1beta1FlowSchemaStatus {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchFlowcontrolApiserverV1beta1FlowSchemaStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchFlowcontrolApiserverV1beta1FlowSchemaStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
}
export interface Response$patchFlowcontrolApiserverV1beta1FlowSchemaStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$FlowSchema;
}
export interface Parameter$listFlowcontrolApiserverV1beta1PriorityLevelConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfigurationList;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfigurationList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfigurationList;
    "application/json;stream=watch": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfigurationList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfigurationList;
}
export interface Parameter$createFlowcontrolApiserverV1beta1PriorityLevelConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createFlowcontrolApiserverV1beta1PriorityLevelConfiguration = RequestBodies.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration.Content;
export interface Response$createFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
}
export interface Response$createFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
}
export interface Response$createFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$202 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
}
export interface Parameter$deleteFlowcontrolApiserverV1beta1CollectionPriorityLevelConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteFlowcontrolApiserverV1beta1CollectionPriorityLevelConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteFlowcontrolApiserverV1beta1CollectionPriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readFlowcontrolApiserverV1beta1PriorityLevelConfiguration {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
}
export interface Parameter$replaceFlowcontrolApiserverV1beta1PriorityLevelConfiguration {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceFlowcontrolApiserverV1beta1PriorityLevelConfiguration = RequestBodies.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration.Content;
export interface Response$replaceFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
}
export interface Response$replaceFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
}
export interface Parameter$deleteFlowcontrolApiserverV1beta1PriorityLevelConfiguration {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteFlowcontrolApiserverV1beta1PriorityLevelConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
}
export interface Response$patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
}
export interface Parameter$readFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
}
export interface Parameter$replaceFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus = RequestBodies.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration.Content;
export interface Response$replaceFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
}
export interface Response$replaceFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
}
export interface Parameter$patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
}
export interface Response$patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta1$PriorityLevelConfiguration;
}
export interface Parameter$watchFlowcontrolApiserverV1beta1FlowSchemaList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchFlowcontrolApiserverV1beta1FlowSchemaList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchFlowcontrolApiserverV1beta1FlowSchema {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchFlowcontrolApiserverV1beta1FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchFlowcontrolApiserverV1beta1PriorityLevelConfigurationList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchFlowcontrolApiserverV1beta1PriorityLevelConfigurationList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchFlowcontrolApiserverV1beta1PriorityLevelConfiguration {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getFlowcontrolApiserverV1beta2APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listFlowcontrolApiserverV1beta2FlowSchema {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listFlowcontrolApiserverV1beta2FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchemaList;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchemaList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchemaList;
    "application/json;stream=watch": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchemaList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchemaList;
}
export interface Parameter$createFlowcontrolApiserverV1beta2FlowSchema {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createFlowcontrolApiserverV1beta2FlowSchema = RequestBodies.io$k8s$api$flowcontrol$v1beta2$FlowSchema.Content;
export interface Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
export interface Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
export interface Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$202 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
export interface Parameter$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readFlowcontrolApiserverV1beta2FlowSchema {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readFlowcontrolApiserverV1beta2FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
export interface Parameter$replaceFlowcontrolApiserverV1beta2FlowSchema {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceFlowcontrolApiserverV1beta2FlowSchema = RequestBodies.io$k8s$api$flowcontrol$v1beta2$FlowSchema.Content;
export interface Response$replaceFlowcontrolApiserverV1beta2FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
export interface Response$replaceFlowcontrolApiserverV1beta2FlowSchema$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
export interface Parameter$deleteFlowcontrolApiserverV1beta2FlowSchema {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteFlowcontrolApiserverV1beta2FlowSchema = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteFlowcontrolApiserverV1beta2FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteFlowcontrolApiserverV1beta2FlowSchema$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchFlowcontrolApiserverV1beta2FlowSchema {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchFlowcontrolApiserverV1beta2FlowSchema = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchFlowcontrolApiserverV1beta2FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
export interface Response$patchFlowcontrolApiserverV1beta2FlowSchema$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
export interface Parameter$readFlowcontrolApiserverV1beta2FlowSchemaStatus {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
export interface Parameter$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus = RequestBodies.io$k8s$api$flowcontrol$v1beta2$FlowSchema.Content;
export interface Response$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
export interface Response$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
export interface Parameter$patchFlowcontrolApiserverV1beta2FlowSchemaStatus {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchFlowcontrolApiserverV1beta2FlowSchemaStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
export interface Response$patchFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
export interface Parameter$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationList;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationList;
    "application/json;stream=watch": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationList;
}
export interface Parameter$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration = RequestBodies.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration.Content;
export interface Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
export interface Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
export interface Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$202 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
export interface Parameter$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
export interface Parameter$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration = RequestBodies.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration.Content;
export interface Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
export interface Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
export interface Parameter$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
export interface Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
export interface Parameter$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
export interface Parameter$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus = RequestBodies.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration.Content;
export interface Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
export interface Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
export interface Parameter$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
export interface Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
export interface Parameter$watchFlowcontrolApiserverV1beta2FlowSchemaList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchFlowcontrolApiserverV1beta2FlowSchemaList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchFlowcontrolApiserverV1beta2FlowSchema {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchFlowcontrolApiserverV1beta2FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getInternalApiserverAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
export interface Response$getInternalApiserverV1alpha1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listInternalApiserverV1alpha1StorageVersion {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listInternalApiserverV1alpha1StorageVersion$Status$200 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersionList;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersionList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersionList;
    "application/json;stream=watch": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersionList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersionList;
}
export interface Parameter$createInternalApiserverV1alpha1StorageVersion {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createInternalApiserverV1alpha1StorageVersion = RequestBodies.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion.Content;
export interface Response$createInternalApiserverV1alpha1StorageVersion$Status$200 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
export interface Response$createInternalApiserverV1alpha1StorageVersion$Status$201 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
export interface Response$createInternalApiserverV1alpha1StorageVersion$Status$202 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
export interface Parameter$deleteInternalApiserverV1alpha1CollectionStorageVersion {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteInternalApiserverV1alpha1CollectionStorageVersion = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteInternalApiserverV1alpha1CollectionStorageVersion$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readInternalApiserverV1alpha1StorageVersion {
    /** name of the StorageVersion */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readInternalApiserverV1alpha1StorageVersion$Status$200 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
export interface Parameter$replaceInternalApiserverV1alpha1StorageVersion {
    /** name of the StorageVersion */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceInternalApiserverV1alpha1StorageVersion = RequestBodies.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion.Content;
export interface Response$replaceInternalApiserverV1alpha1StorageVersion$Status$200 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
export interface Response$replaceInternalApiserverV1alpha1StorageVersion$Status$201 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
export interface Parameter$deleteInternalApiserverV1alpha1StorageVersion {
    /** name of the StorageVersion */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteInternalApiserverV1alpha1StorageVersion = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteInternalApiserverV1alpha1StorageVersion$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteInternalApiserverV1alpha1StorageVersion$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchInternalApiserverV1alpha1StorageVersion {
    /** name of the StorageVersion */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchInternalApiserverV1alpha1StorageVersion = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchInternalApiserverV1alpha1StorageVersion$Status$200 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
export interface Response$patchInternalApiserverV1alpha1StorageVersion$Status$201 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
export interface Parameter$readInternalApiserverV1alpha1StorageVersionStatus {
    /** name of the StorageVersion */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readInternalApiserverV1alpha1StorageVersionStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
export interface Parameter$replaceInternalApiserverV1alpha1StorageVersionStatus {
    /** name of the StorageVersion */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceInternalApiserverV1alpha1StorageVersionStatus = RequestBodies.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion.Content;
export interface Response$replaceInternalApiserverV1alpha1StorageVersionStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
export interface Response$replaceInternalApiserverV1alpha1StorageVersionStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
export interface Parameter$patchInternalApiserverV1alpha1StorageVersionStatus {
    /** name of the StorageVersion */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchInternalApiserverV1alpha1StorageVersionStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchInternalApiserverV1alpha1StorageVersionStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
export interface Response$patchInternalApiserverV1alpha1StorageVersionStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
export interface Parameter$watchInternalApiserverV1alpha1StorageVersionList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchInternalApiserverV1alpha1StorageVersionList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchInternalApiserverV1alpha1StorageVersion {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the StorageVersion */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchInternalApiserverV1alpha1StorageVersion$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getNetworkingAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
export interface Response$getNetworkingV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listNetworkingV1IngressClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listNetworkingV1IngressClass$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$IngressClassList;
    "application/yaml": Schemas.io$k8s$api$networking$v1$IngressClassList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$IngressClassList;
    "application/json;stream=watch": Schemas.io$k8s$api$networking$v1$IngressClassList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$networking$v1$IngressClassList;
}
export interface Parameter$createNetworkingV1IngressClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createNetworkingV1IngressClass = RequestBodies.io$k8s$api$networking$v1$IngressClass.Content;
export interface Response$createNetworkingV1IngressClass$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/yaml": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$IngressClass;
}
export interface Response$createNetworkingV1IngressClass$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/yaml": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$IngressClass;
}
export interface Response$createNetworkingV1IngressClass$Status$202 {
    "application/json": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/yaml": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$IngressClass;
}
export interface Parameter$deleteNetworkingV1CollectionIngressClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteNetworkingV1CollectionIngressClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteNetworkingV1CollectionIngressClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readNetworkingV1IngressClass {
    /** name of the IngressClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readNetworkingV1IngressClass$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/yaml": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$IngressClass;
}
export interface Parameter$replaceNetworkingV1IngressClass {
    /** name of the IngressClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceNetworkingV1IngressClass = RequestBodies.io$k8s$api$networking$v1$IngressClass.Content;
export interface Response$replaceNetworkingV1IngressClass$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/yaml": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$IngressClass;
}
export interface Response$replaceNetworkingV1IngressClass$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/yaml": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$IngressClass;
}
export interface Parameter$deleteNetworkingV1IngressClass {
    /** name of the IngressClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteNetworkingV1IngressClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteNetworkingV1IngressClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteNetworkingV1IngressClass$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchNetworkingV1IngressClass {
    /** name of the IngressClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchNetworkingV1IngressClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchNetworkingV1IngressClass$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/yaml": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$IngressClass;
}
export interface Response$patchNetworkingV1IngressClass$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/yaml": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$IngressClass;
}
export interface Parameter$listNetworkingV1IngressForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listNetworkingV1IngressForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$IngressList;
    "application/yaml": Schemas.io$k8s$api$networking$v1$IngressList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$IngressList;
    "application/json;stream=watch": Schemas.io$k8s$api$networking$v1$IngressList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$networking$v1$IngressList;
}
export interface Parameter$listNetworkingV1NamespacedIngress {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listNetworkingV1NamespacedIngress$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$IngressList;
    "application/yaml": Schemas.io$k8s$api$networking$v1$IngressList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$IngressList;
    "application/json;stream=watch": Schemas.io$k8s$api$networking$v1$IngressList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$networking$v1$IngressList;
}
export interface Parameter$createNetworkingV1NamespacedIngress {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createNetworkingV1NamespacedIngress = RequestBodies.io$k8s$api$networking$v1$Ingress.Content;
export interface Response$createNetworkingV1NamespacedIngress$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
export interface Response$createNetworkingV1NamespacedIngress$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
export interface Response$createNetworkingV1NamespacedIngress$Status$202 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
export interface Parameter$deleteNetworkingV1CollectionNamespacedIngress {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteNetworkingV1CollectionNamespacedIngress = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteNetworkingV1CollectionNamespacedIngress$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readNetworkingV1NamespacedIngress {
    /** name of the Ingress */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readNetworkingV1NamespacedIngress$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
export interface Parameter$replaceNetworkingV1NamespacedIngress {
    /** name of the Ingress */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceNetworkingV1NamespacedIngress = RequestBodies.io$k8s$api$networking$v1$Ingress.Content;
export interface Response$replaceNetworkingV1NamespacedIngress$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
export interface Response$replaceNetworkingV1NamespacedIngress$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
export interface Parameter$deleteNetworkingV1NamespacedIngress {
    /** name of the Ingress */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteNetworkingV1NamespacedIngress = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteNetworkingV1NamespacedIngress$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteNetworkingV1NamespacedIngress$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchNetworkingV1NamespacedIngress {
    /** name of the Ingress */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchNetworkingV1NamespacedIngress = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchNetworkingV1NamespacedIngress$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
export interface Response$patchNetworkingV1NamespacedIngress$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
export interface Parameter$readNetworkingV1NamespacedIngressStatus {
    /** name of the Ingress */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readNetworkingV1NamespacedIngressStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
export interface Parameter$replaceNetworkingV1NamespacedIngressStatus {
    /** name of the Ingress */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceNetworkingV1NamespacedIngressStatus = RequestBodies.io$k8s$api$networking$v1$Ingress.Content;
export interface Response$replaceNetworkingV1NamespacedIngressStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
export interface Response$replaceNetworkingV1NamespacedIngressStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
export interface Parameter$patchNetworkingV1NamespacedIngressStatus {
    /** name of the Ingress */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchNetworkingV1NamespacedIngressStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchNetworkingV1NamespacedIngressStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
export interface Response$patchNetworkingV1NamespacedIngressStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
export interface Parameter$listNetworkingV1NamespacedNetworkPolicy {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listNetworkingV1NamespacedNetworkPolicy$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicyList;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicyList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicyList;
    "application/json;stream=watch": Schemas.io$k8s$api$networking$v1$NetworkPolicyList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$networking$v1$NetworkPolicyList;
}
export interface Parameter$createNetworkingV1NamespacedNetworkPolicy {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createNetworkingV1NamespacedNetworkPolicy = RequestBodies.io$k8s$api$networking$v1$NetworkPolicy.Content;
export interface Response$createNetworkingV1NamespacedNetworkPolicy$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
}
export interface Response$createNetworkingV1NamespacedNetworkPolicy$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
}
export interface Response$createNetworkingV1NamespacedNetworkPolicy$Status$202 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
}
export interface Parameter$deleteNetworkingV1CollectionNamespacedNetworkPolicy {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteNetworkingV1CollectionNamespacedNetworkPolicy = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteNetworkingV1CollectionNamespacedNetworkPolicy$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readNetworkingV1NamespacedNetworkPolicy {
    /** name of the NetworkPolicy */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readNetworkingV1NamespacedNetworkPolicy$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
}
export interface Parameter$replaceNetworkingV1NamespacedNetworkPolicy {
    /** name of the NetworkPolicy */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceNetworkingV1NamespacedNetworkPolicy = RequestBodies.io$k8s$api$networking$v1$NetworkPolicy.Content;
export interface Response$replaceNetworkingV1NamespacedNetworkPolicy$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
}
export interface Response$replaceNetworkingV1NamespacedNetworkPolicy$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
}
export interface Parameter$deleteNetworkingV1NamespacedNetworkPolicy {
    /** name of the NetworkPolicy */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteNetworkingV1NamespacedNetworkPolicy = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteNetworkingV1NamespacedNetworkPolicy$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteNetworkingV1NamespacedNetworkPolicy$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchNetworkingV1NamespacedNetworkPolicy {
    /** name of the NetworkPolicy */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchNetworkingV1NamespacedNetworkPolicy = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchNetworkingV1NamespacedNetworkPolicy$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
}
export interface Response$patchNetworkingV1NamespacedNetworkPolicy$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
}
export interface Parameter$listNetworkingV1NetworkPolicyForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listNetworkingV1NetworkPolicyForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicyList;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicyList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicyList;
    "application/json;stream=watch": Schemas.io$k8s$api$networking$v1$NetworkPolicyList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$networking$v1$NetworkPolicyList;
}
export interface Parameter$watchNetworkingV1IngressClassList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchNetworkingV1IngressClassList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchNetworkingV1IngressClass {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the IngressClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchNetworkingV1IngressClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchNetworkingV1IngressListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchNetworkingV1IngressListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchNetworkingV1NamespacedIngressList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchNetworkingV1NamespacedIngressList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchNetworkingV1NamespacedIngress {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Ingress */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchNetworkingV1NamespacedIngress$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchNetworkingV1NamespacedNetworkPolicyList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchNetworkingV1NamespacedNetworkPolicyList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchNetworkingV1NamespacedNetworkPolicy {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the NetworkPolicy */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchNetworkingV1NamespacedNetworkPolicy$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchNetworkingV1NetworkPolicyListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchNetworkingV1NetworkPolicyListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getNodeAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
export interface Response$getNodeV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listNodeV1RuntimeClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listNodeV1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$api$node$v1$RuntimeClassList;
    "application/yaml": Schemas.io$k8s$api$node$v1$RuntimeClassList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1$RuntimeClassList;
    "application/json;stream=watch": Schemas.io$k8s$api$node$v1$RuntimeClassList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$node$v1$RuntimeClassList;
}
export interface Parameter$createNodeV1RuntimeClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createNodeV1RuntimeClass = RequestBodies.io$k8s$api$node$v1$RuntimeClass.Content;
export interface Response$createNodeV1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1$RuntimeClass;
}
export interface Response$createNodeV1RuntimeClass$Status$201 {
    "application/json": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1$RuntimeClass;
}
export interface Response$createNodeV1RuntimeClass$Status$202 {
    "application/json": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1$RuntimeClass;
}
export interface Parameter$deleteNodeV1CollectionRuntimeClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteNodeV1CollectionRuntimeClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteNodeV1CollectionRuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readNodeV1RuntimeClass {
    /** name of the RuntimeClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readNodeV1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1$RuntimeClass;
}
export interface Parameter$replaceNodeV1RuntimeClass {
    /** name of the RuntimeClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceNodeV1RuntimeClass = RequestBodies.io$k8s$api$node$v1$RuntimeClass.Content;
export interface Response$replaceNodeV1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1$RuntimeClass;
}
export interface Response$replaceNodeV1RuntimeClass$Status$201 {
    "application/json": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1$RuntimeClass;
}
export interface Parameter$deleteNodeV1RuntimeClass {
    /** name of the RuntimeClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteNodeV1RuntimeClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteNodeV1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteNodeV1RuntimeClass$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchNodeV1RuntimeClass {
    /** name of the RuntimeClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchNodeV1RuntimeClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchNodeV1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1$RuntimeClass;
}
export interface Response$patchNodeV1RuntimeClass$Status$201 {
    "application/json": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1$RuntimeClass;
}
export interface Parameter$watchNodeV1RuntimeClassList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchNodeV1RuntimeClassList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchNodeV1RuntimeClass {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the RuntimeClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchNodeV1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getNodeV1alpha1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listNodeV1alpha1RuntimeClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listNodeV1alpha1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$api$node$v1alpha1$RuntimeClassList;
    "application/yaml": Schemas.io$k8s$api$node$v1alpha1$RuntimeClassList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1alpha1$RuntimeClassList;
    "application/json;stream=watch": Schemas.io$k8s$api$node$v1alpha1$RuntimeClassList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$node$v1alpha1$RuntimeClassList;
}
export interface Parameter$createNodeV1alpha1RuntimeClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createNodeV1alpha1RuntimeClass = RequestBodies.io$k8s$api$node$v1alpha1$RuntimeClass.Content;
export interface Response$createNodeV1alpha1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
}
export interface Response$createNodeV1alpha1RuntimeClass$Status$201 {
    "application/json": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
}
export interface Response$createNodeV1alpha1RuntimeClass$Status$202 {
    "application/json": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
}
export interface Parameter$deleteNodeV1alpha1CollectionRuntimeClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteNodeV1alpha1CollectionRuntimeClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteNodeV1alpha1CollectionRuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readNodeV1alpha1RuntimeClass {
    /** name of the RuntimeClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readNodeV1alpha1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
}
export interface Parameter$replaceNodeV1alpha1RuntimeClass {
    /** name of the RuntimeClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceNodeV1alpha1RuntimeClass = RequestBodies.io$k8s$api$node$v1alpha1$RuntimeClass.Content;
export interface Response$replaceNodeV1alpha1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
}
export interface Response$replaceNodeV1alpha1RuntimeClass$Status$201 {
    "application/json": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
}
export interface Parameter$deleteNodeV1alpha1RuntimeClass {
    /** name of the RuntimeClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteNodeV1alpha1RuntimeClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteNodeV1alpha1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteNodeV1alpha1RuntimeClass$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchNodeV1alpha1RuntimeClass {
    /** name of the RuntimeClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchNodeV1alpha1RuntimeClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchNodeV1alpha1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
}
export interface Response$patchNodeV1alpha1RuntimeClass$Status$201 {
    "application/json": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1alpha1$RuntimeClass;
}
export interface Parameter$watchNodeV1alpha1RuntimeClassList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchNodeV1alpha1RuntimeClassList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchNodeV1alpha1RuntimeClass {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the RuntimeClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchNodeV1alpha1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getNodeV1beta1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listNodeV1beta1RuntimeClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listNodeV1beta1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$api$node$v1beta1$RuntimeClassList;
    "application/yaml": Schemas.io$k8s$api$node$v1beta1$RuntimeClassList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1beta1$RuntimeClassList;
    "application/json;stream=watch": Schemas.io$k8s$api$node$v1beta1$RuntimeClassList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$node$v1beta1$RuntimeClassList;
}
export interface Parameter$createNodeV1beta1RuntimeClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createNodeV1beta1RuntimeClass = RequestBodies.io$k8s$api$node$v1beta1$RuntimeClass.Content;
export interface Response$createNodeV1beta1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
}
export interface Response$createNodeV1beta1RuntimeClass$Status$201 {
    "application/json": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
}
export interface Response$createNodeV1beta1RuntimeClass$Status$202 {
    "application/json": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
}
export interface Parameter$deleteNodeV1beta1CollectionRuntimeClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteNodeV1beta1CollectionRuntimeClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteNodeV1beta1CollectionRuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readNodeV1beta1RuntimeClass {
    /** name of the RuntimeClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readNodeV1beta1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
}
export interface Parameter$replaceNodeV1beta1RuntimeClass {
    /** name of the RuntimeClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceNodeV1beta1RuntimeClass = RequestBodies.io$k8s$api$node$v1beta1$RuntimeClass.Content;
export interface Response$replaceNodeV1beta1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
}
export interface Response$replaceNodeV1beta1RuntimeClass$Status$201 {
    "application/json": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
}
export interface Parameter$deleteNodeV1beta1RuntimeClass {
    /** name of the RuntimeClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteNodeV1beta1RuntimeClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteNodeV1beta1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteNodeV1beta1RuntimeClass$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchNodeV1beta1RuntimeClass {
    /** name of the RuntimeClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchNodeV1beta1RuntimeClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchNodeV1beta1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
}
export interface Response$patchNodeV1beta1RuntimeClass$Status$201 {
    "application/json": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1beta1$RuntimeClass;
}
export interface Parameter$watchNodeV1beta1RuntimeClassList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchNodeV1beta1RuntimeClassList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchNodeV1beta1RuntimeClass {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the RuntimeClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchNodeV1beta1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getPolicyAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
export interface Response$getPolicyV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listPolicyV1NamespacedPodDisruptionBudget {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listPolicyV1NamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetList;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetList;
    "application/json;stream=watch": Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetList;
}
export interface Parameter$createPolicyV1NamespacedPodDisruptionBudget {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createPolicyV1NamespacedPodDisruptionBudget = RequestBodies.io$k8s$api$policy$v1$PodDisruptionBudget.Content;
export interface Response$createPolicyV1NamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
export interface Response$createPolicyV1NamespacedPodDisruptionBudget$Status$201 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
export interface Response$createPolicyV1NamespacedPodDisruptionBudget$Status$202 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
export interface Parameter$deletePolicyV1CollectionNamespacedPodDisruptionBudget {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deletePolicyV1CollectionNamespacedPodDisruptionBudget = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deletePolicyV1CollectionNamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readPolicyV1NamespacedPodDisruptionBudget {
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readPolicyV1NamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
export interface Parameter$replacePolicyV1NamespacedPodDisruptionBudget {
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replacePolicyV1NamespacedPodDisruptionBudget = RequestBodies.io$k8s$api$policy$v1$PodDisruptionBudget.Content;
export interface Response$replacePolicyV1NamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
export interface Response$replacePolicyV1NamespacedPodDisruptionBudget$Status$201 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
export interface Parameter$deletePolicyV1NamespacedPodDisruptionBudget {
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deletePolicyV1NamespacedPodDisruptionBudget = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deletePolicyV1NamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deletePolicyV1NamespacedPodDisruptionBudget$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchPolicyV1NamespacedPodDisruptionBudget {
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchPolicyV1NamespacedPodDisruptionBudget = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchPolicyV1NamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
export interface Response$patchPolicyV1NamespacedPodDisruptionBudget$Status$201 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
export interface Parameter$readPolicyV1NamespacedPodDisruptionBudgetStatus {
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readPolicyV1NamespacedPodDisruptionBudgetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
export interface Parameter$replacePolicyV1NamespacedPodDisruptionBudgetStatus {
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replacePolicyV1NamespacedPodDisruptionBudgetStatus = RequestBodies.io$k8s$api$policy$v1$PodDisruptionBudget.Content;
export interface Response$replacePolicyV1NamespacedPodDisruptionBudgetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
export interface Response$replacePolicyV1NamespacedPodDisruptionBudgetStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
export interface Parameter$patchPolicyV1NamespacedPodDisruptionBudgetStatus {
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchPolicyV1NamespacedPodDisruptionBudgetStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchPolicyV1NamespacedPodDisruptionBudgetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
export interface Response$patchPolicyV1NamespacedPodDisruptionBudgetStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
export interface Parameter$listPolicyV1PodDisruptionBudgetForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listPolicyV1PodDisruptionBudgetForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetList;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetList;
    "application/json;stream=watch": Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetList;
}
export interface Parameter$watchPolicyV1NamespacedPodDisruptionBudgetList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchPolicyV1NamespacedPodDisruptionBudgetList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchPolicyV1NamespacedPodDisruptionBudget {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchPolicyV1NamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchPolicyV1PodDisruptionBudgetListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchPolicyV1PodDisruptionBudgetListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getPolicyV1beta1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listPolicyV1beta1NamespacedPodDisruptionBudget {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listPolicyV1beta1NamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudgetList;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudgetList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudgetList;
    "application/json;stream=watch": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudgetList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudgetList;
}
export interface Parameter$createPolicyV1beta1NamespacedPodDisruptionBudget {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createPolicyV1beta1NamespacedPodDisruptionBudget = RequestBodies.io$k8s$api$policy$v1beta1$PodDisruptionBudget.Content;
export interface Response$createPolicyV1beta1NamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
}
export interface Response$createPolicyV1beta1NamespacedPodDisruptionBudget$Status$201 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
}
export interface Response$createPolicyV1beta1NamespacedPodDisruptionBudget$Status$202 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
}
export interface Parameter$deletePolicyV1beta1CollectionNamespacedPodDisruptionBudget {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deletePolicyV1beta1CollectionNamespacedPodDisruptionBudget = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deletePolicyV1beta1CollectionNamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readPolicyV1beta1NamespacedPodDisruptionBudget {
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readPolicyV1beta1NamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
}
export interface Parameter$replacePolicyV1beta1NamespacedPodDisruptionBudget {
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replacePolicyV1beta1NamespacedPodDisruptionBudget = RequestBodies.io$k8s$api$policy$v1beta1$PodDisruptionBudget.Content;
export interface Response$replacePolicyV1beta1NamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
}
export interface Response$replacePolicyV1beta1NamespacedPodDisruptionBudget$Status$201 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
}
export interface Parameter$deletePolicyV1beta1NamespacedPodDisruptionBudget {
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deletePolicyV1beta1NamespacedPodDisruptionBudget = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deletePolicyV1beta1NamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deletePolicyV1beta1NamespacedPodDisruptionBudget$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchPolicyV1beta1NamespacedPodDisruptionBudget {
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchPolicyV1beta1NamespacedPodDisruptionBudget = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchPolicyV1beta1NamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
}
export interface Response$patchPolicyV1beta1NamespacedPodDisruptionBudget$Status$201 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
}
export interface Parameter$readPolicyV1beta1NamespacedPodDisruptionBudgetStatus {
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readPolicyV1beta1NamespacedPodDisruptionBudgetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
}
export interface Parameter$replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus {
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus = RequestBodies.io$k8s$api$policy$v1beta1$PodDisruptionBudget.Content;
export interface Response$replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
}
export interface Response$replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
}
export interface Parameter$patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus {
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
}
export interface Response$patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudget;
}
export interface Parameter$listPolicyV1beta1PodDisruptionBudgetForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listPolicyV1beta1PodDisruptionBudgetForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudgetList;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudgetList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudgetList;
    "application/json;stream=watch": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudgetList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$policy$v1beta1$PodDisruptionBudgetList;
}
export interface Parameter$listPolicyV1beta1PodSecurityPolicy {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listPolicyV1beta1PodSecurityPolicy$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicyList;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicyList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicyList;
    "application/json;stream=watch": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicyList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicyList;
}
export interface Parameter$createPolicyV1beta1PodSecurityPolicy {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createPolicyV1beta1PodSecurityPolicy = RequestBodies.io$k8s$api$policy$v1beta1$PodSecurityPolicy.Content;
export interface Response$createPolicyV1beta1PodSecurityPolicy$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
}
export interface Response$createPolicyV1beta1PodSecurityPolicy$Status$201 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
}
export interface Response$createPolicyV1beta1PodSecurityPolicy$Status$202 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
}
export interface Parameter$deletePolicyV1beta1CollectionPodSecurityPolicy {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deletePolicyV1beta1CollectionPodSecurityPolicy = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deletePolicyV1beta1CollectionPodSecurityPolicy$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readPolicyV1beta1PodSecurityPolicy {
    /** name of the PodSecurityPolicy */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readPolicyV1beta1PodSecurityPolicy$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
}
export interface Parameter$replacePolicyV1beta1PodSecurityPolicy {
    /** name of the PodSecurityPolicy */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replacePolicyV1beta1PodSecurityPolicy = RequestBodies.io$k8s$api$policy$v1beta1$PodSecurityPolicy.Content;
export interface Response$replacePolicyV1beta1PodSecurityPolicy$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
}
export interface Response$replacePolicyV1beta1PodSecurityPolicy$Status$201 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
}
export interface Parameter$deletePolicyV1beta1PodSecurityPolicy {
    /** name of the PodSecurityPolicy */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deletePolicyV1beta1PodSecurityPolicy = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deletePolicyV1beta1PodSecurityPolicy$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
}
export interface Response$deletePolicyV1beta1PodSecurityPolicy$Status$202 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
}
export interface Parameter$patchPolicyV1beta1PodSecurityPolicy {
    /** name of the PodSecurityPolicy */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchPolicyV1beta1PodSecurityPolicy = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchPolicyV1beta1PodSecurityPolicy$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
}
export interface Response$patchPolicyV1beta1PodSecurityPolicy$Status$201 {
    "application/json": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
    "application/yaml": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1beta1$PodSecurityPolicy;
}
export interface Parameter$watchPolicyV1beta1NamespacedPodDisruptionBudgetList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchPolicyV1beta1NamespacedPodDisruptionBudgetList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchPolicyV1beta1NamespacedPodDisruptionBudget {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchPolicyV1beta1NamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchPolicyV1beta1PodDisruptionBudgetListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchPolicyV1beta1PodDisruptionBudgetListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchPolicyV1beta1PodSecurityPolicyList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchPolicyV1beta1PodSecurityPolicyList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchPolicyV1beta1PodSecurityPolicy {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the PodSecurityPolicy */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchPolicyV1beta1PodSecurityPolicy$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getRbacAuthorizationAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
export interface Response$getRbacAuthorizationV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listRbacAuthorizationV1ClusterRoleBinding {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listRbacAuthorizationV1ClusterRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRoleBindingList;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRoleBindingList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRoleBindingList;
    "application/json;stream=watch": Schemas.io$k8s$api$rbac$v1$ClusterRoleBindingList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$rbac$v1$ClusterRoleBindingList;
}
export interface Parameter$createRbacAuthorizationV1ClusterRoleBinding {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createRbacAuthorizationV1ClusterRoleBinding = RequestBodies.io$k8s$api$rbac$v1$ClusterRoleBinding.Content;
export interface Response$createRbacAuthorizationV1ClusterRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
}
export interface Response$createRbacAuthorizationV1ClusterRoleBinding$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
}
export interface Response$createRbacAuthorizationV1ClusterRoleBinding$Status$202 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
}
export interface Parameter$deleteRbacAuthorizationV1CollectionClusterRoleBinding {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteRbacAuthorizationV1CollectionClusterRoleBinding = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteRbacAuthorizationV1CollectionClusterRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readRbacAuthorizationV1ClusterRoleBinding {
    /** name of the ClusterRoleBinding */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readRbacAuthorizationV1ClusterRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
}
export interface Parameter$replaceRbacAuthorizationV1ClusterRoleBinding {
    /** name of the ClusterRoleBinding */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceRbacAuthorizationV1ClusterRoleBinding = RequestBodies.io$k8s$api$rbac$v1$ClusterRoleBinding.Content;
export interface Response$replaceRbacAuthorizationV1ClusterRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
}
export interface Response$replaceRbacAuthorizationV1ClusterRoleBinding$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
}
export interface Parameter$deleteRbacAuthorizationV1ClusterRoleBinding {
    /** name of the ClusterRoleBinding */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteRbacAuthorizationV1ClusterRoleBinding = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteRbacAuthorizationV1ClusterRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteRbacAuthorizationV1ClusterRoleBinding$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchRbacAuthorizationV1ClusterRoleBinding {
    /** name of the ClusterRoleBinding */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchRbacAuthorizationV1ClusterRoleBinding = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchRbacAuthorizationV1ClusterRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
}
export interface Response$patchRbacAuthorizationV1ClusterRoleBinding$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
}
export interface Parameter$listRbacAuthorizationV1ClusterRole {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listRbacAuthorizationV1ClusterRole$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRoleList;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRoleList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRoleList;
    "application/json;stream=watch": Schemas.io$k8s$api$rbac$v1$ClusterRoleList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$rbac$v1$ClusterRoleList;
}
export interface Parameter$createRbacAuthorizationV1ClusterRole {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createRbacAuthorizationV1ClusterRole = RequestBodies.io$k8s$api$rbac$v1$ClusterRole.Content;
export interface Response$createRbacAuthorizationV1ClusterRole$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRole;
}
export interface Response$createRbacAuthorizationV1ClusterRole$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRole;
}
export interface Response$createRbacAuthorizationV1ClusterRole$Status$202 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRole;
}
export interface Parameter$deleteRbacAuthorizationV1CollectionClusterRole {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteRbacAuthorizationV1CollectionClusterRole = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteRbacAuthorizationV1CollectionClusterRole$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readRbacAuthorizationV1ClusterRole {
    /** name of the ClusterRole */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readRbacAuthorizationV1ClusterRole$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRole;
}
export interface Parameter$replaceRbacAuthorizationV1ClusterRole {
    /** name of the ClusterRole */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceRbacAuthorizationV1ClusterRole = RequestBodies.io$k8s$api$rbac$v1$ClusterRole.Content;
export interface Response$replaceRbacAuthorizationV1ClusterRole$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRole;
}
export interface Response$replaceRbacAuthorizationV1ClusterRole$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRole;
}
export interface Parameter$deleteRbacAuthorizationV1ClusterRole {
    /** name of the ClusterRole */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteRbacAuthorizationV1ClusterRole = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteRbacAuthorizationV1ClusterRole$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteRbacAuthorizationV1ClusterRole$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchRbacAuthorizationV1ClusterRole {
    /** name of the ClusterRole */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchRbacAuthorizationV1ClusterRole = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchRbacAuthorizationV1ClusterRole$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRole;
}
export interface Response$patchRbacAuthorizationV1ClusterRole$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRole;
}
export interface Parameter$listRbacAuthorizationV1NamespacedRoleBinding {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listRbacAuthorizationV1NamespacedRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleBindingList;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleBindingList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleBindingList;
    "application/json;stream=watch": Schemas.io$k8s$api$rbac$v1$RoleBindingList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$rbac$v1$RoleBindingList;
}
export interface Parameter$createRbacAuthorizationV1NamespacedRoleBinding {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createRbacAuthorizationV1NamespacedRoleBinding = RequestBodies.io$k8s$api$rbac$v1$RoleBinding.Content;
export interface Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleBinding;
}
export interface Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleBinding;
}
export interface Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$202 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleBinding;
}
export interface Parameter$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readRbacAuthorizationV1NamespacedRoleBinding {
    /** name of the RoleBinding */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readRbacAuthorizationV1NamespacedRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleBinding;
}
export interface Parameter$replaceRbacAuthorizationV1NamespacedRoleBinding {
    /** name of the RoleBinding */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceRbacAuthorizationV1NamespacedRoleBinding = RequestBodies.io$k8s$api$rbac$v1$RoleBinding.Content;
export interface Response$replaceRbacAuthorizationV1NamespacedRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleBinding;
}
export interface Response$replaceRbacAuthorizationV1NamespacedRoleBinding$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleBinding;
}
export interface Parameter$deleteRbacAuthorizationV1NamespacedRoleBinding {
    /** name of the RoleBinding */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteRbacAuthorizationV1NamespacedRoleBinding = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteRbacAuthorizationV1NamespacedRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteRbacAuthorizationV1NamespacedRoleBinding$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchRbacAuthorizationV1NamespacedRoleBinding {
    /** name of the RoleBinding */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchRbacAuthorizationV1NamespacedRoleBinding = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchRbacAuthorizationV1NamespacedRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleBinding;
}
export interface Response$patchRbacAuthorizationV1NamespacedRoleBinding$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleBinding;
}
export interface Parameter$listRbacAuthorizationV1NamespacedRole {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listRbacAuthorizationV1NamespacedRole$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleList;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleList;
    "application/json;stream=watch": Schemas.io$k8s$api$rbac$v1$RoleList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$rbac$v1$RoleList;
}
export interface Parameter$createRbacAuthorizationV1NamespacedRole {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createRbacAuthorizationV1NamespacedRole = RequestBodies.io$k8s$api$rbac$v1$Role.Content;
export interface Response$createRbacAuthorizationV1NamespacedRole$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$Role;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$Role;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$Role;
}
export interface Response$createRbacAuthorizationV1NamespacedRole$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$Role;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$Role;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$Role;
}
export interface Response$createRbacAuthorizationV1NamespacedRole$Status$202 {
    "application/json": Schemas.io$k8s$api$rbac$v1$Role;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$Role;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$Role;
}
export interface Parameter$deleteRbacAuthorizationV1CollectionNamespacedRole {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteRbacAuthorizationV1CollectionNamespacedRole = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteRbacAuthorizationV1CollectionNamespacedRole$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readRbacAuthorizationV1NamespacedRole {
    /** name of the Role */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readRbacAuthorizationV1NamespacedRole$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$Role;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$Role;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$Role;
}
export interface Parameter$replaceRbacAuthorizationV1NamespacedRole {
    /** name of the Role */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceRbacAuthorizationV1NamespacedRole = RequestBodies.io$k8s$api$rbac$v1$Role.Content;
export interface Response$replaceRbacAuthorizationV1NamespacedRole$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$Role;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$Role;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$Role;
}
export interface Response$replaceRbacAuthorizationV1NamespacedRole$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$Role;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$Role;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$Role;
}
export interface Parameter$deleteRbacAuthorizationV1NamespacedRole {
    /** name of the Role */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteRbacAuthorizationV1NamespacedRole = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteRbacAuthorizationV1NamespacedRole$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteRbacAuthorizationV1NamespacedRole$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchRbacAuthorizationV1NamespacedRole {
    /** name of the Role */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchRbacAuthorizationV1NamespacedRole = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchRbacAuthorizationV1NamespacedRole$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$Role;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$Role;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$Role;
}
export interface Response$patchRbacAuthorizationV1NamespacedRole$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$Role;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$Role;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$Role;
}
export interface Parameter$listRbacAuthorizationV1RoleBindingForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listRbacAuthorizationV1RoleBindingForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleBindingList;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleBindingList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleBindingList;
    "application/json;stream=watch": Schemas.io$k8s$api$rbac$v1$RoleBindingList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$rbac$v1$RoleBindingList;
}
export interface Parameter$listRbacAuthorizationV1RoleForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listRbacAuthorizationV1RoleForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleList;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleList;
    "application/json;stream=watch": Schemas.io$k8s$api$rbac$v1$RoleList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$rbac$v1$RoleList;
}
export interface Parameter$watchRbacAuthorizationV1ClusterRoleBindingList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchRbacAuthorizationV1ClusterRoleBindingList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchRbacAuthorizationV1ClusterRoleBinding {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ClusterRoleBinding */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchRbacAuthorizationV1ClusterRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchRbacAuthorizationV1ClusterRoleList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchRbacAuthorizationV1ClusterRoleList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchRbacAuthorizationV1ClusterRole {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ClusterRole */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchRbacAuthorizationV1ClusterRole$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchRbacAuthorizationV1NamespacedRoleBindingList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchRbacAuthorizationV1NamespacedRoleBindingList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchRbacAuthorizationV1NamespacedRoleBinding {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the RoleBinding */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchRbacAuthorizationV1NamespacedRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchRbacAuthorizationV1NamespacedRoleList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchRbacAuthorizationV1NamespacedRoleList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchRbacAuthorizationV1NamespacedRole {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Role */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchRbacAuthorizationV1NamespacedRole$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchRbacAuthorizationV1RoleBindingListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchRbacAuthorizationV1RoleBindingListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchRbacAuthorizationV1RoleListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchRbacAuthorizationV1RoleListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getSchedulingAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
export interface Response$getSchedulingV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listSchedulingV1PriorityClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listSchedulingV1PriorityClass$Status$200 {
    "application/json": Schemas.io$k8s$api$scheduling$v1$PriorityClassList;
    "application/yaml": Schemas.io$k8s$api$scheduling$v1$PriorityClassList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$scheduling$v1$PriorityClassList;
    "application/json;stream=watch": Schemas.io$k8s$api$scheduling$v1$PriorityClassList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$scheduling$v1$PriorityClassList;
}
export interface Parameter$createSchedulingV1PriorityClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createSchedulingV1PriorityClass = RequestBodies.io$k8s$api$scheduling$v1$PriorityClass.Content;
export interface Response$createSchedulingV1PriorityClass$Status$200 {
    "application/json": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/yaml": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
}
export interface Response$createSchedulingV1PriorityClass$Status$201 {
    "application/json": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/yaml": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
}
export interface Response$createSchedulingV1PriorityClass$Status$202 {
    "application/json": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/yaml": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
}
export interface Parameter$deleteSchedulingV1CollectionPriorityClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteSchedulingV1CollectionPriorityClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteSchedulingV1CollectionPriorityClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readSchedulingV1PriorityClass {
    /** name of the PriorityClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readSchedulingV1PriorityClass$Status$200 {
    "application/json": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/yaml": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
}
export interface Parameter$replaceSchedulingV1PriorityClass {
    /** name of the PriorityClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceSchedulingV1PriorityClass = RequestBodies.io$k8s$api$scheduling$v1$PriorityClass.Content;
export interface Response$replaceSchedulingV1PriorityClass$Status$200 {
    "application/json": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/yaml": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
}
export interface Response$replaceSchedulingV1PriorityClass$Status$201 {
    "application/json": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/yaml": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
}
export interface Parameter$deleteSchedulingV1PriorityClass {
    /** name of the PriorityClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteSchedulingV1PriorityClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteSchedulingV1PriorityClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteSchedulingV1PriorityClass$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchSchedulingV1PriorityClass {
    /** name of the PriorityClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchSchedulingV1PriorityClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchSchedulingV1PriorityClass$Status$200 {
    "application/json": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/yaml": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
}
export interface Response$patchSchedulingV1PriorityClass$Status$201 {
    "application/json": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/yaml": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
}
export interface Parameter$watchSchedulingV1PriorityClassList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchSchedulingV1PriorityClassList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchSchedulingV1PriorityClass {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the PriorityClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchSchedulingV1PriorityClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getStorageAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
export interface Response$getStorageV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listStorageV1CSIDriver {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listStorageV1CSIDriver$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIDriverList;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIDriverList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIDriverList;
    "application/json;stream=watch": Schemas.io$k8s$api$storage$v1$CSIDriverList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$storage$v1$CSIDriverList;
}
export interface Parameter$createStorageV1CSIDriver {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createStorageV1CSIDriver = RequestBodies.io$k8s$api$storage$v1$CSIDriver.Content;
export interface Response$createStorageV1CSIDriver$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIDriver;
}
export interface Response$createStorageV1CSIDriver$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIDriver;
}
export interface Response$createStorageV1CSIDriver$Status$202 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIDriver;
}
export interface Parameter$deleteStorageV1CollectionCSIDriver {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteStorageV1CollectionCSIDriver = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteStorageV1CollectionCSIDriver$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readStorageV1CSIDriver {
    /** name of the CSIDriver */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readStorageV1CSIDriver$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIDriver;
}
export interface Parameter$replaceStorageV1CSIDriver {
    /** name of the CSIDriver */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceStorageV1CSIDriver = RequestBodies.io$k8s$api$storage$v1$CSIDriver.Content;
export interface Response$replaceStorageV1CSIDriver$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIDriver;
}
export interface Response$replaceStorageV1CSIDriver$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIDriver;
}
export interface Parameter$deleteStorageV1CSIDriver {
    /** name of the CSIDriver */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteStorageV1CSIDriver = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteStorageV1CSIDriver$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIDriver;
}
export interface Response$deleteStorageV1CSIDriver$Status$202 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIDriver;
}
export interface Parameter$patchStorageV1CSIDriver {
    /** name of the CSIDriver */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchStorageV1CSIDriver = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchStorageV1CSIDriver$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIDriver;
}
export interface Response$patchStorageV1CSIDriver$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIDriver;
}
export interface Parameter$listStorageV1CSINode {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listStorageV1CSINode$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSINodeList;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSINodeList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSINodeList;
    "application/json;stream=watch": Schemas.io$k8s$api$storage$v1$CSINodeList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$storage$v1$CSINodeList;
}
export interface Parameter$createStorageV1CSINode {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createStorageV1CSINode = RequestBodies.io$k8s$api$storage$v1$CSINode.Content;
export interface Response$createStorageV1CSINode$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSINode;
}
export interface Response$createStorageV1CSINode$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSINode;
}
export interface Response$createStorageV1CSINode$Status$202 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSINode;
}
export interface Parameter$deleteStorageV1CollectionCSINode {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteStorageV1CollectionCSINode = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteStorageV1CollectionCSINode$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readStorageV1CSINode {
    /** name of the CSINode */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readStorageV1CSINode$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSINode;
}
export interface Parameter$replaceStorageV1CSINode {
    /** name of the CSINode */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceStorageV1CSINode = RequestBodies.io$k8s$api$storage$v1$CSINode.Content;
export interface Response$replaceStorageV1CSINode$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSINode;
}
export interface Response$replaceStorageV1CSINode$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSINode;
}
export interface Parameter$deleteStorageV1CSINode {
    /** name of the CSINode */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteStorageV1CSINode = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteStorageV1CSINode$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSINode;
}
export interface Response$deleteStorageV1CSINode$Status$202 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSINode;
}
export interface Parameter$patchStorageV1CSINode {
    /** name of the CSINode */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchStorageV1CSINode = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchStorageV1CSINode$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSINode;
}
export interface Response$patchStorageV1CSINode$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSINode;
}
export interface Parameter$listStorageV1StorageClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listStorageV1StorageClass$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$StorageClassList;
    "application/yaml": Schemas.io$k8s$api$storage$v1$StorageClassList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$StorageClassList;
    "application/json;stream=watch": Schemas.io$k8s$api$storage$v1$StorageClassList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$storage$v1$StorageClassList;
}
export interface Parameter$createStorageV1StorageClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createStorageV1StorageClass = RequestBodies.io$k8s$api$storage$v1$StorageClass.Content;
export interface Response$createStorageV1StorageClass$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/yaml": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$StorageClass;
}
export interface Response$createStorageV1StorageClass$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/yaml": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$StorageClass;
}
export interface Response$createStorageV1StorageClass$Status$202 {
    "application/json": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/yaml": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$StorageClass;
}
export interface Parameter$deleteStorageV1CollectionStorageClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteStorageV1CollectionStorageClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteStorageV1CollectionStorageClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readStorageV1StorageClass {
    /** name of the StorageClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readStorageV1StorageClass$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/yaml": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$StorageClass;
}
export interface Parameter$replaceStorageV1StorageClass {
    /** name of the StorageClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceStorageV1StorageClass = RequestBodies.io$k8s$api$storage$v1$StorageClass.Content;
export interface Response$replaceStorageV1StorageClass$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/yaml": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$StorageClass;
}
export interface Response$replaceStorageV1StorageClass$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/yaml": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$StorageClass;
}
export interface Parameter$deleteStorageV1StorageClass {
    /** name of the StorageClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteStorageV1StorageClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteStorageV1StorageClass$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/yaml": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$StorageClass;
}
export interface Response$deleteStorageV1StorageClass$Status$202 {
    "application/json": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/yaml": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$StorageClass;
}
export interface Parameter$patchStorageV1StorageClass {
    /** name of the StorageClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchStorageV1StorageClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchStorageV1StorageClass$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/yaml": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$StorageClass;
}
export interface Response$patchStorageV1StorageClass$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/yaml": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$StorageClass;
}
export interface Parameter$listStorageV1VolumeAttachment {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listStorageV1VolumeAttachment$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachmentList;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachmentList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachmentList;
    "application/json;stream=watch": Schemas.io$k8s$api$storage$v1$VolumeAttachmentList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$storage$v1$VolumeAttachmentList;
}
export interface Parameter$createStorageV1VolumeAttachment {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createStorageV1VolumeAttachment = RequestBodies.io$k8s$api$storage$v1$VolumeAttachment.Content;
export interface Response$createStorageV1VolumeAttachment$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
export interface Response$createStorageV1VolumeAttachment$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
export interface Response$createStorageV1VolumeAttachment$Status$202 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
export interface Parameter$deleteStorageV1CollectionVolumeAttachment {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteStorageV1CollectionVolumeAttachment = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteStorageV1CollectionVolumeAttachment$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readStorageV1VolumeAttachment {
    /** name of the VolumeAttachment */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readStorageV1VolumeAttachment$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
export interface Parameter$replaceStorageV1VolumeAttachment {
    /** name of the VolumeAttachment */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceStorageV1VolumeAttachment = RequestBodies.io$k8s$api$storage$v1$VolumeAttachment.Content;
export interface Response$replaceStorageV1VolumeAttachment$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
export interface Response$replaceStorageV1VolumeAttachment$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
export interface Parameter$deleteStorageV1VolumeAttachment {
    /** name of the VolumeAttachment */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteStorageV1VolumeAttachment = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteStorageV1VolumeAttachment$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
export interface Response$deleteStorageV1VolumeAttachment$Status$202 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
export interface Parameter$patchStorageV1VolumeAttachment {
    /** name of the VolumeAttachment */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchStorageV1VolumeAttachment = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchStorageV1VolumeAttachment$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
export interface Response$patchStorageV1VolumeAttachment$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
export interface Parameter$readStorageV1VolumeAttachmentStatus {
    /** name of the VolumeAttachment */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readStorageV1VolumeAttachmentStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
export interface Parameter$replaceStorageV1VolumeAttachmentStatus {
    /** name of the VolumeAttachment */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceStorageV1VolumeAttachmentStatus = RequestBodies.io$k8s$api$storage$v1$VolumeAttachment.Content;
export interface Response$replaceStorageV1VolumeAttachmentStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
export interface Response$replaceStorageV1VolumeAttachmentStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
export interface Parameter$patchStorageV1VolumeAttachmentStatus {
    /** name of the VolumeAttachment */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchStorageV1VolumeAttachmentStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchStorageV1VolumeAttachmentStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
export interface Response$patchStorageV1VolumeAttachmentStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
export interface Parameter$watchStorageV1CSIDriverList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchStorageV1CSIDriverList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchStorageV1CSIDriver {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the CSIDriver */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchStorageV1CSIDriver$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchStorageV1CSINodeList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchStorageV1CSINodeList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchStorageV1CSINode {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the CSINode */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchStorageV1CSINode$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchStorageV1StorageClassList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchStorageV1StorageClassList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchStorageV1StorageClass {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the StorageClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchStorageV1StorageClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchStorageV1VolumeAttachmentList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchStorageV1VolumeAttachmentList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchStorageV1VolumeAttachment {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the VolumeAttachment */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchStorageV1VolumeAttachment$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getStorageV1alpha1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listStorageV1alpha1CSIStorageCapacityForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listStorageV1alpha1CSIStorageCapacityForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacityList;
    "application/yaml": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacityList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacityList;
    "application/json;stream=watch": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacityList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacityList;
}
export interface Parameter$listStorageV1alpha1NamespacedCSIStorageCapacity {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listStorageV1alpha1NamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacityList;
    "application/yaml": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacityList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacityList;
    "application/json;stream=watch": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacityList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacityList;
}
export interface Parameter$createStorageV1alpha1NamespacedCSIStorageCapacity {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createStorageV1alpha1NamespacedCSIStorageCapacity = RequestBodies.io$k8s$api$storage$v1alpha1$CSIStorageCapacity.Content;
export interface Response$createStorageV1alpha1NamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
}
export interface Response$createStorageV1alpha1NamespacedCSIStorageCapacity$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
}
export interface Response$createStorageV1alpha1NamespacedCSIStorageCapacity$Status$202 {
    "application/json": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
}
export interface Parameter$deleteStorageV1alpha1CollectionNamespacedCSIStorageCapacity {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteStorageV1alpha1CollectionNamespacedCSIStorageCapacity = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteStorageV1alpha1CollectionNamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readStorageV1alpha1NamespacedCSIStorageCapacity {
    /** name of the CSIStorageCapacity */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readStorageV1alpha1NamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
}
export interface Parameter$replaceStorageV1alpha1NamespacedCSIStorageCapacity {
    /** name of the CSIStorageCapacity */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceStorageV1alpha1NamespacedCSIStorageCapacity = RequestBodies.io$k8s$api$storage$v1alpha1$CSIStorageCapacity.Content;
export interface Response$replaceStorageV1alpha1NamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
}
export interface Response$replaceStorageV1alpha1NamespacedCSIStorageCapacity$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
}
export interface Parameter$deleteStorageV1alpha1NamespacedCSIStorageCapacity {
    /** name of the CSIStorageCapacity */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteStorageV1alpha1NamespacedCSIStorageCapacity = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteStorageV1alpha1NamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteStorageV1alpha1NamespacedCSIStorageCapacity$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchStorageV1alpha1NamespacedCSIStorageCapacity {
    /** name of the CSIStorageCapacity */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchStorageV1alpha1NamespacedCSIStorageCapacity = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchStorageV1alpha1NamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
}
export interface Response$patchStorageV1alpha1NamespacedCSIStorageCapacity$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1alpha1$CSIStorageCapacity;
}
export interface Parameter$watchStorageV1alpha1CSIStorageCapacityListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchStorageV1alpha1CSIStorageCapacityListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchStorageV1alpha1NamespacedCSIStorageCapacityList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchStorageV1alpha1NamespacedCSIStorageCapacityList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchStorageV1alpha1NamespacedCSIStorageCapacity {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the CSIStorageCapacity */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchStorageV1alpha1NamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Response$getStorageV1beta1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
export interface Parameter$listStorageV1beta1CSIStorageCapacityForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listStorageV1beta1CSIStorageCapacityForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacityList;
    "application/yaml": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacityList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacityList;
    "application/json;stream=watch": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacityList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacityList;
}
export interface Parameter$listStorageV1beta1NamespacedCSIStorageCapacity {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$listStorageV1beta1NamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacityList;
    "application/yaml": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacityList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacityList;
    "application/json;stream=watch": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacityList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacityList;
}
export interface Parameter$createStorageV1beta1NamespacedCSIStorageCapacity {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$createStorageV1beta1NamespacedCSIStorageCapacity = RequestBodies.io$k8s$api$storage$v1beta1$CSIStorageCapacity.Content;
export interface Response$createStorageV1beta1NamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
}
export interface Response$createStorageV1beta1NamespacedCSIStorageCapacity$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
}
export interface Response$createStorageV1beta1NamespacedCSIStorageCapacity$Status$202 {
    "application/json": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
}
export interface Parameter$deleteStorageV1beta1CollectionNamespacedCSIStorageCapacity {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
export declare type RequestBody$deleteStorageV1beta1CollectionNamespacedCSIStorageCapacity = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteStorageV1beta1CollectionNamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$readStorageV1beta1NamespacedCSIStorageCapacity {
    /** name of the CSIStorageCapacity */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
export interface Response$readStorageV1beta1NamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
}
export interface Parameter$replaceStorageV1beta1NamespacedCSIStorageCapacity {
    /** name of the CSIStorageCapacity */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
}
export declare type RequestBody$replaceStorageV1beta1NamespacedCSIStorageCapacity = RequestBodies.io$k8s$api$storage$v1beta1$CSIStorageCapacity.Content;
export interface Response$replaceStorageV1beta1NamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
}
export interface Response$replaceStorageV1beta1NamespacedCSIStorageCapacity$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
}
export interface Parameter$deleteStorageV1beta1NamespacedCSIStorageCapacity {
    /** name of the CSIStorageCapacity */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
export declare type RequestBody$deleteStorageV1beta1NamespacedCSIStorageCapacity = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
export interface Response$deleteStorageV1beta1NamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Response$deleteStorageV1beta1NamespacedCSIStorageCapacity$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
export interface Parameter$patchStorageV1beta1NamespacedCSIStorageCapacity {
    /** name of the CSIStorageCapacity */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation determines how the server should respond to unknown/duplicate fields in the object in the request. Introduced as alpha in 1.23, older servers or servers with the `ServerSideFieldValidation` feature disabled will discard valid values specified in  this param and not perform any server side field validation. Valid values are: - Ignore: ignores unknown/duplicate fields. - Warn: responds with a warning for each unknown/duplicate field, but successfully serves the request. - Strict: fails the request on unknown/duplicate fields. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
export declare type RequestBody$patchStorageV1beta1NamespacedCSIStorageCapacity = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
export interface Response$patchStorageV1beta1NamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
}
export interface Response$patchStorageV1beta1NamespacedCSIStorageCapacity$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1beta1$CSIStorageCapacity;
}
export interface Parameter$watchStorageV1beta1CSIStorageCapacityListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchStorageV1beta1CSIStorageCapacityListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchStorageV1beta1NamespacedCSIStorageCapacityList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchStorageV1beta1NamespacedCSIStorageCapacityList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$watchStorageV1beta1NamespacedCSIStorageCapacity {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the CSIStorageCapacity */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
export interface Response$watchStorageV1beta1NamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
export interface Parameter$logFileHandler {
    /** path to the log */
    logpath: string;
}
export interface Response$getServiceAccountIssuerOpenIDKeyset$Status$200 {
    "application/jwk-set+json": string;
}
export interface Response$getCodeVersion$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$version$Info;
}
export declare type ResponseContentType$getServiceAccountIssuerOpenIDConfiguration = keyof Response$getServiceAccountIssuerOpenIDConfiguration$Status$200;
export declare type ResponseContentType$getCoreAPIVersions = keyof Response$getCoreAPIVersions$Status$200;
export interface Params$getCoreAPIVersions<U extends ResponseContentType$getCoreAPIVersions> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$getCoreV1APIResources = keyof Response$getCoreV1APIResources$Status$200;
export interface Params$getCoreV1APIResources<U extends ResponseContentType$getCoreV1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listCoreV1ComponentStatus = keyof Response$listCoreV1ComponentStatus$Status$200;
export interface Params$listCoreV1ComponentStatus<U extends ResponseContentType$listCoreV1ComponentStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1ComponentStatus;
}
export declare type ResponseContentType$readCoreV1ComponentStatus = keyof Response$readCoreV1ComponentStatus$Status$200;
export interface Params$readCoreV1ComponentStatus<U extends ResponseContentType$readCoreV1ComponentStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1ComponentStatus;
}
export declare type ResponseContentType$listCoreV1ConfigMapForAllNamespaces = keyof Response$listCoreV1ConfigMapForAllNamespaces$Status$200;
export interface Params$listCoreV1ConfigMapForAllNamespaces<U extends ResponseContentType$listCoreV1ConfigMapForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1ConfigMapForAllNamespaces;
}
export declare type ResponseContentType$listCoreV1EndpointsForAllNamespaces = keyof Response$listCoreV1EndpointsForAllNamespaces$Status$200;
export interface Params$listCoreV1EndpointsForAllNamespaces<U extends ResponseContentType$listCoreV1EndpointsForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1EndpointsForAllNamespaces;
}
export declare type ResponseContentType$listCoreV1EventForAllNamespaces = keyof Response$listCoreV1EventForAllNamespaces$Status$200;
export interface Params$listCoreV1EventForAllNamespaces<U extends ResponseContentType$listCoreV1EventForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1EventForAllNamespaces;
}
export declare type ResponseContentType$listCoreV1LimitRangeForAllNamespaces = keyof Response$listCoreV1LimitRangeForAllNamespaces$Status$200;
export interface Params$listCoreV1LimitRangeForAllNamespaces<U extends ResponseContentType$listCoreV1LimitRangeForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1LimitRangeForAllNamespaces;
}
export declare type ResponseContentType$listCoreV1Namespace = keyof Response$listCoreV1Namespace$Status$200;
export interface Params$listCoreV1Namespace<U extends ResponseContentType$listCoreV1Namespace> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1Namespace;
}
export declare type RequestContentType$createCoreV1Namespace = keyof RequestBody$createCoreV1Namespace;
export declare type ResponseContentType$createCoreV1Namespace = keyof Response$createCoreV1Namespace$Status$200 | keyof Response$createCoreV1Namespace$Status$201 | keyof Response$createCoreV1Namespace$Status$202;
export interface Params$createCoreV1Namespace<U extends ResponseContentType$createCoreV1Namespace> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1Namespace;
    requestBody: RequestBody$createCoreV1Namespace["*/*"];
}
export declare type RequestContentType$createCoreV1NamespacedBinding = keyof RequestBody$createCoreV1NamespacedBinding;
export declare type ResponseContentType$createCoreV1NamespacedBinding = keyof Response$createCoreV1NamespacedBinding$Status$200 | keyof Response$createCoreV1NamespacedBinding$Status$201 | keyof Response$createCoreV1NamespacedBinding$Status$202;
export interface Params$createCoreV1NamespacedBinding<U extends ResponseContentType$createCoreV1NamespacedBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedBinding;
    requestBody: RequestBody$createCoreV1NamespacedBinding["*/*"];
}
export declare type ResponseContentType$listCoreV1NamespacedConfigMap = keyof Response$listCoreV1NamespacedConfigMap$Status$200;
export interface Params$listCoreV1NamespacedConfigMap<U extends ResponseContentType$listCoreV1NamespacedConfigMap> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedConfigMap;
}
export declare type RequestContentType$createCoreV1NamespacedConfigMap = keyof RequestBody$createCoreV1NamespacedConfigMap;
export declare type ResponseContentType$createCoreV1NamespacedConfigMap = keyof Response$createCoreV1NamespacedConfigMap$Status$200 | keyof Response$createCoreV1NamespacedConfigMap$Status$201 | keyof Response$createCoreV1NamespacedConfigMap$Status$202;
export interface Params$createCoreV1NamespacedConfigMap<U extends ResponseContentType$createCoreV1NamespacedConfigMap> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedConfigMap;
    requestBody: RequestBody$createCoreV1NamespacedConfigMap["*/*"];
}
export declare type RequestContentType$deleteCoreV1CollectionNamespacedConfigMap = keyof RequestBody$deleteCoreV1CollectionNamespacedConfigMap;
export declare type ResponseContentType$deleteCoreV1CollectionNamespacedConfigMap = keyof Response$deleteCoreV1CollectionNamespacedConfigMap$Status$200;
export interface Params$deleteCoreV1CollectionNamespacedConfigMap<U extends ResponseContentType$deleteCoreV1CollectionNamespacedConfigMap> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedConfigMap;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedConfigMap["*/*"];
}
export declare type ResponseContentType$readCoreV1NamespacedConfigMap = keyof Response$readCoreV1NamespacedConfigMap$Status$200;
export interface Params$readCoreV1NamespacedConfigMap<U extends ResponseContentType$readCoreV1NamespacedConfigMap> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedConfigMap;
}
export declare type RequestContentType$replaceCoreV1NamespacedConfigMap = keyof RequestBody$replaceCoreV1NamespacedConfigMap;
export declare type ResponseContentType$replaceCoreV1NamespacedConfigMap = keyof Response$replaceCoreV1NamespacedConfigMap$Status$200 | keyof Response$replaceCoreV1NamespacedConfigMap$Status$201;
export interface Params$replaceCoreV1NamespacedConfigMap<U extends ResponseContentType$replaceCoreV1NamespacedConfigMap> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedConfigMap;
    requestBody: RequestBody$replaceCoreV1NamespacedConfigMap["*/*"];
}
export declare type RequestContentType$deleteCoreV1NamespacedConfigMap = keyof RequestBody$deleteCoreV1NamespacedConfigMap;
export declare type ResponseContentType$deleteCoreV1NamespacedConfigMap = keyof Response$deleteCoreV1NamespacedConfigMap$Status$200 | keyof Response$deleteCoreV1NamespacedConfigMap$Status$202;
export interface Params$deleteCoreV1NamespacedConfigMap<U extends ResponseContentType$deleteCoreV1NamespacedConfigMap> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedConfigMap;
    requestBody: RequestBody$deleteCoreV1NamespacedConfigMap["*/*"];
}
export declare type RequestContentType$patchCoreV1NamespacedConfigMap = keyof RequestBody$patchCoreV1NamespacedConfigMap;
export declare type ResponseContentType$patchCoreV1NamespacedConfigMap = keyof Response$patchCoreV1NamespacedConfigMap$Status$200 | keyof Response$patchCoreV1NamespacedConfigMap$Status$201;
export interface Params$patchCoreV1NamespacedConfigMap<T extends RequestContentType$patchCoreV1NamespacedConfigMap, U extends ResponseContentType$patchCoreV1NamespacedConfigMap> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedConfigMap;
    requestBody: RequestBody$patchCoreV1NamespacedConfigMap[T];
}
export declare type ResponseContentType$listCoreV1NamespacedEndpoints = keyof Response$listCoreV1NamespacedEndpoints$Status$200;
export interface Params$listCoreV1NamespacedEndpoints<U extends ResponseContentType$listCoreV1NamespacedEndpoints> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedEndpoints;
}
export declare type RequestContentType$createCoreV1NamespacedEndpoints = keyof RequestBody$createCoreV1NamespacedEndpoints;
export declare type ResponseContentType$createCoreV1NamespacedEndpoints = keyof Response$createCoreV1NamespacedEndpoints$Status$200 | keyof Response$createCoreV1NamespacedEndpoints$Status$201 | keyof Response$createCoreV1NamespacedEndpoints$Status$202;
export interface Params$createCoreV1NamespacedEndpoints<U extends ResponseContentType$createCoreV1NamespacedEndpoints> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedEndpoints;
    requestBody: RequestBody$createCoreV1NamespacedEndpoints["*/*"];
}
export declare type RequestContentType$deleteCoreV1CollectionNamespacedEndpoints = keyof RequestBody$deleteCoreV1CollectionNamespacedEndpoints;
export declare type ResponseContentType$deleteCoreV1CollectionNamespacedEndpoints = keyof Response$deleteCoreV1CollectionNamespacedEndpoints$Status$200;
export interface Params$deleteCoreV1CollectionNamespacedEndpoints<U extends ResponseContentType$deleteCoreV1CollectionNamespacedEndpoints> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedEndpoints;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedEndpoints["*/*"];
}
export declare type ResponseContentType$readCoreV1NamespacedEndpoints = keyof Response$readCoreV1NamespacedEndpoints$Status$200;
export interface Params$readCoreV1NamespacedEndpoints<U extends ResponseContentType$readCoreV1NamespacedEndpoints> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedEndpoints;
}
export declare type RequestContentType$replaceCoreV1NamespacedEndpoints = keyof RequestBody$replaceCoreV1NamespacedEndpoints;
export declare type ResponseContentType$replaceCoreV1NamespacedEndpoints = keyof Response$replaceCoreV1NamespacedEndpoints$Status$200 | keyof Response$replaceCoreV1NamespacedEndpoints$Status$201;
export interface Params$replaceCoreV1NamespacedEndpoints<U extends ResponseContentType$replaceCoreV1NamespacedEndpoints> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedEndpoints;
    requestBody: RequestBody$replaceCoreV1NamespacedEndpoints["*/*"];
}
export declare type RequestContentType$deleteCoreV1NamespacedEndpoints = keyof RequestBody$deleteCoreV1NamespacedEndpoints;
export declare type ResponseContentType$deleteCoreV1NamespacedEndpoints = keyof Response$deleteCoreV1NamespacedEndpoints$Status$200 | keyof Response$deleteCoreV1NamespacedEndpoints$Status$202;
export interface Params$deleteCoreV1NamespacedEndpoints<U extends ResponseContentType$deleteCoreV1NamespacedEndpoints> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedEndpoints;
    requestBody: RequestBody$deleteCoreV1NamespacedEndpoints["*/*"];
}
export declare type RequestContentType$patchCoreV1NamespacedEndpoints = keyof RequestBody$patchCoreV1NamespacedEndpoints;
export declare type ResponseContentType$patchCoreV1NamespacedEndpoints = keyof Response$patchCoreV1NamespacedEndpoints$Status$200 | keyof Response$patchCoreV1NamespacedEndpoints$Status$201;
export interface Params$patchCoreV1NamespacedEndpoints<T extends RequestContentType$patchCoreV1NamespacedEndpoints, U extends ResponseContentType$patchCoreV1NamespacedEndpoints> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedEndpoints;
    requestBody: RequestBody$patchCoreV1NamespacedEndpoints[T];
}
export declare type ResponseContentType$listCoreV1NamespacedEvent = keyof Response$listCoreV1NamespacedEvent$Status$200;
export interface Params$listCoreV1NamespacedEvent<U extends ResponseContentType$listCoreV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedEvent;
}
export declare type RequestContentType$createCoreV1NamespacedEvent = keyof RequestBody$createCoreV1NamespacedEvent;
export declare type ResponseContentType$createCoreV1NamespacedEvent = keyof Response$createCoreV1NamespacedEvent$Status$200 | keyof Response$createCoreV1NamespacedEvent$Status$201 | keyof Response$createCoreV1NamespacedEvent$Status$202;
export interface Params$createCoreV1NamespacedEvent<U extends ResponseContentType$createCoreV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedEvent;
    requestBody: RequestBody$createCoreV1NamespacedEvent["*/*"];
}
export declare type RequestContentType$deleteCoreV1CollectionNamespacedEvent = keyof RequestBody$deleteCoreV1CollectionNamespacedEvent;
export declare type ResponseContentType$deleteCoreV1CollectionNamespacedEvent = keyof Response$deleteCoreV1CollectionNamespacedEvent$Status$200;
export interface Params$deleteCoreV1CollectionNamespacedEvent<U extends ResponseContentType$deleteCoreV1CollectionNamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedEvent;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedEvent["*/*"];
}
export declare type ResponseContentType$readCoreV1NamespacedEvent = keyof Response$readCoreV1NamespacedEvent$Status$200;
export interface Params$readCoreV1NamespacedEvent<U extends ResponseContentType$readCoreV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedEvent;
}
export declare type RequestContentType$replaceCoreV1NamespacedEvent = keyof RequestBody$replaceCoreV1NamespacedEvent;
export declare type ResponseContentType$replaceCoreV1NamespacedEvent = keyof Response$replaceCoreV1NamespacedEvent$Status$200 | keyof Response$replaceCoreV1NamespacedEvent$Status$201;
export interface Params$replaceCoreV1NamespacedEvent<U extends ResponseContentType$replaceCoreV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedEvent;
    requestBody: RequestBody$replaceCoreV1NamespacedEvent["*/*"];
}
export declare type RequestContentType$deleteCoreV1NamespacedEvent = keyof RequestBody$deleteCoreV1NamespacedEvent;
export declare type ResponseContentType$deleteCoreV1NamespacedEvent = keyof Response$deleteCoreV1NamespacedEvent$Status$200 | keyof Response$deleteCoreV1NamespacedEvent$Status$202;
export interface Params$deleteCoreV1NamespacedEvent<U extends ResponseContentType$deleteCoreV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedEvent;
    requestBody: RequestBody$deleteCoreV1NamespacedEvent["*/*"];
}
export declare type RequestContentType$patchCoreV1NamespacedEvent = keyof RequestBody$patchCoreV1NamespacedEvent;
export declare type ResponseContentType$patchCoreV1NamespacedEvent = keyof Response$patchCoreV1NamespacedEvent$Status$200 | keyof Response$patchCoreV1NamespacedEvent$Status$201;
export interface Params$patchCoreV1NamespacedEvent<T extends RequestContentType$patchCoreV1NamespacedEvent, U extends ResponseContentType$patchCoreV1NamespacedEvent> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedEvent;
    requestBody: RequestBody$patchCoreV1NamespacedEvent[T];
}
export declare type ResponseContentType$listCoreV1NamespacedLimitRange = keyof Response$listCoreV1NamespacedLimitRange$Status$200;
export interface Params$listCoreV1NamespacedLimitRange<U extends ResponseContentType$listCoreV1NamespacedLimitRange> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedLimitRange;
}
export declare type RequestContentType$createCoreV1NamespacedLimitRange = keyof RequestBody$createCoreV1NamespacedLimitRange;
export declare type ResponseContentType$createCoreV1NamespacedLimitRange = keyof Response$createCoreV1NamespacedLimitRange$Status$200 | keyof Response$createCoreV1NamespacedLimitRange$Status$201 | keyof Response$createCoreV1NamespacedLimitRange$Status$202;
export interface Params$createCoreV1NamespacedLimitRange<U extends ResponseContentType$createCoreV1NamespacedLimitRange> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedLimitRange;
    requestBody: RequestBody$createCoreV1NamespacedLimitRange["*/*"];
}
export declare type RequestContentType$deleteCoreV1CollectionNamespacedLimitRange = keyof RequestBody$deleteCoreV1CollectionNamespacedLimitRange;
export declare type ResponseContentType$deleteCoreV1CollectionNamespacedLimitRange = keyof Response$deleteCoreV1CollectionNamespacedLimitRange$Status$200;
export interface Params$deleteCoreV1CollectionNamespacedLimitRange<U extends ResponseContentType$deleteCoreV1CollectionNamespacedLimitRange> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedLimitRange;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedLimitRange["*/*"];
}
export declare type ResponseContentType$readCoreV1NamespacedLimitRange = keyof Response$readCoreV1NamespacedLimitRange$Status$200;
export interface Params$readCoreV1NamespacedLimitRange<U extends ResponseContentType$readCoreV1NamespacedLimitRange> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedLimitRange;
}
export declare type RequestContentType$replaceCoreV1NamespacedLimitRange = keyof RequestBody$replaceCoreV1NamespacedLimitRange;
export declare type ResponseContentType$replaceCoreV1NamespacedLimitRange = keyof Response$replaceCoreV1NamespacedLimitRange$Status$200 | keyof Response$replaceCoreV1NamespacedLimitRange$Status$201;
export interface Params$replaceCoreV1NamespacedLimitRange<U extends ResponseContentType$replaceCoreV1NamespacedLimitRange> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedLimitRange;
    requestBody: RequestBody$replaceCoreV1NamespacedLimitRange["*/*"];
}
export declare type RequestContentType$deleteCoreV1NamespacedLimitRange = keyof RequestBody$deleteCoreV1NamespacedLimitRange;
export declare type ResponseContentType$deleteCoreV1NamespacedLimitRange = keyof Response$deleteCoreV1NamespacedLimitRange$Status$200 | keyof Response$deleteCoreV1NamespacedLimitRange$Status$202;
export interface Params$deleteCoreV1NamespacedLimitRange<U extends ResponseContentType$deleteCoreV1NamespacedLimitRange> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedLimitRange;
    requestBody: RequestBody$deleteCoreV1NamespacedLimitRange["*/*"];
}
export declare type RequestContentType$patchCoreV1NamespacedLimitRange = keyof RequestBody$patchCoreV1NamespacedLimitRange;
export declare type ResponseContentType$patchCoreV1NamespacedLimitRange = keyof Response$patchCoreV1NamespacedLimitRange$Status$200 | keyof Response$patchCoreV1NamespacedLimitRange$Status$201;
export interface Params$patchCoreV1NamespacedLimitRange<T extends RequestContentType$patchCoreV1NamespacedLimitRange, U extends ResponseContentType$patchCoreV1NamespacedLimitRange> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedLimitRange;
    requestBody: RequestBody$patchCoreV1NamespacedLimitRange[T];
}
export declare type ResponseContentType$listCoreV1NamespacedPersistentVolumeClaim = keyof Response$listCoreV1NamespacedPersistentVolumeClaim$Status$200;
export interface Params$listCoreV1NamespacedPersistentVolumeClaim<U extends ResponseContentType$listCoreV1NamespacedPersistentVolumeClaim> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedPersistentVolumeClaim;
}
export declare type RequestContentType$createCoreV1NamespacedPersistentVolumeClaim = keyof RequestBody$createCoreV1NamespacedPersistentVolumeClaim;
export declare type ResponseContentType$createCoreV1NamespacedPersistentVolumeClaim = keyof Response$createCoreV1NamespacedPersistentVolumeClaim$Status$200 | keyof Response$createCoreV1NamespacedPersistentVolumeClaim$Status$201 | keyof Response$createCoreV1NamespacedPersistentVolumeClaim$Status$202;
export interface Params$createCoreV1NamespacedPersistentVolumeClaim<U extends ResponseContentType$createCoreV1NamespacedPersistentVolumeClaim> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedPersistentVolumeClaim;
    requestBody: RequestBody$createCoreV1NamespacedPersistentVolumeClaim["*/*"];
}
export declare type RequestContentType$deleteCoreV1CollectionNamespacedPersistentVolumeClaim = keyof RequestBody$deleteCoreV1CollectionNamespacedPersistentVolumeClaim;
export declare type ResponseContentType$deleteCoreV1CollectionNamespacedPersistentVolumeClaim = keyof Response$deleteCoreV1CollectionNamespacedPersistentVolumeClaim$Status$200;
export interface Params$deleteCoreV1CollectionNamespacedPersistentVolumeClaim<U extends ResponseContentType$deleteCoreV1CollectionNamespacedPersistentVolumeClaim> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedPersistentVolumeClaim;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedPersistentVolumeClaim["*/*"];
}
export declare type ResponseContentType$readCoreV1NamespacedPersistentVolumeClaim = keyof Response$readCoreV1NamespacedPersistentVolumeClaim$Status$200;
export interface Params$readCoreV1NamespacedPersistentVolumeClaim<U extends ResponseContentType$readCoreV1NamespacedPersistentVolumeClaim> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedPersistentVolumeClaim;
}
export declare type RequestContentType$replaceCoreV1NamespacedPersistentVolumeClaim = keyof RequestBody$replaceCoreV1NamespacedPersistentVolumeClaim;
export declare type ResponseContentType$replaceCoreV1NamespacedPersistentVolumeClaim = keyof Response$replaceCoreV1NamespacedPersistentVolumeClaim$Status$200 | keyof Response$replaceCoreV1NamespacedPersistentVolumeClaim$Status$201;
export interface Params$replaceCoreV1NamespacedPersistentVolumeClaim<U extends ResponseContentType$replaceCoreV1NamespacedPersistentVolumeClaim> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedPersistentVolumeClaim;
    requestBody: RequestBody$replaceCoreV1NamespacedPersistentVolumeClaim["*/*"];
}
export declare type RequestContentType$deleteCoreV1NamespacedPersistentVolumeClaim = keyof RequestBody$deleteCoreV1NamespacedPersistentVolumeClaim;
export declare type ResponseContentType$deleteCoreV1NamespacedPersistentVolumeClaim = keyof Response$deleteCoreV1NamespacedPersistentVolumeClaim$Status$200 | keyof Response$deleteCoreV1NamespacedPersistentVolumeClaim$Status$202;
export interface Params$deleteCoreV1NamespacedPersistentVolumeClaim<U extends ResponseContentType$deleteCoreV1NamespacedPersistentVolumeClaim> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedPersistentVolumeClaim;
    requestBody: RequestBody$deleteCoreV1NamespacedPersistentVolumeClaim["*/*"];
}
export declare type RequestContentType$patchCoreV1NamespacedPersistentVolumeClaim = keyof RequestBody$patchCoreV1NamespacedPersistentVolumeClaim;
export declare type ResponseContentType$patchCoreV1NamespacedPersistentVolumeClaim = keyof Response$patchCoreV1NamespacedPersistentVolumeClaim$Status$200 | keyof Response$patchCoreV1NamespacedPersistentVolumeClaim$Status$201;
export interface Params$patchCoreV1NamespacedPersistentVolumeClaim<T extends RequestContentType$patchCoreV1NamespacedPersistentVolumeClaim, U extends ResponseContentType$patchCoreV1NamespacedPersistentVolumeClaim> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedPersistentVolumeClaim;
    requestBody: RequestBody$patchCoreV1NamespacedPersistentVolumeClaim[T];
}
export declare type ResponseContentType$readCoreV1NamespacedPersistentVolumeClaimStatus = keyof Response$readCoreV1NamespacedPersistentVolumeClaimStatus$Status$200;
export interface Params$readCoreV1NamespacedPersistentVolumeClaimStatus<U extends ResponseContentType$readCoreV1NamespacedPersistentVolumeClaimStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedPersistentVolumeClaimStatus;
}
export declare type RequestContentType$replaceCoreV1NamespacedPersistentVolumeClaimStatus = keyof RequestBody$replaceCoreV1NamespacedPersistentVolumeClaimStatus;
export declare type ResponseContentType$replaceCoreV1NamespacedPersistentVolumeClaimStatus = keyof Response$replaceCoreV1NamespacedPersistentVolumeClaimStatus$Status$200 | keyof Response$replaceCoreV1NamespacedPersistentVolumeClaimStatus$Status$201;
export interface Params$replaceCoreV1NamespacedPersistentVolumeClaimStatus<U extends ResponseContentType$replaceCoreV1NamespacedPersistentVolumeClaimStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedPersistentVolumeClaimStatus;
    requestBody: RequestBody$replaceCoreV1NamespacedPersistentVolumeClaimStatus["*/*"];
}
export declare type RequestContentType$patchCoreV1NamespacedPersistentVolumeClaimStatus = keyof RequestBody$patchCoreV1NamespacedPersistentVolumeClaimStatus;
export declare type ResponseContentType$patchCoreV1NamespacedPersistentVolumeClaimStatus = keyof Response$patchCoreV1NamespacedPersistentVolumeClaimStatus$Status$200 | keyof Response$patchCoreV1NamespacedPersistentVolumeClaimStatus$Status$201;
export interface Params$patchCoreV1NamespacedPersistentVolumeClaimStatus<T extends RequestContentType$patchCoreV1NamespacedPersistentVolumeClaimStatus, U extends ResponseContentType$patchCoreV1NamespacedPersistentVolumeClaimStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedPersistentVolumeClaimStatus;
    requestBody: RequestBody$patchCoreV1NamespacedPersistentVolumeClaimStatus[T];
}
export declare type ResponseContentType$listCoreV1NamespacedPod = keyof Response$listCoreV1NamespacedPod$Status$200;
export interface Params$listCoreV1NamespacedPod<U extends ResponseContentType$listCoreV1NamespacedPod> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedPod;
}
export declare type RequestContentType$createCoreV1NamespacedPod = keyof RequestBody$createCoreV1NamespacedPod;
export declare type ResponseContentType$createCoreV1NamespacedPod = keyof Response$createCoreV1NamespacedPod$Status$200 | keyof Response$createCoreV1NamespacedPod$Status$201 | keyof Response$createCoreV1NamespacedPod$Status$202;
export interface Params$createCoreV1NamespacedPod<U extends ResponseContentType$createCoreV1NamespacedPod> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedPod;
    requestBody: RequestBody$createCoreV1NamespacedPod["*/*"];
}
export declare type RequestContentType$deleteCoreV1CollectionNamespacedPod = keyof RequestBody$deleteCoreV1CollectionNamespacedPod;
export declare type ResponseContentType$deleteCoreV1CollectionNamespacedPod = keyof Response$deleteCoreV1CollectionNamespacedPod$Status$200;
export interface Params$deleteCoreV1CollectionNamespacedPod<U extends ResponseContentType$deleteCoreV1CollectionNamespacedPod> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedPod;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedPod["*/*"];
}
export declare type ResponseContentType$readCoreV1NamespacedPod = keyof Response$readCoreV1NamespacedPod$Status$200;
export interface Params$readCoreV1NamespacedPod<U extends ResponseContentType$readCoreV1NamespacedPod> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedPod;
}
export declare type RequestContentType$replaceCoreV1NamespacedPod = keyof RequestBody$replaceCoreV1NamespacedPod;
export declare type ResponseContentType$replaceCoreV1NamespacedPod = keyof Response$replaceCoreV1NamespacedPod$Status$200 | keyof Response$replaceCoreV1NamespacedPod$Status$201;
export interface Params$replaceCoreV1NamespacedPod<U extends ResponseContentType$replaceCoreV1NamespacedPod> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedPod;
    requestBody: RequestBody$replaceCoreV1NamespacedPod["*/*"];
}
export declare type RequestContentType$deleteCoreV1NamespacedPod = keyof RequestBody$deleteCoreV1NamespacedPod;
export declare type ResponseContentType$deleteCoreV1NamespacedPod = keyof Response$deleteCoreV1NamespacedPod$Status$200 | keyof Response$deleteCoreV1NamespacedPod$Status$202;
export interface Params$deleteCoreV1NamespacedPod<U extends ResponseContentType$deleteCoreV1NamespacedPod> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedPod;
    requestBody: RequestBody$deleteCoreV1NamespacedPod["*/*"];
}
export declare type RequestContentType$patchCoreV1NamespacedPod = keyof RequestBody$patchCoreV1NamespacedPod;
export declare type ResponseContentType$patchCoreV1NamespacedPod = keyof Response$patchCoreV1NamespacedPod$Status$200 | keyof Response$patchCoreV1NamespacedPod$Status$201;
export interface Params$patchCoreV1NamespacedPod<T extends RequestContentType$patchCoreV1NamespacedPod, U extends ResponseContentType$patchCoreV1NamespacedPod> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedPod;
    requestBody: RequestBody$patchCoreV1NamespacedPod[T];
}
export declare type ResponseContentType$connectCoreV1GetNamespacedPodAttach = keyof Response$connectCoreV1GetNamespacedPodAttach$Status$200;
export interface Params$connectCoreV1GetNamespacedPodAttach {
    parameter: Parameter$connectCoreV1GetNamespacedPodAttach;
}
export declare type ResponseContentType$connectCoreV1PostNamespacedPodAttach = keyof Response$connectCoreV1PostNamespacedPodAttach$Status$200;
export interface Params$connectCoreV1PostNamespacedPodAttach {
    parameter: Parameter$connectCoreV1PostNamespacedPodAttach;
}
export declare type RequestContentType$createCoreV1NamespacedPodBinding = keyof RequestBody$createCoreV1NamespacedPodBinding;
export declare type ResponseContentType$createCoreV1NamespacedPodBinding = keyof Response$createCoreV1NamespacedPodBinding$Status$200 | keyof Response$createCoreV1NamespacedPodBinding$Status$201 | keyof Response$createCoreV1NamespacedPodBinding$Status$202;
export interface Params$createCoreV1NamespacedPodBinding<U extends ResponseContentType$createCoreV1NamespacedPodBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedPodBinding;
    requestBody: RequestBody$createCoreV1NamespacedPodBinding["*/*"];
}
export declare type ResponseContentType$readCoreV1NamespacedPodEphemeralcontainers = keyof Response$readCoreV1NamespacedPodEphemeralcontainers$Status$200;
export interface Params$readCoreV1NamespacedPodEphemeralcontainers<U extends ResponseContentType$readCoreV1NamespacedPodEphemeralcontainers> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedPodEphemeralcontainers;
}
export declare type RequestContentType$replaceCoreV1NamespacedPodEphemeralcontainers = keyof RequestBody$replaceCoreV1NamespacedPodEphemeralcontainers;
export declare type ResponseContentType$replaceCoreV1NamespacedPodEphemeralcontainers = keyof Response$replaceCoreV1NamespacedPodEphemeralcontainers$Status$200 | keyof Response$replaceCoreV1NamespacedPodEphemeralcontainers$Status$201;
export interface Params$replaceCoreV1NamespacedPodEphemeralcontainers<U extends ResponseContentType$replaceCoreV1NamespacedPodEphemeralcontainers> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedPodEphemeralcontainers;
    requestBody: RequestBody$replaceCoreV1NamespacedPodEphemeralcontainers["*/*"];
}
export declare type RequestContentType$patchCoreV1NamespacedPodEphemeralcontainers = keyof RequestBody$patchCoreV1NamespacedPodEphemeralcontainers;
export declare type ResponseContentType$patchCoreV1NamespacedPodEphemeralcontainers = keyof Response$patchCoreV1NamespacedPodEphemeralcontainers$Status$200 | keyof Response$patchCoreV1NamespacedPodEphemeralcontainers$Status$201;
export interface Params$patchCoreV1NamespacedPodEphemeralcontainers<T extends RequestContentType$patchCoreV1NamespacedPodEphemeralcontainers, U extends ResponseContentType$patchCoreV1NamespacedPodEphemeralcontainers> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedPodEphemeralcontainers;
    requestBody: RequestBody$patchCoreV1NamespacedPodEphemeralcontainers[T];
}
export declare type RequestContentType$createCoreV1NamespacedPodEviction = keyof RequestBody$createCoreV1NamespacedPodEviction;
export declare type ResponseContentType$createCoreV1NamespacedPodEviction = keyof Response$createCoreV1NamespacedPodEviction$Status$200 | keyof Response$createCoreV1NamespacedPodEviction$Status$201 | keyof Response$createCoreV1NamespacedPodEviction$Status$202;
export interface Params$createCoreV1NamespacedPodEviction<U extends ResponseContentType$createCoreV1NamespacedPodEviction> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedPodEviction;
    requestBody: RequestBody$createCoreV1NamespacedPodEviction["*/*"];
}
export declare type ResponseContentType$connectCoreV1GetNamespacedPodExec = keyof Response$connectCoreV1GetNamespacedPodExec$Status$200;
export interface Params$connectCoreV1GetNamespacedPodExec {
    parameter: Parameter$connectCoreV1GetNamespacedPodExec;
}
export declare type ResponseContentType$connectCoreV1PostNamespacedPodExec = keyof Response$connectCoreV1PostNamespacedPodExec$Status$200;
export interface Params$connectCoreV1PostNamespacedPodExec {
    parameter: Parameter$connectCoreV1PostNamespacedPodExec;
}
export declare type ResponseContentType$readCoreV1NamespacedPodLog = keyof Response$readCoreV1NamespacedPodLog$Status$200;
export interface Params$readCoreV1NamespacedPodLog<U extends ResponseContentType$readCoreV1NamespacedPodLog> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedPodLog;
}
export declare type ResponseContentType$connectCoreV1GetNamespacedPodPortforward = keyof Response$connectCoreV1GetNamespacedPodPortforward$Status$200;
export interface Params$connectCoreV1GetNamespacedPodPortforward {
    parameter: Parameter$connectCoreV1GetNamespacedPodPortforward;
}
export declare type ResponseContentType$connectCoreV1PostNamespacedPodPortforward = keyof Response$connectCoreV1PostNamespacedPodPortforward$Status$200;
export interface Params$connectCoreV1PostNamespacedPodPortforward {
    parameter: Parameter$connectCoreV1PostNamespacedPodPortforward;
}
export declare type ResponseContentType$connectCoreV1GetNamespacedPodProxy = keyof Response$connectCoreV1GetNamespacedPodProxy$Status$200;
export interface Params$connectCoreV1GetNamespacedPodProxy {
    parameter: Parameter$connectCoreV1GetNamespacedPodProxy;
}
export declare type ResponseContentType$connectCoreV1PutNamespacedPodProxy = keyof Response$connectCoreV1PutNamespacedPodProxy$Status$200;
export interface Params$connectCoreV1PutNamespacedPodProxy {
    parameter: Parameter$connectCoreV1PutNamespacedPodProxy;
}
export declare type ResponseContentType$connectCoreV1PostNamespacedPodProxy = keyof Response$connectCoreV1PostNamespacedPodProxy$Status$200;
export interface Params$connectCoreV1PostNamespacedPodProxy {
    parameter: Parameter$connectCoreV1PostNamespacedPodProxy;
}
export declare type ResponseContentType$connectCoreV1DeleteNamespacedPodProxy = keyof Response$connectCoreV1DeleteNamespacedPodProxy$Status$200;
export interface Params$connectCoreV1DeleteNamespacedPodProxy {
    parameter: Parameter$connectCoreV1DeleteNamespacedPodProxy;
}
export declare type ResponseContentType$connectCoreV1OptionsNamespacedPodProxy = keyof Response$connectCoreV1OptionsNamespacedPodProxy$Status$200;
export interface Params$connectCoreV1OptionsNamespacedPodProxy {
    parameter: Parameter$connectCoreV1OptionsNamespacedPodProxy;
}
export declare type ResponseContentType$connectCoreV1HeadNamespacedPodProxy = keyof Response$connectCoreV1HeadNamespacedPodProxy$Status$200;
export interface Params$connectCoreV1HeadNamespacedPodProxy {
    parameter: Parameter$connectCoreV1HeadNamespacedPodProxy;
}
export declare type ResponseContentType$connectCoreV1PatchNamespacedPodProxy = keyof Response$connectCoreV1PatchNamespacedPodProxy$Status$200;
export interface Params$connectCoreV1PatchNamespacedPodProxy {
    parameter: Parameter$connectCoreV1PatchNamespacedPodProxy;
}
export declare type ResponseContentType$connectCoreV1GetNamespacedPodProxyWithPath = keyof Response$connectCoreV1GetNamespacedPodProxyWithPath$Status$200;
export interface Params$connectCoreV1GetNamespacedPodProxyWithPath {
    parameter: Parameter$connectCoreV1GetNamespacedPodProxyWithPath;
}
export declare type ResponseContentType$connectCoreV1PutNamespacedPodProxyWithPath = keyof Response$connectCoreV1PutNamespacedPodProxyWithPath$Status$200;
export interface Params$connectCoreV1PutNamespacedPodProxyWithPath {
    parameter: Parameter$connectCoreV1PutNamespacedPodProxyWithPath;
}
export declare type ResponseContentType$connectCoreV1PostNamespacedPodProxyWithPath = keyof Response$connectCoreV1PostNamespacedPodProxyWithPath$Status$200;
export interface Params$connectCoreV1PostNamespacedPodProxyWithPath {
    parameter: Parameter$connectCoreV1PostNamespacedPodProxyWithPath;
}
export declare type ResponseContentType$connectCoreV1DeleteNamespacedPodProxyWithPath = keyof Response$connectCoreV1DeleteNamespacedPodProxyWithPath$Status$200;
export interface Params$connectCoreV1DeleteNamespacedPodProxyWithPath {
    parameter: Parameter$connectCoreV1DeleteNamespacedPodProxyWithPath;
}
export declare type ResponseContentType$connectCoreV1OptionsNamespacedPodProxyWithPath = keyof Response$connectCoreV1OptionsNamespacedPodProxyWithPath$Status$200;
export interface Params$connectCoreV1OptionsNamespacedPodProxyWithPath {
    parameter: Parameter$connectCoreV1OptionsNamespacedPodProxyWithPath;
}
export declare type ResponseContentType$connectCoreV1HeadNamespacedPodProxyWithPath = keyof Response$connectCoreV1HeadNamespacedPodProxyWithPath$Status$200;
export interface Params$connectCoreV1HeadNamespacedPodProxyWithPath {
    parameter: Parameter$connectCoreV1HeadNamespacedPodProxyWithPath;
}
export declare type ResponseContentType$connectCoreV1PatchNamespacedPodProxyWithPath = keyof Response$connectCoreV1PatchNamespacedPodProxyWithPath$Status$200;
export interface Params$connectCoreV1PatchNamespacedPodProxyWithPath {
    parameter: Parameter$connectCoreV1PatchNamespacedPodProxyWithPath;
}
export declare type ResponseContentType$readCoreV1NamespacedPodStatus = keyof Response$readCoreV1NamespacedPodStatus$Status$200;
export interface Params$readCoreV1NamespacedPodStatus<U extends ResponseContentType$readCoreV1NamespacedPodStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedPodStatus;
}
export declare type RequestContentType$replaceCoreV1NamespacedPodStatus = keyof RequestBody$replaceCoreV1NamespacedPodStatus;
export declare type ResponseContentType$replaceCoreV1NamespacedPodStatus = keyof Response$replaceCoreV1NamespacedPodStatus$Status$200 | keyof Response$replaceCoreV1NamespacedPodStatus$Status$201;
export interface Params$replaceCoreV1NamespacedPodStatus<U extends ResponseContentType$replaceCoreV1NamespacedPodStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedPodStatus;
    requestBody: RequestBody$replaceCoreV1NamespacedPodStatus["*/*"];
}
export declare type RequestContentType$patchCoreV1NamespacedPodStatus = keyof RequestBody$patchCoreV1NamespacedPodStatus;
export declare type ResponseContentType$patchCoreV1NamespacedPodStatus = keyof Response$patchCoreV1NamespacedPodStatus$Status$200 | keyof Response$patchCoreV1NamespacedPodStatus$Status$201;
export interface Params$patchCoreV1NamespacedPodStatus<T extends RequestContentType$patchCoreV1NamespacedPodStatus, U extends ResponseContentType$patchCoreV1NamespacedPodStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedPodStatus;
    requestBody: RequestBody$patchCoreV1NamespacedPodStatus[T];
}
export declare type ResponseContentType$listCoreV1NamespacedPodTemplate = keyof Response$listCoreV1NamespacedPodTemplate$Status$200;
export interface Params$listCoreV1NamespacedPodTemplate<U extends ResponseContentType$listCoreV1NamespacedPodTemplate> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedPodTemplate;
}
export declare type RequestContentType$createCoreV1NamespacedPodTemplate = keyof RequestBody$createCoreV1NamespacedPodTemplate;
export declare type ResponseContentType$createCoreV1NamespacedPodTemplate = keyof Response$createCoreV1NamespacedPodTemplate$Status$200 | keyof Response$createCoreV1NamespacedPodTemplate$Status$201 | keyof Response$createCoreV1NamespacedPodTemplate$Status$202;
export interface Params$createCoreV1NamespacedPodTemplate<U extends ResponseContentType$createCoreV1NamespacedPodTemplate> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedPodTemplate;
    requestBody: RequestBody$createCoreV1NamespacedPodTemplate["*/*"];
}
export declare type RequestContentType$deleteCoreV1CollectionNamespacedPodTemplate = keyof RequestBody$deleteCoreV1CollectionNamespacedPodTemplate;
export declare type ResponseContentType$deleteCoreV1CollectionNamespacedPodTemplate = keyof Response$deleteCoreV1CollectionNamespacedPodTemplate$Status$200;
export interface Params$deleteCoreV1CollectionNamespacedPodTemplate<U extends ResponseContentType$deleteCoreV1CollectionNamespacedPodTemplate> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedPodTemplate;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedPodTemplate["*/*"];
}
export declare type ResponseContentType$readCoreV1NamespacedPodTemplate = keyof Response$readCoreV1NamespacedPodTemplate$Status$200;
export interface Params$readCoreV1NamespacedPodTemplate<U extends ResponseContentType$readCoreV1NamespacedPodTemplate> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedPodTemplate;
}
export declare type RequestContentType$replaceCoreV1NamespacedPodTemplate = keyof RequestBody$replaceCoreV1NamespacedPodTemplate;
export declare type ResponseContentType$replaceCoreV1NamespacedPodTemplate = keyof Response$replaceCoreV1NamespacedPodTemplate$Status$200 | keyof Response$replaceCoreV1NamespacedPodTemplate$Status$201;
export interface Params$replaceCoreV1NamespacedPodTemplate<U extends ResponseContentType$replaceCoreV1NamespacedPodTemplate> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedPodTemplate;
    requestBody: RequestBody$replaceCoreV1NamespacedPodTemplate["*/*"];
}
export declare type RequestContentType$deleteCoreV1NamespacedPodTemplate = keyof RequestBody$deleteCoreV1NamespacedPodTemplate;
export declare type ResponseContentType$deleteCoreV1NamespacedPodTemplate = keyof Response$deleteCoreV1NamespacedPodTemplate$Status$200 | keyof Response$deleteCoreV1NamespacedPodTemplate$Status$202;
export interface Params$deleteCoreV1NamespacedPodTemplate<U extends ResponseContentType$deleteCoreV1NamespacedPodTemplate> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedPodTemplate;
    requestBody: RequestBody$deleteCoreV1NamespacedPodTemplate["*/*"];
}
export declare type RequestContentType$patchCoreV1NamespacedPodTemplate = keyof RequestBody$patchCoreV1NamespacedPodTemplate;
export declare type ResponseContentType$patchCoreV1NamespacedPodTemplate = keyof Response$patchCoreV1NamespacedPodTemplate$Status$200 | keyof Response$patchCoreV1NamespacedPodTemplate$Status$201;
export interface Params$patchCoreV1NamespacedPodTemplate<T extends RequestContentType$patchCoreV1NamespacedPodTemplate, U extends ResponseContentType$patchCoreV1NamespacedPodTemplate> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedPodTemplate;
    requestBody: RequestBody$patchCoreV1NamespacedPodTemplate[T];
}
export declare type ResponseContentType$listCoreV1NamespacedReplicationController = keyof Response$listCoreV1NamespacedReplicationController$Status$200;
export interface Params$listCoreV1NamespacedReplicationController<U extends ResponseContentType$listCoreV1NamespacedReplicationController> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedReplicationController;
}
export declare type RequestContentType$createCoreV1NamespacedReplicationController = keyof RequestBody$createCoreV1NamespacedReplicationController;
export declare type ResponseContentType$createCoreV1NamespacedReplicationController = keyof Response$createCoreV1NamespacedReplicationController$Status$200 | keyof Response$createCoreV1NamespacedReplicationController$Status$201 | keyof Response$createCoreV1NamespacedReplicationController$Status$202;
export interface Params$createCoreV1NamespacedReplicationController<U extends ResponseContentType$createCoreV1NamespacedReplicationController> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedReplicationController;
    requestBody: RequestBody$createCoreV1NamespacedReplicationController["*/*"];
}
export declare type RequestContentType$deleteCoreV1CollectionNamespacedReplicationController = keyof RequestBody$deleteCoreV1CollectionNamespacedReplicationController;
export declare type ResponseContentType$deleteCoreV1CollectionNamespacedReplicationController = keyof Response$deleteCoreV1CollectionNamespacedReplicationController$Status$200;
export interface Params$deleteCoreV1CollectionNamespacedReplicationController<U extends ResponseContentType$deleteCoreV1CollectionNamespacedReplicationController> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedReplicationController;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedReplicationController["*/*"];
}
export declare type ResponseContentType$readCoreV1NamespacedReplicationController = keyof Response$readCoreV1NamespacedReplicationController$Status$200;
export interface Params$readCoreV1NamespacedReplicationController<U extends ResponseContentType$readCoreV1NamespacedReplicationController> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedReplicationController;
}
export declare type RequestContentType$replaceCoreV1NamespacedReplicationController = keyof RequestBody$replaceCoreV1NamespacedReplicationController;
export declare type ResponseContentType$replaceCoreV1NamespacedReplicationController = keyof Response$replaceCoreV1NamespacedReplicationController$Status$200 | keyof Response$replaceCoreV1NamespacedReplicationController$Status$201;
export interface Params$replaceCoreV1NamespacedReplicationController<U extends ResponseContentType$replaceCoreV1NamespacedReplicationController> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedReplicationController;
    requestBody: RequestBody$replaceCoreV1NamespacedReplicationController["*/*"];
}
export declare type RequestContentType$deleteCoreV1NamespacedReplicationController = keyof RequestBody$deleteCoreV1NamespacedReplicationController;
export declare type ResponseContentType$deleteCoreV1NamespacedReplicationController = keyof Response$deleteCoreV1NamespacedReplicationController$Status$200 | keyof Response$deleteCoreV1NamespacedReplicationController$Status$202;
export interface Params$deleteCoreV1NamespacedReplicationController<U extends ResponseContentType$deleteCoreV1NamespacedReplicationController> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedReplicationController;
    requestBody: RequestBody$deleteCoreV1NamespacedReplicationController["*/*"];
}
export declare type RequestContentType$patchCoreV1NamespacedReplicationController = keyof RequestBody$patchCoreV1NamespacedReplicationController;
export declare type ResponseContentType$patchCoreV1NamespacedReplicationController = keyof Response$patchCoreV1NamespacedReplicationController$Status$200 | keyof Response$patchCoreV1NamespacedReplicationController$Status$201;
export interface Params$patchCoreV1NamespacedReplicationController<T extends RequestContentType$patchCoreV1NamespacedReplicationController, U extends ResponseContentType$patchCoreV1NamespacedReplicationController> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedReplicationController;
    requestBody: RequestBody$patchCoreV1NamespacedReplicationController[T];
}
export declare type ResponseContentType$readCoreV1NamespacedReplicationControllerScale = keyof Response$readCoreV1NamespacedReplicationControllerScale$Status$200;
export interface Params$readCoreV1NamespacedReplicationControllerScale<U extends ResponseContentType$readCoreV1NamespacedReplicationControllerScale> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedReplicationControllerScale;
}
export declare type RequestContentType$replaceCoreV1NamespacedReplicationControllerScale = keyof RequestBody$replaceCoreV1NamespacedReplicationControllerScale;
export declare type ResponseContentType$replaceCoreV1NamespacedReplicationControllerScale = keyof Response$replaceCoreV1NamespacedReplicationControllerScale$Status$200 | keyof Response$replaceCoreV1NamespacedReplicationControllerScale$Status$201;
export interface Params$replaceCoreV1NamespacedReplicationControllerScale<U extends ResponseContentType$replaceCoreV1NamespacedReplicationControllerScale> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedReplicationControllerScale;
    requestBody: RequestBody$replaceCoreV1NamespacedReplicationControllerScale["*/*"];
}
export declare type RequestContentType$patchCoreV1NamespacedReplicationControllerScale = keyof RequestBody$patchCoreV1NamespacedReplicationControllerScale;
export declare type ResponseContentType$patchCoreV1NamespacedReplicationControllerScale = keyof Response$patchCoreV1NamespacedReplicationControllerScale$Status$200 | keyof Response$patchCoreV1NamespacedReplicationControllerScale$Status$201;
export interface Params$patchCoreV1NamespacedReplicationControllerScale<T extends RequestContentType$patchCoreV1NamespacedReplicationControllerScale, U extends ResponseContentType$patchCoreV1NamespacedReplicationControllerScale> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedReplicationControllerScale;
    requestBody: RequestBody$patchCoreV1NamespacedReplicationControllerScale[T];
}
export declare type ResponseContentType$readCoreV1NamespacedReplicationControllerStatus = keyof Response$readCoreV1NamespacedReplicationControllerStatus$Status$200;
export interface Params$readCoreV1NamespacedReplicationControllerStatus<U extends ResponseContentType$readCoreV1NamespacedReplicationControllerStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedReplicationControllerStatus;
}
export declare type RequestContentType$replaceCoreV1NamespacedReplicationControllerStatus = keyof RequestBody$replaceCoreV1NamespacedReplicationControllerStatus;
export declare type ResponseContentType$replaceCoreV1NamespacedReplicationControllerStatus = keyof Response$replaceCoreV1NamespacedReplicationControllerStatus$Status$200 | keyof Response$replaceCoreV1NamespacedReplicationControllerStatus$Status$201;
export interface Params$replaceCoreV1NamespacedReplicationControllerStatus<U extends ResponseContentType$replaceCoreV1NamespacedReplicationControllerStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedReplicationControllerStatus;
    requestBody: RequestBody$replaceCoreV1NamespacedReplicationControllerStatus["*/*"];
}
export declare type RequestContentType$patchCoreV1NamespacedReplicationControllerStatus = keyof RequestBody$patchCoreV1NamespacedReplicationControllerStatus;
export declare type ResponseContentType$patchCoreV1NamespacedReplicationControllerStatus = keyof Response$patchCoreV1NamespacedReplicationControllerStatus$Status$200 | keyof Response$patchCoreV1NamespacedReplicationControllerStatus$Status$201;
export interface Params$patchCoreV1NamespacedReplicationControllerStatus<T extends RequestContentType$patchCoreV1NamespacedReplicationControllerStatus, U extends ResponseContentType$patchCoreV1NamespacedReplicationControllerStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedReplicationControllerStatus;
    requestBody: RequestBody$patchCoreV1NamespacedReplicationControllerStatus[T];
}
export declare type ResponseContentType$listCoreV1NamespacedResourceQuota = keyof Response$listCoreV1NamespacedResourceQuota$Status$200;
export interface Params$listCoreV1NamespacedResourceQuota<U extends ResponseContentType$listCoreV1NamespacedResourceQuota> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedResourceQuota;
}
export declare type RequestContentType$createCoreV1NamespacedResourceQuota = keyof RequestBody$createCoreV1NamespacedResourceQuota;
export declare type ResponseContentType$createCoreV1NamespacedResourceQuota = keyof Response$createCoreV1NamespacedResourceQuota$Status$200 | keyof Response$createCoreV1NamespacedResourceQuota$Status$201 | keyof Response$createCoreV1NamespacedResourceQuota$Status$202;
export interface Params$createCoreV1NamespacedResourceQuota<U extends ResponseContentType$createCoreV1NamespacedResourceQuota> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedResourceQuota;
    requestBody: RequestBody$createCoreV1NamespacedResourceQuota["*/*"];
}
export declare type RequestContentType$deleteCoreV1CollectionNamespacedResourceQuota = keyof RequestBody$deleteCoreV1CollectionNamespacedResourceQuota;
export declare type ResponseContentType$deleteCoreV1CollectionNamespacedResourceQuota = keyof Response$deleteCoreV1CollectionNamespacedResourceQuota$Status$200;
export interface Params$deleteCoreV1CollectionNamespacedResourceQuota<U extends ResponseContentType$deleteCoreV1CollectionNamespacedResourceQuota> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedResourceQuota;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedResourceQuota["*/*"];
}
export declare type ResponseContentType$readCoreV1NamespacedResourceQuota = keyof Response$readCoreV1NamespacedResourceQuota$Status$200;
export interface Params$readCoreV1NamespacedResourceQuota<U extends ResponseContentType$readCoreV1NamespacedResourceQuota> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedResourceQuota;
}
export declare type RequestContentType$replaceCoreV1NamespacedResourceQuota = keyof RequestBody$replaceCoreV1NamespacedResourceQuota;
export declare type ResponseContentType$replaceCoreV1NamespacedResourceQuota = keyof Response$replaceCoreV1NamespacedResourceQuota$Status$200 | keyof Response$replaceCoreV1NamespacedResourceQuota$Status$201;
export interface Params$replaceCoreV1NamespacedResourceQuota<U extends ResponseContentType$replaceCoreV1NamespacedResourceQuota> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedResourceQuota;
    requestBody: RequestBody$replaceCoreV1NamespacedResourceQuota["*/*"];
}
export declare type RequestContentType$deleteCoreV1NamespacedResourceQuota = keyof RequestBody$deleteCoreV1NamespacedResourceQuota;
export declare type ResponseContentType$deleteCoreV1NamespacedResourceQuota = keyof Response$deleteCoreV1NamespacedResourceQuota$Status$200 | keyof Response$deleteCoreV1NamespacedResourceQuota$Status$202;
export interface Params$deleteCoreV1NamespacedResourceQuota<U extends ResponseContentType$deleteCoreV1NamespacedResourceQuota> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedResourceQuota;
    requestBody: RequestBody$deleteCoreV1NamespacedResourceQuota["*/*"];
}
export declare type RequestContentType$patchCoreV1NamespacedResourceQuota = keyof RequestBody$patchCoreV1NamespacedResourceQuota;
export declare type ResponseContentType$patchCoreV1NamespacedResourceQuota = keyof Response$patchCoreV1NamespacedResourceQuota$Status$200 | keyof Response$patchCoreV1NamespacedResourceQuota$Status$201;
export interface Params$patchCoreV1NamespacedResourceQuota<T extends RequestContentType$patchCoreV1NamespacedResourceQuota, U extends ResponseContentType$patchCoreV1NamespacedResourceQuota> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedResourceQuota;
    requestBody: RequestBody$patchCoreV1NamespacedResourceQuota[T];
}
export declare type ResponseContentType$readCoreV1NamespacedResourceQuotaStatus = keyof Response$readCoreV1NamespacedResourceQuotaStatus$Status$200;
export interface Params$readCoreV1NamespacedResourceQuotaStatus<U extends ResponseContentType$readCoreV1NamespacedResourceQuotaStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedResourceQuotaStatus;
}
export declare type RequestContentType$replaceCoreV1NamespacedResourceQuotaStatus = keyof RequestBody$replaceCoreV1NamespacedResourceQuotaStatus;
export declare type ResponseContentType$replaceCoreV1NamespacedResourceQuotaStatus = keyof Response$replaceCoreV1NamespacedResourceQuotaStatus$Status$200 | keyof Response$replaceCoreV1NamespacedResourceQuotaStatus$Status$201;
export interface Params$replaceCoreV1NamespacedResourceQuotaStatus<U extends ResponseContentType$replaceCoreV1NamespacedResourceQuotaStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedResourceQuotaStatus;
    requestBody: RequestBody$replaceCoreV1NamespacedResourceQuotaStatus["*/*"];
}
export declare type RequestContentType$patchCoreV1NamespacedResourceQuotaStatus = keyof RequestBody$patchCoreV1NamespacedResourceQuotaStatus;
export declare type ResponseContentType$patchCoreV1NamespacedResourceQuotaStatus = keyof Response$patchCoreV1NamespacedResourceQuotaStatus$Status$200 | keyof Response$patchCoreV1NamespacedResourceQuotaStatus$Status$201;
export interface Params$patchCoreV1NamespacedResourceQuotaStatus<T extends RequestContentType$patchCoreV1NamespacedResourceQuotaStatus, U extends ResponseContentType$patchCoreV1NamespacedResourceQuotaStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedResourceQuotaStatus;
    requestBody: RequestBody$patchCoreV1NamespacedResourceQuotaStatus[T];
}
export declare type ResponseContentType$listCoreV1NamespacedSecret = keyof Response$listCoreV1NamespacedSecret$Status$200;
export interface Params$listCoreV1NamespacedSecret<U extends ResponseContentType$listCoreV1NamespacedSecret> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedSecret;
}
export declare type RequestContentType$createCoreV1NamespacedSecret = keyof RequestBody$createCoreV1NamespacedSecret;
export declare type ResponseContentType$createCoreV1NamespacedSecret = keyof Response$createCoreV1NamespacedSecret$Status$200 | keyof Response$createCoreV1NamespacedSecret$Status$201 | keyof Response$createCoreV1NamespacedSecret$Status$202;
export interface Params$createCoreV1NamespacedSecret<U extends ResponseContentType$createCoreV1NamespacedSecret> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedSecret;
    requestBody: RequestBody$createCoreV1NamespacedSecret["*/*"];
}
export declare type RequestContentType$deleteCoreV1CollectionNamespacedSecret = keyof RequestBody$deleteCoreV1CollectionNamespacedSecret;
export declare type ResponseContentType$deleteCoreV1CollectionNamespacedSecret = keyof Response$deleteCoreV1CollectionNamespacedSecret$Status$200;
export interface Params$deleteCoreV1CollectionNamespacedSecret<U extends ResponseContentType$deleteCoreV1CollectionNamespacedSecret> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedSecret;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedSecret["*/*"];
}
export declare type ResponseContentType$readCoreV1NamespacedSecret = keyof Response$readCoreV1NamespacedSecret$Status$200;
export interface Params$readCoreV1NamespacedSecret<U extends ResponseContentType$readCoreV1NamespacedSecret> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedSecret;
}
export declare type RequestContentType$replaceCoreV1NamespacedSecret = keyof RequestBody$replaceCoreV1NamespacedSecret;
export declare type ResponseContentType$replaceCoreV1NamespacedSecret = keyof Response$replaceCoreV1NamespacedSecret$Status$200 | keyof Response$replaceCoreV1NamespacedSecret$Status$201;
export interface Params$replaceCoreV1NamespacedSecret<U extends ResponseContentType$replaceCoreV1NamespacedSecret> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedSecret;
    requestBody: RequestBody$replaceCoreV1NamespacedSecret["*/*"];
}
export declare type RequestContentType$deleteCoreV1NamespacedSecret = keyof RequestBody$deleteCoreV1NamespacedSecret;
export declare type ResponseContentType$deleteCoreV1NamespacedSecret = keyof Response$deleteCoreV1NamespacedSecret$Status$200 | keyof Response$deleteCoreV1NamespacedSecret$Status$202;
export interface Params$deleteCoreV1NamespacedSecret<U extends ResponseContentType$deleteCoreV1NamespacedSecret> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedSecret;
    requestBody: RequestBody$deleteCoreV1NamespacedSecret["*/*"];
}
export declare type RequestContentType$patchCoreV1NamespacedSecret = keyof RequestBody$patchCoreV1NamespacedSecret;
export declare type ResponseContentType$patchCoreV1NamespacedSecret = keyof Response$patchCoreV1NamespacedSecret$Status$200 | keyof Response$patchCoreV1NamespacedSecret$Status$201;
export interface Params$patchCoreV1NamespacedSecret<T extends RequestContentType$patchCoreV1NamespacedSecret, U extends ResponseContentType$patchCoreV1NamespacedSecret> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedSecret;
    requestBody: RequestBody$patchCoreV1NamespacedSecret[T];
}
export declare type ResponseContentType$listCoreV1NamespacedServiceAccount = keyof Response$listCoreV1NamespacedServiceAccount$Status$200;
export interface Params$listCoreV1NamespacedServiceAccount<U extends ResponseContentType$listCoreV1NamespacedServiceAccount> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedServiceAccount;
}
export declare type RequestContentType$createCoreV1NamespacedServiceAccount = keyof RequestBody$createCoreV1NamespacedServiceAccount;
export declare type ResponseContentType$createCoreV1NamespacedServiceAccount = keyof Response$createCoreV1NamespacedServiceAccount$Status$200 | keyof Response$createCoreV1NamespacedServiceAccount$Status$201 | keyof Response$createCoreV1NamespacedServiceAccount$Status$202;
export interface Params$createCoreV1NamespacedServiceAccount<U extends ResponseContentType$createCoreV1NamespacedServiceAccount> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedServiceAccount;
    requestBody: RequestBody$createCoreV1NamespacedServiceAccount["*/*"];
}
export declare type RequestContentType$deleteCoreV1CollectionNamespacedServiceAccount = keyof RequestBody$deleteCoreV1CollectionNamespacedServiceAccount;
export declare type ResponseContentType$deleteCoreV1CollectionNamespacedServiceAccount = keyof Response$deleteCoreV1CollectionNamespacedServiceAccount$Status$200;
export interface Params$deleteCoreV1CollectionNamespacedServiceAccount<U extends ResponseContentType$deleteCoreV1CollectionNamespacedServiceAccount> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedServiceAccount;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedServiceAccount["*/*"];
}
export declare type ResponseContentType$readCoreV1NamespacedServiceAccount = keyof Response$readCoreV1NamespacedServiceAccount$Status$200;
export interface Params$readCoreV1NamespacedServiceAccount<U extends ResponseContentType$readCoreV1NamespacedServiceAccount> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedServiceAccount;
}
export declare type RequestContentType$replaceCoreV1NamespacedServiceAccount = keyof RequestBody$replaceCoreV1NamespacedServiceAccount;
export declare type ResponseContentType$replaceCoreV1NamespacedServiceAccount = keyof Response$replaceCoreV1NamespacedServiceAccount$Status$200 | keyof Response$replaceCoreV1NamespacedServiceAccount$Status$201;
export interface Params$replaceCoreV1NamespacedServiceAccount<U extends ResponseContentType$replaceCoreV1NamespacedServiceAccount> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedServiceAccount;
    requestBody: RequestBody$replaceCoreV1NamespacedServiceAccount["*/*"];
}
export declare type RequestContentType$deleteCoreV1NamespacedServiceAccount = keyof RequestBody$deleteCoreV1NamespacedServiceAccount;
export declare type ResponseContentType$deleteCoreV1NamespacedServiceAccount = keyof Response$deleteCoreV1NamespacedServiceAccount$Status$200 | keyof Response$deleteCoreV1NamespacedServiceAccount$Status$202;
export interface Params$deleteCoreV1NamespacedServiceAccount<U extends ResponseContentType$deleteCoreV1NamespacedServiceAccount> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedServiceAccount;
    requestBody: RequestBody$deleteCoreV1NamespacedServiceAccount["*/*"];
}
export declare type RequestContentType$patchCoreV1NamespacedServiceAccount = keyof RequestBody$patchCoreV1NamespacedServiceAccount;
export declare type ResponseContentType$patchCoreV1NamespacedServiceAccount = keyof Response$patchCoreV1NamespacedServiceAccount$Status$200 | keyof Response$patchCoreV1NamespacedServiceAccount$Status$201;
export interface Params$patchCoreV1NamespacedServiceAccount<T extends RequestContentType$patchCoreV1NamespacedServiceAccount, U extends ResponseContentType$patchCoreV1NamespacedServiceAccount> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedServiceAccount;
    requestBody: RequestBody$patchCoreV1NamespacedServiceAccount[T];
}
export declare type RequestContentType$createCoreV1NamespacedServiceAccountToken = keyof RequestBody$createCoreV1NamespacedServiceAccountToken;
export declare type ResponseContentType$createCoreV1NamespacedServiceAccountToken = keyof Response$createCoreV1NamespacedServiceAccountToken$Status$200 | keyof Response$createCoreV1NamespacedServiceAccountToken$Status$201 | keyof Response$createCoreV1NamespacedServiceAccountToken$Status$202;
export interface Params$createCoreV1NamespacedServiceAccountToken<U extends ResponseContentType$createCoreV1NamespacedServiceAccountToken> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedServiceAccountToken;
    requestBody: RequestBody$createCoreV1NamespacedServiceAccountToken["*/*"];
}
export declare type ResponseContentType$listCoreV1NamespacedService = keyof Response$listCoreV1NamespacedService$Status$200;
export interface Params$listCoreV1NamespacedService<U extends ResponseContentType$listCoreV1NamespacedService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedService;
}
export declare type RequestContentType$createCoreV1NamespacedService = keyof RequestBody$createCoreV1NamespacedService;
export declare type ResponseContentType$createCoreV1NamespacedService = keyof Response$createCoreV1NamespacedService$Status$200 | keyof Response$createCoreV1NamespacedService$Status$201 | keyof Response$createCoreV1NamespacedService$Status$202;
export interface Params$createCoreV1NamespacedService<U extends ResponseContentType$createCoreV1NamespacedService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedService;
    requestBody: RequestBody$createCoreV1NamespacedService["*/*"];
}
export declare type RequestContentType$deleteCoreV1CollectionNamespacedService = keyof RequestBody$deleteCoreV1CollectionNamespacedService;
export declare type ResponseContentType$deleteCoreV1CollectionNamespacedService = keyof Response$deleteCoreV1CollectionNamespacedService$Status$200;
export interface Params$deleteCoreV1CollectionNamespacedService<U extends ResponseContentType$deleteCoreV1CollectionNamespacedService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedService;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedService["*/*"];
}
export declare type ResponseContentType$readCoreV1NamespacedService = keyof Response$readCoreV1NamespacedService$Status$200;
export interface Params$readCoreV1NamespacedService<U extends ResponseContentType$readCoreV1NamespacedService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedService;
}
export declare type RequestContentType$replaceCoreV1NamespacedService = keyof RequestBody$replaceCoreV1NamespacedService;
export declare type ResponseContentType$replaceCoreV1NamespacedService = keyof Response$replaceCoreV1NamespacedService$Status$200 | keyof Response$replaceCoreV1NamespacedService$Status$201;
export interface Params$replaceCoreV1NamespacedService<U extends ResponseContentType$replaceCoreV1NamespacedService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedService;
    requestBody: RequestBody$replaceCoreV1NamespacedService["*/*"];
}
export declare type RequestContentType$deleteCoreV1NamespacedService = keyof RequestBody$deleteCoreV1NamespacedService;
export declare type ResponseContentType$deleteCoreV1NamespacedService = keyof Response$deleteCoreV1NamespacedService$Status$200 | keyof Response$deleteCoreV1NamespacedService$Status$202;
export interface Params$deleteCoreV1NamespacedService<U extends ResponseContentType$deleteCoreV1NamespacedService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedService;
    requestBody: RequestBody$deleteCoreV1NamespacedService["*/*"];
}
export declare type RequestContentType$patchCoreV1NamespacedService = keyof RequestBody$patchCoreV1NamespacedService;
export declare type ResponseContentType$patchCoreV1NamespacedService = keyof Response$patchCoreV1NamespacedService$Status$200 | keyof Response$patchCoreV1NamespacedService$Status$201;
export interface Params$patchCoreV1NamespacedService<T extends RequestContentType$patchCoreV1NamespacedService, U extends ResponseContentType$patchCoreV1NamespacedService> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedService;
    requestBody: RequestBody$patchCoreV1NamespacedService[T];
}
export declare type ResponseContentType$connectCoreV1GetNamespacedServiceProxy = keyof Response$connectCoreV1GetNamespacedServiceProxy$Status$200;
export interface Params$connectCoreV1GetNamespacedServiceProxy {
    parameter: Parameter$connectCoreV1GetNamespacedServiceProxy;
}
export declare type ResponseContentType$connectCoreV1PutNamespacedServiceProxy = keyof Response$connectCoreV1PutNamespacedServiceProxy$Status$200;
export interface Params$connectCoreV1PutNamespacedServiceProxy {
    parameter: Parameter$connectCoreV1PutNamespacedServiceProxy;
}
export declare type ResponseContentType$connectCoreV1PostNamespacedServiceProxy = keyof Response$connectCoreV1PostNamespacedServiceProxy$Status$200;
export interface Params$connectCoreV1PostNamespacedServiceProxy {
    parameter: Parameter$connectCoreV1PostNamespacedServiceProxy;
}
export declare type ResponseContentType$connectCoreV1DeleteNamespacedServiceProxy = keyof Response$connectCoreV1DeleteNamespacedServiceProxy$Status$200;
export interface Params$connectCoreV1DeleteNamespacedServiceProxy {
    parameter: Parameter$connectCoreV1DeleteNamespacedServiceProxy;
}
export declare type ResponseContentType$connectCoreV1OptionsNamespacedServiceProxy = keyof Response$connectCoreV1OptionsNamespacedServiceProxy$Status$200;
export interface Params$connectCoreV1OptionsNamespacedServiceProxy {
    parameter: Parameter$connectCoreV1OptionsNamespacedServiceProxy;
}
export declare type ResponseContentType$connectCoreV1HeadNamespacedServiceProxy = keyof Response$connectCoreV1HeadNamespacedServiceProxy$Status$200;
export interface Params$connectCoreV1HeadNamespacedServiceProxy {
    parameter: Parameter$connectCoreV1HeadNamespacedServiceProxy;
}
export declare type ResponseContentType$connectCoreV1PatchNamespacedServiceProxy = keyof Response$connectCoreV1PatchNamespacedServiceProxy$Status$200;
export interface Params$connectCoreV1PatchNamespacedServiceProxy {
    parameter: Parameter$connectCoreV1PatchNamespacedServiceProxy;
}
export declare type ResponseContentType$connectCoreV1GetNamespacedServiceProxyWithPath = keyof Response$connectCoreV1GetNamespacedServiceProxyWithPath$Status$200;
export interface Params$connectCoreV1GetNamespacedServiceProxyWithPath {
    parameter: Parameter$connectCoreV1GetNamespacedServiceProxyWithPath;
}
export declare type ResponseContentType$connectCoreV1PutNamespacedServiceProxyWithPath = keyof Response$connectCoreV1PutNamespacedServiceProxyWithPath$Status$200;
export interface Params$connectCoreV1PutNamespacedServiceProxyWithPath {
    parameter: Parameter$connectCoreV1PutNamespacedServiceProxyWithPath;
}
export declare type ResponseContentType$connectCoreV1PostNamespacedServiceProxyWithPath = keyof Response$connectCoreV1PostNamespacedServiceProxyWithPath$Status$200;
export interface Params$connectCoreV1PostNamespacedServiceProxyWithPath {
    parameter: Parameter$connectCoreV1PostNamespacedServiceProxyWithPath;
}
export declare type ResponseContentType$connectCoreV1DeleteNamespacedServiceProxyWithPath = keyof Response$connectCoreV1DeleteNamespacedServiceProxyWithPath$Status$200;
export interface Params$connectCoreV1DeleteNamespacedServiceProxyWithPath {
    parameter: Parameter$connectCoreV1DeleteNamespacedServiceProxyWithPath;
}
export declare type ResponseContentType$connectCoreV1OptionsNamespacedServiceProxyWithPath = keyof Response$connectCoreV1OptionsNamespacedServiceProxyWithPath$Status$200;
export interface Params$connectCoreV1OptionsNamespacedServiceProxyWithPath {
    parameter: Parameter$connectCoreV1OptionsNamespacedServiceProxyWithPath;
}
export declare type ResponseContentType$connectCoreV1HeadNamespacedServiceProxyWithPath = keyof Response$connectCoreV1HeadNamespacedServiceProxyWithPath$Status$200;
export interface Params$connectCoreV1HeadNamespacedServiceProxyWithPath {
    parameter: Parameter$connectCoreV1HeadNamespacedServiceProxyWithPath;
}
export declare type ResponseContentType$connectCoreV1PatchNamespacedServiceProxyWithPath = keyof Response$connectCoreV1PatchNamespacedServiceProxyWithPath$Status$200;
export interface Params$connectCoreV1PatchNamespacedServiceProxyWithPath {
    parameter: Parameter$connectCoreV1PatchNamespacedServiceProxyWithPath;
}
export declare type ResponseContentType$readCoreV1NamespacedServiceStatus = keyof Response$readCoreV1NamespacedServiceStatus$Status$200;
export interface Params$readCoreV1NamespacedServiceStatus<U extends ResponseContentType$readCoreV1NamespacedServiceStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedServiceStatus;
}
export declare type RequestContentType$replaceCoreV1NamespacedServiceStatus = keyof RequestBody$replaceCoreV1NamespacedServiceStatus;
export declare type ResponseContentType$replaceCoreV1NamespacedServiceStatus = keyof Response$replaceCoreV1NamespacedServiceStatus$Status$200 | keyof Response$replaceCoreV1NamespacedServiceStatus$Status$201;
export interface Params$replaceCoreV1NamespacedServiceStatus<U extends ResponseContentType$replaceCoreV1NamespacedServiceStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedServiceStatus;
    requestBody: RequestBody$replaceCoreV1NamespacedServiceStatus["*/*"];
}
export declare type RequestContentType$patchCoreV1NamespacedServiceStatus = keyof RequestBody$patchCoreV1NamespacedServiceStatus;
export declare type ResponseContentType$patchCoreV1NamespacedServiceStatus = keyof Response$patchCoreV1NamespacedServiceStatus$Status$200 | keyof Response$patchCoreV1NamespacedServiceStatus$Status$201;
export interface Params$patchCoreV1NamespacedServiceStatus<T extends RequestContentType$patchCoreV1NamespacedServiceStatus, U extends ResponseContentType$patchCoreV1NamespacedServiceStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedServiceStatus;
    requestBody: RequestBody$patchCoreV1NamespacedServiceStatus[T];
}
export declare type ResponseContentType$readCoreV1Namespace = keyof Response$readCoreV1Namespace$Status$200;
export interface Params$readCoreV1Namespace<U extends ResponseContentType$readCoreV1Namespace> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1Namespace;
}
export declare type RequestContentType$replaceCoreV1Namespace = keyof RequestBody$replaceCoreV1Namespace;
export declare type ResponseContentType$replaceCoreV1Namespace = keyof Response$replaceCoreV1Namespace$Status$200 | keyof Response$replaceCoreV1Namespace$Status$201;
export interface Params$replaceCoreV1Namespace<U extends ResponseContentType$replaceCoreV1Namespace> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1Namespace;
    requestBody: RequestBody$replaceCoreV1Namespace["*/*"];
}
export declare type RequestContentType$deleteCoreV1Namespace = keyof RequestBody$deleteCoreV1Namespace;
export declare type ResponseContentType$deleteCoreV1Namespace = keyof Response$deleteCoreV1Namespace$Status$200 | keyof Response$deleteCoreV1Namespace$Status$202;
export interface Params$deleteCoreV1Namespace<U extends ResponseContentType$deleteCoreV1Namespace> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1Namespace;
    requestBody: RequestBody$deleteCoreV1Namespace["*/*"];
}
export declare type RequestContentType$patchCoreV1Namespace = keyof RequestBody$patchCoreV1Namespace;
export declare type ResponseContentType$patchCoreV1Namespace = keyof Response$patchCoreV1Namespace$Status$200 | keyof Response$patchCoreV1Namespace$Status$201;
export interface Params$patchCoreV1Namespace<T extends RequestContentType$patchCoreV1Namespace, U extends ResponseContentType$patchCoreV1Namespace> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1Namespace;
    requestBody: RequestBody$patchCoreV1Namespace[T];
}
export declare type RequestContentType$replaceCoreV1NamespaceFinalize = keyof RequestBody$replaceCoreV1NamespaceFinalize;
export declare type ResponseContentType$replaceCoreV1NamespaceFinalize = keyof Response$replaceCoreV1NamespaceFinalize$Status$200 | keyof Response$replaceCoreV1NamespaceFinalize$Status$201;
export interface Params$replaceCoreV1NamespaceFinalize<U extends ResponseContentType$replaceCoreV1NamespaceFinalize> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespaceFinalize;
    requestBody: RequestBody$replaceCoreV1NamespaceFinalize["*/*"];
}
export declare type ResponseContentType$readCoreV1NamespaceStatus = keyof Response$readCoreV1NamespaceStatus$Status$200;
export interface Params$readCoreV1NamespaceStatus<U extends ResponseContentType$readCoreV1NamespaceStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespaceStatus;
}
export declare type RequestContentType$replaceCoreV1NamespaceStatus = keyof RequestBody$replaceCoreV1NamespaceStatus;
export declare type ResponseContentType$replaceCoreV1NamespaceStatus = keyof Response$replaceCoreV1NamespaceStatus$Status$200 | keyof Response$replaceCoreV1NamespaceStatus$Status$201;
export interface Params$replaceCoreV1NamespaceStatus<U extends ResponseContentType$replaceCoreV1NamespaceStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespaceStatus;
    requestBody: RequestBody$replaceCoreV1NamespaceStatus["*/*"];
}
export declare type RequestContentType$patchCoreV1NamespaceStatus = keyof RequestBody$patchCoreV1NamespaceStatus;
export declare type ResponseContentType$patchCoreV1NamespaceStatus = keyof Response$patchCoreV1NamespaceStatus$Status$200 | keyof Response$patchCoreV1NamespaceStatus$Status$201;
export interface Params$patchCoreV1NamespaceStatus<T extends RequestContentType$patchCoreV1NamespaceStatus, U extends ResponseContentType$patchCoreV1NamespaceStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespaceStatus;
    requestBody: RequestBody$patchCoreV1NamespaceStatus[T];
}
export declare type ResponseContentType$listCoreV1Node = keyof Response$listCoreV1Node$Status$200;
export interface Params$listCoreV1Node<U extends ResponseContentType$listCoreV1Node> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1Node;
}
export declare type RequestContentType$createCoreV1Node = keyof RequestBody$createCoreV1Node;
export declare type ResponseContentType$createCoreV1Node = keyof Response$createCoreV1Node$Status$200 | keyof Response$createCoreV1Node$Status$201 | keyof Response$createCoreV1Node$Status$202;
export interface Params$createCoreV1Node<U extends ResponseContentType$createCoreV1Node> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1Node;
    requestBody: RequestBody$createCoreV1Node["*/*"];
}
export declare type RequestContentType$deleteCoreV1CollectionNode = keyof RequestBody$deleteCoreV1CollectionNode;
export declare type ResponseContentType$deleteCoreV1CollectionNode = keyof Response$deleteCoreV1CollectionNode$Status$200;
export interface Params$deleteCoreV1CollectionNode<U extends ResponseContentType$deleteCoreV1CollectionNode> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNode;
    requestBody: RequestBody$deleteCoreV1CollectionNode["*/*"];
}
export declare type ResponseContentType$readCoreV1Node = keyof Response$readCoreV1Node$Status$200;
export interface Params$readCoreV1Node<U extends ResponseContentType$readCoreV1Node> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1Node;
}
export declare type RequestContentType$replaceCoreV1Node = keyof RequestBody$replaceCoreV1Node;
export declare type ResponseContentType$replaceCoreV1Node = keyof Response$replaceCoreV1Node$Status$200 | keyof Response$replaceCoreV1Node$Status$201;
export interface Params$replaceCoreV1Node<U extends ResponseContentType$replaceCoreV1Node> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1Node;
    requestBody: RequestBody$replaceCoreV1Node["*/*"];
}
export declare type RequestContentType$deleteCoreV1Node = keyof RequestBody$deleteCoreV1Node;
export declare type ResponseContentType$deleteCoreV1Node = keyof Response$deleteCoreV1Node$Status$200 | keyof Response$deleteCoreV1Node$Status$202;
export interface Params$deleteCoreV1Node<U extends ResponseContentType$deleteCoreV1Node> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1Node;
    requestBody: RequestBody$deleteCoreV1Node["*/*"];
}
export declare type RequestContentType$patchCoreV1Node = keyof RequestBody$patchCoreV1Node;
export declare type ResponseContentType$patchCoreV1Node = keyof Response$patchCoreV1Node$Status$200 | keyof Response$patchCoreV1Node$Status$201;
export interface Params$patchCoreV1Node<T extends RequestContentType$patchCoreV1Node, U extends ResponseContentType$patchCoreV1Node> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1Node;
    requestBody: RequestBody$patchCoreV1Node[T];
}
export declare type ResponseContentType$connectCoreV1GetNodeProxy = keyof Response$connectCoreV1GetNodeProxy$Status$200;
export interface Params$connectCoreV1GetNodeProxy {
    parameter: Parameter$connectCoreV1GetNodeProxy;
}
export declare type ResponseContentType$connectCoreV1PutNodeProxy = keyof Response$connectCoreV1PutNodeProxy$Status$200;
export interface Params$connectCoreV1PutNodeProxy {
    parameter: Parameter$connectCoreV1PutNodeProxy;
}
export declare type ResponseContentType$connectCoreV1PostNodeProxy = keyof Response$connectCoreV1PostNodeProxy$Status$200;
export interface Params$connectCoreV1PostNodeProxy {
    parameter: Parameter$connectCoreV1PostNodeProxy;
}
export declare type ResponseContentType$connectCoreV1DeleteNodeProxy = keyof Response$connectCoreV1DeleteNodeProxy$Status$200;
export interface Params$connectCoreV1DeleteNodeProxy {
    parameter: Parameter$connectCoreV1DeleteNodeProxy;
}
export declare type ResponseContentType$connectCoreV1OptionsNodeProxy = keyof Response$connectCoreV1OptionsNodeProxy$Status$200;
export interface Params$connectCoreV1OptionsNodeProxy {
    parameter: Parameter$connectCoreV1OptionsNodeProxy;
}
export declare type ResponseContentType$connectCoreV1HeadNodeProxy = keyof Response$connectCoreV1HeadNodeProxy$Status$200;
export interface Params$connectCoreV1HeadNodeProxy {
    parameter: Parameter$connectCoreV1HeadNodeProxy;
}
export declare type ResponseContentType$connectCoreV1PatchNodeProxy = keyof Response$connectCoreV1PatchNodeProxy$Status$200;
export interface Params$connectCoreV1PatchNodeProxy {
    parameter: Parameter$connectCoreV1PatchNodeProxy;
}
export declare type ResponseContentType$connectCoreV1GetNodeProxyWithPath = keyof Response$connectCoreV1GetNodeProxyWithPath$Status$200;
export interface Params$connectCoreV1GetNodeProxyWithPath {
    parameter: Parameter$connectCoreV1GetNodeProxyWithPath;
}
export declare type ResponseContentType$connectCoreV1PutNodeProxyWithPath = keyof Response$connectCoreV1PutNodeProxyWithPath$Status$200;
export interface Params$connectCoreV1PutNodeProxyWithPath {
    parameter: Parameter$connectCoreV1PutNodeProxyWithPath;
}
export declare type ResponseContentType$connectCoreV1PostNodeProxyWithPath = keyof Response$connectCoreV1PostNodeProxyWithPath$Status$200;
export interface Params$connectCoreV1PostNodeProxyWithPath {
    parameter: Parameter$connectCoreV1PostNodeProxyWithPath;
}
export declare type ResponseContentType$connectCoreV1DeleteNodeProxyWithPath = keyof Response$connectCoreV1DeleteNodeProxyWithPath$Status$200;
export interface Params$connectCoreV1DeleteNodeProxyWithPath {
    parameter: Parameter$connectCoreV1DeleteNodeProxyWithPath;
}
export declare type ResponseContentType$connectCoreV1OptionsNodeProxyWithPath = keyof Response$connectCoreV1OptionsNodeProxyWithPath$Status$200;
export interface Params$connectCoreV1OptionsNodeProxyWithPath {
    parameter: Parameter$connectCoreV1OptionsNodeProxyWithPath;
}
export declare type ResponseContentType$connectCoreV1HeadNodeProxyWithPath = keyof Response$connectCoreV1HeadNodeProxyWithPath$Status$200;
export interface Params$connectCoreV1HeadNodeProxyWithPath {
    parameter: Parameter$connectCoreV1HeadNodeProxyWithPath;
}
export declare type ResponseContentType$connectCoreV1PatchNodeProxyWithPath = keyof Response$connectCoreV1PatchNodeProxyWithPath$Status$200;
export interface Params$connectCoreV1PatchNodeProxyWithPath {
    parameter: Parameter$connectCoreV1PatchNodeProxyWithPath;
}
export declare type ResponseContentType$readCoreV1NodeStatus = keyof Response$readCoreV1NodeStatus$Status$200;
export interface Params$readCoreV1NodeStatus<U extends ResponseContentType$readCoreV1NodeStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NodeStatus;
}
export declare type RequestContentType$replaceCoreV1NodeStatus = keyof RequestBody$replaceCoreV1NodeStatus;
export declare type ResponseContentType$replaceCoreV1NodeStatus = keyof Response$replaceCoreV1NodeStatus$Status$200 | keyof Response$replaceCoreV1NodeStatus$Status$201;
export interface Params$replaceCoreV1NodeStatus<U extends ResponseContentType$replaceCoreV1NodeStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NodeStatus;
    requestBody: RequestBody$replaceCoreV1NodeStatus["*/*"];
}
export declare type RequestContentType$patchCoreV1NodeStatus = keyof RequestBody$patchCoreV1NodeStatus;
export declare type ResponseContentType$patchCoreV1NodeStatus = keyof Response$patchCoreV1NodeStatus$Status$200 | keyof Response$patchCoreV1NodeStatus$Status$201;
export interface Params$patchCoreV1NodeStatus<T extends RequestContentType$patchCoreV1NodeStatus, U extends ResponseContentType$patchCoreV1NodeStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NodeStatus;
    requestBody: RequestBody$patchCoreV1NodeStatus[T];
}
export declare type ResponseContentType$listCoreV1PersistentVolumeClaimForAllNamespaces = keyof Response$listCoreV1PersistentVolumeClaimForAllNamespaces$Status$200;
export interface Params$listCoreV1PersistentVolumeClaimForAllNamespaces<U extends ResponseContentType$listCoreV1PersistentVolumeClaimForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1PersistentVolumeClaimForAllNamespaces;
}
export declare type ResponseContentType$listCoreV1PersistentVolume = keyof Response$listCoreV1PersistentVolume$Status$200;
export interface Params$listCoreV1PersistentVolume<U extends ResponseContentType$listCoreV1PersistentVolume> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1PersistentVolume;
}
export declare type RequestContentType$createCoreV1PersistentVolume = keyof RequestBody$createCoreV1PersistentVolume;
export declare type ResponseContentType$createCoreV1PersistentVolume = keyof Response$createCoreV1PersistentVolume$Status$200 | keyof Response$createCoreV1PersistentVolume$Status$201 | keyof Response$createCoreV1PersistentVolume$Status$202;
export interface Params$createCoreV1PersistentVolume<U extends ResponseContentType$createCoreV1PersistentVolume> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1PersistentVolume;
    requestBody: RequestBody$createCoreV1PersistentVolume["*/*"];
}
export declare type RequestContentType$deleteCoreV1CollectionPersistentVolume = keyof RequestBody$deleteCoreV1CollectionPersistentVolume;
export declare type ResponseContentType$deleteCoreV1CollectionPersistentVolume = keyof Response$deleteCoreV1CollectionPersistentVolume$Status$200;
export interface Params$deleteCoreV1CollectionPersistentVolume<U extends ResponseContentType$deleteCoreV1CollectionPersistentVolume> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionPersistentVolume;
    requestBody: RequestBody$deleteCoreV1CollectionPersistentVolume["*/*"];
}
export declare type ResponseContentType$readCoreV1PersistentVolume = keyof Response$readCoreV1PersistentVolume$Status$200;
export interface Params$readCoreV1PersistentVolume<U extends ResponseContentType$readCoreV1PersistentVolume> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1PersistentVolume;
}
export declare type RequestContentType$replaceCoreV1PersistentVolume = keyof RequestBody$replaceCoreV1PersistentVolume;
export declare type ResponseContentType$replaceCoreV1PersistentVolume = keyof Response$replaceCoreV1PersistentVolume$Status$200 | keyof Response$replaceCoreV1PersistentVolume$Status$201;
export interface Params$replaceCoreV1PersistentVolume<U extends ResponseContentType$replaceCoreV1PersistentVolume> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1PersistentVolume;
    requestBody: RequestBody$replaceCoreV1PersistentVolume["*/*"];
}
export declare type RequestContentType$deleteCoreV1PersistentVolume = keyof RequestBody$deleteCoreV1PersistentVolume;
export declare type ResponseContentType$deleteCoreV1PersistentVolume = keyof Response$deleteCoreV1PersistentVolume$Status$200 | keyof Response$deleteCoreV1PersistentVolume$Status$202;
export interface Params$deleteCoreV1PersistentVolume<U extends ResponseContentType$deleteCoreV1PersistentVolume> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1PersistentVolume;
    requestBody: RequestBody$deleteCoreV1PersistentVolume["*/*"];
}
export declare type RequestContentType$patchCoreV1PersistentVolume = keyof RequestBody$patchCoreV1PersistentVolume;
export declare type ResponseContentType$patchCoreV1PersistentVolume = keyof Response$patchCoreV1PersistentVolume$Status$200 | keyof Response$patchCoreV1PersistentVolume$Status$201;
export interface Params$patchCoreV1PersistentVolume<T extends RequestContentType$patchCoreV1PersistentVolume, U extends ResponseContentType$patchCoreV1PersistentVolume> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1PersistentVolume;
    requestBody: RequestBody$patchCoreV1PersistentVolume[T];
}
export declare type ResponseContentType$readCoreV1PersistentVolumeStatus = keyof Response$readCoreV1PersistentVolumeStatus$Status$200;
export interface Params$readCoreV1PersistentVolumeStatus<U extends ResponseContentType$readCoreV1PersistentVolumeStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1PersistentVolumeStatus;
}
export declare type RequestContentType$replaceCoreV1PersistentVolumeStatus = keyof RequestBody$replaceCoreV1PersistentVolumeStatus;
export declare type ResponseContentType$replaceCoreV1PersistentVolumeStatus = keyof Response$replaceCoreV1PersistentVolumeStatus$Status$200 | keyof Response$replaceCoreV1PersistentVolumeStatus$Status$201;
export interface Params$replaceCoreV1PersistentVolumeStatus<U extends ResponseContentType$replaceCoreV1PersistentVolumeStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1PersistentVolumeStatus;
    requestBody: RequestBody$replaceCoreV1PersistentVolumeStatus["*/*"];
}
export declare type RequestContentType$patchCoreV1PersistentVolumeStatus = keyof RequestBody$patchCoreV1PersistentVolumeStatus;
export declare type ResponseContentType$patchCoreV1PersistentVolumeStatus = keyof Response$patchCoreV1PersistentVolumeStatus$Status$200 | keyof Response$patchCoreV1PersistentVolumeStatus$Status$201;
export interface Params$patchCoreV1PersistentVolumeStatus<T extends RequestContentType$patchCoreV1PersistentVolumeStatus, U extends ResponseContentType$patchCoreV1PersistentVolumeStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1PersistentVolumeStatus;
    requestBody: RequestBody$patchCoreV1PersistentVolumeStatus[T];
}
export declare type ResponseContentType$listCoreV1PodForAllNamespaces = keyof Response$listCoreV1PodForAllNamespaces$Status$200;
export interface Params$listCoreV1PodForAllNamespaces<U extends ResponseContentType$listCoreV1PodForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1PodForAllNamespaces;
}
export declare type ResponseContentType$listCoreV1PodTemplateForAllNamespaces = keyof Response$listCoreV1PodTemplateForAllNamespaces$Status$200;
export interface Params$listCoreV1PodTemplateForAllNamespaces<U extends ResponseContentType$listCoreV1PodTemplateForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1PodTemplateForAllNamespaces;
}
export declare type ResponseContentType$listCoreV1ReplicationControllerForAllNamespaces = keyof Response$listCoreV1ReplicationControllerForAllNamespaces$Status$200;
export interface Params$listCoreV1ReplicationControllerForAllNamespaces<U extends ResponseContentType$listCoreV1ReplicationControllerForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1ReplicationControllerForAllNamespaces;
}
export declare type ResponseContentType$listCoreV1ResourceQuotaForAllNamespaces = keyof Response$listCoreV1ResourceQuotaForAllNamespaces$Status$200;
export interface Params$listCoreV1ResourceQuotaForAllNamespaces<U extends ResponseContentType$listCoreV1ResourceQuotaForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1ResourceQuotaForAllNamespaces;
}
export declare type ResponseContentType$listCoreV1SecretForAllNamespaces = keyof Response$listCoreV1SecretForAllNamespaces$Status$200;
export interface Params$listCoreV1SecretForAllNamespaces<U extends ResponseContentType$listCoreV1SecretForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1SecretForAllNamespaces;
}
export declare type ResponseContentType$listCoreV1ServiceAccountForAllNamespaces = keyof Response$listCoreV1ServiceAccountForAllNamespaces$Status$200;
export interface Params$listCoreV1ServiceAccountForAllNamespaces<U extends ResponseContentType$listCoreV1ServiceAccountForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1ServiceAccountForAllNamespaces;
}
export declare type ResponseContentType$listCoreV1ServiceForAllNamespaces = keyof Response$listCoreV1ServiceForAllNamespaces$Status$200;
export interface Params$listCoreV1ServiceForAllNamespaces<U extends ResponseContentType$listCoreV1ServiceForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1ServiceForAllNamespaces;
}
export declare type ResponseContentType$watchCoreV1ConfigMapListForAllNamespaces = keyof Response$watchCoreV1ConfigMapListForAllNamespaces$Status$200;
export interface Params$watchCoreV1ConfigMapListForAllNamespaces<U extends ResponseContentType$watchCoreV1ConfigMapListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1ConfigMapListForAllNamespaces;
}
export declare type ResponseContentType$watchCoreV1EndpointsListForAllNamespaces = keyof Response$watchCoreV1EndpointsListForAllNamespaces$Status$200;
export interface Params$watchCoreV1EndpointsListForAllNamespaces<U extends ResponseContentType$watchCoreV1EndpointsListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1EndpointsListForAllNamespaces;
}
export declare type ResponseContentType$watchCoreV1EventListForAllNamespaces = keyof Response$watchCoreV1EventListForAllNamespaces$Status$200;
export interface Params$watchCoreV1EventListForAllNamespaces<U extends ResponseContentType$watchCoreV1EventListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1EventListForAllNamespaces;
}
export declare type ResponseContentType$watchCoreV1LimitRangeListForAllNamespaces = keyof Response$watchCoreV1LimitRangeListForAllNamespaces$Status$200;
export interface Params$watchCoreV1LimitRangeListForAllNamespaces<U extends ResponseContentType$watchCoreV1LimitRangeListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1LimitRangeListForAllNamespaces;
}
export declare type ResponseContentType$watchCoreV1NamespaceList = keyof Response$watchCoreV1NamespaceList$Status$200;
export interface Params$watchCoreV1NamespaceList<U extends ResponseContentType$watchCoreV1NamespaceList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespaceList;
}
export declare type ResponseContentType$watchCoreV1NamespacedConfigMapList = keyof Response$watchCoreV1NamespacedConfigMapList$Status$200;
export interface Params$watchCoreV1NamespacedConfigMapList<U extends ResponseContentType$watchCoreV1NamespacedConfigMapList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedConfigMapList;
}
export declare type ResponseContentType$watchCoreV1NamespacedConfigMap = keyof Response$watchCoreV1NamespacedConfigMap$Status$200;
export interface Params$watchCoreV1NamespacedConfigMap<U extends ResponseContentType$watchCoreV1NamespacedConfigMap> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedConfigMap;
}
export declare type ResponseContentType$watchCoreV1NamespacedEndpointsList = keyof Response$watchCoreV1NamespacedEndpointsList$Status$200;
export interface Params$watchCoreV1NamespacedEndpointsList<U extends ResponseContentType$watchCoreV1NamespacedEndpointsList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedEndpointsList;
}
export declare type ResponseContentType$watchCoreV1NamespacedEndpoints = keyof Response$watchCoreV1NamespacedEndpoints$Status$200;
export interface Params$watchCoreV1NamespacedEndpoints<U extends ResponseContentType$watchCoreV1NamespacedEndpoints> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedEndpoints;
}
export declare type ResponseContentType$watchCoreV1NamespacedEventList = keyof Response$watchCoreV1NamespacedEventList$Status$200;
export interface Params$watchCoreV1NamespacedEventList<U extends ResponseContentType$watchCoreV1NamespacedEventList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedEventList;
}
export declare type ResponseContentType$watchCoreV1NamespacedEvent = keyof Response$watchCoreV1NamespacedEvent$Status$200;
export interface Params$watchCoreV1NamespacedEvent<U extends ResponseContentType$watchCoreV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedEvent;
}
export declare type ResponseContentType$watchCoreV1NamespacedLimitRangeList = keyof Response$watchCoreV1NamespacedLimitRangeList$Status$200;
export interface Params$watchCoreV1NamespacedLimitRangeList<U extends ResponseContentType$watchCoreV1NamespacedLimitRangeList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedLimitRangeList;
}
export declare type ResponseContentType$watchCoreV1NamespacedLimitRange = keyof Response$watchCoreV1NamespacedLimitRange$Status$200;
export interface Params$watchCoreV1NamespacedLimitRange<U extends ResponseContentType$watchCoreV1NamespacedLimitRange> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedLimitRange;
}
export declare type ResponseContentType$watchCoreV1NamespacedPersistentVolumeClaimList = keyof Response$watchCoreV1NamespacedPersistentVolumeClaimList$Status$200;
export interface Params$watchCoreV1NamespacedPersistentVolumeClaimList<U extends ResponseContentType$watchCoreV1NamespacedPersistentVolumeClaimList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedPersistentVolumeClaimList;
}
export declare type ResponseContentType$watchCoreV1NamespacedPersistentVolumeClaim = keyof Response$watchCoreV1NamespacedPersistentVolumeClaim$Status$200;
export interface Params$watchCoreV1NamespacedPersistentVolumeClaim<U extends ResponseContentType$watchCoreV1NamespacedPersistentVolumeClaim> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedPersistentVolumeClaim;
}
export declare type ResponseContentType$watchCoreV1NamespacedPodList = keyof Response$watchCoreV1NamespacedPodList$Status$200;
export interface Params$watchCoreV1NamespacedPodList<U extends ResponseContentType$watchCoreV1NamespacedPodList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedPodList;
}
export declare type ResponseContentType$watchCoreV1NamespacedPod = keyof Response$watchCoreV1NamespacedPod$Status$200;
export interface Params$watchCoreV1NamespacedPod<U extends ResponseContentType$watchCoreV1NamespacedPod> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedPod;
}
export declare type ResponseContentType$watchCoreV1NamespacedPodTemplateList = keyof Response$watchCoreV1NamespacedPodTemplateList$Status$200;
export interface Params$watchCoreV1NamespacedPodTemplateList<U extends ResponseContentType$watchCoreV1NamespacedPodTemplateList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedPodTemplateList;
}
export declare type ResponseContentType$watchCoreV1NamespacedPodTemplate = keyof Response$watchCoreV1NamespacedPodTemplate$Status$200;
export interface Params$watchCoreV1NamespacedPodTemplate<U extends ResponseContentType$watchCoreV1NamespacedPodTemplate> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedPodTemplate;
}
export declare type ResponseContentType$watchCoreV1NamespacedReplicationControllerList = keyof Response$watchCoreV1NamespacedReplicationControllerList$Status$200;
export interface Params$watchCoreV1NamespacedReplicationControllerList<U extends ResponseContentType$watchCoreV1NamespacedReplicationControllerList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedReplicationControllerList;
}
export declare type ResponseContentType$watchCoreV1NamespacedReplicationController = keyof Response$watchCoreV1NamespacedReplicationController$Status$200;
export interface Params$watchCoreV1NamespacedReplicationController<U extends ResponseContentType$watchCoreV1NamespacedReplicationController> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedReplicationController;
}
export declare type ResponseContentType$watchCoreV1NamespacedResourceQuotaList = keyof Response$watchCoreV1NamespacedResourceQuotaList$Status$200;
export interface Params$watchCoreV1NamespacedResourceQuotaList<U extends ResponseContentType$watchCoreV1NamespacedResourceQuotaList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedResourceQuotaList;
}
export declare type ResponseContentType$watchCoreV1NamespacedResourceQuota = keyof Response$watchCoreV1NamespacedResourceQuota$Status$200;
export interface Params$watchCoreV1NamespacedResourceQuota<U extends ResponseContentType$watchCoreV1NamespacedResourceQuota> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedResourceQuota;
}
export declare type ResponseContentType$watchCoreV1NamespacedSecretList = keyof Response$watchCoreV1NamespacedSecretList$Status$200;
export interface Params$watchCoreV1NamespacedSecretList<U extends ResponseContentType$watchCoreV1NamespacedSecretList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedSecretList;
}
export declare type ResponseContentType$watchCoreV1NamespacedSecret = keyof Response$watchCoreV1NamespacedSecret$Status$200;
export interface Params$watchCoreV1NamespacedSecret<U extends ResponseContentType$watchCoreV1NamespacedSecret> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedSecret;
}
export declare type ResponseContentType$watchCoreV1NamespacedServiceAccountList = keyof Response$watchCoreV1NamespacedServiceAccountList$Status$200;
export interface Params$watchCoreV1NamespacedServiceAccountList<U extends ResponseContentType$watchCoreV1NamespacedServiceAccountList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedServiceAccountList;
}
export declare type ResponseContentType$watchCoreV1NamespacedServiceAccount = keyof Response$watchCoreV1NamespacedServiceAccount$Status$200;
export interface Params$watchCoreV1NamespacedServiceAccount<U extends ResponseContentType$watchCoreV1NamespacedServiceAccount> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedServiceAccount;
}
export declare type ResponseContentType$watchCoreV1NamespacedServiceList = keyof Response$watchCoreV1NamespacedServiceList$Status$200;
export interface Params$watchCoreV1NamespacedServiceList<U extends ResponseContentType$watchCoreV1NamespacedServiceList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedServiceList;
}
export declare type ResponseContentType$watchCoreV1NamespacedService = keyof Response$watchCoreV1NamespacedService$Status$200;
export interface Params$watchCoreV1NamespacedService<U extends ResponseContentType$watchCoreV1NamespacedService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedService;
}
export declare type ResponseContentType$watchCoreV1Namespace = keyof Response$watchCoreV1Namespace$Status$200;
export interface Params$watchCoreV1Namespace<U extends ResponseContentType$watchCoreV1Namespace> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1Namespace;
}
export declare type ResponseContentType$watchCoreV1NodeList = keyof Response$watchCoreV1NodeList$Status$200;
export interface Params$watchCoreV1NodeList<U extends ResponseContentType$watchCoreV1NodeList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NodeList;
}
export declare type ResponseContentType$watchCoreV1Node = keyof Response$watchCoreV1Node$Status$200;
export interface Params$watchCoreV1Node<U extends ResponseContentType$watchCoreV1Node> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1Node;
}
export declare type ResponseContentType$watchCoreV1PersistentVolumeClaimListForAllNamespaces = keyof Response$watchCoreV1PersistentVolumeClaimListForAllNamespaces$Status$200;
export interface Params$watchCoreV1PersistentVolumeClaimListForAllNamespaces<U extends ResponseContentType$watchCoreV1PersistentVolumeClaimListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1PersistentVolumeClaimListForAllNamespaces;
}
export declare type ResponseContentType$watchCoreV1PersistentVolumeList = keyof Response$watchCoreV1PersistentVolumeList$Status$200;
export interface Params$watchCoreV1PersistentVolumeList<U extends ResponseContentType$watchCoreV1PersistentVolumeList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1PersistentVolumeList;
}
export declare type ResponseContentType$watchCoreV1PersistentVolume = keyof Response$watchCoreV1PersistentVolume$Status$200;
export interface Params$watchCoreV1PersistentVolume<U extends ResponseContentType$watchCoreV1PersistentVolume> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1PersistentVolume;
}
export declare type ResponseContentType$watchCoreV1PodListForAllNamespaces = keyof Response$watchCoreV1PodListForAllNamespaces$Status$200;
export interface Params$watchCoreV1PodListForAllNamespaces<U extends ResponseContentType$watchCoreV1PodListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1PodListForAllNamespaces;
}
export declare type ResponseContentType$watchCoreV1PodTemplateListForAllNamespaces = keyof Response$watchCoreV1PodTemplateListForAllNamespaces$Status$200;
export interface Params$watchCoreV1PodTemplateListForAllNamespaces<U extends ResponseContentType$watchCoreV1PodTemplateListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1PodTemplateListForAllNamespaces;
}
export declare type ResponseContentType$watchCoreV1ReplicationControllerListForAllNamespaces = keyof Response$watchCoreV1ReplicationControllerListForAllNamespaces$Status$200;
export interface Params$watchCoreV1ReplicationControllerListForAllNamespaces<U extends ResponseContentType$watchCoreV1ReplicationControllerListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1ReplicationControllerListForAllNamespaces;
}
export declare type ResponseContentType$watchCoreV1ResourceQuotaListForAllNamespaces = keyof Response$watchCoreV1ResourceQuotaListForAllNamespaces$Status$200;
export interface Params$watchCoreV1ResourceQuotaListForAllNamespaces<U extends ResponseContentType$watchCoreV1ResourceQuotaListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1ResourceQuotaListForAllNamespaces;
}
export declare type ResponseContentType$watchCoreV1SecretListForAllNamespaces = keyof Response$watchCoreV1SecretListForAllNamespaces$Status$200;
export interface Params$watchCoreV1SecretListForAllNamespaces<U extends ResponseContentType$watchCoreV1SecretListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1SecretListForAllNamespaces;
}
export declare type ResponseContentType$watchCoreV1ServiceAccountListForAllNamespaces = keyof Response$watchCoreV1ServiceAccountListForAllNamespaces$Status$200;
export interface Params$watchCoreV1ServiceAccountListForAllNamespaces<U extends ResponseContentType$watchCoreV1ServiceAccountListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1ServiceAccountListForAllNamespaces;
}
export declare type ResponseContentType$watchCoreV1ServiceListForAllNamespaces = keyof Response$watchCoreV1ServiceListForAllNamespaces$Status$200;
export interface Params$watchCoreV1ServiceListForAllNamespaces<U extends ResponseContentType$watchCoreV1ServiceListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1ServiceListForAllNamespaces;
}
export declare type ResponseContentType$getAPIVersions = keyof Response$getAPIVersions$Status$200;
export interface Params$getAPIVersions<U extends ResponseContentType$getAPIVersions> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$getAdmissionregistrationAPIGroup = keyof Response$getAdmissionregistrationAPIGroup$Status$200;
export interface Params$getAdmissionregistrationAPIGroup<U extends ResponseContentType$getAdmissionregistrationAPIGroup> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$getAdmissionregistrationV1APIResources = keyof Response$getAdmissionregistrationV1APIResources$Status$200;
export interface Params$getAdmissionregistrationV1APIResources<U extends ResponseContentType$getAdmissionregistrationV1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listAdmissionregistrationV1MutatingWebhookConfiguration = keyof Response$listAdmissionregistrationV1MutatingWebhookConfiguration$Status$200;
export interface Params$listAdmissionregistrationV1MutatingWebhookConfiguration<U extends ResponseContentType$listAdmissionregistrationV1MutatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAdmissionregistrationV1MutatingWebhookConfiguration;
}
export declare type RequestContentType$createAdmissionregistrationV1MutatingWebhookConfiguration = keyof RequestBody$createAdmissionregistrationV1MutatingWebhookConfiguration;
export declare type ResponseContentType$createAdmissionregistrationV1MutatingWebhookConfiguration = keyof Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | keyof Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$201 | keyof Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$202;
export interface Params$createAdmissionregistrationV1MutatingWebhookConfiguration<U extends ResponseContentType$createAdmissionregistrationV1MutatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAdmissionregistrationV1MutatingWebhookConfiguration;
    requestBody: RequestBody$createAdmissionregistrationV1MutatingWebhookConfiguration["*/*"];
}
export declare type RequestContentType$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration = keyof RequestBody$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration;
export declare type ResponseContentType$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration = keyof Response$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration$Status$200;
export interface Params$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration<U extends ResponseContentType$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration;
    requestBody: RequestBody$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration["*/*"];
}
export declare type ResponseContentType$readAdmissionregistrationV1MutatingWebhookConfiguration = keyof Response$readAdmissionregistrationV1MutatingWebhookConfiguration$Status$200;
export interface Params$readAdmissionregistrationV1MutatingWebhookConfiguration<U extends ResponseContentType$readAdmissionregistrationV1MutatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAdmissionregistrationV1MutatingWebhookConfiguration;
}
export declare type RequestContentType$replaceAdmissionregistrationV1MutatingWebhookConfiguration = keyof RequestBody$replaceAdmissionregistrationV1MutatingWebhookConfiguration;
export declare type ResponseContentType$replaceAdmissionregistrationV1MutatingWebhookConfiguration = keyof Response$replaceAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | keyof Response$replaceAdmissionregistrationV1MutatingWebhookConfiguration$Status$201;
export interface Params$replaceAdmissionregistrationV1MutatingWebhookConfiguration<U extends ResponseContentType$replaceAdmissionregistrationV1MutatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAdmissionregistrationV1MutatingWebhookConfiguration;
    requestBody: RequestBody$replaceAdmissionregistrationV1MutatingWebhookConfiguration["*/*"];
}
export declare type RequestContentType$deleteAdmissionregistrationV1MutatingWebhookConfiguration = keyof RequestBody$deleteAdmissionregistrationV1MutatingWebhookConfiguration;
export declare type ResponseContentType$deleteAdmissionregistrationV1MutatingWebhookConfiguration = keyof Response$deleteAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | keyof Response$deleteAdmissionregistrationV1MutatingWebhookConfiguration$Status$202;
export interface Params$deleteAdmissionregistrationV1MutatingWebhookConfiguration<U extends ResponseContentType$deleteAdmissionregistrationV1MutatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAdmissionregistrationV1MutatingWebhookConfiguration;
    requestBody: RequestBody$deleteAdmissionregistrationV1MutatingWebhookConfiguration["*/*"];
}
export declare type RequestContentType$patchAdmissionregistrationV1MutatingWebhookConfiguration = keyof RequestBody$patchAdmissionregistrationV1MutatingWebhookConfiguration;
export declare type ResponseContentType$patchAdmissionregistrationV1MutatingWebhookConfiguration = keyof Response$patchAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | keyof Response$patchAdmissionregistrationV1MutatingWebhookConfiguration$Status$201;
export interface Params$patchAdmissionregistrationV1MutatingWebhookConfiguration<T extends RequestContentType$patchAdmissionregistrationV1MutatingWebhookConfiguration, U extends ResponseContentType$patchAdmissionregistrationV1MutatingWebhookConfiguration> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAdmissionregistrationV1MutatingWebhookConfiguration;
    requestBody: RequestBody$patchAdmissionregistrationV1MutatingWebhookConfiguration[T];
}
export declare type ResponseContentType$listAdmissionregistrationV1ValidatingWebhookConfiguration = keyof Response$listAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200;
export interface Params$listAdmissionregistrationV1ValidatingWebhookConfiguration<U extends ResponseContentType$listAdmissionregistrationV1ValidatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAdmissionregistrationV1ValidatingWebhookConfiguration;
}
export declare type RequestContentType$createAdmissionregistrationV1ValidatingWebhookConfiguration = keyof RequestBody$createAdmissionregistrationV1ValidatingWebhookConfiguration;
export declare type ResponseContentType$createAdmissionregistrationV1ValidatingWebhookConfiguration = keyof Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | keyof Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201 | keyof Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$202;
export interface Params$createAdmissionregistrationV1ValidatingWebhookConfiguration<U extends ResponseContentType$createAdmissionregistrationV1ValidatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAdmissionregistrationV1ValidatingWebhookConfiguration;
    requestBody: RequestBody$createAdmissionregistrationV1ValidatingWebhookConfiguration["*/*"];
}
export declare type RequestContentType$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration = keyof RequestBody$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration;
export declare type ResponseContentType$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration = keyof Response$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration$Status$200;
export interface Params$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration<U extends ResponseContentType$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration;
    requestBody: RequestBody$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration["*/*"];
}
export declare type ResponseContentType$readAdmissionregistrationV1ValidatingWebhookConfiguration = keyof Response$readAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200;
export interface Params$readAdmissionregistrationV1ValidatingWebhookConfiguration<U extends ResponseContentType$readAdmissionregistrationV1ValidatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAdmissionregistrationV1ValidatingWebhookConfiguration;
}
export declare type RequestContentType$replaceAdmissionregistrationV1ValidatingWebhookConfiguration = keyof RequestBody$replaceAdmissionregistrationV1ValidatingWebhookConfiguration;
export declare type ResponseContentType$replaceAdmissionregistrationV1ValidatingWebhookConfiguration = keyof Response$replaceAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | keyof Response$replaceAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201;
export interface Params$replaceAdmissionregistrationV1ValidatingWebhookConfiguration<U extends ResponseContentType$replaceAdmissionregistrationV1ValidatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAdmissionregistrationV1ValidatingWebhookConfiguration;
    requestBody: RequestBody$replaceAdmissionregistrationV1ValidatingWebhookConfiguration["*/*"];
}
export declare type RequestContentType$deleteAdmissionregistrationV1ValidatingWebhookConfiguration = keyof RequestBody$deleteAdmissionregistrationV1ValidatingWebhookConfiguration;
export declare type ResponseContentType$deleteAdmissionregistrationV1ValidatingWebhookConfiguration = keyof Response$deleteAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | keyof Response$deleteAdmissionregistrationV1ValidatingWebhookConfiguration$Status$202;
export interface Params$deleteAdmissionregistrationV1ValidatingWebhookConfiguration<U extends ResponseContentType$deleteAdmissionregistrationV1ValidatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAdmissionregistrationV1ValidatingWebhookConfiguration;
    requestBody: RequestBody$deleteAdmissionregistrationV1ValidatingWebhookConfiguration["*/*"];
}
export declare type RequestContentType$patchAdmissionregistrationV1ValidatingWebhookConfiguration = keyof RequestBody$patchAdmissionregistrationV1ValidatingWebhookConfiguration;
export declare type ResponseContentType$patchAdmissionregistrationV1ValidatingWebhookConfiguration = keyof Response$patchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | keyof Response$patchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201;
export interface Params$patchAdmissionregistrationV1ValidatingWebhookConfiguration<T extends RequestContentType$patchAdmissionregistrationV1ValidatingWebhookConfiguration, U extends ResponseContentType$patchAdmissionregistrationV1ValidatingWebhookConfiguration> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAdmissionregistrationV1ValidatingWebhookConfiguration;
    requestBody: RequestBody$patchAdmissionregistrationV1ValidatingWebhookConfiguration[T];
}
export declare type ResponseContentType$watchAdmissionregistrationV1MutatingWebhookConfigurationList = keyof Response$watchAdmissionregistrationV1MutatingWebhookConfigurationList$Status$200;
export interface Params$watchAdmissionregistrationV1MutatingWebhookConfigurationList<U extends ResponseContentType$watchAdmissionregistrationV1MutatingWebhookConfigurationList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAdmissionregistrationV1MutatingWebhookConfigurationList;
}
export declare type ResponseContentType$watchAdmissionregistrationV1MutatingWebhookConfiguration = keyof Response$watchAdmissionregistrationV1MutatingWebhookConfiguration$Status$200;
export interface Params$watchAdmissionregistrationV1MutatingWebhookConfiguration<U extends ResponseContentType$watchAdmissionregistrationV1MutatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAdmissionregistrationV1MutatingWebhookConfiguration;
}
export declare type ResponseContentType$watchAdmissionregistrationV1ValidatingWebhookConfigurationList = keyof Response$watchAdmissionregistrationV1ValidatingWebhookConfigurationList$Status$200;
export interface Params$watchAdmissionregistrationV1ValidatingWebhookConfigurationList<U extends ResponseContentType$watchAdmissionregistrationV1ValidatingWebhookConfigurationList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAdmissionregistrationV1ValidatingWebhookConfigurationList;
}
export declare type ResponseContentType$watchAdmissionregistrationV1ValidatingWebhookConfiguration = keyof Response$watchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200;
export interface Params$watchAdmissionregistrationV1ValidatingWebhookConfiguration<U extends ResponseContentType$watchAdmissionregistrationV1ValidatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAdmissionregistrationV1ValidatingWebhookConfiguration;
}
export declare type ResponseContentType$getApiextensionsAPIGroup = keyof Response$getApiextensionsAPIGroup$Status$200;
export interface Params$getApiextensionsAPIGroup<U extends ResponseContentType$getApiextensionsAPIGroup> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$getApiextensionsV1APIResources = keyof Response$getApiextensionsV1APIResources$Status$200;
export interface Params$getApiextensionsV1APIResources<U extends ResponseContentType$getApiextensionsV1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listApiextensionsV1CustomResourceDefinition = keyof Response$listApiextensionsV1CustomResourceDefinition$Status$200;
export interface Params$listApiextensionsV1CustomResourceDefinition<U extends ResponseContentType$listApiextensionsV1CustomResourceDefinition> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listApiextensionsV1CustomResourceDefinition;
}
export declare type RequestContentType$createApiextensionsV1CustomResourceDefinition = keyof RequestBody$createApiextensionsV1CustomResourceDefinition;
export declare type ResponseContentType$createApiextensionsV1CustomResourceDefinition = keyof Response$createApiextensionsV1CustomResourceDefinition$Status$200 | keyof Response$createApiextensionsV1CustomResourceDefinition$Status$201 | keyof Response$createApiextensionsV1CustomResourceDefinition$Status$202;
export interface Params$createApiextensionsV1CustomResourceDefinition<U extends ResponseContentType$createApiextensionsV1CustomResourceDefinition> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createApiextensionsV1CustomResourceDefinition;
    requestBody: RequestBody$createApiextensionsV1CustomResourceDefinition["*/*"];
}
export declare type RequestContentType$deleteApiextensionsV1CollectionCustomResourceDefinition = keyof RequestBody$deleteApiextensionsV1CollectionCustomResourceDefinition;
export declare type ResponseContentType$deleteApiextensionsV1CollectionCustomResourceDefinition = keyof Response$deleteApiextensionsV1CollectionCustomResourceDefinition$Status$200;
export interface Params$deleteApiextensionsV1CollectionCustomResourceDefinition<U extends ResponseContentType$deleteApiextensionsV1CollectionCustomResourceDefinition> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteApiextensionsV1CollectionCustomResourceDefinition;
    requestBody: RequestBody$deleteApiextensionsV1CollectionCustomResourceDefinition["*/*"];
}
export declare type ResponseContentType$readApiextensionsV1CustomResourceDefinition = keyof Response$readApiextensionsV1CustomResourceDefinition$Status$200;
export interface Params$readApiextensionsV1CustomResourceDefinition<U extends ResponseContentType$readApiextensionsV1CustomResourceDefinition> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readApiextensionsV1CustomResourceDefinition;
}
export declare type RequestContentType$replaceApiextensionsV1CustomResourceDefinition = keyof RequestBody$replaceApiextensionsV1CustomResourceDefinition;
export declare type ResponseContentType$replaceApiextensionsV1CustomResourceDefinition = keyof Response$replaceApiextensionsV1CustomResourceDefinition$Status$200 | keyof Response$replaceApiextensionsV1CustomResourceDefinition$Status$201;
export interface Params$replaceApiextensionsV1CustomResourceDefinition<U extends ResponseContentType$replaceApiextensionsV1CustomResourceDefinition> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceApiextensionsV1CustomResourceDefinition;
    requestBody: RequestBody$replaceApiextensionsV1CustomResourceDefinition["*/*"];
}
export declare type RequestContentType$deleteApiextensionsV1CustomResourceDefinition = keyof RequestBody$deleteApiextensionsV1CustomResourceDefinition;
export declare type ResponseContentType$deleteApiextensionsV1CustomResourceDefinition = keyof Response$deleteApiextensionsV1CustomResourceDefinition$Status$200 | keyof Response$deleteApiextensionsV1CustomResourceDefinition$Status$202;
export interface Params$deleteApiextensionsV1CustomResourceDefinition<U extends ResponseContentType$deleteApiextensionsV1CustomResourceDefinition> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteApiextensionsV1CustomResourceDefinition;
    requestBody: RequestBody$deleteApiextensionsV1CustomResourceDefinition["*/*"];
}
export declare type RequestContentType$patchApiextensionsV1CustomResourceDefinition = keyof RequestBody$patchApiextensionsV1CustomResourceDefinition;
export declare type ResponseContentType$patchApiextensionsV1CustomResourceDefinition = keyof Response$patchApiextensionsV1CustomResourceDefinition$Status$200 | keyof Response$patchApiextensionsV1CustomResourceDefinition$Status$201;
export interface Params$patchApiextensionsV1CustomResourceDefinition<T extends RequestContentType$patchApiextensionsV1CustomResourceDefinition, U extends ResponseContentType$patchApiextensionsV1CustomResourceDefinition> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchApiextensionsV1CustomResourceDefinition;
    requestBody: RequestBody$patchApiextensionsV1CustomResourceDefinition[T];
}
export declare type ResponseContentType$readApiextensionsV1CustomResourceDefinitionStatus = keyof Response$readApiextensionsV1CustomResourceDefinitionStatus$Status$200;
export interface Params$readApiextensionsV1CustomResourceDefinitionStatus<U extends ResponseContentType$readApiextensionsV1CustomResourceDefinitionStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readApiextensionsV1CustomResourceDefinitionStatus;
}
export declare type RequestContentType$replaceApiextensionsV1CustomResourceDefinitionStatus = keyof RequestBody$replaceApiextensionsV1CustomResourceDefinitionStatus;
export declare type ResponseContentType$replaceApiextensionsV1CustomResourceDefinitionStatus = keyof Response$replaceApiextensionsV1CustomResourceDefinitionStatus$Status$200 | keyof Response$replaceApiextensionsV1CustomResourceDefinitionStatus$Status$201;
export interface Params$replaceApiextensionsV1CustomResourceDefinitionStatus<U extends ResponseContentType$replaceApiextensionsV1CustomResourceDefinitionStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceApiextensionsV1CustomResourceDefinitionStatus;
    requestBody: RequestBody$replaceApiextensionsV1CustomResourceDefinitionStatus["*/*"];
}
export declare type RequestContentType$patchApiextensionsV1CustomResourceDefinitionStatus = keyof RequestBody$patchApiextensionsV1CustomResourceDefinitionStatus;
export declare type ResponseContentType$patchApiextensionsV1CustomResourceDefinitionStatus = keyof Response$patchApiextensionsV1CustomResourceDefinitionStatus$Status$200 | keyof Response$patchApiextensionsV1CustomResourceDefinitionStatus$Status$201;
export interface Params$patchApiextensionsV1CustomResourceDefinitionStatus<T extends RequestContentType$patchApiextensionsV1CustomResourceDefinitionStatus, U extends ResponseContentType$patchApiextensionsV1CustomResourceDefinitionStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchApiextensionsV1CustomResourceDefinitionStatus;
    requestBody: RequestBody$patchApiextensionsV1CustomResourceDefinitionStatus[T];
}
export declare type ResponseContentType$watchApiextensionsV1CustomResourceDefinitionList = keyof Response$watchApiextensionsV1CustomResourceDefinitionList$Status$200;
export interface Params$watchApiextensionsV1CustomResourceDefinitionList<U extends ResponseContentType$watchApiextensionsV1CustomResourceDefinitionList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchApiextensionsV1CustomResourceDefinitionList;
}
export declare type ResponseContentType$watchApiextensionsV1CustomResourceDefinition = keyof Response$watchApiextensionsV1CustomResourceDefinition$Status$200;
export interface Params$watchApiextensionsV1CustomResourceDefinition<U extends ResponseContentType$watchApiextensionsV1CustomResourceDefinition> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchApiextensionsV1CustomResourceDefinition;
}
export declare type ResponseContentType$getApiregistrationAPIGroup = keyof Response$getApiregistrationAPIGroup$Status$200;
export interface Params$getApiregistrationAPIGroup<U extends ResponseContentType$getApiregistrationAPIGroup> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$getApiregistrationV1APIResources = keyof Response$getApiregistrationV1APIResources$Status$200;
export interface Params$getApiregistrationV1APIResources<U extends ResponseContentType$getApiregistrationV1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listApiregistrationV1APIService = keyof Response$listApiregistrationV1APIService$Status$200;
export interface Params$listApiregistrationV1APIService<U extends ResponseContentType$listApiregistrationV1APIService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listApiregistrationV1APIService;
}
export declare type RequestContentType$createApiregistrationV1APIService = keyof RequestBody$createApiregistrationV1APIService;
export declare type ResponseContentType$createApiregistrationV1APIService = keyof Response$createApiregistrationV1APIService$Status$200 | keyof Response$createApiregistrationV1APIService$Status$201 | keyof Response$createApiregistrationV1APIService$Status$202;
export interface Params$createApiregistrationV1APIService<U extends ResponseContentType$createApiregistrationV1APIService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createApiregistrationV1APIService;
    requestBody: RequestBody$createApiregistrationV1APIService["*/*"];
}
export declare type RequestContentType$deleteApiregistrationV1CollectionAPIService = keyof RequestBody$deleteApiregistrationV1CollectionAPIService;
export declare type ResponseContentType$deleteApiregistrationV1CollectionAPIService = keyof Response$deleteApiregistrationV1CollectionAPIService$Status$200;
export interface Params$deleteApiregistrationV1CollectionAPIService<U extends ResponseContentType$deleteApiregistrationV1CollectionAPIService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteApiregistrationV1CollectionAPIService;
    requestBody: RequestBody$deleteApiregistrationV1CollectionAPIService["*/*"];
}
export declare type ResponseContentType$readApiregistrationV1APIService = keyof Response$readApiregistrationV1APIService$Status$200;
export interface Params$readApiregistrationV1APIService<U extends ResponseContentType$readApiregistrationV1APIService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readApiregistrationV1APIService;
}
export declare type RequestContentType$replaceApiregistrationV1APIService = keyof RequestBody$replaceApiregistrationV1APIService;
export declare type ResponseContentType$replaceApiregistrationV1APIService = keyof Response$replaceApiregistrationV1APIService$Status$200 | keyof Response$replaceApiregistrationV1APIService$Status$201;
export interface Params$replaceApiregistrationV1APIService<U extends ResponseContentType$replaceApiregistrationV1APIService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceApiregistrationV1APIService;
    requestBody: RequestBody$replaceApiregistrationV1APIService["*/*"];
}
export declare type RequestContentType$deleteApiregistrationV1APIService = keyof RequestBody$deleteApiregistrationV1APIService;
export declare type ResponseContentType$deleteApiregistrationV1APIService = keyof Response$deleteApiregistrationV1APIService$Status$200 | keyof Response$deleteApiregistrationV1APIService$Status$202;
export interface Params$deleteApiregistrationV1APIService<U extends ResponseContentType$deleteApiregistrationV1APIService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteApiregistrationV1APIService;
    requestBody: RequestBody$deleteApiregistrationV1APIService["*/*"];
}
export declare type RequestContentType$patchApiregistrationV1APIService = keyof RequestBody$patchApiregistrationV1APIService;
export declare type ResponseContentType$patchApiregistrationV1APIService = keyof Response$patchApiregistrationV1APIService$Status$200 | keyof Response$patchApiregistrationV1APIService$Status$201;
export interface Params$patchApiregistrationV1APIService<T extends RequestContentType$patchApiregistrationV1APIService, U extends ResponseContentType$patchApiregistrationV1APIService> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchApiregistrationV1APIService;
    requestBody: RequestBody$patchApiregistrationV1APIService[T];
}
export declare type ResponseContentType$readApiregistrationV1APIServiceStatus = keyof Response$readApiregistrationV1APIServiceStatus$Status$200;
export interface Params$readApiregistrationV1APIServiceStatus<U extends ResponseContentType$readApiregistrationV1APIServiceStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readApiregistrationV1APIServiceStatus;
}
export declare type RequestContentType$replaceApiregistrationV1APIServiceStatus = keyof RequestBody$replaceApiregistrationV1APIServiceStatus;
export declare type ResponseContentType$replaceApiregistrationV1APIServiceStatus = keyof Response$replaceApiregistrationV1APIServiceStatus$Status$200 | keyof Response$replaceApiregistrationV1APIServiceStatus$Status$201;
export interface Params$replaceApiregistrationV1APIServiceStatus<U extends ResponseContentType$replaceApiregistrationV1APIServiceStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceApiregistrationV1APIServiceStatus;
    requestBody: RequestBody$replaceApiregistrationV1APIServiceStatus["*/*"];
}
export declare type RequestContentType$patchApiregistrationV1APIServiceStatus = keyof RequestBody$patchApiregistrationV1APIServiceStatus;
export declare type ResponseContentType$patchApiregistrationV1APIServiceStatus = keyof Response$patchApiregistrationV1APIServiceStatus$Status$200 | keyof Response$patchApiregistrationV1APIServiceStatus$Status$201;
export interface Params$patchApiregistrationV1APIServiceStatus<T extends RequestContentType$patchApiregistrationV1APIServiceStatus, U extends ResponseContentType$patchApiregistrationV1APIServiceStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchApiregistrationV1APIServiceStatus;
    requestBody: RequestBody$patchApiregistrationV1APIServiceStatus[T];
}
export declare type ResponseContentType$watchApiregistrationV1APIServiceList = keyof Response$watchApiregistrationV1APIServiceList$Status$200;
export interface Params$watchApiregistrationV1APIServiceList<U extends ResponseContentType$watchApiregistrationV1APIServiceList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchApiregistrationV1APIServiceList;
}
export declare type ResponseContentType$watchApiregistrationV1APIService = keyof Response$watchApiregistrationV1APIService$Status$200;
export interface Params$watchApiregistrationV1APIService<U extends ResponseContentType$watchApiregistrationV1APIService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchApiregistrationV1APIService;
}
export declare type ResponseContentType$getAppsAPIGroup = keyof Response$getAppsAPIGroup$Status$200;
export interface Params$getAppsAPIGroup<U extends ResponseContentType$getAppsAPIGroup> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$getAppsV1APIResources = keyof Response$getAppsV1APIResources$Status$200;
export interface Params$getAppsV1APIResources<U extends ResponseContentType$getAppsV1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listAppsV1ControllerRevisionForAllNamespaces = keyof Response$listAppsV1ControllerRevisionForAllNamespaces$Status$200;
export interface Params$listAppsV1ControllerRevisionForAllNamespaces<U extends ResponseContentType$listAppsV1ControllerRevisionForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAppsV1ControllerRevisionForAllNamespaces;
}
export declare type ResponseContentType$listAppsV1DaemonSetForAllNamespaces = keyof Response$listAppsV1DaemonSetForAllNamespaces$Status$200;
export interface Params$listAppsV1DaemonSetForAllNamespaces<U extends ResponseContentType$listAppsV1DaemonSetForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAppsV1DaemonSetForAllNamespaces;
}
export declare type ResponseContentType$listAppsV1DeploymentForAllNamespaces = keyof Response$listAppsV1DeploymentForAllNamespaces$Status$200;
export interface Params$listAppsV1DeploymentForAllNamespaces<U extends ResponseContentType$listAppsV1DeploymentForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAppsV1DeploymentForAllNamespaces;
}
export declare type ResponseContentType$listAppsV1NamespacedControllerRevision = keyof Response$listAppsV1NamespacedControllerRevision$Status$200;
export interface Params$listAppsV1NamespacedControllerRevision<U extends ResponseContentType$listAppsV1NamespacedControllerRevision> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAppsV1NamespacedControllerRevision;
}
export declare type RequestContentType$createAppsV1NamespacedControllerRevision = keyof RequestBody$createAppsV1NamespacedControllerRevision;
export declare type ResponseContentType$createAppsV1NamespacedControllerRevision = keyof Response$createAppsV1NamespacedControllerRevision$Status$200 | keyof Response$createAppsV1NamespacedControllerRevision$Status$201 | keyof Response$createAppsV1NamespacedControllerRevision$Status$202;
export interface Params$createAppsV1NamespacedControllerRevision<U extends ResponseContentType$createAppsV1NamespacedControllerRevision> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAppsV1NamespacedControllerRevision;
    requestBody: RequestBody$createAppsV1NamespacedControllerRevision["*/*"];
}
export declare type RequestContentType$deleteAppsV1CollectionNamespacedControllerRevision = keyof RequestBody$deleteAppsV1CollectionNamespacedControllerRevision;
export declare type ResponseContentType$deleteAppsV1CollectionNamespacedControllerRevision = keyof Response$deleteAppsV1CollectionNamespacedControllerRevision$Status$200;
export interface Params$deleteAppsV1CollectionNamespacedControllerRevision<U extends ResponseContentType$deleteAppsV1CollectionNamespacedControllerRevision> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAppsV1CollectionNamespacedControllerRevision;
    requestBody: RequestBody$deleteAppsV1CollectionNamespacedControllerRevision["*/*"];
}
export declare type ResponseContentType$readAppsV1NamespacedControllerRevision = keyof Response$readAppsV1NamespacedControllerRevision$Status$200;
export interface Params$readAppsV1NamespacedControllerRevision<U extends ResponseContentType$readAppsV1NamespacedControllerRevision> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedControllerRevision;
}
export declare type RequestContentType$replaceAppsV1NamespacedControllerRevision = keyof RequestBody$replaceAppsV1NamespacedControllerRevision;
export declare type ResponseContentType$replaceAppsV1NamespacedControllerRevision = keyof Response$replaceAppsV1NamespacedControllerRevision$Status$200 | keyof Response$replaceAppsV1NamespacedControllerRevision$Status$201;
export interface Params$replaceAppsV1NamespacedControllerRevision<U extends ResponseContentType$replaceAppsV1NamespacedControllerRevision> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedControllerRevision;
    requestBody: RequestBody$replaceAppsV1NamespacedControllerRevision["*/*"];
}
export declare type RequestContentType$deleteAppsV1NamespacedControllerRevision = keyof RequestBody$deleteAppsV1NamespacedControllerRevision;
export declare type ResponseContentType$deleteAppsV1NamespacedControllerRevision = keyof Response$deleteAppsV1NamespacedControllerRevision$Status$200 | keyof Response$deleteAppsV1NamespacedControllerRevision$Status$202;
export interface Params$deleteAppsV1NamespacedControllerRevision<U extends ResponseContentType$deleteAppsV1NamespacedControllerRevision> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAppsV1NamespacedControllerRevision;
    requestBody: RequestBody$deleteAppsV1NamespacedControllerRevision["*/*"];
}
export declare type RequestContentType$patchAppsV1NamespacedControllerRevision = keyof RequestBody$patchAppsV1NamespacedControllerRevision;
export declare type ResponseContentType$patchAppsV1NamespacedControllerRevision = keyof Response$patchAppsV1NamespacedControllerRevision$Status$200 | keyof Response$patchAppsV1NamespacedControllerRevision$Status$201;
export interface Params$patchAppsV1NamespacedControllerRevision<T extends RequestContentType$patchAppsV1NamespacedControllerRevision, U extends ResponseContentType$patchAppsV1NamespacedControllerRevision> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedControllerRevision;
    requestBody: RequestBody$patchAppsV1NamespacedControllerRevision[T];
}
export declare type ResponseContentType$listAppsV1NamespacedDaemonSet = keyof Response$listAppsV1NamespacedDaemonSet$Status$200;
export interface Params$listAppsV1NamespacedDaemonSet<U extends ResponseContentType$listAppsV1NamespacedDaemonSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAppsV1NamespacedDaemonSet;
}
export declare type RequestContentType$createAppsV1NamespacedDaemonSet = keyof RequestBody$createAppsV1NamespacedDaemonSet;
export declare type ResponseContentType$createAppsV1NamespacedDaemonSet = keyof Response$createAppsV1NamespacedDaemonSet$Status$200 | keyof Response$createAppsV1NamespacedDaemonSet$Status$201 | keyof Response$createAppsV1NamespacedDaemonSet$Status$202;
export interface Params$createAppsV1NamespacedDaemonSet<U extends ResponseContentType$createAppsV1NamespacedDaemonSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAppsV1NamespacedDaemonSet;
    requestBody: RequestBody$createAppsV1NamespacedDaemonSet["*/*"];
}
export declare type RequestContentType$deleteAppsV1CollectionNamespacedDaemonSet = keyof RequestBody$deleteAppsV1CollectionNamespacedDaemonSet;
export declare type ResponseContentType$deleteAppsV1CollectionNamespacedDaemonSet = keyof Response$deleteAppsV1CollectionNamespacedDaemonSet$Status$200;
export interface Params$deleteAppsV1CollectionNamespacedDaemonSet<U extends ResponseContentType$deleteAppsV1CollectionNamespacedDaemonSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAppsV1CollectionNamespacedDaemonSet;
    requestBody: RequestBody$deleteAppsV1CollectionNamespacedDaemonSet["*/*"];
}
export declare type ResponseContentType$readAppsV1NamespacedDaemonSet = keyof Response$readAppsV1NamespacedDaemonSet$Status$200;
export interface Params$readAppsV1NamespacedDaemonSet<U extends ResponseContentType$readAppsV1NamespacedDaemonSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedDaemonSet;
}
export declare type RequestContentType$replaceAppsV1NamespacedDaemonSet = keyof RequestBody$replaceAppsV1NamespacedDaemonSet;
export declare type ResponseContentType$replaceAppsV1NamespacedDaemonSet = keyof Response$replaceAppsV1NamespacedDaemonSet$Status$200 | keyof Response$replaceAppsV1NamespacedDaemonSet$Status$201;
export interface Params$replaceAppsV1NamespacedDaemonSet<U extends ResponseContentType$replaceAppsV1NamespacedDaemonSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedDaemonSet;
    requestBody: RequestBody$replaceAppsV1NamespacedDaemonSet["*/*"];
}
export declare type RequestContentType$deleteAppsV1NamespacedDaemonSet = keyof RequestBody$deleteAppsV1NamespacedDaemonSet;
export declare type ResponseContentType$deleteAppsV1NamespacedDaemonSet = keyof Response$deleteAppsV1NamespacedDaemonSet$Status$200 | keyof Response$deleteAppsV1NamespacedDaemonSet$Status$202;
export interface Params$deleteAppsV1NamespacedDaemonSet<U extends ResponseContentType$deleteAppsV1NamespacedDaemonSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAppsV1NamespacedDaemonSet;
    requestBody: RequestBody$deleteAppsV1NamespacedDaemonSet["*/*"];
}
export declare type RequestContentType$patchAppsV1NamespacedDaemonSet = keyof RequestBody$patchAppsV1NamespacedDaemonSet;
export declare type ResponseContentType$patchAppsV1NamespacedDaemonSet = keyof Response$patchAppsV1NamespacedDaemonSet$Status$200 | keyof Response$patchAppsV1NamespacedDaemonSet$Status$201;
export interface Params$patchAppsV1NamespacedDaemonSet<T extends RequestContentType$patchAppsV1NamespacedDaemonSet, U extends ResponseContentType$patchAppsV1NamespacedDaemonSet> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedDaemonSet;
    requestBody: RequestBody$patchAppsV1NamespacedDaemonSet[T];
}
export declare type ResponseContentType$readAppsV1NamespacedDaemonSetStatus = keyof Response$readAppsV1NamespacedDaemonSetStatus$Status$200;
export interface Params$readAppsV1NamespacedDaemonSetStatus<U extends ResponseContentType$readAppsV1NamespacedDaemonSetStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedDaemonSetStatus;
}
export declare type RequestContentType$replaceAppsV1NamespacedDaemonSetStatus = keyof RequestBody$replaceAppsV1NamespacedDaemonSetStatus;
export declare type ResponseContentType$replaceAppsV1NamespacedDaemonSetStatus = keyof Response$replaceAppsV1NamespacedDaemonSetStatus$Status$200 | keyof Response$replaceAppsV1NamespacedDaemonSetStatus$Status$201;
export interface Params$replaceAppsV1NamespacedDaemonSetStatus<U extends ResponseContentType$replaceAppsV1NamespacedDaemonSetStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedDaemonSetStatus;
    requestBody: RequestBody$replaceAppsV1NamespacedDaemonSetStatus["*/*"];
}
export declare type RequestContentType$patchAppsV1NamespacedDaemonSetStatus = keyof RequestBody$patchAppsV1NamespacedDaemonSetStatus;
export declare type ResponseContentType$patchAppsV1NamespacedDaemonSetStatus = keyof Response$patchAppsV1NamespacedDaemonSetStatus$Status$200 | keyof Response$patchAppsV1NamespacedDaemonSetStatus$Status$201;
export interface Params$patchAppsV1NamespacedDaemonSetStatus<T extends RequestContentType$patchAppsV1NamespacedDaemonSetStatus, U extends ResponseContentType$patchAppsV1NamespacedDaemonSetStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedDaemonSetStatus;
    requestBody: RequestBody$patchAppsV1NamespacedDaemonSetStatus[T];
}
export declare type ResponseContentType$listAppsV1NamespacedDeployment = keyof Response$listAppsV1NamespacedDeployment$Status$200;
export interface Params$listAppsV1NamespacedDeployment<U extends ResponseContentType$listAppsV1NamespacedDeployment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAppsV1NamespacedDeployment;
}
export declare type RequestContentType$createAppsV1NamespacedDeployment = keyof RequestBody$createAppsV1NamespacedDeployment;
export declare type ResponseContentType$createAppsV1NamespacedDeployment = keyof Response$createAppsV1NamespacedDeployment$Status$200 | keyof Response$createAppsV1NamespacedDeployment$Status$201 | keyof Response$createAppsV1NamespacedDeployment$Status$202;
export interface Params$createAppsV1NamespacedDeployment<U extends ResponseContentType$createAppsV1NamespacedDeployment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAppsV1NamespacedDeployment;
    requestBody: RequestBody$createAppsV1NamespacedDeployment["*/*"];
}
export declare type RequestContentType$deleteAppsV1CollectionNamespacedDeployment = keyof RequestBody$deleteAppsV1CollectionNamespacedDeployment;
export declare type ResponseContentType$deleteAppsV1CollectionNamespacedDeployment = keyof Response$deleteAppsV1CollectionNamespacedDeployment$Status$200;
export interface Params$deleteAppsV1CollectionNamespacedDeployment<U extends ResponseContentType$deleteAppsV1CollectionNamespacedDeployment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAppsV1CollectionNamespacedDeployment;
    requestBody: RequestBody$deleteAppsV1CollectionNamespacedDeployment["*/*"];
}
export declare type ResponseContentType$readAppsV1NamespacedDeployment = keyof Response$readAppsV1NamespacedDeployment$Status$200;
export interface Params$readAppsV1NamespacedDeployment<U extends ResponseContentType$readAppsV1NamespacedDeployment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedDeployment;
}
export declare type RequestContentType$replaceAppsV1NamespacedDeployment = keyof RequestBody$replaceAppsV1NamespacedDeployment;
export declare type ResponseContentType$replaceAppsV1NamespacedDeployment = keyof Response$replaceAppsV1NamespacedDeployment$Status$200 | keyof Response$replaceAppsV1NamespacedDeployment$Status$201;
export interface Params$replaceAppsV1NamespacedDeployment<U extends ResponseContentType$replaceAppsV1NamespacedDeployment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedDeployment;
    requestBody: RequestBody$replaceAppsV1NamespacedDeployment["*/*"];
}
export declare type RequestContentType$deleteAppsV1NamespacedDeployment = keyof RequestBody$deleteAppsV1NamespacedDeployment;
export declare type ResponseContentType$deleteAppsV1NamespacedDeployment = keyof Response$deleteAppsV1NamespacedDeployment$Status$200 | keyof Response$deleteAppsV1NamespacedDeployment$Status$202;
export interface Params$deleteAppsV1NamespacedDeployment<U extends ResponseContentType$deleteAppsV1NamespacedDeployment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAppsV1NamespacedDeployment;
    requestBody: RequestBody$deleteAppsV1NamespacedDeployment["*/*"];
}
export declare type RequestContentType$patchAppsV1NamespacedDeployment = keyof RequestBody$patchAppsV1NamespacedDeployment;
export declare type ResponseContentType$patchAppsV1NamespacedDeployment = keyof Response$patchAppsV1NamespacedDeployment$Status$200 | keyof Response$patchAppsV1NamespacedDeployment$Status$201;
export interface Params$patchAppsV1NamespacedDeployment<T extends RequestContentType$patchAppsV1NamespacedDeployment, U extends ResponseContentType$patchAppsV1NamespacedDeployment> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedDeployment;
    requestBody: RequestBody$patchAppsV1NamespacedDeployment[T];
}
export declare type ResponseContentType$readAppsV1NamespacedDeploymentScale = keyof Response$readAppsV1NamespacedDeploymentScale$Status$200;
export interface Params$readAppsV1NamespacedDeploymentScale<U extends ResponseContentType$readAppsV1NamespacedDeploymentScale> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedDeploymentScale;
}
export declare type RequestContentType$replaceAppsV1NamespacedDeploymentScale = keyof RequestBody$replaceAppsV1NamespacedDeploymentScale;
export declare type ResponseContentType$replaceAppsV1NamespacedDeploymentScale = keyof Response$replaceAppsV1NamespacedDeploymentScale$Status$200 | keyof Response$replaceAppsV1NamespacedDeploymentScale$Status$201;
export interface Params$replaceAppsV1NamespacedDeploymentScale<U extends ResponseContentType$replaceAppsV1NamespacedDeploymentScale> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedDeploymentScale;
    requestBody: RequestBody$replaceAppsV1NamespacedDeploymentScale["*/*"];
}
export declare type RequestContentType$patchAppsV1NamespacedDeploymentScale = keyof RequestBody$patchAppsV1NamespacedDeploymentScale;
export declare type ResponseContentType$patchAppsV1NamespacedDeploymentScale = keyof Response$patchAppsV1NamespacedDeploymentScale$Status$200 | keyof Response$patchAppsV1NamespacedDeploymentScale$Status$201;
export interface Params$patchAppsV1NamespacedDeploymentScale<T extends RequestContentType$patchAppsV1NamespacedDeploymentScale, U extends ResponseContentType$patchAppsV1NamespacedDeploymentScale> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedDeploymentScale;
    requestBody: RequestBody$patchAppsV1NamespacedDeploymentScale[T];
}
export declare type ResponseContentType$readAppsV1NamespacedDeploymentStatus = keyof Response$readAppsV1NamespacedDeploymentStatus$Status$200;
export interface Params$readAppsV1NamespacedDeploymentStatus<U extends ResponseContentType$readAppsV1NamespacedDeploymentStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedDeploymentStatus;
}
export declare type RequestContentType$replaceAppsV1NamespacedDeploymentStatus = keyof RequestBody$replaceAppsV1NamespacedDeploymentStatus;
export declare type ResponseContentType$replaceAppsV1NamespacedDeploymentStatus = keyof Response$replaceAppsV1NamespacedDeploymentStatus$Status$200 | keyof Response$replaceAppsV1NamespacedDeploymentStatus$Status$201;
export interface Params$replaceAppsV1NamespacedDeploymentStatus<U extends ResponseContentType$replaceAppsV1NamespacedDeploymentStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedDeploymentStatus;
    requestBody: RequestBody$replaceAppsV1NamespacedDeploymentStatus["*/*"];
}
export declare type RequestContentType$patchAppsV1NamespacedDeploymentStatus = keyof RequestBody$patchAppsV1NamespacedDeploymentStatus;
export declare type ResponseContentType$patchAppsV1NamespacedDeploymentStatus = keyof Response$patchAppsV1NamespacedDeploymentStatus$Status$200 | keyof Response$patchAppsV1NamespacedDeploymentStatus$Status$201;
export interface Params$patchAppsV1NamespacedDeploymentStatus<T extends RequestContentType$patchAppsV1NamespacedDeploymentStatus, U extends ResponseContentType$patchAppsV1NamespacedDeploymentStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedDeploymentStatus;
    requestBody: RequestBody$patchAppsV1NamespacedDeploymentStatus[T];
}
export declare type ResponseContentType$listAppsV1NamespacedReplicaSet = keyof Response$listAppsV1NamespacedReplicaSet$Status$200;
export interface Params$listAppsV1NamespacedReplicaSet<U extends ResponseContentType$listAppsV1NamespacedReplicaSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAppsV1NamespacedReplicaSet;
}
export declare type RequestContentType$createAppsV1NamespacedReplicaSet = keyof RequestBody$createAppsV1NamespacedReplicaSet;
export declare type ResponseContentType$createAppsV1NamespacedReplicaSet = keyof Response$createAppsV1NamespacedReplicaSet$Status$200 | keyof Response$createAppsV1NamespacedReplicaSet$Status$201 | keyof Response$createAppsV1NamespacedReplicaSet$Status$202;
export interface Params$createAppsV1NamespacedReplicaSet<U extends ResponseContentType$createAppsV1NamespacedReplicaSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAppsV1NamespacedReplicaSet;
    requestBody: RequestBody$createAppsV1NamespacedReplicaSet["*/*"];
}
export declare type RequestContentType$deleteAppsV1CollectionNamespacedReplicaSet = keyof RequestBody$deleteAppsV1CollectionNamespacedReplicaSet;
export declare type ResponseContentType$deleteAppsV1CollectionNamespacedReplicaSet = keyof Response$deleteAppsV1CollectionNamespacedReplicaSet$Status$200;
export interface Params$deleteAppsV1CollectionNamespacedReplicaSet<U extends ResponseContentType$deleteAppsV1CollectionNamespacedReplicaSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAppsV1CollectionNamespacedReplicaSet;
    requestBody: RequestBody$deleteAppsV1CollectionNamespacedReplicaSet["*/*"];
}
export declare type ResponseContentType$readAppsV1NamespacedReplicaSet = keyof Response$readAppsV1NamespacedReplicaSet$Status$200;
export interface Params$readAppsV1NamespacedReplicaSet<U extends ResponseContentType$readAppsV1NamespacedReplicaSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedReplicaSet;
}
export declare type RequestContentType$replaceAppsV1NamespacedReplicaSet = keyof RequestBody$replaceAppsV1NamespacedReplicaSet;
export declare type ResponseContentType$replaceAppsV1NamespacedReplicaSet = keyof Response$replaceAppsV1NamespacedReplicaSet$Status$200 | keyof Response$replaceAppsV1NamespacedReplicaSet$Status$201;
export interface Params$replaceAppsV1NamespacedReplicaSet<U extends ResponseContentType$replaceAppsV1NamespacedReplicaSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedReplicaSet;
    requestBody: RequestBody$replaceAppsV1NamespacedReplicaSet["*/*"];
}
export declare type RequestContentType$deleteAppsV1NamespacedReplicaSet = keyof RequestBody$deleteAppsV1NamespacedReplicaSet;
export declare type ResponseContentType$deleteAppsV1NamespacedReplicaSet = keyof Response$deleteAppsV1NamespacedReplicaSet$Status$200 | keyof Response$deleteAppsV1NamespacedReplicaSet$Status$202;
export interface Params$deleteAppsV1NamespacedReplicaSet<U extends ResponseContentType$deleteAppsV1NamespacedReplicaSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAppsV1NamespacedReplicaSet;
    requestBody: RequestBody$deleteAppsV1NamespacedReplicaSet["*/*"];
}
export declare type RequestContentType$patchAppsV1NamespacedReplicaSet = keyof RequestBody$patchAppsV1NamespacedReplicaSet;
export declare type ResponseContentType$patchAppsV1NamespacedReplicaSet = keyof Response$patchAppsV1NamespacedReplicaSet$Status$200 | keyof Response$patchAppsV1NamespacedReplicaSet$Status$201;
export interface Params$patchAppsV1NamespacedReplicaSet<T extends RequestContentType$patchAppsV1NamespacedReplicaSet, U extends ResponseContentType$patchAppsV1NamespacedReplicaSet> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedReplicaSet;
    requestBody: RequestBody$patchAppsV1NamespacedReplicaSet[T];
}
export declare type ResponseContentType$readAppsV1NamespacedReplicaSetScale = keyof Response$readAppsV1NamespacedReplicaSetScale$Status$200;
export interface Params$readAppsV1NamespacedReplicaSetScale<U extends ResponseContentType$readAppsV1NamespacedReplicaSetScale> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedReplicaSetScale;
}
export declare type RequestContentType$replaceAppsV1NamespacedReplicaSetScale = keyof RequestBody$replaceAppsV1NamespacedReplicaSetScale;
export declare type ResponseContentType$replaceAppsV1NamespacedReplicaSetScale = keyof Response$replaceAppsV1NamespacedReplicaSetScale$Status$200 | keyof Response$replaceAppsV1NamespacedReplicaSetScale$Status$201;
export interface Params$replaceAppsV1NamespacedReplicaSetScale<U extends ResponseContentType$replaceAppsV1NamespacedReplicaSetScale> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedReplicaSetScale;
    requestBody: RequestBody$replaceAppsV1NamespacedReplicaSetScale["*/*"];
}
export declare type RequestContentType$patchAppsV1NamespacedReplicaSetScale = keyof RequestBody$patchAppsV1NamespacedReplicaSetScale;
export declare type ResponseContentType$patchAppsV1NamespacedReplicaSetScale = keyof Response$patchAppsV1NamespacedReplicaSetScale$Status$200 | keyof Response$patchAppsV1NamespacedReplicaSetScale$Status$201;
export interface Params$patchAppsV1NamespacedReplicaSetScale<T extends RequestContentType$patchAppsV1NamespacedReplicaSetScale, U extends ResponseContentType$patchAppsV1NamespacedReplicaSetScale> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedReplicaSetScale;
    requestBody: RequestBody$patchAppsV1NamespacedReplicaSetScale[T];
}
export declare type ResponseContentType$readAppsV1NamespacedReplicaSetStatus = keyof Response$readAppsV1NamespacedReplicaSetStatus$Status$200;
export interface Params$readAppsV1NamespacedReplicaSetStatus<U extends ResponseContentType$readAppsV1NamespacedReplicaSetStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedReplicaSetStatus;
}
export declare type RequestContentType$replaceAppsV1NamespacedReplicaSetStatus = keyof RequestBody$replaceAppsV1NamespacedReplicaSetStatus;
export declare type ResponseContentType$replaceAppsV1NamespacedReplicaSetStatus = keyof Response$replaceAppsV1NamespacedReplicaSetStatus$Status$200 | keyof Response$replaceAppsV1NamespacedReplicaSetStatus$Status$201;
export interface Params$replaceAppsV1NamespacedReplicaSetStatus<U extends ResponseContentType$replaceAppsV1NamespacedReplicaSetStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedReplicaSetStatus;
    requestBody: RequestBody$replaceAppsV1NamespacedReplicaSetStatus["*/*"];
}
export declare type RequestContentType$patchAppsV1NamespacedReplicaSetStatus = keyof RequestBody$patchAppsV1NamespacedReplicaSetStatus;
export declare type ResponseContentType$patchAppsV1NamespacedReplicaSetStatus = keyof Response$patchAppsV1NamespacedReplicaSetStatus$Status$200 | keyof Response$patchAppsV1NamespacedReplicaSetStatus$Status$201;
export interface Params$patchAppsV1NamespacedReplicaSetStatus<T extends RequestContentType$patchAppsV1NamespacedReplicaSetStatus, U extends ResponseContentType$patchAppsV1NamespacedReplicaSetStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedReplicaSetStatus;
    requestBody: RequestBody$patchAppsV1NamespacedReplicaSetStatus[T];
}
export declare type ResponseContentType$listAppsV1NamespacedStatefulSet = keyof Response$listAppsV1NamespacedStatefulSet$Status$200;
export interface Params$listAppsV1NamespacedStatefulSet<U extends ResponseContentType$listAppsV1NamespacedStatefulSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAppsV1NamespacedStatefulSet;
}
export declare type RequestContentType$createAppsV1NamespacedStatefulSet = keyof RequestBody$createAppsV1NamespacedStatefulSet;
export declare type ResponseContentType$createAppsV1NamespacedStatefulSet = keyof Response$createAppsV1NamespacedStatefulSet$Status$200 | keyof Response$createAppsV1NamespacedStatefulSet$Status$201 | keyof Response$createAppsV1NamespacedStatefulSet$Status$202;
export interface Params$createAppsV1NamespacedStatefulSet<U extends ResponseContentType$createAppsV1NamespacedStatefulSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAppsV1NamespacedStatefulSet;
    requestBody: RequestBody$createAppsV1NamespacedStatefulSet["*/*"];
}
export declare type RequestContentType$deleteAppsV1CollectionNamespacedStatefulSet = keyof RequestBody$deleteAppsV1CollectionNamespacedStatefulSet;
export declare type ResponseContentType$deleteAppsV1CollectionNamespacedStatefulSet = keyof Response$deleteAppsV1CollectionNamespacedStatefulSet$Status$200;
export interface Params$deleteAppsV1CollectionNamespacedStatefulSet<U extends ResponseContentType$deleteAppsV1CollectionNamespacedStatefulSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAppsV1CollectionNamespacedStatefulSet;
    requestBody: RequestBody$deleteAppsV1CollectionNamespacedStatefulSet["*/*"];
}
export declare type ResponseContentType$readAppsV1NamespacedStatefulSet = keyof Response$readAppsV1NamespacedStatefulSet$Status$200;
export interface Params$readAppsV1NamespacedStatefulSet<U extends ResponseContentType$readAppsV1NamespacedStatefulSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedStatefulSet;
}
export declare type RequestContentType$replaceAppsV1NamespacedStatefulSet = keyof RequestBody$replaceAppsV1NamespacedStatefulSet;
export declare type ResponseContentType$replaceAppsV1NamespacedStatefulSet = keyof Response$replaceAppsV1NamespacedStatefulSet$Status$200 | keyof Response$replaceAppsV1NamespacedStatefulSet$Status$201;
export interface Params$replaceAppsV1NamespacedStatefulSet<U extends ResponseContentType$replaceAppsV1NamespacedStatefulSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedStatefulSet;
    requestBody: RequestBody$replaceAppsV1NamespacedStatefulSet["*/*"];
}
export declare type RequestContentType$deleteAppsV1NamespacedStatefulSet = keyof RequestBody$deleteAppsV1NamespacedStatefulSet;
export declare type ResponseContentType$deleteAppsV1NamespacedStatefulSet = keyof Response$deleteAppsV1NamespacedStatefulSet$Status$200 | keyof Response$deleteAppsV1NamespacedStatefulSet$Status$202;
export interface Params$deleteAppsV1NamespacedStatefulSet<U extends ResponseContentType$deleteAppsV1NamespacedStatefulSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAppsV1NamespacedStatefulSet;
    requestBody: RequestBody$deleteAppsV1NamespacedStatefulSet["*/*"];
}
export declare type RequestContentType$patchAppsV1NamespacedStatefulSet = keyof RequestBody$patchAppsV1NamespacedStatefulSet;
export declare type ResponseContentType$patchAppsV1NamespacedStatefulSet = keyof Response$patchAppsV1NamespacedStatefulSet$Status$200 | keyof Response$patchAppsV1NamespacedStatefulSet$Status$201;
export interface Params$patchAppsV1NamespacedStatefulSet<T extends RequestContentType$patchAppsV1NamespacedStatefulSet, U extends ResponseContentType$patchAppsV1NamespacedStatefulSet> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedStatefulSet;
    requestBody: RequestBody$patchAppsV1NamespacedStatefulSet[T];
}
export declare type ResponseContentType$readAppsV1NamespacedStatefulSetScale = keyof Response$readAppsV1NamespacedStatefulSetScale$Status$200;
export interface Params$readAppsV1NamespacedStatefulSetScale<U extends ResponseContentType$readAppsV1NamespacedStatefulSetScale> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedStatefulSetScale;
}
export declare type RequestContentType$replaceAppsV1NamespacedStatefulSetScale = keyof RequestBody$replaceAppsV1NamespacedStatefulSetScale;
export declare type ResponseContentType$replaceAppsV1NamespacedStatefulSetScale = keyof Response$replaceAppsV1NamespacedStatefulSetScale$Status$200 | keyof Response$replaceAppsV1NamespacedStatefulSetScale$Status$201;
export interface Params$replaceAppsV1NamespacedStatefulSetScale<U extends ResponseContentType$replaceAppsV1NamespacedStatefulSetScale> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedStatefulSetScale;
    requestBody: RequestBody$replaceAppsV1NamespacedStatefulSetScale["*/*"];
}
export declare type RequestContentType$patchAppsV1NamespacedStatefulSetScale = keyof RequestBody$patchAppsV1NamespacedStatefulSetScale;
export declare type ResponseContentType$patchAppsV1NamespacedStatefulSetScale = keyof Response$patchAppsV1NamespacedStatefulSetScale$Status$200 | keyof Response$patchAppsV1NamespacedStatefulSetScale$Status$201;
export interface Params$patchAppsV1NamespacedStatefulSetScale<T extends RequestContentType$patchAppsV1NamespacedStatefulSetScale, U extends ResponseContentType$patchAppsV1NamespacedStatefulSetScale> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedStatefulSetScale;
    requestBody: RequestBody$patchAppsV1NamespacedStatefulSetScale[T];
}
export declare type ResponseContentType$readAppsV1NamespacedStatefulSetStatus = keyof Response$readAppsV1NamespacedStatefulSetStatus$Status$200;
export interface Params$readAppsV1NamespacedStatefulSetStatus<U extends ResponseContentType$readAppsV1NamespacedStatefulSetStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedStatefulSetStatus;
}
export declare type RequestContentType$replaceAppsV1NamespacedStatefulSetStatus = keyof RequestBody$replaceAppsV1NamespacedStatefulSetStatus;
export declare type ResponseContentType$replaceAppsV1NamespacedStatefulSetStatus = keyof Response$replaceAppsV1NamespacedStatefulSetStatus$Status$200 | keyof Response$replaceAppsV1NamespacedStatefulSetStatus$Status$201;
export interface Params$replaceAppsV1NamespacedStatefulSetStatus<U extends ResponseContentType$replaceAppsV1NamespacedStatefulSetStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedStatefulSetStatus;
    requestBody: RequestBody$replaceAppsV1NamespacedStatefulSetStatus["*/*"];
}
export declare type RequestContentType$patchAppsV1NamespacedStatefulSetStatus = keyof RequestBody$patchAppsV1NamespacedStatefulSetStatus;
export declare type ResponseContentType$patchAppsV1NamespacedStatefulSetStatus = keyof Response$patchAppsV1NamespacedStatefulSetStatus$Status$200 | keyof Response$patchAppsV1NamespacedStatefulSetStatus$Status$201;
export interface Params$patchAppsV1NamespacedStatefulSetStatus<T extends RequestContentType$patchAppsV1NamespacedStatefulSetStatus, U extends ResponseContentType$patchAppsV1NamespacedStatefulSetStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedStatefulSetStatus;
    requestBody: RequestBody$patchAppsV1NamespacedStatefulSetStatus[T];
}
export declare type ResponseContentType$listAppsV1ReplicaSetForAllNamespaces = keyof Response$listAppsV1ReplicaSetForAllNamespaces$Status$200;
export interface Params$listAppsV1ReplicaSetForAllNamespaces<U extends ResponseContentType$listAppsV1ReplicaSetForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAppsV1ReplicaSetForAllNamespaces;
}
export declare type ResponseContentType$listAppsV1StatefulSetForAllNamespaces = keyof Response$listAppsV1StatefulSetForAllNamespaces$Status$200;
export interface Params$listAppsV1StatefulSetForAllNamespaces<U extends ResponseContentType$listAppsV1StatefulSetForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAppsV1StatefulSetForAllNamespaces;
}
export declare type ResponseContentType$watchAppsV1ControllerRevisionListForAllNamespaces = keyof Response$watchAppsV1ControllerRevisionListForAllNamespaces$Status$200;
export interface Params$watchAppsV1ControllerRevisionListForAllNamespaces<U extends ResponseContentType$watchAppsV1ControllerRevisionListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1ControllerRevisionListForAllNamespaces;
}
export declare type ResponseContentType$watchAppsV1DaemonSetListForAllNamespaces = keyof Response$watchAppsV1DaemonSetListForAllNamespaces$Status$200;
export interface Params$watchAppsV1DaemonSetListForAllNamespaces<U extends ResponseContentType$watchAppsV1DaemonSetListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1DaemonSetListForAllNamespaces;
}
export declare type ResponseContentType$watchAppsV1DeploymentListForAllNamespaces = keyof Response$watchAppsV1DeploymentListForAllNamespaces$Status$200;
export interface Params$watchAppsV1DeploymentListForAllNamespaces<U extends ResponseContentType$watchAppsV1DeploymentListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1DeploymentListForAllNamespaces;
}
export declare type ResponseContentType$watchAppsV1NamespacedControllerRevisionList = keyof Response$watchAppsV1NamespacedControllerRevisionList$Status$200;
export interface Params$watchAppsV1NamespacedControllerRevisionList<U extends ResponseContentType$watchAppsV1NamespacedControllerRevisionList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1NamespacedControllerRevisionList;
}
export declare type ResponseContentType$watchAppsV1NamespacedControllerRevision = keyof Response$watchAppsV1NamespacedControllerRevision$Status$200;
export interface Params$watchAppsV1NamespacedControllerRevision<U extends ResponseContentType$watchAppsV1NamespacedControllerRevision> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1NamespacedControllerRevision;
}
export declare type ResponseContentType$watchAppsV1NamespacedDaemonSetList = keyof Response$watchAppsV1NamespacedDaemonSetList$Status$200;
export interface Params$watchAppsV1NamespacedDaemonSetList<U extends ResponseContentType$watchAppsV1NamespacedDaemonSetList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1NamespacedDaemonSetList;
}
export declare type ResponseContentType$watchAppsV1NamespacedDaemonSet = keyof Response$watchAppsV1NamespacedDaemonSet$Status$200;
export interface Params$watchAppsV1NamespacedDaemonSet<U extends ResponseContentType$watchAppsV1NamespacedDaemonSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1NamespacedDaemonSet;
}
export declare type ResponseContentType$watchAppsV1NamespacedDeploymentList = keyof Response$watchAppsV1NamespacedDeploymentList$Status$200;
export interface Params$watchAppsV1NamespacedDeploymentList<U extends ResponseContentType$watchAppsV1NamespacedDeploymentList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1NamespacedDeploymentList;
}
export declare type ResponseContentType$watchAppsV1NamespacedDeployment = keyof Response$watchAppsV1NamespacedDeployment$Status$200;
export interface Params$watchAppsV1NamespacedDeployment<U extends ResponseContentType$watchAppsV1NamespacedDeployment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1NamespacedDeployment;
}
export declare type ResponseContentType$watchAppsV1NamespacedReplicaSetList = keyof Response$watchAppsV1NamespacedReplicaSetList$Status$200;
export interface Params$watchAppsV1NamespacedReplicaSetList<U extends ResponseContentType$watchAppsV1NamespacedReplicaSetList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1NamespacedReplicaSetList;
}
export declare type ResponseContentType$watchAppsV1NamespacedReplicaSet = keyof Response$watchAppsV1NamespacedReplicaSet$Status$200;
export interface Params$watchAppsV1NamespacedReplicaSet<U extends ResponseContentType$watchAppsV1NamespacedReplicaSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1NamespacedReplicaSet;
}
export declare type ResponseContentType$watchAppsV1NamespacedStatefulSetList = keyof Response$watchAppsV1NamespacedStatefulSetList$Status$200;
export interface Params$watchAppsV1NamespacedStatefulSetList<U extends ResponseContentType$watchAppsV1NamespacedStatefulSetList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1NamespacedStatefulSetList;
}
export declare type ResponseContentType$watchAppsV1NamespacedStatefulSet = keyof Response$watchAppsV1NamespacedStatefulSet$Status$200;
export interface Params$watchAppsV1NamespacedStatefulSet<U extends ResponseContentType$watchAppsV1NamespacedStatefulSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1NamespacedStatefulSet;
}
export declare type ResponseContentType$watchAppsV1ReplicaSetListForAllNamespaces = keyof Response$watchAppsV1ReplicaSetListForAllNamespaces$Status$200;
export interface Params$watchAppsV1ReplicaSetListForAllNamespaces<U extends ResponseContentType$watchAppsV1ReplicaSetListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1ReplicaSetListForAllNamespaces;
}
export declare type ResponseContentType$watchAppsV1StatefulSetListForAllNamespaces = keyof Response$watchAppsV1StatefulSetListForAllNamespaces$Status$200;
export interface Params$watchAppsV1StatefulSetListForAllNamespaces<U extends ResponseContentType$watchAppsV1StatefulSetListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1StatefulSetListForAllNamespaces;
}
export declare type ResponseContentType$getAuthenticationAPIGroup = keyof Response$getAuthenticationAPIGroup$Status$200;
export interface Params$getAuthenticationAPIGroup<U extends ResponseContentType$getAuthenticationAPIGroup> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$getAuthenticationV1APIResources = keyof Response$getAuthenticationV1APIResources$Status$200;
export interface Params$getAuthenticationV1APIResources<U extends ResponseContentType$getAuthenticationV1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type RequestContentType$createAuthenticationV1TokenReview = keyof RequestBody$createAuthenticationV1TokenReview;
export declare type ResponseContentType$createAuthenticationV1TokenReview = keyof Response$createAuthenticationV1TokenReview$Status$200 | keyof Response$createAuthenticationV1TokenReview$Status$201 | keyof Response$createAuthenticationV1TokenReview$Status$202;
export interface Params$createAuthenticationV1TokenReview<U extends ResponseContentType$createAuthenticationV1TokenReview> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAuthenticationV1TokenReview;
    requestBody: RequestBody$createAuthenticationV1TokenReview["*/*"];
}
export declare type ResponseContentType$getAuthorizationAPIGroup = keyof Response$getAuthorizationAPIGroup$Status$200;
export interface Params$getAuthorizationAPIGroup<U extends ResponseContentType$getAuthorizationAPIGroup> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$getAuthorizationV1APIResources = keyof Response$getAuthorizationV1APIResources$Status$200;
export interface Params$getAuthorizationV1APIResources<U extends ResponseContentType$getAuthorizationV1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type RequestContentType$createAuthorizationV1NamespacedLocalSubjectAccessReview = keyof RequestBody$createAuthorizationV1NamespacedLocalSubjectAccessReview;
export declare type ResponseContentType$createAuthorizationV1NamespacedLocalSubjectAccessReview = keyof Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$200 | keyof Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$201 | keyof Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$202;
export interface Params$createAuthorizationV1NamespacedLocalSubjectAccessReview<U extends ResponseContentType$createAuthorizationV1NamespacedLocalSubjectAccessReview> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAuthorizationV1NamespacedLocalSubjectAccessReview;
    requestBody: RequestBody$createAuthorizationV1NamespacedLocalSubjectAccessReview["*/*"];
}
export declare type RequestContentType$createAuthorizationV1SelfSubjectAccessReview = keyof RequestBody$createAuthorizationV1SelfSubjectAccessReview;
export declare type ResponseContentType$createAuthorizationV1SelfSubjectAccessReview = keyof Response$createAuthorizationV1SelfSubjectAccessReview$Status$200 | keyof Response$createAuthorizationV1SelfSubjectAccessReview$Status$201 | keyof Response$createAuthorizationV1SelfSubjectAccessReview$Status$202;
export interface Params$createAuthorizationV1SelfSubjectAccessReview<U extends ResponseContentType$createAuthorizationV1SelfSubjectAccessReview> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAuthorizationV1SelfSubjectAccessReview;
    requestBody: RequestBody$createAuthorizationV1SelfSubjectAccessReview["*/*"];
}
export declare type RequestContentType$createAuthorizationV1SelfSubjectRulesReview = keyof RequestBody$createAuthorizationV1SelfSubjectRulesReview;
export declare type ResponseContentType$createAuthorizationV1SelfSubjectRulesReview = keyof Response$createAuthorizationV1SelfSubjectRulesReview$Status$200 | keyof Response$createAuthorizationV1SelfSubjectRulesReview$Status$201 | keyof Response$createAuthorizationV1SelfSubjectRulesReview$Status$202;
export interface Params$createAuthorizationV1SelfSubjectRulesReview<U extends ResponseContentType$createAuthorizationV1SelfSubjectRulesReview> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAuthorizationV1SelfSubjectRulesReview;
    requestBody: RequestBody$createAuthorizationV1SelfSubjectRulesReview["*/*"];
}
export declare type RequestContentType$createAuthorizationV1SubjectAccessReview = keyof RequestBody$createAuthorizationV1SubjectAccessReview;
export declare type ResponseContentType$createAuthorizationV1SubjectAccessReview = keyof Response$createAuthorizationV1SubjectAccessReview$Status$200 | keyof Response$createAuthorizationV1SubjectAccessReview$Status$201 | keyof Response$createAuthorizationV1SubjectAccessReview$Status$202;
export interface Params$createAuthorizationV1SubjectAccessReview<U extends ResponseContentType$createAuthorizationV1SubjectAccessReview> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAuthorizationV1SubjectAccessReview;
    requestBody: RequestBody$createAuthorizationV1SubjectAccessReview["*/*"];
}
export declare type ResponseContentType$getAutoscalingAPIGroup = keyof Response$getAutoscalingAPIGroup$Status$200;
export interface Params$getAutoscalingAPIGroup<U extends ResponseContentType$getAutoscalingAPIGroup> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$getAutoscalingV1APIResources = keyof Response$getAutoscalingV1APIResources$Status$200;
export interface Params$getAutoscalingV1APIResources<U extends ResponseContentType$getAutoscalingV1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces = keyof Response$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces$Status$200;
export interface Params$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces<U extends ResponseContentType$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces;
}
export declare type ResponseContentType$listAutoscalingV1NamespacedHorizontalPodAutoscaler = keyof Response$listAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200;
export interface Params$listAutoscalingV1NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$listAutoscalingV1NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAutoscalingV1NamespacedHorizontalPodAutoscaler;
}
export declare type RequestContentType$createAutoscalingV1NamespacedHorizontalPodAutoscaler = keyof RequestBody$createAutoscalingV1NamespacedHorizontalPodAutoscaler;
export declare type ResponseContentType$createAutoscalingV1NamespacedHorizontalPodAutoscaler = keyof Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201 | keyof Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$202;
export interface Params$createAutoscalingV1NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$createAutoscalingV1NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAutoscalingV1NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$createAutoscalingV1NamespacedHorizontalPodAutoscaler["*/*"];
}
export declare type RequestContentType$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler = keyof RequestBody$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler;
export declare type ResponseContentType$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler = keyof Response$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler$Status$200;
export interface Params$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler<U extends ResponseContentType$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler["*/*"];
}
export declare type ResponseContentType$readAutoscalingV1NamespacedHorizontalPodAutoscaler = keyof Response$readAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200;
export interface Params$readAutoscalingV1NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$readAutoscalingV1NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAutoscalingV1NamespacedHorizontalPodAutoscaler;
}
export declare type RequestContentType$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler = keyof RequestBody$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler;
export declare type ResponseContentType$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler = keyof Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201;
export interface Params$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler["*/*"];
}
export declare type RequestContentType$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler = keyof RequestBody$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler;
export declare type ResponseContentType$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler = keyof Response$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$202;
export interface Params$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler["*/*"];
}
export declare type RequestContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscaler = keyof RequestBody$patchAutoscalingV1NamespacedHorizontalPodAutoscaler;
export declare type ResponseContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscaler = keyof Response$patchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$patchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201;
export interface Params$patchAutoscalingV1NamespacedHorizontalPodAutoscaler<T extends RequestContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscaler, U extends ResponseContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscaler> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAutoscalingV1NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$patchAutoscalingV1NamespacedHorizontalPodAutoscaler[T];
}
export declare type ResponseContentType$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus = keyof Response$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200;
export interface Params$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus<U extends ResponseContentType$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus;
}
export declare type RequestContentType$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus = keyof RequestBody$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus;
export declare type ResponseContentType$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus = keyof Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200 | keyof Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$201;
export interface Params$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus<U extends ResponseContentType$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus;
    requestBody: RequestBody$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus["*/*"];
}
export declare type RequestContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus = keyof RequestBody$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus;
export declare type ResponseContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus = keyof Response$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200 | keyof Response$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$201;
export interface Params$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus<T extends RequestContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus, U extends ResponseContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus;
    requestBody: RequestBody$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus[T];
}
export declare type ResponseContentType$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces = keyof Response$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces$Status$200;
export interface Params$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces<U extends ResponseContentType$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces;
}
export declare type ResponseContentType$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList = keyof Response$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList$Status$200;
export interface Params$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList<U extends ResponseContentType$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList;
}
export declare type ResponseContentType$watchAutoscalingV1NamespacedHorizontalPodAutoscaler = keyof Response$watchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200;
export interface Params$watchAutoscalingV1NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$watchAutoscalingV1NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAutoscalingV1NamespacedHorizontalPodAutoscaler;
}
export declare type ResponseContentType$getAutoscalingV2APIResources = keyof Response$getAutoscalingV2APIResources$Status$200;
export interface Params$getAutoscalingV2APIResources<U extends ResponseContentType$getAutoscalingV2APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces = keyof Response$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces$Status$200;
export interface Params$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces<U extends ResponseContentType$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces;
}
export declare type ResponseContentType$listAutoscalingV2NamespacedHorizontalPodAutoscaler = keyof Response$listAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200;
export interface Params$listAutoscalingV2NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$listAutoscalingV2NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAutoscalingV2NamespacedHorizontalPodAutoscaler;
}
export declare type RequestContentType$createAutoscalingV2NamespacedHorizontalPodAutoscaler = keyof RequestBody$createAutoscalingV2NamespacedHorizontalPodAutoscaler;
export declare type ResponseContentType$createAutoscalingV2NamespacedHorizontalPodAutoscaler = keyof Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201 | keyof Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$202;
export interface Params$createAutoscalingV2NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$createAutoscalingV2NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAutoscalingV2NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$createAutoscalingV2NamespacedHorizontalPodAutoscaler["*/*"];
}
export declare type RequestContentType$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler = keyof RequestBody$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler;
export declare type ResponseContentType$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler = keyof Response$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler$Status$200;
export interface Params$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler<U extends ResponseContentType$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler["*/*"];
}
export declare type ResponseContentType$readAutoscalingV2NamespacedHorizontalPodAutoscaler = keyof Response$readAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200;
export interface Params$readAutoscalingV2NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$readAutoscalingV2NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAutoscalingV2NamespacedHorizontalPodAutoscaler;
}
export declare type RequestContentType$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler = keyof RequestBody$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler;
export declare type ResponseContentType$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler = keyof Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201;
export interface Params$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler["*/*"];
}
export declare type RequestContentType$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler = keyof RequestBody$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler;
export declare type ResponseContentType$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler = keyof Response$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$202;
export interface Params$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler["*/*"];
}
export declare type RequestContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscaler = keyof RequestBody$patchAutoscalingV2NamespacedHorizontalPodAutoscaler;
export declare type ResponseContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscaler = keyof Response$patchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$patchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201;
export interface Params$patchAutoscalingV2NamespacedHorizontalPodAutoscaler<T extends RequestContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscaler, U extends ResponseContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscaler> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAutoscalingV2NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$patchAutoscalingV2NamespacedHorizontalPodAutoscaler[T];
}
export declare type ResponseContentType$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus = keyof Response$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200;
export interface Params$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus<U extends ResponseContentType$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus;
}
export declare type RequestContentType$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus = keyof RequestBody$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus;
export declare type ResponseContentType$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus = keyof Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200 | keyof Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$201;
export interface Params$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus<U extends ResponseContentType$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus;
    requestBody: RequestBody$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus["*/*"];
}
export declare type RequestContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus = keyof RequestBody$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus;
export declare type ResponseContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus = keyof Response$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200 | keyof Response$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$201;
export interface Params$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus<T extends RequestContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus, U extends ResponseContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus;
    requestBody: RequestBody$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus[T];
}
export declare type ResponseContentType$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces = keyof Response$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces$Status$200;
export interface Params$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces<U extends ResponseContentType$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces;
}
export declare type ResponseContentType$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList = keyof Response$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList$Status$200;
export interface Params$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList<U extends ResponseContentType$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList;
}
export declare type ResponseContentType$watchAutoscalingV2NamespacedHorizontalPodAutoscaler = keyof Response$watchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200;
export interface Params$watchAutoscalingV2NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$watchAutoscalingV2NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAutoscalingV2NamespacedHorizontalPodAutoscaler;
}
export declare type ResponseContentType$getAutoscalingV2beta1APIResources = keyof Response$getAutoscalingV2beta1APIResources$Status$200;
export interface Params$getAutoscalingV2beta1APIResources<U extends ResponseContentType$getAutoscalingV2beta1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listAutoscalingV2beta1HorizontalPodAutoscalerForAllNamespaces = keyof Response$listAutoscalingV2beta1HorizontalPodAutoscalerForAllNamespaces$Status$200;
export interface Params$listAutoscalingV2beta1HorizontalPodAutoscalerForAllNamespaces<U extends ResponseContentType$listAutoscalingV2beta1HorizontalPodAutoscalerForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAutoscalingV2beta1HorizontalPodAutoscalerForAllNamespaces;
}
export declare type ResponseContentType$listAutoscalingV2beta1NamespacedHorizontalPodAutoscaler = keyof Response$listAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200;
export interface Params$listAutoscalingV2beta1NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$listAutoscalingV2beta1NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAutoscalingV2beta1NamespacedHorizontalPodAutoscaler;
}
export declare type RequestContentType$createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler = keyof RequestBody$createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler;
export declare type ResponseContentType$createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler = keyof Response$createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$201 | keyof Response$createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$202;
export interface Params$createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler["*/*"];
}
export declare type RequestContentType$deleteAutoscalingV2beta1CollectionNamespacedHorizontalPodAutoscaler = keyof RequestBody$deleteAutoscalingV2beta1CollectionNamespacedHorizontalPodAutoscaler;
export declare type ResponseContentType$deleteAutoscalingV2beta1CollectionNamespacedHorizontalPodAutoscaler = keyof Response$deleteAutoscalingV2beta1CollectionNamespacedHorizontalPodAutoscaler$Status$200;
export interface Params$deleteAutoscalingV2beta1CollectionNamespacedHorizontalPodAutoscaler<U extends ResponseContentType$deleteAutoscalingV2beta1CollectionNamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAutoscalingV2beta1CollectionNamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$deleteAutoscalingV2beta1CollectionNamespacedHorizontalPodAutoscaler["*/*"];
}
export declare type ResponseContentType$readAutoscalingV2beta1NamespacedHorizontalPodAutoscaler = keyof Response$readAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200;
export interface Params$readAutoscalingV2beta1NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$readAutoscalingV2beta1NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAutoscalingV2beta1NamespacedHorizontalPodAutoscaler;
}
export declare type RequestContentType$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler = keyof RequestBody$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler;
export declare type ResponseContentType$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler = keyof Response$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$201;
export interface Params$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler["*/*"];
}
export declare type RequestContentType$deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler = keyof RequestBody$deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler;
export declare type ResponseContentType$deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler = keyof Response$deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$202;
export interface Params$deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler["*/*"];
}
export declare type RequestContentType$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler = keyof RequestBody$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler;
export declare type ResponseContentType$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler = keyof Response$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$201;
export interface Params$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler<T extends RequestContentType$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler, U extends ResponseContentType$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler[T];
}
export declare type ResponseContentType$readAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus = keyof Response$readAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus$Status$200;
export interface Params$readAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus<U extends ResponseContentType$readAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus;
}
export declare type RequestContentType$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus = keyof RequestBody$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus;
export declare type ResponseContentType$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus = keyof Response$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus$Status$200 | keyof Response$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus$Status$201;
export interface Params$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus<U extends ResponseContentType$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus;
    requestBody: RequestBody$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus["*/*"];
}
export declare type RequestContentType$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus = keyof RequestBody$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus;
export declare type ResponseContentType$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus = keyof Response$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus$Status$200 | keyof Response$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus$Status$201;
export interface Params$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus<T extends RequestContentType$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus, U extends ResponseContentType$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus;
    requestBody: RequestBody$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus[T];
}
export declare type ResponseContentType$watchAutoscalingV2beta1HorizontalPodAutoscalerListForAllNamespaces = keyof Response$watchAutoscalingV2beta1HorizontalPodAutoscalerListForAllNamespaces$Status$200;
export interface Params$watchAutoscalingV2beta1HorizontalPodAutoscalerListForAllNamespaces<U extends ResponseContentType$watchAutoscalingV2beta1HorizontalPodAutoscalerListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAutoscalingV2beta1HorizontalPodAutoscalerListForAllNamespaces;
}
export declare type ResponseContentType$watchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerList = keyof Response$watchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerList$Status$200;
export interface Params$watchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerList<U extends ResponseContentType$watchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerList;
}
export declare type ResponseContentType$watchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler = keyof Response$watchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200;
export interface Params$watchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$watchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler;
}
export declare type ResponseContentType$getAutoscalingV2beta2APIResources = keyof Response$getAutoscalingV2beta2APIResources$Status$200;
export interface Params$getAutoscalingV2beta2APIResources<U extends ResponseContentType$getAutoscalingV2beta2APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listAutoscalingV2beta2HorizontalPodAutoscalerForAllNamespaces = keyof Response$listAutoscalingV2beta2HorizontalPodAutoscalerForAllNamespaces$Status$200;
export interface Params$listAutoscalingV2beta2HorizontalPodAutoscalerForAllNamespaces<U extends ResponseContentType$listAutoscalingV2beta2HorizontalPodAutoscalerForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAutoscalingV2beta2HorizontalPodAutoscalerForAllNamespaces;
}
export declare type ResponseContentType$listAutoscalingV2beta2NamespacedHorizontalPodAutoscaler = keyof Response$listAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200;
export interface Params$listAutoscalingV2beta2NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$listAutoscalingV2beta2NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAutoscalingV2beta2NamespacedHorizontalPodAutoscaler;
}
export declare type RequestContentType$createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler = keyof RequestBody$createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler;
export declare type ResponseContentType$createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler = keyof Response$createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$201 | keyof Response$createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$202;
export interface Params$createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler["*/*"];
}
export declare type RequestContentType$deleteAutoscalingV2beta2CollectionNamespacedHorizontalPodAutoscaler = keyof RequestBody$deleteAutoscalingV2beta2CollectionNamespacedHorizontalPodAutoscaler;
export declare type ResponseContentType$deleteAutoscalingV2beta2CollectionNamespacedHorizontalPodAutoscaler = keyof Response$deleteAutoscalingV2beta2CollectionNamespacedHorizontalPodAutoscaler$Status$200;
export interface Params$deleteAutoscalingV2beta2CollectionNamespacedHorizontalPodAutoscaler<U extends ResponseContentType$deleteAutoscalingV2beta2CollectionNamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAutoscalingV2beta2CollectionNamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$deleteAutoscalingV2beta2CollectionNamespacedHorizontalPodAutoscaler["*/*"];
}
export declare type ResponseContentType$readAutoscalingV2beta2NamespacedHorizontalPodAutoscaler = keyof Response$readAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200;
export interface Params$readAutoscalingV2beta2NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$readAutoscalingV2beta2NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAutoscalingV2beta2NamespacedHorizontalPodAutoscaler;
}
export declare type RequestContentType$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler = keyof RequestBody$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler;
export declare type ResponseContentType$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler = keyof Response$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$201;
export interface Params$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler["*/*"];
}
export declare type RequestContentType$deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler = keyof RequestBody$deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler;
export declare type ResponseContentType$deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler = keyof Response$deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$202;
export interface Params$deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler["*/*"];
}
export declare type RequestContentType$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler = keyof RequestBody$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler;
export declare type ResponseContentType$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler = keyof Response$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$201;
export interface Params$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler<T extends RequestContentType$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler, U extends ResponseContentType$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler[T];
}
export declare type ResponseContentType$readAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus = keyof Response$readAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus$Status$200;
export interface Params$readAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus<U extends ResponseContentType$readAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus;
}
export declare type RequestContentType$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus = keyof RequestBody$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus;
export declare type ResponseContentType$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus = keyof Response$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus$Status$200 | keyof Response$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus$Status$201;
export interface Params$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus<U extends ResponseContentType$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus;
    requestBody: RequestBody$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus["*/*"];
}
export declare type RequestContentType$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus = keyof RequestBody$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus;
export declare type ResponseContentType$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus = keyof Response$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus$Status$200 | keyof Response$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus$Status$201;
export interface Params$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus<T extends RequestContentType$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus, U extends ResponseContentType$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus;
    requestBody: RequestBody$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus[T];
}
export declare type ResponseContentType$watchAutoscalingV2beta2HorizontalPodAutoscalerListForAllNamespaces = keyof Response$watchAutoscalingV2beta2HorizontalPodAutoscalerListForAllNamespaces$Status$200;
export interface Params$watchAutoscalingV2beta2HorizontalPodAutoscalerListForAllNamespaces<U extends ResponseContentType$watchAutoscalingV2beta2HorizontalPodAutoscalerListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAutoscalingV2beta2HorizontalPodAutoscalerListForAllNamespaces;
}
export declare type ResponseContentType$watchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerList = keyof Response$watchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerList$Status$200;
export interface Params$watchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerList<U extends ResponseContentType$watchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerList;
}
export declare type ResponseContentType$watchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler = keyof Response$watchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200;
export interface Params$watchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$watchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler;
}
export declare type ResponseContentType$getBatchAPIGroup = keyof Response$getBatchAPIGroup$Status$200;
export interface Params$getBatchAPIGroup<U extends ResponseContentType$getBatchAPIGroup> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$getBatchV1APIResources = keyof Response$getBatchV1APIResources$Status$200;
export interface Params$getBatchV1APIResources<U extends ResponseContentType$getBatchV1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listBatchV1CronJobForAllNamespaces = keyof Response$listBatchV1CronJobForAllNamespaces$Status$200;
export interface Params$listBatchV1CronJobForAllNamespaces<U extends ResponseContentType$listBatchV1CronJobForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listBatchV1CronJobForAllNamespaces;
}
export declare type ResponseContentType$listBatchV1JobForAllNamespaces = keyof Response$listBatchV1JobForAllNamespaces$Status$200;
export interface Params$listBatchV1JobForAllNamespaces<U extends ResponseContentType$listBatchV1JobForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listBatchV1JobForAllNamespaces;
}
export declare type ResponseContentType$listBatchV1NamespacedCronJob = keyof Response$listBatchV1NamespacedCronJob$Status$200;
export interface Params$listBatchV1NamespacedCronJob<U extends ResponseContentType$listBatchV1NamespacedCronJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listBatchV1NamespacedCronJob;
}
export declare type RequestContentType$createBatchV1NamespacedCronJob = keyof RequestBody$createBatchV1NamespacedCronJob;
export declare type ResponseContentType$createBatchV1NamespacedCronJob = keyof Response$createBatchV1NamespacedCronJob$Status$200 | keyof Response$createBatchV1NamespacedCronJob$Status$201 | keyof Response$createBatchV1NamespacedCronJob$Status$202;
export interface Params$createBatchV1NamespacedCronJob<U extends ResponseContentType$createBatchV1NamespacedCronJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createBatchV1NamespacedCronJob;
    requestBody: RequestBody$createBatchV1NamespacedCronJob["*/*"];
}
export declare type RequestContentType$deleteBatchV1CollectionNamespacedCronJob = keyof RequestBody$deleteBatchV1CollectionNamespacedCronJob;
export declare type ResponseContentType$deleteBatchV1CollectionNamespacedCronJob = keyof Response$deleteBatchV1CollectionNamespacedCronJob$Status$200;
export interface Params$deleteBatchV1CollectionNamespacedCronJob<U extends ResponseContentType$deleteBatchV1CollectionNamespacedCronJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteBatchV1CollectionNamespacedCronJob;
    requestBody: RequestBody$deleteBatchV1CollectionNamespacedCronJob["*/*"];
}
export declare type ResponseContentType$readBatchV1NamespacedCronJob = keyof Response$readBatchV1NamespacedCronJob$Status$200;
export interface Params$readBatchV1NamespacedCronJob<U extends ResponseContentType$readBatchV1NamespacedCronJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readBatchV1NamespacedCronJob;
}
export declare type RequestContentType$replaceBatchV1NamespacedCronJob = keyof RequestBody$replaceBatchV1NamespacedCronJob;
export declare type ResponseContentType$replaceBatchV1NamespacedCronJob = keyof Response$replaceBatchV1NamespacedCronJob$Status$200 | keyof Response$replaceBatchV1NamespacedCronJob$Status$201;
export interface Params$replaceBatchV1NamespacedCronJob<U extends ResponseContentType$replaceBatchV1NamespacedCronJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceBatchV1NamespacedCronJob;
    requestBody: RequestBody$replaceBatchV1NamespacedCronJob["*/*"];
}
export declare type RequestContentType$deleteBatchV1NamespacedCronJob = keyof RequestBody$deleteBatchV1NamespacedCronJob;
export declare type ResponseContentType$deleteBatchV1NamespacedCronJob = keyof Response$deleteBatchV1NamespacedCronJob$Status$200 | keyof Response$deleteBatchV1NamespacedCronJob$Status$202;
export interface Params$deleteBatchV1NamespacedCronJob<U extends ResponseContentType$deleteBatchV1NamespacedCronJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteBatchV1NamespacedCronJob;
    requestBody: RequestBody$deleteBatchV1NamespacedCronJob["*/*"];
}
export declare type RequestContentType$patchBatchV1NamespacedCronJob = keyof RequestBody$patchBatchV1NamespacedCronJob;
export declare type ResponseContentType$patchBatchV1NamespacedCronJob = keyof Response$patchBatchV1NamespacedCronJob$Status$200 | keyof Response$patchBatchV1NamespacedCronJob$Status$201;
export interface Params$patchBatchV1NamespacedCronJob<T extends RequestContentType$patchBatchV1NamespacedCronJob, U extends ResponseContentType$patchBatchV1NamespacedCronJob> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchBatchV1NamespacedCronJob;
    requestBody: RequestBody$patchBatchV1NamespacedCronJob[T];
}
export declare type ResponseContentType$readBatchV1NamespacedCronJobStatus = keyof Response$readBatchV1NamespacedCronJobStatus$Status$200;
export interface Params$readBatchV1NamespacedCronJobStatus<U extends ResponseContentType$readBatchV1NamespacedCronJobStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readBatchV1NamespacedCronJobStatus;
}
export declare type RequestContentType$replaceBatchV1NamespacedCronJobStatus = keyof RequestBody$replaceBatchV1NamespacedCronJobStatus;
export declare type ResponseContentType$replaceBatchV1NamespacedCronJobStatus = keyof Response$replaceBatchV1NamespacedCronJobStatus$Status$200 | keyof Response$replaceBatchV1NamespacedCronJobStatus$Status$201;
export interface Params$replaceBatchV1NamespacedCronJobStatus<U extends ResponseContentType$replaceBatchV1NamespacedCronJobStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceBatchV1NamespacedCronJobStatus;
    requestBody: RequestBody$replaceBatchV1NamespacedCronJobStatus["*/*"];
}
export declare type RequestContentType$patchBatchV1NamespacedCronJobStatus = keyof RequestBody$patchBatchV1NamespacedCronJobStatus;
export declare type ResponseContentType$patchBatchV1NamespacedCronJobStatus = keyof Response$patchBatchV1NamespacedCronJobStatus$Status$200 | keyof Response$patchBatchV1NamespacedCronJobStatus$Status$201;
export interface Params$patchBatchV1NamespacedCronJobStatus<T extends RequestContentType$patchBatchV1NamespacedCronJobStatus, U extends ResponseContentType$patchBatchV1NamespacedCronJobStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchBatchV1NamespacedCronJobStatus;
    requestBody: RequestBody$patchBatchV1NamespacedCronJobStatus[T];
}
export declare type ResponseContentType$listBatchV1NamespacedJob = keyof Response$listBatchV1NamespacedJob$Status$200;
export interface Params$listBatchV1NamespacedJob<U extends ResponseContentType$listBatchV1NamespacedJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listBatchV1NamespacedJob;
}
export declare type RequestContentType$createBatchV1NamespacedJob = keyof RequestBody$createBatchV1NamespacedJob;
export declare type ResponseContentType$createBatchV1NamespacedJob = keyof Response$createBatchV1NamespacedJob$Status$200 | keyof Response$createBatchV1NamespacedJob$Status$201 | keyof Response$createBatchV1NamespacedJob$Status$202;
export interface Params$createBatchV1NamespacedJob<U extends ResponseContentType$createBatchV1NamespacedJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createBatchV1NamespacedJob;
    requestBody: RequestBody$createBatchV1NamespacedJob["*/*"];
}
export declare type RequestContentType$deleteBatchV1CollectionNamespacedJob = keyof RequestBody$deleteBatchV1CollectionNamespacedJob;
export declare type ResponseContentType$deleteBatchV1CollectionNamespacedJob = keyof Response$deleteBatchV1CollectionNamespacedJob$Status$200;
export interface Params$deleteBatchV1CollectionNamespacedJob<U extends ResponseContentType$deleteBatchV1CollectionNamespacedJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteBatchV1CollectionNamespacedJob;
    requestBody: RequestBody$deleteBatchV1CollectionNamespacedJob["*/*"];
}
export declare type ResponseContentType$readBatchV1NamespacedJob = keyof Response$readBatchV1NamespacedJob$Status$200;
export interface Params$readBatchV1NamespacedJob<U extends ResponseContentType$readBatchV1NamespacedJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readBatchV1NamespacedJob;
}
export declare type RequestContentType$replaceBatchV1NamespacedJob = keyof RequestBody$replaceBatchV1NamespacedJob;
export declare type ResponseContentType$replaceBatchV1NamespacedJob = keyof Response$replaceBatchV1NamespacedJob$Status$200 | keyof Response$replaceBatchV1NamespacedJob$Status$201;
export interface Params$replaceBatchV1NamespacedJob<U extends ResponseContentType$replaceBatchV1NamespacedJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceBatchV1NamespacedJob;
    requestBody: RequestBody$replaceBatchV1NamespacedJob["*/*"];
}
export declare type RequestContentType$deleteBatchV1NamespacedJob = keyof RequestBody$deleteBatchV1NamespacedJob;
export declare type ResponseContentType$deleteBatchV1NamespacedJob = keyof Response$deleteBatchV1NamespacedJob$Status$200 | keyof Response$deleteBatchV1NamespacedJob$Status$202;
export interface Params$deleteBatchV1NamespacedJob<U extends ResponseContentType$deleteBatchV1NamespacedJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteBatchV1NamespacedJob;
    requestBody: RequestBody$deleteBatchV1NamespacedJob["*/*"];
}
export declare type RequestContentType$patchBatchV1NamespacedJob = keyof RequestBody$patchBatchV1NamespacedJob;
export declare type ResponseContentType$patchBatchV1NamespacedJob = keyof Response$patchBatchV1NamespacedJob$Status$200 | keyof Response$patchBatchV1NamespacedJob$Status$201;
export interface Params$patchBatchV1NamespacedJob<T extends RequestContentType$patchBatchV1NamespacedJob, U extends ResponseContentType$patchBatchV1NamespacedJob> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchBatchV1NamespacedJob;
    requestBody: RequestBody$patchBatchV1NamespacedJob[T];
}
export declare type ResponseContentType$readBatchV1NamespacedJobStatus = keyof Response$readBatchV1NamespacedJobStatus$Status$200;
export interface Params$readBatchV1NamespacedJobStatus<U extends ResponseContentType$readBatchV1NamespacedJobStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readBatchV1NamespacedJobStatus;
}
export declare type RequestContentType$replaceBatchV1NamespacedJobStatus = keyof RequestBody$replaceBatchV1NamespacedJobStatus;
export declare type ResponseContentType$replaceBatchV1NamespacedJobStatus = keyof Response$replaceBatchV1NamespacedJobStatus$Status$200 | keyof Response$replaceBatchV1NamespacedJobStatus$Status$201;
export interface Params$replaceBatchV1NamespacedJobStatus<U extends ResponseContentType$replaceBatchV1NamespacedJobStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceBatchV1NamespacedJobStatus;
    requestBody: RequestBody$replaceBatchV1NamespacedJobStatus["*/*"];
}
export declare type RequestContentType$patchBatchV1NamespacedJobStatus = keyof RequestBody$patchBatchV1NamespacedJobStatus;
export declare type ResponseContentType$patchBatchV1NamespacedJobStatus = keyof Response$patchBatchV1NamespacedJobStatus$Status$200 | keyof Response$patchBatchV1NamespacedJobStatus$Status$201;
export interface Params$patchBatchV1NamespacedJobStatus<T extends RequestContentType$patchBatchV1NamespacedJobStatus, U extends ResponseContentType$patchBatchV1NamespacedJobStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchBatchV1NamespacedJobStatus;
    requestBody: RequestBody$patchBatchV1NamespacedJobStatus[T];
}
export declare type ResponseContentType$watchBatchV1CronJobListForAllNamespaces = keyof Response$watchBatchV1CronJobListForAllNamespaces$Status$200;
export interface Params$watchBatchV1CronJobListForAllNamespaces<U extends ResponseContentType$watchBatchV1CronJobListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchBatchV1CronJobListForAllNamespaces;
}
export declare type ResponseContentType$watchBatchV1JobListForAllNamespaces = keyof Response$watchBatchV1JobListForAllNamespaces$Status$200;
export interface Params$watchBatchV1JobListForAllNamespaces<U extends ResponseContentType$watchBatchV1JobListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchBatchV1JobListForAllNamespaces;
}
export declare type ResponseContentType$watchBatchV1NamespacedCronJobList = keyof Response$watchBatchV1NamespacedCronJobList$Status$200;
export interface Params$watchBatchV1NamespacedCronJobList<U extends ResponseContentType$watchBatchV1NamespacedCronJobList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchBatchV1NamespacedCronJobList;
}
export declare type ResponseContentType$watchBatchV1NamespacedCronJob = keyof Response$watchBatchV1NamespacedCronJob$Status$200;
export interface Params$watchBatchV1NamespacedCronJob<U extends ResponseContentType$watchBatchV1NamespacedCronJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchBatchV1NamespacedCronJob;
}
export declare type ResponseContentType$watchBatchV1NamespacedJobList = keyof Response$watchBatchV1NamespacedJobList$Status$200;
export interface Params$watchBatchV1NamespacedJobList<U extends ResponseContentType$watchBatchV1NamespacedJobList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchBatchV1NamespacedJobList;
}
export declare type ResponseContentType$watchBatchV1NamespacedJob = keyof Response$watchBatchV1NamespacedJob$Status$200;
export interface Params$watchBatchV1NamespacedJob<U extends ResponseContentType$watchBatchV1NamespacedJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchBatchV1NamespacedJob;
}
export declare type ResponseContentType$getBatchV1beta1APIResources = keyof Response$getBatchV1beta1APIResources$Status$200;
export interface Params$getBatchV1beta1APIResources<U extends ResponseContentType$getBatchV1beta1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listBatchV1beta1CronJobForAllNamespaces = keyof Response$listBatchV1beta1CronJobForAllNamespaces$Status$200;
export interface Params$listBatchV1beta1CronJobForAllNamespaces<U extends ResponseContentType$listBatchV1beta1CronJobForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listBatchV1beta1CronJobForAllNamespaces;
}
export declare type ResponseContentType$listBatchV1beta1NamespacedCronJob = keyof Response$listBatchV1beta1NamespacedCronJob$Status$200;
export interface Params$listBatchV1beta1NamespacedCronJob<U extends ResponseContentType$listBatchV1beta1NamespacedCronJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listBatchV1beta1NamespacedCronJob;
}
export declare type RequestContentType$createBatchV1beta1NamespacedCronJob = keyof RequestBody$createBatchV1beta1NamespacedCronJob;
export declare type ResponseContentType$createBatchV1beta1NamespacedCronJob = keyof Response$createBatchV1beta1NamespacedCronJob$Status$200 | keyof Response$createBatchV1beta1NamespacedCronJob$Status$201 | keyof Response$createBatchV1beta1NamespacedCronJob$Status$202;
export interface Params$createBatchV1beta1NamespacedCronJob<U extends ResponseContentType$createBatchV1beta1NamespacedCronJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createBatchV1beta1NamespacedCronJob;
    requestBody: RequestBody$createBatchV1beta1NamespacedCronJob["*/*"];
}
export declare type RequestContentType$deleteBatchV1beta1CollectionNamespacedCronJob = keyof RequestBody$deleteBatchV1beta1CollectionNamespacedCronJob;
export declare type ResponseContentType$deleteBatchV1beta1CollectionNamespacedCronJob = keyof Response$deleteBatchV1beta1CollectionNamespacedCronJob$Status$200;
export interface Params$deleteBatchV1beta1CollectionNamespacedCronJob<U extends ResponseContentType$deleteBatchV1beta1CollectionNamespacedCronJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteBatchV1beta1CollectionNamespacedCronJob;
    requestBody: RequestBody$deleteBatchV1beta1CollectionNamespacedCronJob["*/*"];
}
export declare type ResponseContentType$readBatchV1beta1NamespacedCronJob = keyof Response$readBatchV1beta1NamespacedCronJob$Status$200;
export interface Params$readBatchV1beta1NamespacedCronJob<U extends ResponseContentType$readBatchV1beta1NamespacedCronJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readBatchV1beta1NamespacedCronJob;
}
export declare type RequestContentType$replaceBatchV1beta1NamespacedCronJob = keyof RequestBody$replaceBatchV1beta1NamespacedCronJob;
export declare type ResponseContentType$replaceBatchV1beta1NamespacedCronJob = keyof Response$replaceBatchV1beta1NamespacedCronJob$Status$200 | keyof Response$replaceBatchV1beta1NamespacedCronJob$Status$201;
export interface Params$replaceBatchV1beta1NamespacedCronJob<U extends ResponseContentType$replaceBatchV1beta1NamespacedCronJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceBatchV1beta1NamespacedCronJob;
    requestBody: RequestBody$replaceBatchV1beta1NamespacedCronJob["*/*"];
}
export declare type RequestContentType$deleteBatchV1beta1NamespacedCronJob = keyof RequestBody$deleteBatchV1beta1NamespacedCronJob;
export declare type ResponseContentType$deleteBatchV1beta1NamespacedCronJob = keyof Response$deleteBatchV1beta1NamespacedCronJob$Status$200 | keyof Response$deleteBatchV1beta1NamespacedCronJob$Status$202;
export interface Params$deleteBatchV1beta1NamespacedCronJob<U extends ResponseContentType$deleteBatchV1beta1NamespacedCronJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteBatchV1beta1NamespacedCronJob;
    requestBody: RequestBody$deleteBatchV1beta1NamespacedCronJob["*/*"];
}
export declare type RequestContentType$patchBatchV1beta1NamespacedCronJob = keyof RequestBody$patchBatchV1beta1NamespacedCronJob;
export declare type ResponseContentType$patchBatchV1beta1NamespacedCronJob = keyof Response$patchBatchV1beta1NamespacedCronJob$Status$200 | keyof Response$patchBatchV1beta1NamespacedCronJob$Status$201;
export interface Params$patchBatchV1beta1NamespacedCronJob<T extends RequestContentType$patchBatchV1beta1NamespacedCronJob, U extends ResponseContentType$patchBatchV1beta1NamespacedCronJob> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchBatchV1beta1NamespacedCronJob;
    requestBody: RequestBody$patchBatchV1beta1NamespacedCronJob[T];
}
export declare type ResponseContentType$readBatchV1beta1NamespacedCronJobStatus = keyof Response$readBatchV1beta1NamespacedCronJobStatus$Status$200;
export interface Params$readBatchV1beta1NamespacedCronJobStatus<U extends ResponseContentType$readBatchV1beta1NamespacedCronJobStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readBatchV1beta1NamespacedCronJobStatus;
}
export declare type RequestContentType$replaceBatchV1beta1NamespacedCronJobStatus = keyof RequestBody$replaceBatchV1beta1NamespacedCronJobStatus;
export declare type ResponseContentType$replaceBatchV1beta1NamespacedCronJobStatus = keyof Response$replaceBatchV1beta1NamespacedCronJobStatus$Status$200 | keyof Response$replaceBatchV1beta1NamespacedCronJobStatus$Status$201;
export interface Params$replaceBatchV1beta1NamespacedCronJobStatus<U extends ResponseContentType$replaceBatchV1beta1NamespacedCronJobStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceBatchV1beta1NamespacedCronJobStatus;
    requestBody: RequestBody$replaceBatchV1beta1NamespacedCronJobStatus["*/*"];
}
export declare type RequestContentType$patchBatchV1beta1NamespacedCronJobStatus = keyof RequestBody$patchBatchV1beta1NamespacedCronJobStatus;
export declare type ResponseContentType$patchBatchV1beta1NamespacedCronJobStatus = keyof Response$patchBatchV1beta1NamespacedCronJobStatus$Status$200 | keyof Response$patchBatchV1beta1NamespacedCronJobStatus$Status$201;
export interface Params$patchBatchV1beta1NamespacedCronJobStatus<T extends RequestContentType$patchBatchV1beta1NamespacedCronJobStatus, U extends ResponseContentType$patchBatchV1beta1NamespacedCronJobStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchBatchV1beta1NamespacedCronJobStatus;
    requestBody: RequestBody$patchBatchV1beta1NamespacedCronJobStatus[T];
}
export declare type ResponseContentType$watchBatchV1beta1CronJobListForAllNamespaces = keyof Response$watchBatchV1beta1CronJobListForAllNamespaces$Status$200;
export interface Params$watchBatchV1beta1CronJobListForAllNamespaces<U extends ResponseContentType$watchBatchV1beta1CronJobListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchBatchV1beta1CronJobListForAllNamespaces;
}
export declare type ResponseContentType$watchBatchV1beta1NamespacedCronJobList = keyof Response$watchBatchV1beta1NamespacedCronJobList$Status$200;
export interface Params$watchBatchV1beta1NamespacedCronJobList<U extends ResponseContentType$watchBatchV1beta1NamespacedCronJobList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchBatchV1beta1NamespacedCronJobList;
}
export declare type ResponseContentType$watchBatchV1beta1NamespacedCronJob = keyof Response$watchBatchV1beta1NamespacedCronJob$Status$200;
export interface Params$watchBatchV1beta1NamespacedCronJob<U extends ResponseContentType$watchBatchV1beta1NamespacedCronJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchBatchV1beta1NamespacedCronJob;
}
export declare type ResponseContentType$getCertificatesAPIGroup = keyof Response$getCertificatesAPIGroup$Status$200;
export interface Params$getCertificatesAPIGroup<U extends ResponseContentType$getCertificatesAPIGroup> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$getCertificatesV1APIResources = keyof Response$getCertificatesV1APIResources$Status$200;
export interface Params$getCertificatesV1APIResources<U extends ResponseContentType$getCertificatesV1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listCertificatesV1CertificateSigningRequest = keyof Response$listCertificatesV1CertificateSigningRequest$Status$200;
export interface Params$listCertificatesV1CertificateSigningRequest<U extends ResponseContentType$listCertificatesV1CertificateSigningRequest> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCertificatesV1CertificateSigningRequest;
}
export declare type RequestContentType$createCertificatesV1CertificateSigningRequest = keyof RequestBody$createCertificatesV1CertificateSigningRequest;
export declare type ResponseContentType$createCertificatesV1CertificateSigningRequest = keyof Response$createCertificatesV1CertificateSigningRequest$Status$200 | keyof Response$createCertificatesV1CertificateSigningRequest$Status$201 | keyof Response$createCertificatesV1CertificateSigningRequest$Status$202;
export interface Params$createCertificatesV1CertificateSigningRequest<U extends ResponseContentType$createCertificatesV1CertificateSigningRequest> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCertificatesV1CertificateSigningRequest;
    requestBody: RequestBody$createCertificatesV1CertificateSigningRequest["*/*"];
}
export declare type RequestContentType$deleteCertificatesV1CollectionCertificateSigningRequest = keyof RequestBody$deleteCertificatesV1CollectionCertificateSigningRequest;
export declare type ResponseContentType$deleteCertificatesV1CollectionCertificateSigningRequest = keyof Response$deleteCertificatesV1CollectionCertificateSigningRequest$Status$200;
export interface Params$deleteCertificatesV1CollectionCertificateSigningRequest<U extends ResponseContentType$deleteCertificatesV1CollectionCertificateSigningRequest> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCertificatesV1CollectionCertificateSigningRequest;
    requestBody: RequestBody$deleteCertificatesV1CollectionCertificateSigningRequest["*/*"];
}
export declare type ResponseContentType$readCertificatesV1CertificateSigningRequest = keyof Response$readCertificatesV1CertificateSigningRequest$Status$200;
export interface Params$readCertificatesV1CertificateSigningRequest<U extends ResponseContentType$readCertificatesV1CertificateSigningRequest> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCertificatesV1CertificateSigningRequest;
}
export declare type RequestContentType$replaceCertificatesV1CertificateSigningRequest = keyof RequestBody$replaceCertificatesV1CertificateSigningRequest;
export declare type ResponseContentType$replaceCertificatesV1CertificateSigningRequest = keyof Response$replaceCertificatesV1CertificateSigningRequest$Status$200 | keyof Response$replaceCertificatesV1CertificateSigningRequest$Status$201;
export interface Params$replaceCertificatesV1CertificateSigningRequest<U extends ResponseContentType$replaceCertificatesV1CertificateSigningRequest> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCertificatesV1CertificateSigningRequest;
    requestBody: RequestBody$replaceCertificatesV1CertificateSigningRequest["*/*"];
}
export declare type RequestContentType$deleteCertificatesV1CertificateSigningRequest = keyof RequestBody$deleteCertificatesV1CertificateSigningRequest;
export declare type ResponseContentType$deleteCertificatesV1CertificateSigningRequest = keyof Response$deleteCertificatesV1CertificateSigningRequest$Status$200 | keyof Response$deleteCertificatesV1CertificateSigningRequest$Status$202;
export interface Params$deleteCertificatesV1CertificateSigningRequest<U extends ResponseContentType$deleteCertificatesV1CertificateSigningRequest> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCertificatesV1CertificateSigningRequest;
    requestBody: RequestBody$deleteCertificatesV1CertificateSigningRequest["*/*"];
}
export declare type RequestContentType$patchCertificatesV1CertificateSigningRequest = keyof RequestBody$patchCertificatesV1CertificateSigningRequest;
export declare type ResponseContentType$patchCertificatesV1CertificateSigningRequest = keyof Response$patchCertificatesV1CertificateSigningRequest$Status$200 | keyof Response$patchCertificatesV1CertificateSigningRequest$Status$201;
export interface Params$patchCertificatesV1CertificateSigningRequest<T extends RequestContentType$patchCertificatesV1CertificateSigningRequest, U extends ResponseContentType$patchCertificatesV1CertificateSigningRequest> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCertificatesV1CertificateSigningRequest;
    requestBody: RequestBody$patchCertificatesV1CertificateSigningRequest[T];
}
export declare type ResponseContentType$readCertificatesV1CertificateSigningRequestApproval = keyof Response$readCertificatesV1CertificateSigningRequestApproval$Status$200;
export interface Params$readCertificatesV1CertificateSigningRequestApproval<U extends ResponseContentType$readCertificatesV1CertificateSigningRequestApproval> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCertificatesV1CertificateSigningRequestApproval;
}
export declare type RequestContentType$replaceCertificatesV1CertificateSigningRequestApproval = keyof RequestBody$replaceCertificatesV1CertificateSigningRequestApproval;
export declare type ResponseContentType$replaceCertificatesV1CertificateSigningRequestApproval = keyof Response$replaceCertificatesV1CertificateSigningRequestApproval$Status$200 | keyof Response$replaceCertificatesV1CertificateSigningRequestApproval$Status$201;
export interface Params$replaceCertificatesV1CertificateSigningRequestApproval<U extends ResponseContentType$replaceCertificatesV1CertificateSigningRequestApproval> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCertificatesV1CertificateSigningRequestApproval;
    requestBody: RequestBody$replaceCertificatesV1CertificateSigningRequestApproval["*/*"];
}
export declare type RequestContentType$patchCertificatesV1CertificateSigningRequestApproval = keyof RequestBody$patchCertificatesV1CertificateSigningRequestApproval;
export declare type ResponseContentType$patchCertificatesV1CertificateSigningRequestApproval = keyof Response$patchCertificatesV1CertificateSigningRequestApproval$Status$200 | keyof Response$patchCertificatesV1CertificateSigningRequestApproval$Status$201;
export interface Params$patchCertificatesV1CertificateSigningRequestApproval<T extends RequestContentType$patchCertificatesV1CertificateSigningRequestApproval, U extends ResponseContentType$patchCertificatesV1CertificateSigningRequestApproval> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCertificatesV1CertificateSigningRequestApproval;
    requestBody: RequestBody$patchCertificatesV1CertificateSigningRequestApproval[T];
}
export declare type ResponseContentType$readCertificatesV1CertificateSigningRequestStatus = keyof Response$readCertificatesV1CertificateSigningRequestStatus$Status$200;
export interface Params$readCertificatesV1CertificateSigningRequestStatus<U extends ResponseContentType$readCertificatesV1CertificateSigningRequestStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCertificatesV1CertificateSigningRequestStatus;
}
export declare type RequestContentType$replaceCertificatesV1CertificateSigningRequestStatus = keyof RequestBody$replaceCertificatesV1CertificateSigningRequestStatus;
export declare type ResponseContentType$replaceCertificatesV1CertificateSigningRequestStatus = keyof Response$replaceCertificatesV1CertificateSigningRequestStatus$Status$200 | keyof Response$replaceCertificatesV1CertificateSigningRequestStatus$Status$201;
export interface Params$replaceCertificatesV1CertificateSigningRequestStatus<U extends ResponseContentType$replaceCertificatesV1CertificateSigningRequestStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCertificatesV1CertificateSigningRequestStatus;
    requestBody: RequestBody$replaceCertificatesV1CertificateSigningRequestStatus["*/*"];
}
export declare type RequestContentType$patchCertificatesV1CertificateSigningRequestStatus = keyof RequestBody$patchCertificatesV1CertificateSigningRequestStatus;
export declare type ResponseContentType$patchCertificatesV1CertificateSigningRequestStatus = keyof Response$patchCertificatesV1CertificateSigningRequestStatus$Status$200 | keyof Response$patchCertificatesV1CertificateSigningRequestStatus$Status$201;
export interface Params$patchCertificatesV1CertificateSigningRequestStatus<T extends RequestContentType$patchCertificatesV1CertificateSigningRequestStatus, U extends ResponseContentType$patchCertificatesV1CertificateSigningRequestStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCertificatesV1CertificateSigningRequestStatus;
    requestBody: RequestBody$patchCertificatesV1CertificateSigningRequestStatus[T];
}
export declare type ResponseContentType$watchCertificatesV1CertificateSigningRequestList = keyof Response$watchCertificatesV1CertificateSigningRequestList$Status$200;
export interface Params$watchCertificatesV1CertificateSigningRequestList<U extends ResponseContentType$watchCertificatesV1CertificateSigningRequestList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCertificatesV1CertificateSigningRequestList;
}
export declare type ResponseContentType$watchCertificatesV1CertificateSigningRequest = keyof Response$watchCertificatesV1CertificateSigningRequest$Status$200;
export interface Params$watchCertificatesV1CertificateSigningRequest<U extends ResponseContentType$watchCertificatesV1CertificateSigningRequest> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCertificatesV1CertificateSigningRequest;
}
export declare type ResponseContentType$getCoordinationAPIGroup = keyof Response$getCoordinationAPIGroup$Status$200;
export interface Params$getCoordinationAPIGroup<U extends ResponseContentType$getCoordinationAPIGroup> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$getCoordinationV1APIResources = keyof Response$getCoordinationV1APIResources$Status$200;
export interface Params$getCoordinationV1APIResources<U extends ResponseContentType$getCoordinationV1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listCoordinationV1LeaseForAllNamespaces = keyof Response$listCoordinationV1LeaseForAllNamespaces$Status$200;
export interface Params$listCoordinationV1LeaseForAllNamespaces<U extends ResponseContentType$listCoordinationV1LeaseForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoordinationV1LeaseForAllNamespaces;
}
export declare type ResponseContentType$listCoordinationV1NamespacedLease = keyof Response$listCoordinationV1NamespacedLease$Status$200;
export interface Params$listCoordinationV1NamespacedLease<U extends ResponseContentType$listCoordinationV1NamespacedLease> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoordinationV1NamespacedLease;
}
export declare type RequestContentType$createCoordinationV1NamespacedLease = keyof RequestBody$createCoordinationV1NamespacedLease;
export declare type ResponseContentType$createCoordinationV1NamespacedLease = keyof Response$createCoordinationV1NamespacedLease$Status$200 | keyof Response$createCoordinationV1NamespacedLease$Status$201 | keyof Response$createCoordinationV1NamespacedLease$Status$202;
export interface Params$createCoordinationV1NamespacedLease<U extends ResponseContentType$createCoordinationV1NamespacedLease> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoordinationV1NamespacedLease;
    requestBody: RequestBody$createCoordinationV1NamespacedLease["*/*"];
}
export declare type RequestContentType$deleteCoordinationV1CollectionNamespacedLease = keyof RequestBody$deleteCoordinationV1CollectionNamespacedLease;
export declare type ResponseContentType$deleteCoordinationV1CollectionNamespacedLease = keyof Response$deleteCoordinationV1CollectionNamespacedLease$Status$200;
export interface Params$deleteCoordinationV1CollectionNamespacedLease<U extends ResponseContentType$deleteCoordinationV1CollectionNamespacedLease> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoordinationV1CollectionNamespacedLease;
    requestBody: RequestBody$deleteCoordinationV1CollectionNamespacedLease["*/*"];
}
export declare type ResponseContentType$readCoordinationV1NamespacedLease = keyof Response$readCoordinationV1NamespacedLease$Status$200;
export interface Params$readCoordinationV1NamespacedLease<U extends ResponseContentType$readCoordinationV1NamespacedLease> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoordinationV1NamespacedLease;
}
export declare type RequestContentType$replaceCoordinationV1NamespacedLease = keyof RequestBody$replaceCoordinationV1NamespacedLease;
export declare type ResponseContentType$replaceCoordinationV1NamespacedLease = keyof Response$replaceCoordinationV1NamespacedLease$Status$200 | keyof Response$replaceCoordinationV1NamespacedLease$Status$201;
export interface Params$replaceCoordinationV1NamespacedLease<U extends ResponseContentType$replaceCoordinationV1NamespacedLease> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoordinationV1NamespacedLease;
    requestBody: RequestBody$replaceCoordinationV1NamespacedLease["*/*"];
}
export declare type RequestContentType$deleteCoordinationV1NamespacedLease = keyof RequestBody$deleteCoordinationV1NamespacedLease;
export declare type ResponseContentType$deleteCoordinationV1NamespacedLease = keyof Response$deleteCoordinationV1NamespacedLease$Status$200 | keyof Response$deleteCoordinationV1NamespacedLease$Status$202;
export interface Params$deleteCoordinationV1NamespacedLease<U extends ResponseContentType$deleteCoordinationV1NamespacedLease> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoordinationV1NamespacedLease;
    requestBody: RequestBody$deleteCoordinationV1NamespacedLease["*/*"];
}
export declare type RequestContentType$patchCoordinationV1NamespacedLease = keyof RequestBody$patchCoordinationV1NamespacedLease;
export declare type ResponseContentType$patchCoordinationV1NamespacedLease = keyof Response$patchCoordinationV1NamespacedLease$Status$200 | keyof Response$patchCoordinationV1NamespacedLease$Status$201;
export interface Params$patchCoordinationV1NamespacedLease<T extends RequestContentType$patchCoordinationV1NamespacedLease, U extends ResponseContentType$patchCoordinationV1NamespacedLease> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoordinationV1NamespacedLease;
    requestBody: RequestBody$patchCoordinationV1NamespacedLease[T];
}
export declare type ResponseContentType$watchCoordinationV1LeaseListForAllNamespaces = keyof Response$watchCoordinationV1LeaseListForAllNamespaces$Status$200;
export interface Params$watchCoordinationV1LeaseListForAllNamespaces<U extends ResponseContentType$watchCoordinationV1LeaseListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoordinationV1LeaseListForAllNamespaces;
}
export declare type ResponseContentType$watchCoordinationV1NamespacedLeaseList = keyof Response$watchCoordinationV1NamespacedLeaseList$Status$200;
export interface Params$watchCoordinationV1NamespacedLeaseList<U extends ResponseContentType$watchCoordinationV1NamespacedLeaseList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoordinationV1NamespacedLeaseList;
}
export declare type ResponseContentType$watchCoordinationV1NamespacedLease = keyof Response$watchCoordinationV1NamespacedLease$Status$200;
export interface Params$watchCoordinationV1NamespacedLease<U extends ResponseContentType$watchCoordinationV1NamespacedLease> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoordinationV1NamespacedLease;
}
export declare type ResponseContentType$getDiscoveryAPIGroup = keyof Response$getDiscoveryAPIGroup$Status$200;
export interface Params$getDiscoveryAPIGroup<U extends ResponseContentType$getDiscoveryAPIGroup> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$getDiscoveryV1APIResources = keyof Response$getDiscoveryV1APIResources$Status$200;
export interface Params$getDiscoveryV1APIResources<U extends ResponseContentType$getDiscoveryV1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listDiscoveryV1EndpointSliceForAllNamespaces = keyof Response$listDiscoveryV1EndpointSliceForAllNamespaces$Status$200;
export interface Params$listDiscoveryV1EndpointSliceForAllNamespaces<U extends ResponseContentType$listDiscoveryV1EndpointSliceForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listDiscoveryV1EndpointSliceForAllNamespaces;
}
export declare type ResponseContentType$listDiscoveryV1NamespacedEndpointSlice = keyof Response$listDiscoveryV1NamespacedEndpointSlice$Status$200;
export interface Params$listDiscoveryV1NamespacedEndpointSlice<U extends ResponseContentType$listDiscoveryV1NamespacedEndpointSlice> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listDiscoveryV1NamespacedEndpointSlice;
}
export declare type RequestContentType$createDiscoveryV1NamespacedEndpointSlice = keyof RequestBody$createDiscoveryV1NamespacedEndpointSlice;
export declare type ResponseContentType$createDiscoveryV1NamespacedEndpointSlice = keyof Response$createDiscoveryV1NamespacedEndpointSlice$Status$200 | keyof Response$createDiscoveryV1NamespacedEndpointSlice$Status$201 | keyof Response$createDiscoveryV1NamespacedEndpointSlice$Status$202;
export interface Params$createDiscoveryV1NamespacedEndpointSlice<U extends ResponseContentType$createDiscoveryV1NamespacedEndpointSlice> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createDiscoveryV1NamespacedEndpointSlice;
    requestBody: RequestBody$createDiscoveryV1NamespacedEndpointSlice["*/*"];
}
export declare type RequestContentType$deleteDiscoveryV1CollectionNamespacedEndpointSlice = keyof RequestBody$deleteDiscoveryV1CollectionNamespacedEndpointSlice;
export declare type ResponseContentType$deleteDiscoveryV1CollectionNamespacedEndpointSlice = keyof Response$deleteDiscoveryV1CollectionNamespacedEndpointSlice$Status$200;
export interface Params$deleteDiscoveryV1CollectionNamespacedEndpointSlice<U extends ResponseContentType$deleteDiscoveryV1CollectionNamespacedEndpointSlice> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteDiscoveryV1CollectionNamespacedEndpointSlice;
    requestBody: RequestBody$deleteDiscoveryV1CollectionNamespacedEndpointSlice["*/*"];
}
export declare type ResponseContentType$readDiscoveryV1NamespacedEndpointSlice = keyof Response$readDiscoveryV1NamespacedEndpointSlice$Status$200;
export interface Params$readDiscoveryV1NamespacedEndpointSlice<U extends ResponseContentType$readDiscoveryV1NamespacedEndpointSlice> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readDiscoveryV1NamespacedEndpointSlice;
}
export declare type RequestContentType$replaceDiscoveryV1NamespacedEndpointSlice = keyof RequestBody$replaceDiscoveryV1NamespacedEndpointSlice;
export declare type ResponseContentType$replaceDiscoveryV1NamespacedEndpointSlice = keyof Response$replaceDiscoveryV1NamespacedEndpointSlice$Status$200 | keyof Response$replaceDiscoveryV1NamespacedEndpointSlice$Status$201;
export interface Params$replaceDiscoveryV1NamespacedEndpointSlice<U extends ResponseContentType$replaceDiscoveryV1NamespacedEndpointSlice> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceDiscoveryV1NamespacedEndpointSlice;
    requestBody: RequestBody$replaceDiscoveryV1NamespacedEndpointSlice["*/*"];
}
export declare type RequestContentType$deleteDiscoveryV1NamespacedEndpointSlice = keyof RequestBody$deleteDiscoveryV1NamespacedEndpointSlice;
export declare type ResponseContentType$deleteDiscoveryV1NamespacedEndpointSlice = keyof Response$deleteDiscoveryV1NamespacedEndpointSlice$Status$200 | keyof Response$deleteDiscoveryV1NamespacedEndpointSlice$Status$202;
export interface Params$deleteDiscoveryV1NamespacedEndpointSlice<U extends ResponseContentType$deleteDiscoveryV1NamespacedEndpointSlice> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteDiscoveryV1NamespacedEndpointSlice;
    requestBody: RequestBody$deleteDiscoveryV1NamespacedEndpointSlice["*/*"];
}
export declare type RequestContentType$patchDiscoveryV1NamespacedEndpointSlice = keyof RequestBody$patchDiscoveryV1NamespacedEndpointSlice;
export declare type ResponseContentType$patchDiscoveryV1NamespacedEndpointSlice = keyof Response$patchDiscoveryV1NamespacedEndpointSlice$Status$200 | keyof Response$patchDiscoveryV1NamespacedEndpointSlice$Status$201;
export interface Params$patchDiscoveryV1NamespacedEndpointSlice<T extends RequestContentType$patchDiscoveryV1NamespacedEndpointSlice, U extends ResponseContentType$patchDiscoveryV1NamespacedEndpointSlice> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchDiscoveryV1NamespacedEndpointSlice;
    requestBody: RequestBody$patchDiscoveryV1NamespacedEndpointSlice[T];
}
export declare type ResponseContentType$watchDiscoveryV1EndpointSliceListForAllNamespaces = keyof Response$watchDiscoveryV1EndpointSliceListForAllNamespaces$Status$200;
export interface Params$watchDiscoveryV1EndpointSliceListForAllNamespaces<U extends ResponseContentType$watchDiscoveryV1EndpointSliceListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchDiscoveryV1EndpointSliceListForAllNamespaces;
}
export declare type ResponseContentType$watchDiscoveryV1NamespacedEndpointSliceList = keyof Response$watchDiscoveryV1NamespacedEndpointSliceList$Status$200;
export interface Params$watchDiscoveryV1NamespacedEndpointSliceList<U extends ResponseContentType$watchDiscoveryV1NamespacedEndpointSliceList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchDiscoveryV1NamespacedEndpointSliceList;
}
export declare type ResponseContentType$watchDiscoveryV1NamespacedEndpointSlice = keyof Response$watchDiscoveryV1NamespacedEndpointSlice$Status$200;
export interface Params$watchDiscoveryV1NamespacedEndpointSlice<U extends ResponseContentType$watchDiscoveryV1NamespacedEndpointSlice> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchDiscoveryV1NamespacedEndpointSlice;
}
export declare type ResponseContentType$getDiscoveryV1beta1APIResources = keyof Response$getDiscoveryV1beta1APIResources$Status$200;
export interface Params$getDiscoveryV1beta1APIResources<U extends ResponseContentType$getDiscoveryV1beta1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listDiscoveryV1beta1EndpointSliceForAllNamespaces = keyof Response$listDiscoveryV1beta1EndpointSliceForAllNamespaces$Status$200;
export interface Params$listDiscoveryV1beta1EndpointSliceForAllNamespaces<U extends ResponseContentType$listDiscoveryV1beta1EndpointSliceForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listDiscoveryV1beta1EndpointSliceForAllNamespaces;
}
export declare type ResponseContentType$listDiscoveryV1beta1NamespacedEndpointSlice = keyof Response$listDiscoveryV1beta1NamespacedEndpointSlice$Status$200;
export interface Params$listDiscoveryV1beta1NamespacedEndpointSlice<U extends ResponseContentType$listDiscoveryV1beta1NamespacedEndpointSlice> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listDiscoveryV1beta1NamespacedEndpointSlice;
}
export declare type RequestContentType$createDiscoveryV1beta1NamespacedEndpointSlice = keyof RequestBody$createDiscoveryV1beta1NamespacedEndpointSlice;
export declare type ResponseContentType$createDiscoveryV1beta1NamespacedEndpointSlice = keyof Response$createDiscoveryV1beta1NamespacedEndpointSlice$Status$200 | keyof Response$createDiscoveryV1beta1NamespacedEndpointSlice$Status$201 | keyof Response$createDiscoveryV1beta1NamespacedEndpointSlice$Status$202;
export interface Params$createDiscoveryV1beta1NamespacedEndpointSlice<U extends ResponseContentType$createDiscoveryV1beta1NamespacedEndpointSlice> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createDiscoveryV1beta1NamespacedEndpointSlice;
    requestBody: RequestBody$createDiscoveryV1beta1NamespacedEndpointSlice["*/*"];
}
export declare type RequestContentType$deleteDiscoveryV1beta1CollectionNamespacedEndpointSlice = keyof RequestBody$deleteDiscoveryV1beta1CollectionNamespacedEndpointSlice;
export declare type ResponseContentType$deleteDiscoveryV1beta1CollectionNamespacedEndpointSlice = keyof Response$deleteDiscoveryV1beta1CollectionNamespacedEndpointSlice$Status$200;
export interface Params$deleteDiscoveryV1beta1CollectionNamespacedEndpointSlice<U extends ResponseContentType$deleteDiscoveryV1beta1CollectionNamespacedEndpointSlice> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteDiscoveryV1beta1CollectionNamespacedEndpointSlice;
    requestBody: RequestBody$deleteDiscoveryV1beta1CollectionNamespacedEndpointSlice["*/*"];
}
export declare type ResponseContentType$readDiscoveryV1beta1NamespacedEndpointSlice = keyof Response$readDiscoveryV1beta1NamespacedEndpointSlice$Status$200;
export interface Params$readDiscoveryV1beta1NamespacedEndpointSlice<U extends ResponseContentType$readDiscoveryV1beta1NamespacedEndpointSlice> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readDiscoveryV1beta1NamespacedEndpointSlice;
}
export declare type RequestContentType$replaceDiscoveryV1beta1NamespacedEndpointSlice = keyof RequestBody$replaceDiscoveryV1beta1NamespacedEndpointSlice;
export declare type ResponseContentType$replaceDiscoveryV1beta1NamespacedEndpointSlice = keyof Response$replaceDiscoveryV1beta1NamespacedEndpointSlice$Status$200 | keyof Response$replaceDiscoveryV1beta1NamespacedEndpointSlice$Status$201;
export interface Params$replaceDiscoveryV1beta1NamespacedEndpointSlice<U extends ResponseContentType$replaceDiscoveryV1beta1NamespacedEndpointSlice> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceDiscoveryV1beta1NamespacedEndpointSlice;
    requestBody: RequestBody$replaceDiscoveryV1beta1NamespacedEndpointSlice["*/*"];
}
export declare type RequestContentType$deleteDiscoveryV1beta1NamespacedEndpointSlice = keyof RequestBody$deleteDiscoveryV1beta1NamespacedEndpointSlice;
export declare type ResponseContentType$deleteDiscoveryV1beta1NamespacedEndpointSlice = keyof Response$deleteDiscoveryV1beta1NamespacedEndpointSlice$Status$200 | keyof Response$deleteDiscoveryV1beta1NamespacedEndpointSlice$Status$202;
export interface Params$deleteDiscoveryV1beta1NamespacedEndpointSlice<U extends ResponseContentType$deleteDiscoveryV1beta1NamespacedEndpointSlice> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteDiscoveryV1beta1NamespacedEndpointSlice;
    requestBody: RequestBody$deleteDiscoveryV1beta1NamespacedEndpointSlice["*/*"];
}
export declare type RequestContentType$patchDiscoveryV1beta1NamespacedEndpointSlice = keyof RequestBody$patchDiscoveryV1beta1NamespacedEndpointSlice;
export declare type ResponseContentType$patchDiscoveryV1beta1NamespacedEndpointSlice = keyof Response$patchDiscoveryV1beta1NamespacedEndpointSlice$Status$200 | keyof Response$patchDiscoveryV1beta1NamespacedEndpointSlice$Status$201;
export interface Params$patchDiscoveryV1beta1NamespacedEndpointSlice<T extends RequestContentType$patchDiscoveryV1beta1NamespacedEndpointSlice, U extends ResponseContentType$patchDiscoveryV1beta1NamespacedEndpointSlice> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchDiscoveryV1beta1NamespacedEndpointSlice;
    requestBody: RequestBody$patchDiscoveryV1beta1NamespacedEndpointSlice[T];
}
export declare type ResponseContentType$watchDiscoveryV1beta1EndpointSliceListForAllNamespaces = keyof Response$watchDiscoveryV1beta1EndpointSliceListForAllNamespaces$Status$200;
export interface Params$watchDiscoveryV1beta1EndpointSliceListForAllNamespaces<U extends ResponseContentType$watchDiscoveryV1beta1EndpointSliceListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchDiscoveryV1beta1EndpointSliceListForAllNamespaces;
}
export declare type ResponseContentType$watchDiscoveryV1beta1NamespacedEndpointSliceList = keyof Response$watchDiscoveryV1beta1NamespacedEndpointSliceList$Status$200;
export interface Params$watchDiscoveryV1beta1NamespacedEndpointSliceList<U extends ResponseContentType$watchDiscoveryV1beta1NamespacedEndpointSliceList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchDiscoveryV1beta1NamespacedEndpointSliceList;
}
export declare type ResponseContentType$watchDiscoveryV1beta1NamespacedEndpointSlice = keyof Response$watchDiscoveryV1beta1NamespacedEndpointSlice$Status$200;
export interface Params$watchDiscoveryV1beta1NamespacedEndpointSlice<U extends ResponseContentType$watchDiscoveryV1beta1NamespacedEndpointSlice> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchDiscoveryV1beta1NamespacedEndpointSlice;
}
export declare type ResponseContentType$getEventsAPIGroup = keyof Response$getEventsAPIGroup$Status$200;
export interface Params$getEventsAPIGroup<U extends ResponseContentType$getEventsAPIGroup> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$getEventsV1APIResources = keyof Response$getEventsV1APIResources$Status$200;
export interface Params$getEventsV1APIResources<U extends ResponseContentType$getEventsV1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listEventsV1EventForAllNamespaces = keyof Response$listEventsV1EventForAllNamespaces$Status$200;
export interface Params$listEventsV1EventForAllNamespaces<U extends ResponseContentType$listEventsV1EventForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listEventsV1EventForAllNamespaces;
}
export declare type ResponseContentType$listEventsV1NamespacedEvent = keyof Response$listEventsV1NamespacedEvent$Status$200;
export interface Params$listEventsV1NamespacedEvent<U extends ResponseContentType$listEventsV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listEventsV1NamespacedEvent;
}
export declare type RequestContentType$createEventsV1NamespacedEvent = keyof RequestBody$createEventsV1NamespacedEvent;
export declare type ResponseContentType$createEventsV1NamespacedEvent = keyof Response$createEventsV1NamespacedEvent$Status$200 | keyof Response$createEventsV1NamespacedEvent$Status$201 | keyof Response$createEventsV1NamespacedEvent$Status$202;
export interface Params$createEventsV1NamespacedEvent<U extends ResponseContentType$createEventsV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createEventsV1NamespacedEvent;
    requestBody: RequestBody$createEventsV1NamespacedEvent["*/*"];
}
export declare type RequestContentType$deleteEventsV1CollectionNamespacedEvent = keyof RequestBody$deleteEventsV1CollectionNamespacedEvent;
export declare type ResponseContentType$deleteEventsV1CollectionNamespacedEvent = keyof Response$deleteEventsV1CollectionNamespacedEvent$Status$200;
export interface Params$deleteEventsV1CollectionNamespacedEvent<U extends ResponseContentType$deleteEventsV1CollectionNamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteEventsV1CollectionNamespacedEvent;
    requestBody: RequestBody$deleteEventsV1CollectionNamespacedEvent["*/*"];
}
export declare type ResponseContentType$readEventsV1NamespacedEvent = keyof Response$readEventsV1NamespacedEvent$Status$200;
export interface Params$readEventsV1NamespacedEvent<U extends ResponseContentType$readEventsV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readEventsV1NamespacedEvent;
}
export declare type RequestContentType$replaceEventsV1NamespacedEvent = keyof RequestBody$replaceEventsV1NamespacedEvent;
export declare type ResponseContentType$replaceEventsV1NamespacedEvent = keyof Response$replaceEventsV1NamespacedEvent$Status$200 | keyof Response$replaceEventsV1NamespacedEvent$Status$201;
export interface Params$replaceEventsV1NamespacedEvent<U extends ResponseContentType$replaceEventsV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceEventsV1NamespacedEvent;
    requestBody: RequestBody$replaceEventsV1NamespacedEvent["*/*"];
}
export declare type RequestContentType$deleteEventsV1NamespacedEvent = keyof RequestBody$deleteEventsV1NamespacedEvent;
export declare type ResponseContentType$deleteEventsV1NamespacedEvent = keyof Response$deleteEventsV1NamespacedEvent$Status$200 | keyof Response$deleteEventsV1NamespacedEvent$Status$202;
export interface Params$deleteEventsV1NamespacedEvent<U extends ResponseContentType$deleteEventsV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteEventsV1NamespacedEvent;
    requestBody: RequestBody$deleteEventsV1NamespacedEvent["*/*"];
}
export declare type RequestContentType$patchEventsV1NamespacedEvent = keyof RequestBody$patchEventsV1NamespacedEvent;
export declare type ResponseContentType$patchEventsV1NamespacedEvent = keyof Response$patchEventsV1NamespacedEvent$Status$200 | keyof Response$patchEventsV1NamespacedEvent$Status$201;
export interface Params$patchEventsV1NamespacedEvent<T extends RequestContentType$patchEventsV1NamespacedEvent, U extends ResponseContentType$patchEventsV1NamespacedEvent> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchEventsV1NamespacedEvent;
    requestBody: RequestBody$patchEventsV1NamespacedEvent[T];
}
export declare type ResponseContentType$watchEventsV1EventListForAllNamespaces = keyof Response$watchEventsV1EventListForAllNamespaces$Status$200;
export interface Params$watchEventsV1EventListForAllNamespaces<U extends ResponseContentType$watchEventsV1EventListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchEventsV1EventListForAllNamespaces;
}
export declare type ResponseContentType$watchEventsV1NamespacedEventList = keyof Response$watchEventsV1NamespacedEventList$Status$200;
export interface Params$watchEventsV1NamespacedEventList<U extends ResponseContentType$watchEventsV1NamespacedEventList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchEventsV1NamespacedEventList;
}
export declare type ResponseContentType$watchEventsV1NamespacedEvent = keyof Response$watchEventsV1NamespacedEvent$Status$200;
export interface Params$watchEventsV1NamespacedEvent<U extends ResponseContentType$watchEventsV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchEventsV1NamespacedEvent;
}
export declare type ResponseContentType$getEventsV1beta1APIResources = keyof Response$getEventsV1beta1APIResources$Status$200;
export interface Params$getEventsV1beta1APIResources<U extends ResponseContentType$getEventsV1beta1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listEventsV1beta1EventForAllNamespaces = keyof Response$listEventsV1beta1EventForAllNamespaces$Status$200;
export interface Params$listEventsV1beta1EventForAllNamespaces<U extends ResponseContentType$listEventsV1beta1EventForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listEventsV1beta1EventForAllNamespaces;
}
export declare type ResponseContentType$listEventsV1beta1NamespacedEvent = keyof Response$listEventsV1beta1NamespacedEvent$Status$200;
export interface Params$listEventsV1beta1NamespacedEvent<U extends ResponseContentType$listEventsV1beta1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listEventsV1beta1NamespacedEvent;
}
export declare type RequestContentType$createEventsV1beta1NamespacedEvent = keyof RequestBody$createEventsV1beta1NamespacedEvent;
export declare type ResponseContentType$createEventsV1beta1NamespacedEvent = keyof Response$createEventsV1beta1NamespacedEvent$Status$200 | keyof Response$createEventsV1beta1NamespacedEvent$Status$201 | keyof Response$createEventsV1beta1NamespacedEvent$Status$202;
export interface Params$createEventsV1beta1NamespacedEvent<U extends ResponseContentType$createEventsV1beta1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createEventsV1beta1NamespacedEvent;
    requestBody: RequestBody$createEventsV1beta1NamespacedEvent["*/*"];
}
export declare type RequestContentType$deleteEventsV1beta1CollectionNamespacedEvent = keyof RequestBody$deleteEventsV1beta1CollectionNamespacedEvent;
export declare type ResponseContentType$deleteEventsV1beta1CollectionNamespacedEvent = keyof Response$deleteEventsV1beta1CollectionNamespacedEvent$Status$200;
export interface Params$deleteEventsV1beta1CollectionNamespacedEvent<U extends ResponseContentType$deleteEventsV1beta1CollectionNamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteEventsV1beta1CollectionNamespacedEvent;
    requestBody: RequestBody$deleteEventsV1beta1CollectionNamespacedEvent["*/*"];
}
export declare type ResponseContentType$readEventsV1beta1NamespacedEvent = keyof Response$readEventsV1beta1NamespacedEvent$Status$200;
export interface Params$readEventsV1beta1NamespacedEvent<U extends ResponseContentType$readEventsV1beta1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readEventsV1beta1NamespacedEvent;
}
export declare type RequestContentType$replaceEventsV1beta1NamespacedEvent = keyof RequestBody$replaceEventsV1beta1NamespacedEvent;
export declare type ResponseContentType$replaceEventsV1beta1NamespacedEvent = keyof Response$replaceEventsV1beta1NamespacedEvent$Status$200 | keyof Response$replaceEventsV1beta1NamespacedEvent$Status$201;
export interface Params$replaceEventsV1beta1NamespacedEvent<U extends ResponseContentType$replaceEventsV1beta1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceEventsV1beta1NamespacedEvent;
    requestBody: RequestBody$replaceEventsV1beta1NamespacedEvent["*/*"];
}
export declare type RequestContentType$deleteEventsV1beta1NamespacedEvent = keyof RequestBody$deleteEventsV1beta1NamespacedEvent;
export declare type ResponseContentType$deleteEventsV1beta1NamespacedEvent = keyof Response$deleteEventsV1beta1NamespacedEvent$Status$200 | keyof Response$deleteEventsV1beta1NamespacedEvent$Status$202;
export interface Params$deleteEventsV1beta1NamespacedEvent<U extends ResponseContentType$deleteEventsV1beta1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteEventsV1beta1NamespacedEvent;
    requestBody: RequestBody$deleteEventsV1beta1NamespacedEvent["*/*"];
}
export declare type RequestContentType$patchEventsV1beta1NamespacedEvent = keyof RequestBody$patchEventsV1beta1NamespacedEvent;
export declare type ResponseContentType$patchEventsV1beta1NamespacedEvent = keyof Response$patchEventsV1beta1NamespacedEvent$Status$200 | keyof Response$patchEventsV1beta1NamespacedEvent$Status$201;
export interface Params$patchEventsV1beta1NamespacedEvent<T extends RequestContentType$patchEventsV1beta1NamespacedEvent, U extends ResponseContentType$patchEventsV1beta1NamespacedEvent> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchEventsV1beta1NamespacedEvent;
    requestBody: RequestBody$patchEventsV1beta1NamespacedEvent[T];
}
export declare type ResponseContentType$watchEventsV1beta1EventListForAllNamespaces = keyof Response$watchEventsV1beta1EventListForAllNamespaces$Status$200;
export interface Params$watchEventsV1beta1EventListForAllNamespaces<U extends ResponseContentType$watchEventsV1beta1EventListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchEventsV1beta1EventListForAllNamespaces;
}
export declare type ResponseContentType$watchEventsV1beta1NamespacedEventList = keyof Response$watchEventsV1beta1NamespacedEventList$Status$200;
export interface Params$watchEventsV1beta1NamespacedEventList<U extends ResponseContentType$watchEventsV1beta1NamespacedEventList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchEventsV1beta1NamespacedEventList;
}
export declare type ResponseContentType$watchEventsV1beta1NamespacedEvent = keyof Response$watchEventsV1beta1NamespacedEvent$Status$200;
export interface Params$watchEventsV1beta1NamespacedEvent<U extends ResponseContentType$watchEventsV1beta1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchEventsV1beta1NamespacedEvent;
}
export declare type ResponseContentType$getFlowcontrolApiserverAPIGroup = keyof Response$getFlowcontrolApiserverAPIGroup$Status$200;
export interface Params$getFlowcontrolApiserverAPIGroup<U extends ResponseContentType$getFlowcontrolApiserverAPIGroup> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$getFlowcontrolApiserverV1beta1APIResources = keyof Response$getFlowcontrolApiserverV1beta1APIResources$Status$200;
export interface Params$getFlowcontrolApiserverV1beta1APIResources<U extends ResponseContentType$getFlowcontrolApiserverV1beta1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listFlowcontrolApiserverV1beta1FlowSchema = keyof Response$listFlowcontrolApiserverV1beta1FlowSchema$Status$200;
export interface Params$listFlowcontrolApiserverV1beta1FlowSchema<U extends ResponseContentType$listFlowcontrolApiserverV1beta1FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listFlowcontrolApiserverV1beta1FlowSchema;
}
export declare type RequestContentType$createFlowcontrolApiserverV1beta1FlowSchema = keyof RequestBody$createFlowcontrolApiserverV1beta1FlowSchema;
export declare type ResponseContentType$createFlowcontrolApiserverV1beta1FlowSchema = keyof Response$createFlowcontrolApiserverV1beta1FlowSchema$Status$200 | keyof Response$createFlowcontrolApiserverV1beta1FlowSchema$Status$201 | keyof Response$createFlowcontrolApiserverV1beta1FlowSchema$Status$202;
export interface Params$createFlowcontrolApiserverV1beta1FlowSchema<U extends ResponseContentType$createFlowcontrolApiserverV1beta1FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createFlowcontrolApiserverV1beta1FlowSchema;
    requestBody: RequestBody$createFlowcontrolApiserverV1beta1FlowSchema["*/*"];
}
export declare type RequestContentType$deleteFlowcontrolApiserverV1beta1CollectionFlowSchema = keyof RequestBody$deleteFlowcontrolApiserverV1beta1CollectionFlowSchema;
export declare type ResponseContentType$deleteFlowcontrolApiserverV1beta1CollectionFlowSchema = keyof Response$deleteFlowcontrolApiserverV1beta1CollectionFlowSchema$Status$200;
export interface Params$deleteFlowcontrolApiserverV1beta1CollectionFlowSchema<U extends ResponseContentType$deleteFlowcontrolApiserverV1beta1CollectionFlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteFlowcontrolApiserverV1beta1CollectionFlowSchema;
    requestBody: RequestBody$deleteFlowcontrolApiserverV1beta1CollectionFlowSchema["*/*"];
}
export declare type ResponseContentType$readFlowcontrolApiserverV1beta1FlowSchema = keyof Response$readFlowcontrolApiserverV1beta1FlowSchema$Status$200;
export interface Params$readFlowcontrolApiserverV1beta1FlowSchema<U extends ResponseContentType$readFlowcontrolApiserverV1beta1FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readFlowcontrolApiserverV1beta1FlowSchema;
}
export declare type RequestContentType$replaceFlowcontrolApiserverV1beta1FlowSchema = keyof RequestBody$replaceFlowcontrolApiserverV1beta1FlowSchema;
export declare type ResponseContentType$replaceFlowcontrolApiserverV1beta1FlowSchema = keyof Response$replaceFlowcontrolApiserverV1beta1FlowSchema$Status$200 | keyof Response$replaceFlowcontrolApiserverV1beta1FlowSchema$Status$201;
export interface Params$replaceFlowcontrolApiserverV1beta1FlowSchema<U extends ResponseContentType$replaceFlowcontrolApiserverV1beta1FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceFlowcontrolApiserverV1beta1FlowSchema;
    requestBody: RequestBody$replaceFlowcontrolApiserverV1beta1FlowSchema["*/*"];
}
export declare type RequestContentType$deleteFlowcontrolApiserverV1beta1FlowSchema = keyof RequestBody$deleteFlowcontrolApiserverV1beta1FlowSchema;
export declare type ResponseContentType$deleteFlowcontrolApiserverV1beta1FlowSchema = keyof Response$deleteFlowcontrolApiserverV1beta1FlowSchema$Status$200 | keyof Response$deleteFlowcontrolApiserverV1beta1FlowSchema$Status$202;
export interface Params$deleteFlowcontrolApiserverV1beta1FlowSchema<U extends ResponseContentType$deleteFlowcontrolApiserverV1beta1FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteFlowcontrolApiserverV1beta1FlowSchema;
    requestBody: RequestBody$deleteFlowcontrolApiserverV1beta1FlowSchema["*/*"];
}
export declare type RequestContentType$patchFlowcontrolApiserverV1beta1FlowSchema = keyof RequestBody$patchFlowcontrolApiserverV1beta1FlowSchema;
export declare type ResponseContentType$patchFlowcontrolApiserverV1beta1FlowSchema = keyof Response$patchFlowcontrolApiserverV1beta1FlowSchema$Status$200 | keyof Response$patchFlowcontrolApiserverV1beta1FlowSchema$Status$201;
export interface Params$patchFlowcontrolApiserverV1beta1FlowSchema<T extends RequestContentType$patchFlowcontrolApiserverV1beta1FlowSchema, U extends ResponseContentType$patchFlowcontrolApiserverV1beta1FlowSchema> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchFlowcontrolApiserverV1beta1FlowSchema;
    requestBody: RequestBody$patchFlowcontrolApiserverV1beta1FlowSchema[T];
}
export declare type ResponseContentType$readFlowcontrolApiserverV1beta1FlowSchemaStatus = keyof Response$readFlowcontrolApiserverV1beta1FlowSchemaStatus$Status$200;
export interface Params$readFlowcontrolApiserverV1beta1FlowSchemaStatus<U extends ResponseContentType$readFlowcontrolApiserverV1beta1FlowSchemaStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readFlowcontrolApiserverV1beta1FlowSchemaStatus;
}
export declare type RequestContentType$replaceFlowcontrolApiserverV1beta1FlowSchemaStatus = keyof RequestBody$replaceFlowcontrolApiserverV1beta1FlowSchemaStatus;
export declare type ResponseContentType$replaceFlowcontrolApiserverV1beta1FlowSchemaStatus = keyof Response$replaceFlowcontrolApiserverV1beta1FlowSchemaStatus$Status$200 | keyof Response$replaceFlowcontrolApiserverV1beta1FlowSchemaStatus$Status$201;
export interface Params$replaceFlowcontrolApiserverV1beta1FlowSchemaStatus<U extends ResponseContentType$replaceFlowcontrolApiserverV1beta1FlowSchemaStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceFlowcontrolApiserverV1beta1FlowSchemaStatus;
    requestBody: RequestBody$replaceFlowcontrolApiserverV1beta1FlowSchemaStatus["*/*"];
}
export declare type RequestContentType$patchFlowcontrolApiserverV1beta1FlowSchemaStatus = keyof RequestBody$patchFlowcontrolApiserverV1beta1FlowSchemaStatus;
export declare type ResponseContentType$patchFlowcontrolApiserverV1beta1FlowSchemaStatus = keyof Response$patchFlowcontrolApiserverV1beta1FlowSchemaStatus$Status$200 | keyof Response$patchFlowcontrolApiserverV1beta1FlowSchemaStatus$Status$201;
export interface Params$patchFlowcontrolApiserverV1beta1FlowSchemaStatus<T extends RequestContentType$patchFlowcontrolApiserverV1beta1FlowSchemaStatus, U extends ResponseContentType$patchFlowcontrolApiserverV1beta1FlowSchemaStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchFlowcontrolApiserverV1beta1FlowSchemaStatus;
    requestBody: RequestBody$patchFlowcontrolApiserverV1beta1FlowSchemaStatus[T];
}
export declare type ResponseContentType$listFlowcontrolApiserverV1beta1PriorityLevelConfiguration = keyof Response$listFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200;
export interface Params$listFlowcontrolApiserverV1beta1PriorityLevelConfiguration<U extends ResponseContentType$listFlowcontrolApiserverV1beta1PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listFlowcontrolApiserverV1beta1PriorityLevelConfiguration;
}
export declare type RequestContentType$createFlowcontrolApiserverV1beta1PriorityLevelConfiguration = keyof RequestBody$createFlowcontrolApiserverV1beta1PriorityLevelConfiguration;
export declare type ResponseContentType$createFlowcontrolApiserverV1beta1PriorityLevelConfiguration = keyof Response$createFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200 | keyof Response$createFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$201 | keyof Response$createFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$202;
export interface Params$createFlowcontrolApiserverV1beta1PriorityLevelConfiguration<U extends ResponseContentType$createFlowcontrolApiserverV1beta1PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createFlowcontrolApiserverV1beta1PriorityLevelConfiguration;
    requestBody: RequestBody$createFlowcontrolApiserverV1beta1PriorityLevelConfiguration["*/*"];
}
export declare type RequestContentType$deleteFlowcontrolApiserverV1beta1CollectionPriorityLevelConfiguration = keyof RequestBody$deleteFlowcontrolApiserverV1beta1CollectionPriorityLevelConfiguration;
export declare type ResponseContentType$deleteFlowcontrolApiserverV1beta1CollectionPriorityLevelConfiguration = keyof Response$deleteFlowcontrolApiserverV1beta1CollectionPriorityLevelConfiguration$Status$200;
export interface Params$deleteFlowcontrolApiserverV1beta1CollectionPriorityLevelConfiguration<U extends ResponseContentType$deleteFlowcontrolApiserverV1beta1CollectionPriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteFlowcontrolApiserverV1beta1CollectionPriorityLevelConfiguration;
    requestBody: RequestBody$deleteFlowcontrolApiserverV1beta1CollectionPriorityLevelConfiguration["*/*"];
}
export declare type ResponseContentType$readFlowcontrolApiserverV1beta1PriorityLevelConfiguration = keyof Response$readFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200;
export interface Params$readFlowcontrolApiserverV1beta1PriorityLevelConfiguration<U extends ResponseContentType$readFlowcontrolApiserverV1beta1PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readFlowcontrolApiserverV1beta1PriorityLevelConfiguration;
}
export declare type RequestContentType$replaceFlowcontrolApiserverV1beta1PriorityLevelConfiguration = keyof RequestBody$replaceFlowcontrolApiserverV1beta1PriorityLevelConfiguration;
export declare type ResponseContentType$replaceFlowcontrolApiserverV1beta1PriorityLevelConfiguration = keyof Response$replaceFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200 | keyof Response$replaceFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$201;
export interface Params$replaceFlowcontrolApiserverV1beta1PriorityLevelConfiguration<U extends ResponseContentType$replaceFlowcontrolApiserverV1beta1PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceFlowcontrolApiserverV1beta1PriorityLevelConfiguration;
    requestBody: RequestBody$replaceFlowcontrolApiserverV1beta1PriorityLevelConfiguration["*/*"];
}
export declare type RequestContentType$deleteFlowcontrolApiserverV1beta1PriorityLevelConfiguration = keyof RequestBody$deleteFlowcontrolApiserverV1beta1PriorityLevelConfiguration;
export declare type ResponseContentType$deleteFlowcontrolApiserverV1beta1PriorityLevelConfiguration = keyof Response$deleteFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200 | keyof Response$deleteFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$202;
export interface Params$deleteFlowcontrolApiserverV1beta1PriorityLevelConfiguration<U extends ResponseContentType$deleteFlowcontrolApiserverV1beta1PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteFlowcontrolApiserverV1beta1PriorityLevelConfiguration;
    requestBody: RequestBody$deleteFlowcontrolApiserverV1beta1PriorityLevelConfiguration["*/*"];
}
export declare type RequestContentType$patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration = keyof RequestBody$patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration;
export declare type ResponseContentType$patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration = keyof Response$patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200 | keyof Response$patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$201;
export interface Params$patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration<T extends RequestContentType$patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration, U extends ResponseContentType$patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration;
    requestBody: RequestBody$patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration[T];
}
export declare type ResponseContentType$readFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus = keyof Response$readFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus$Status$200;
export interface Params$readFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus<U extends ResponseContentType$readFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus;
}
export declare type RequestContentType$replaceFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus = keyof RequestBody$replaceFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus;
export declare type ResponseContentType$replaceFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus = keyof Response$replaceFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus$Status$200 | keyof Response$replaceFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus$Status$201;
export interface Params$replaceFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus<U extends ResponseContentType$replaceFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus;
    requestBody: RequestBody$replaceFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus["*/*"];
}
export declare type RequestContentType$patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus = keyof RequestBody$patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus;
export declare type ResponseContentType$patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus = keyof Response$patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus$Status$200 | keyof Response$patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus$Status$201;
export interface Params$patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus<T extends RequestContentType$patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus, U extends ResponseContentType$patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus;
    requestBody: RequestBody$patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus[T];
}
export declare type ResponseContentType$watchFlowcontrolApiserverV1beta1FlowSchemaList = keyof Response$watchFlowcontrolApiserverV1beta1FlowSchemaList$Status$200;
export interface Params$watchFlowcontrolApiserverV1beta1FlowSchemaList<U extends ResponseContentType$watchFlowcontrolApiserverV1beta1FlowSchemaList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchFlowcontrolApiserverV1beta1FlowSchemaList;
}
export declare type ResponseContentType$watchFlowcontrolApiserverV1beta1FlowSchema = keyof Response$watchFlowcontrolApiserverV1beta1FlowSchema$Status$200;
export interface Params$watchFlowcontrolApiserverV1beta1FlowSchema<U extends ResponseContentType$watchFlowcontrolApiserverV1beta1FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchFlowcontrolApiserverV1beta1FlowSchema;
}
export declare type ResponseContentType$watchFlowcontrolApiserverV1beta1PriorityLevelConfigurationList = keyof Response$watchFlowcontrolApiserverV1beta1PriorityLevelConfigurationList$Status$200;
export interface Params$watchFlowcontrolApiserverV1beta1PriorityLevelConfigurationList<U extends ResponseContentType$watchFlowcontrolApiserverV1beta1PriorityLevelConfigurationList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchFlowcontrolApiserverV1beta1PriorityLevelConfigurationList;
}
export declare type ResponseContentType$watchFlowcontrolApiserverV1beta1PriorityLevelConfiguration = keyof Response$watchFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200;
export interface Params$watchFlowcontrolApiserverV1beta1PriorityLevelConfiguration<U extends ResponseContentType$watchFlowcontrolApiserverV1beta1PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchFlowcontrolApiserverV1beta1PriorityLevelConfiguration;
}
export declare type ResponseContentType$getFlowcontrolApiserverV1beta2APIResources = keyof Response$getFlowcontrolApiserverV1beta2APIResources$Status$200;
export interface Params$getFlowcontrolApiserverV1beta2APIResources<U extends ResponseContentType$getFlowcontrolApiserverV1beta2APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listFlowcontrolApiserverV1beta2FlowSchema = keyof Response$listFlowcontrolApiserverV1beta2FlowSchema$Status$200;
export interface Params$listFlowcontrolApiserverV1beta2FlowSchema<U extends ResponseContentType$listFlowcontrolApiserverV1beta2FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listFlowcontrolApiserverV1beta2FlowSchema;
}
export declare type RequestContentType$createFlowcontrolApiserverV1beta2FlowSchema = keyof RequestBody$createFlowcontrolApiserverV1beta2FlowSchema;
export declare type ResponseContentType$createFlowcontrolApiserverV1beta2FlowSchema = keyof Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$200 | keyof Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$201 | keyof Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$202;
export interface Params$createFlowcontrolApiserverV1beta2FlowSchema<U extends ResponseContentType$createFlowcontrolApiserverV1beta2FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createFlowcontrolApiserverV1beta2FlowSchema;
    requestBody: RequestBody$createFlowcontrolApiserverV1beta2FlowSchema["*/*"];
}
export declare type RequestContentType$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema = keyof RequestBody$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema;
export declare type ResponseContentType$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema = keyof Response$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema$Status$200;
export interface Params$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema<U extends ResponseContentType$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema;
    requestBody: RequestBody$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema["*/*"];
}
export declare type ResponseContentType$readFlowcontrolApiserverV1beta2FlowSchema = keyof Response$readFlowcontrolApiserverV1beta2FlowSchema$Status$200;
export interface Params$readFlowcontrolApiserverV1beta2FlowSchema<U extends ResponseContentType$readFlowcontrolApiserverV1beta2FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readFlowcontrolApiserverV1beta2FlowSchema;
}
export declare type RequestContentType$replaceFlowcontrolApiserverV1beta2FlowSchema = keyof RequestBody$replaceFlowcontrolApiserverV1beta2FlowSchema;
export declare type ResponseContentType$replaceFlowcontrolApiserverV1beta2FlowSchema = keyof Response$replaceFlowcontrolApiserverV1beta2FlowSchema$Status$200 | keyof Response$replaceFlowcontrolApiserverV1beta2FlowSchema$Status$201;
export interface Params$replaceFlowcontrolApiserverV1beta2FlowSchema<U extends ResponseContentType$replaceFlowcontrolApiserverV1beta2FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceFlowcontrolApiserverV1beta2FlowSchema;
    requestBody: RequestBody$replaceFlowcontrolApiserverV1beta2FlowSchema["*/*"];
}
export declare type RequestContentType$deleteFlowcontrolApiserverV1beta2FlowSchema = keyof RequestBody$deleteFlowcontrolApiserverV1beta2FlowSchema;
export declare type ResponseContentType$deleteFlowcontrolApiserverV1beta2FlowSchema = keyof Response$deleteFlowcontrolApiserverV1beta2FlowSchema$Status$200 | keyof Response$deleteFlowcontrolApiserverV1beta2FlowSchema$Status$202;
export interface Params$deleteFlowcontrolApiserverV1beta2FlowSchema<U extends ResponseContentType$deleteFlowcontrolApiserverV1beta2FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteFlowcontrolApiserverV1beta2FlowSchema;
    requestBody: RequestBody$deleteFlowcontrolApiserverV1beta2FlowSchema["*/*"];
}
export declare type RequestContentType$patchFlowcontrolApiserverV1beta2FlowSchema = keyof RequestBody$patchFlowcontrolApiserverV1beta2FlowSchema;
export declare type ResponseContentType$patchFlowcontrolApiserverV1beta2FlowSchema = keyof Response$patchFlowcontrolApiserverV1beta2FlowSchema$Status$200 | keyof Response$patchFlowcontrolApiserverV1beta2FlowSchema$Status$201;
export interface Params$patchFlowcontrolApiserverV1beta2FlowSchema<T extends RequestContentType$patchFlowcontrolApiserverV1beta2FlowSchema, U extends ResponseContentType$patchFlowcontrolApiserverV1beta2FlowSchema> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchFlowcontrolApiserverV1beta2FlowSchema;
    requestBody: RequestBody$patchFlowcontrolApiserverV1beta2FlowSchema[T];
}
export declare type ResponseContentType$readFlowcontrolApiserverV1beta2FlowSchemaStatus = keyof Response$readFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200;
export interface Params$readFlowcontrolApiserverV1beta2FlowSchemaStatus<U extends ResponseContentType$readFlowcontrolApiserverV1beta2FlowSchemaStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readFlowcontrolApiserverV1beta2FlowSchemaStatus;
}
export declare type RequestContentType$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus = keyof RequestBody$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus;
export declare type ResponseContentType$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus = keyof Response$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200 | keyof Response$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$201;
export interface Params$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus<U extends ResponseContentType$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus;
    requestBody: RequestBody$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus["*/*"];
}
export declare type RequestContentType$patchFlowcontrolApiserverV1beta2FlowSchemaStatus = keyof RequestBody$patchFlowcontrolApiserverV1beta2FlowSchemaStatus;
export declare type ResponseContentType$patchFlowcontrolApiserverV1beta2FlowSchemaStatus = keyof Response$patchFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200 | keyof Response$patchFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$201;
export interface Params$patchFlowcontrolApiserverV1beta2FlowSchemaStatus<T extends RequestContentType$patchFlowcontrolApiserverV1beta2FlowSchemaStatus, U extends ResponseContentType$patchFlowcontrolApiserverV1beta2FlowSchemaStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchFlowcontrolApiserverV1beta2FlowSchemaStatus;
    requestBody: RequestBody$patchFlowcontrolApiserverV1beta2FlowSchemaStatus[T];
}
export declare type ResponseContentType$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration = keyof Response$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200;
export interface Params$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration<U extends ResponseContentType$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration;
}
export declare type RequestContentType$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration = keyof RequestBody$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration;
export declare type ResponseContentType$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration = keyof Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | keyof Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201 | keyof Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$202;
export interface Params$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration<U extends ResponseContentType$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration;
    requestBody: RequestBody$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration["*/*"];
}
export declare type RequestContentType$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration = keyof RequestBody$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration;
export declare type ResponseContentType$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration = keyof Response$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration$Status$200;
export interface Params$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration<U extends ResponseContentType$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration;
    requestBody: RequestBody$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration["*/*"];
}
export declare type ResponseContentType$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration = keyof Response$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200;
export interface Params$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration<U extends ResponseContentType$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration;
}
export declare type RequestContentType$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration = keyof RequestBody$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration;
export declare type ResponseContentType$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration = keyof Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | keyof Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201;
export interface Params$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration<U extends ResponseContentType$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration;
    requestBody: RequestBody$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration["*/*"];
}
export declare type RequestContentType$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration = keyof RequestBody$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration;
export declare type ResponseContentType$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration = keyof Response$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | keyof Response$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$202;
export interface Params$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration<U extends ResponseContentType$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration;
    requestBody: RequestBody$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration["*/*"];
}
export declare type RequestContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration = keyof RequestBody$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration;
export declare type ResponseContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration = keyof Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | keyof Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201;
export interface Params$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration<T extends RequestContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration, U extends ResponseContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration;
    requestBody: RequestBody$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration[T];
}
export declare type ResponseContentType$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus = keyof Response$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200;
export interface Params$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus<U extends ResponseContentType$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus;
}
export declare type RequestContentType$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus = keyof RequestBody$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus;
export declare type ResponseContentType$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus = keyof Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200 | keyof Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$201;
export interface Params$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus<U extends ResponseContentType$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus;
    requestBody: RequestBody$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus["*/*"];
}
export declare type RequestContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus = keyof RequestBody$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus;
export declare type ResponseContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus = keyof Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200 | keyof Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$201;
export interface Params$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus<T extends RequestContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus, U extends ResponseContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus;
    requestBody: RequestBody$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus[T];
}
export declare type ResponseContentType$watchFlowcontrolApiserverV1beta2FlowSchemaList = keyof Response$watchFlowcontrolApiserverV1beta2FlowSchemaList$Status$200;
export interface Params$watchFlowcontrolApiserverV1beta2FlowSchemaList<U extends ResponseContentType$watchFlowcontrolApiserverV1beta2FlowSchemaList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchFlowcontrolApiserverV1beta2FlowSchemaList;
}
export declare type ResponseContentType$watchFlowcontrolApiserverV1beta2FlowSchema = keyof Response$watchFlowcontrolApiserverV1beta2FlowSchema$Status$200;
export interface Params$watchFlowcontrolApiserverV1beta2FlowSchema<U extends ResponseContentType$watchFlowcontrolApiserverV1beta2FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchFlowcontrolApiserverV1beta2FlowSchema;
}
export declare type ResponseContentType$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList = keyof Response$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList$Status$200;
export interface Params$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList<U extends ResponseContentType$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList;
}
export declare type ResponseContentType$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration = keyof Response$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200;
export interface Params$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration<U extends ResponseContentType$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration;
}
export declare type ResponseContentType$getInternalApiserverAPIGroup = keyof Response$getInternalApiserverAPIGroup$Status$200;
export interface Params$getInternalApiserverAPIGroup<U extends ResponseContentType$getInternalApiserverAPIGroup> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$getInternalApiserverV1alpha1APIResources = keyof Response$getInternalApiserverV1alpha1APIResources$Status$200;
export interface Params$getInternalApiserverV1alpha1APIResources<U extends ResponseContentType$getInternalApiserverV1alpha1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listInternalApiserverV1alpha1StorageVersion = keyof Response$listInternalApiserverV1alpha1StorageVersion$Status$200;
export interface Params$listInternalApiserverV1alpha1StorageVersion<U extends ResponseContentType$listInternalApiserverV1alpha1StorageVersion> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listInternalApiserverV1alpha1StorageVersion;
}
export declare type RequestContentType$createInternalApiserverV1alpha1StorageVersion = keyof RequestBody$createInternalApiserverV1alpha1StorageVersion;
export declare type ResponseContentType$createInternalApiserverV1alpha1StorageVersion = keyof Response$createInternalApiserverV1alpha1StorageVersion$Status$200 | keyof Response$createInternalApiserverV1alpha1StorageVersion$Status$201 | keyof Response$createInternalApiserverV1alpha1StorageVersion$Status$202;
export interface Params$createInternalApiserverV1alpha1StorageVersion<U extends ResponseContentType$createInternalApiserverV1alpha1StorageVersion> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createInternalApiserverV1alpha1StorageVersion;
    requestBody: RequestBody$createInternalApiserverV1alpha1StorageVersion["*/*"];
}
export declare type RequestContentType$deleteInternalApiserverV1alpha1CollectionStorageVersion = keyof RequestBody$deleteInternalApiserverV1alpha1CollectionStorageVersion;
export declare type ResponseContentType$deleteInternalApiserverV1alpha1CollectionStorageVersion = keyof Response$deleteInternalApiserverV1alpha1CollectionStorageVersion$Status$200;
export interface Params$deleteInternalApiserverV1alpha1CollectionStorageVersion<U extends ResponseContentType$deleteInternalApiserverV1alpha1CollectionStorageVersion> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteInternalApiserverV1alpha1CollectionStorageVersion;
    requestBody: RequestBody$deleteInternalApiserverV1alpha1CollectionStorageVersion["*/*"];
}
export declare type ResponseContentType$readInternalApiserverV1alpha1StorageVersion = keyof Response$readInternalApiserverV1alpha1StorageVersion$Status$200;
export interface Params$readInternalApiserverV1alpha1StorageVersion<U extends ResponseContentType$readInternalApiserverV1alpha1StorageVersion> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readInternalApiserverV1alpha1StorageVersion;
}
export declare type RequestContentType$replaceInternalApiserverV1alpha1StorageVersion = keyof RequestBody$replaceInternalApiserverV1alpha1StorageVersion;
export declare type ResponseContentType$replaceInternalApiserverV1alpha1StorageVersion = keyof Response$replaceInternalApiserverV1alpha1StorageVersion$Status$200 | keyof Response$replaceInternalApiserverV1alpha1StorageVersion$Status$201;
export interface Params$replaceInternalApiserverV1alpha1StorageVersion<U extends ResponseContentType$replaceInternalApiserverV1alpha1StorageVersion> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceInternalApiserverV1alpha1StorageVersion;
    requestBody: RequestBody$replaceInternalApiserverV1alpha1StorageVersion["*/*"];
}
export declare type RequestContentType$deleteInternalApiserverV1alpha1StorageVersion = keyof RequestBody$deleteInternalApiserverV1alpha1StorageVersion;
export declare type ResponseContentType$deleteInternalApiserverV1alpha1StorageVersion = keyof Response$deleteInternalApiserverV1alpha1StorageVersion$Status$200 | keyof Response$deleteInternalApiserverV1alpha1StorageVersion$Status$202;
export interface Params$deleteInternalApiserverV1alpha1StorageVersion<U extends ResponseContentType$deleteInternalApiserverV1alpha1StorageVersion> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteInternalApiserverV1alpha1StorageVersion;
    requestBody: RequestBody$deleteInternalApiserverV1alpha1StorageVersion["*/*"];
}
export declare type RequestContentType$patchInternalApiserverV1alpha1StorageVersion = keyof RequestBody$patchInternalApiserverV1alpha1StorageVersion;
export declare type ResponseContentType$patchInternalApiserverV1alpha1StorageVersion = keyof Response$patchInternalApiserverV1alpha1StorageVersion$Status$200 | keyof Response$patchInternalApiserverV1alpha1StorageVersion$Status$201;
export interface Params$patchInternalApiserverV1alpha1StorageVersion<T extends RequestContentType$patchInternalApiserverV1alpha1StorageVersion, U extends ResponseContentType$patchInternalApiserverV1alpha1StorageVersion> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchInternalApiserverV1alpha1StorageVersion;
    requestBody: RequestBody$patchInternalApiserverV1alpha1StorageVersion[T];
}
export declare type ResponseContentType$readInternalApiserverV1alpha1StorageVersionStatus = keyof Response$readInternalApiserverV1alpha1StorageVersionStatus$Status$200;
export interface Params$readInternalApiserverV1alpha1StorageVersionStatus<U extends ResponseContentType$readInternalApiserverV1alpha1StorageVersionStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readInternalApiserverV1alpha1StorageVersionStatus;
}
export declare type RequestContentType$replaceInternalApiserverV1alpha1StorageVersionStatus = keyof RequestBody$replaceInternalApiserverV1alpha1StorageVersionStatus;
export declare type ResponseContentType$replaceInternalApiserverV1alpha1StorageVersionStatus = keyof Response$replaceInternalApiserverV1alpha1StorageVersionStatus$Status$200 | keyof Response$replaceInternalApiserverV1alpha1StorageVersionStatus$Status$201;
export interface Params$replaceInternalApiserverV1alpha1StorageVersionStatus<U extends ResponseContentType$replaceInternalApiserverV1alpha1StorageVersionStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceInternalApiserverV1alpha1StorageVersionStatus;
    requestBody: RequestBody$replaceInternalApiserverV1alpha1StorageVersionStatus["*/*"];
}
export declare type RequestContentType$patchInternalApiserverV1alpha1StorageVersionStatus = keyof RequestBody$patchInternalApiserverV1alpha1StorageVersionStatus;
export declare type ResponseContentType$patchInternalApiserverV1alpha1StorageVersionStatus = keyof Response$patchInternalApiserverV1alpha1StorageVersionStatus$Status$200 | keyof Response$patchInternalApiserverV1alpha1StorageVersionStatus$Status$201;
export interface Params$patchInternalApiserverV1alpha1StorageVersionStatus<T extends RequestContentType$patchInternalApiserverV1alpha1StorageVersionStatus, U extends ResponseContentType$patchInternalApiserverV1alpha1StorageVersionStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchInternalApiserverV1alpha1StorageVersionStatus;
    requestBody: RequestBody$patchInternalApiserverV1alpha1StorageVersionStatus[T];
}
export declare type ResponseContentType$watchInternalApiserverV1alpha1StorageVersionList = keyof Response$watchInternalApiserverV1alpha1StorageVersionList$Status$200;
export interface Params$watchInternalApiserverV1alpha1StorageVersionList<U extends ResponseContentType$watchInternalApiserverV1alpha1StorageVersionList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchInternalApiserverV1alpha1StorageVersionList;
}
export declare type ResponseContentType$watchInternalApiserverV1alpha1StorageVersion = keyof Response$watchInternalApiserverV1alpha1StorageVersion$Status$200;
export interface Params$watchInternalApiserverV1alpha1StorageVersion<U extends ResponseContentType$watchInternalApiserverV1alpha1StorageVersion> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchInternalApiserverV1alpha1StorageVersion;
}
export declare type ResponseContentType$getNetworkingAPIGroup = keyof Response$getNetworkingAPIGroup$Status$200;
export interface Params$getNetworkingAPIGroup<U extends ResponseContentType$getNetworkingAPIGroup> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$getNetworkingV1APIResources = keyof Response$getNetworkingV1APIResources$Status$200;
export interface Params$getNetworkingV1APIResources<U extends ResponseContentType$getNetworkingV1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listNetworkingV1IngressClass = keyof Response$listNetworkingV1IngressClass$Status$200;
export interface Params$listNetworkingV1IngressClass<U extends ResponseContentType$listNetworkingV1IngressClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listNetworkingV1IngressClass;
}
export declare type RequestContentType$createNetworkingV1IngressClass = keyof RequestBody$createNetworkingV1IngressClass;
export declare type ResponseContentType$createNetworkingV1IngressClass = keyof Response$createNetworkingV1IngressClass$Status$200 | keyof Response$createNetworkingV1IngressClass$Status$201 | keyof Response$createNetworkingV1IngressClass$Status$202;
export interface Params$createNetworkingV1IngressClass<U extends ResponseContentType$createNetworkingV1IngressClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createNetworkingV1IngressClass;
    requestBody: RequestBody$createNetworkingV1IngressClass["*/*"];
}
export declare type RequestContentType$deleteNetworkingV1CollectionIngressClass = keyof RequestBody$deleteNetworkingV1CollectionIngressClass;
export declare type ResponseContentType$deleteNetworkingV1CollectionIngressClass = keyof Response$deleteNetworkingV1CollectionIngressClass$Status$200;
export interface Params$deleteNetworkingV1CollectionIngressClass<U extends ResponseContentType$deleteNetworkingV1CollectionIngressClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNetworkingV1CollectionIngressClass;
    requestBody: RequestBody$deleteNetworkingV1CollectionIngressClass["*/*"];
}
export declare type ResponseContentType$readNetworkingV1IngressClass = keyof Response$readNetworkingV1IngressClass$Status$200;
export interface Params$readNetworkingV1IngressClass<U extends ResponseContentType$readNetworkingV1IngressClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readNetworkingV1IngressClass;
}
export declare type RequestContentType$replaceNetworkingV1IngressClass = keyof RequestBody$replaceNetworkingV1IngressClass;
export declare type ResponseContentType$replaceNetworkingV1IngressClass = keyof Response$replaceNetworkingV1IngressClass$Status$200 | keyof Response$replaceNetworkingV1IngressClass$Status$201;
export interface Params$replaceNetworkingV1IngressClass<U extends ResponseContentType$replaceNetworkingV1IngressClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceNetworkingV1IngressClass;
    requestBody: RequestBody$replaceNetworkingV1IngressClass["*/*"];
}
export declare type RequestContentType$deleteNetworkingV1IngressClass = keyof RequestBody$deleteNetworkingV1IngressClass;
export declare type ResponseContentType$deleteNetworkingV1IngressClass = keyof Response$deleteNetworkingV1IngressClass$Status$200 | keyof Response$deleteNetworkingV1IngressClass$Status$202;
export interface Params$deleteNetworkingV1IngressClass<U extends ResponseContentType$deleteNetworkingV1IngressClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNetworkingV1IngressClass;
    requestBody: RequestBody$deleteNetworkingV1IngressClass["*/*"];
}
export declare type RequestContentType$patchNetworkingV1IngressClass = keyof RequestBody$patchNetworkingV1IngressClass;
export declare type ResponseContentType$patchNetworkingV1IngressClass = keyof Response$patchNetworkingV1IngressClass$Status$200 | keyof Response$patchNetworkingV1IngressClass$Status$201;
export interface Params$patchNetworkingV1IngressClass<T extends RequestContentType$patchNetworkingV1IngressClass, U extends ResponseContentType$patchNetworkingV1IngressClass> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchNetworkingV1IngressClass;
    requestBody: RequestBody$patchNetworkingV1IngressClass[T];
}
export declare type ResponseContentType$listNetworkingV1IngressForAllNamespaces = keyof Response$listNetworkingV1IngressForAllNamespaces$Status$200;
export interface Params$listNetworkingV1IngressForAllNamespaces<U extends ResponseContentType$listNetworkingV1IngressForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listNetworkingV1IngressForAllNamespaces;
}
export declare type ResponseContentType$listNetworkingV1NamespacedIngress = keyof Response$listNetworkingV1NamespacedIngress$Status$200;
export interface Params$listNetworkingV1NamespacedIngress<U extends ResponseContentType$listNetworkingV1NamespacedIngress> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listNetworkingV1NamespacedIngress;
}
export declare type RequestContentType$createNetworkingV1NamespacedIngress = keyof RequestBody$createNetworkingV1NamespacedIngress;
export declare type ResponseContentType$createNetworkingV1NamespacedIngress = keyof Response$createNetworkingV1NamespacedIngress$Status$200 | keyof Response$createNetworkingV1NamespacedIngress$Status$201 | keyof Response$createNetworkingV1NamespacedIngress$Status$202;
export interface Params$createNetworkingV1NamespacedIngress<U extends ResponseContentType$createNetworkingV1NamespacedIngress> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createNetworkingV1NamespacedIngress;
    requestBody: RequestBody$createNetworkingV1NamespacedIngress["*/*"];
}
export declare type RequestContentType$deleteNetworkingV1CollectionNamespacedIngress = keyof RequestBody$deleteNetworkingV1CollectionNamespacedIngress;
export declare type ResponseContentType$deleteNetworkingV1CollectionNamespacedIngress = keyof Response$deleteNetworkingV1CollectionNamespacedIngress$Status$200;
export interface Params$deleteNetworkingV1CollectionNamespacedIngress<U extends ResponseContentType$deleteNetworkingV1CollectionNamespacedIngress> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNetworkingV1CollectionNamespacedIngress;
    requestBody: RequestBody$deleteNetworkingV1CollectionNamespacedIngress["*/*"];
}
export declare type ResponseContentType$readNetworkingV1NamespacedIngress = keyof Response$readNetworkingV1NamespacedIngress$Status$200;
export interface Params$readNetworkingV1NamespacedIngress<U extends ResponseContentType$readNetworkingV1NamespacedIngress> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readNetworkingV1NamespacedIngress;
}
export declare type RequestContentType$replaceNetworkingV1NamespacedIngress = keyof RequestBody$replaceNetworkingV1NamespacedIngress;
export declare type ResponseContentType$replaceNetworkingV1NamespacedIngress = keyof Response$replaceNetworkingV1NamespacedIngress$Status$200 | keyof Response$replaceNetworkingV1NamespacedIngress$Status$201;
export interface Params$replaceNetworkingV1NamespacedIngress<U extends ResponseContentType$replaceNetworkingV1NamespacedIngress> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceNetworkingV1NamespacedIngress;
    requestBody: RequestBody$replaceNetworkingV1NamespacedIngress["*/*"];
}
export declare type RequestContentType$deleteNetworkingV1NamespacedIngress = keyof RequestBody$deleteNetworkingV1NamespacedIngress;
export declare type ResponseContentType$deleteNetworkingV1NamespacedIngress = keyof Response$deleteNetworkingV1NamespacedIngress$Status$200 | keyof Response$deleteNetworkingV1NamespacedIngress$Status$202;
export interface Params$deleteNetworkingV1NamespacedIngress<U extends ResponseContentType$deleteNetworkingV1NamespacedIngress> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNetworkingV1NamespacedIngress;
    requestBody: RequestBody$deleteNetworkingV1NamespacedIngress["*/*"];
}
export declare type RequestContentType$patchNetworkingV1NamespacedIngress = keyof RequestBody$patchNetworkingV1NamespacedIngress;
export declare type ResponseContentType$patchNetworkingV1NamespacedIngress = keyof Response$patchNetworkingV1NamespacedIngress$Status$200 | keyof Response$patchNetworkingV1NamespacedIngress$Status$201;
export interface Params$patchNetworkingV1NamespacedIngress<T extends RequestContentType$patchNetworkingV1NamespacedIngress, U extends ResponseContentType$patchNetworkingV1NamespacedIngress> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchNetworkingV1NamespacedIngress;
    requestBody: RequestBody$patchNetworkingV1NamespacedIngress[T];
}
export declare type ResponseContentType$readNetworkingV1NamespacedIngressStatus = keyof Response$readNetworkingV1NamespacedIngressStatus$Status$200;
export interface Params$readNetworkingV1NamespacedIngressStatus<U extends ResponseContentType$readNetworkingV1NamespacedIngressStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readNetworkingV1NamespacedIngressStatus;
}
export declare type RequestContentType$replaceNetworkingV1NamespacedIngressStatus = keyof RequestBody$replaceNetworkingV1NamespacedIngressStatus;
export declare type ResponseContentType$replaceNetworkingV1NamespacedIngressStatus = keyof Response$replaceNetworkingV1NamespacedIngressStatus$Status$200 | keyof Response$replaceNetworkingV1NamespacedIngressStatus$Status$201;
export interface Params$replaceNetworkingV1NamespacedIngressStatus<U extends ResponseContentType$replaceNetworkingV1NamespacedIngressStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceNetworkingV1NamespacedIngressStatus;
    requestBody: RequestBody$replaceNetworkingV1NamespacedIngressStatus["*/*"];
}
export declare type RequestContentType$patchNetworkingV1NamespacedIngressStatus = keyof RequestBody$patchNetworkingV1NamespacedIngressStatus;
export declare type ResponseContentType$patchNetworkingV1NamespacedIngressStatus = keyof Response$patchNetworkingV1NamespacedIngressStatus$Status$200 | keyof Response$patchNetworkingV1NamespacedIngressStatus$Status$201;
export interface Params$patchNetworkingV1NamespacedIngressStatus<T extends RequestContentType$patchNetworkingV1NamespacedIngressStatus, U extends ResponseContentType$patchNetworkingV1NamespacedIngressStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchNetworkingV1NamespacedIngressStatus;
    requestBody: RequestBody$patchNetworkingV1NamespacedIngressStatus[T];
}
export declare type ResponseContentType$listNetworkingV1NamespacedNetworkPolicy = keyof Response$listNetworkingV1NamespacedNetworkPolicy$Status$200;
export interface Params$listNetworkingV1NamespacedNetworkPolicy<U extends ResponseContentType$listNetworkingV1NamespacedNetworkPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listNetworkingV1NamespacedNetworkPolicy;
}
export declare type RequestContentType$createNetworkingV1NamespacedNetworkPolicy = keyof RequestBody$createNetworkingV1NamespacedNetworkPolicy;
export declare type ResponseContentType$createNetworkingV1NamespacedNetworkPolicy = keyof Response$createNetworkingV1NamespacedNetworkPolicy$Status$200 | keyof Response$createNetworkingV1NamespacedNetworkPolicy$Status$201 | keyof Response$createNetworkingV1NamespacedNetworkPolicy$Status$202;
export interface Params$createNetworkingV1NamespacedNetworkPolicy<U extends ResponseContentType$createNetworkingV1NamespacedNetworkPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createNetworkingV1NamespacedNetworkPolicy;
    requestBody: RequestBody$createNetworkingV1NamespacedNetworkPolicy["*/*"];
}
export declare type RequestContentType$deleteNetworkingV1CollectionNamespacedNetworkPolicy = keyof RequestBody$deleteNetworkingV1CollectionNamespacedNetworkPolicy;
export declare type ResponseContentType$deleteNetworkingV1CollectionNamespacedNetworkPolicy = keyof Response$deleteNetworkingV1CollectionNamespacedNetworkPolicy$Status$200;
export interface Params$deleteNetworkingV1CollectionNamespacedNetworkPolicy<U extends ResponseContentType$deleteNetworkingV1CollectionNamespacedNetworkPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNetworkingV1CollectionNamespacedNetworkPolicy;
    requestBody: RequestBody$deleteNetworkingV1CollectionNamespacedNetworkPolicy["*/*"];
}
export declare type ResponseContentType$readNetworkingV1NamespacedNetworkPolicy = keyof Response$readNetworkingV1NamespacedNetworkPolicy$Status$200;
export interface Params$readNetworkingV1NamespacedNetworkPolicy<U extends ResponseContentType$readNetworkingV1NamespacedNetworkPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readNetworkingV1NamespacedNetworkPolicy;
}
export declare type RequestContentType$replaceNetworkingV1NamespacedNetworkPolicy = keyof RequestBody$replaceNetworkingV1NamespacedNetworkPolicy;
export declare type ResponseContentType$replaceNetworkingV1NamespacedNetworkPolicy = keyof Response$replaceNetworkingV1NamespacedNetworkPolicy$Status$200 | keyof Response$replaceNetworkingV1NamespacedNetworkPolicy$Status$201;
export interface Params$replaceNetworkingV1NamespacedNetworkPolicy<U extends ResponseContentType$replaceNetworkingV1NamespacedNetworkPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceNetworkingV1NamespacedNetworkPolicy;
    requestBody: RequestBody$replaceNetworkingV1NamespacedNetworkPolicy["*/*"];
}
export declare type RequestContentType$deleteNetworkingV1NamespacedNetworkPolicy = keyof RequestBody$deleteNetworkingV1NamespacedNetworkPolicy;
export declare type ResponseContentType$deleteNetworkingV1NamespacedNetworkPolicy = keyof Response$deleteNetworkingV1NamespacedNetworkPolicy$Status$200 | keyof Response$deleteNetworkingV1NamespacedNetworkPolicy$Status$202;
export interface Params$deleteNetworkingV1NamespacedNetworkPolicy<U extends ResponseContentType$deleteNetworkingV1NamespacedNetworkPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNetworkingV1NamespacedNetworkPolicy;
    requestBody: RequestBody$deleteNetworkingV1NamespacedNetworkPolicy["*/*"];
}
export declare type RequestContentType$patchNetworkingV1NamespacedNetworkPolicy = keyof RequestBody$patchNetworkingV1NamespacedNetworkPolicy;
export declare type ResponseContentType$patchNetworkingV1NamespacedNetworkPolicy = keyof Response$patchNetworkingV1NamespacedNetworkPolicy$Status$200 | keyof Response$patchNetworkingV1NamespacedNetworkPolicy$Status$201;
export interface Params$patchNetworkingV1NamespacedNetworkPolicy<T extends RequestContentType$patchNetworkingV1NamespacedNetworkPolicy, U extends ResponseContentType$patchNetworkingV1NamespacedNetworkPolicy> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchNetworkingV1NamespacedNetworkPolicy;
    requestBody: RequestBody$patchNetworkingV1NamespacedNetworkPolicy[T];
}
export declare type ResponseContentType$listNetworkingV1NetworkPolicyForAllNamespaces = keyof Response$listNetworkingV1NetworkPolicyForAllNamespaces$Status$200;
export interface Params$listNetworkingV1NetworkPolicyForAllNamespaces<U extends ResponseContentType$listNetworkingV1NetworkPolicyForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listNetworkingV1NetworkPolicyForAllNamespaces;
}
export declare type ResponseContentType$watchNetworkingV1IngressClassList = keyof Response$watchNetworkingV1IngressClassList$Status$200;
export interface Params$watchNetworkingV1IngressClassList<U extends ResponseContentType$watchNetworkingV1IngressClassList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNetworkingV1IngressClassList;
}
export declare type ResponseContentType$watchNetworkingV1IngressClass = keyof Response$watchNetworkingV1IngressClass$Status$200;
export interface Params$watchNetworkingV1IngressClass<U extends ResponseContentType$watchNetworkingV1IngressClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNetworkingV1IngressClass;
}
export declare type ResponseContentType$watchNetworkingV1IngressListForAllNamespaces = keyof Response$watchNetworkingV1IngressListForAllNamespaces$Status$200;
export interface Params$watchNetworkingV1IngressListForAllNamespaces<U extends ResponseContentType$watchNetworkingV1IngressListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNetworkingV1IngressListForAllNamespaces;
}
export declare type ResponseContentType$watchNetworkingV1NamespacedIngressList = keyof Response$watchNetworkingV1NamespacedIngressList$Status$200;
export interface Params$watchNetworkingV1NamespacedIngressList<U extends ResponseContentType$watchNetworkingV1NamespacedIngressList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNetworkingV1NamespacedIngressList;
}
export declare type ResponseContentType$watchNetworkingV1NamespacedIngress = keyof Response$watchNetworkingV1NamespacedIngress$Status$200;
export interface Params$watchNetworkingV1NamespacedIngress<U extends ResponseContentType$watchNetworkingV1NamespacedIngress> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNetworkingV1NamespacedIngress;
}
export declare type ResponseContentType$watchNetworkingV1NamespacedNetworkPolicyList = keyof Response$watchNetworkingV1NamespacedNetworkPolicyList$Status$200;
export interface Params$watchNetworkingV1NamespacedNetworkPolicyList<U extends ResponseContentType$watchNetworkingV1NamespacedNetworkPolicyList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNetworkingV1NamespacedNetworkPolicyList;
}
export declare type ResponseContentType$watchNetworkingV1NamespacedNetworkPolicy = keyof Response$watchNetworkingV1NamespacedNetworkPolicy$Status$200;
export interface Params$watchNetworkingV1NamespacedNetworkPolicy<U extends ResponseContentType$watchNetworkingV1NamespacedNetworkPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNetworkingV1NamespacedNetworkPolicy;
}
export declare type ResponseContentType$watchNetworkingV1NetworkPolicyListForAllNamespaces = keyof Response$watchNetworkingV1NetworkPolicyListForAllNamespaces$Status$200;
export interface Params$watchNetworkingV1NetworkPolicyListForAllNamespaces<U extends ResponseContentType$watchNetworkingV1NetworkPolicyListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNetworkingV1NetworkPolicyListForAllNamespaces;
}
export declare type ResponseContentType$getNodeAPIGroup = keyof Response$getNodeAPIGroup$Status$200;
export interface Params$getNodeAPIGroup<U extends ResponseContentType$getNodeAPIGroup> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$getNodeV1APIResources = keyof Response$getNodeV1APIResources$Status$200;
export interface Params$getNodeV1APIResources<U extends ResponseContentType$getNodeV1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listNodeV1RuntimeClass = keyof Response$listNodeV1RuntimeClass$Status$200;
export interface Params$listNodeV1RuntimeClass<U extends ResponseContentType$listNodeV1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listNodeV1RuntimeClass;
}
export declare type RequestContentType$createNodeV1RuntimeClass = keyof RequestBody$createNodeV1RuntimeClass;
export declare type ResponseContentType$createNodeV1RuntimeClass = keyof Response$createNodeV1RuntimeClass$Status$200 | keyof Response$createNodeV1RuntimeClass$Status$201 | keyof Response$createNodeV1RuntimeClass$Status$202;
export interface Params$createNodeV1RuntimeClass<U extends ResponseContentType$createNodeV1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createNodeV1RuntimeClass;
    requestBody: RequestBody$createNodeV1RuntimeClass["*/*"];
}
export declare type RequestContentType$deleteNodeV1CollectionRuntimeClass = keyof RequestBody$deleteNodeV1CollectionRuntimeClass;
export declare type ResponseContentType$deleteNodeV1CollectionRuntimeClass = keyof Response$deleteNodeV1CollectionRuntimeClass$Status$200;
export interface Params$deleteNodeV1CollectionRuntimeClass<U extends ResponseContentType$deleteNodeV1CollectionRuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNodeV1CollectionRuntimeClass;
    requestBody: RequestBody$deleteNodeV1CollectionRuntimeClass["*/*"];
}
export declare type ResponseContentType$readNodeV1RuntimeClass = keyof Response$readNodeV1RuntimeClass$Status$200;
export interface Params$readNodeV1RuntimeClass<U extends ResponseContentType$readNodeV1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readNodeV1RuntimeClass;
}
export declare type RequestContentType$replaceNodeV1RuntimeClass = keyof RequestBody$replaceNodeV1RuntimeClass;
export declare type ResponseContentType$replaceNodeV1RuntimeClass = keyof Response$replaceNodeV1RuntimeClass$Status$200 | keyof Response$replaceNodeV1RuntimeClass$Status$201;
export interface Params$replaceNodeV1RuntimeClass<U extends ResponseContentType$replaceNodeV1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceNodeV1RuntimeClass;
    requestBody: RequestBody$replaceNodeV1RuntimeClass["*/*"];
}
export declare type RequestContentType$deleteNodeV1RuntimeClass = keyof RequestBody$deleteNodeV1RuntimeClass;
export declare type ResponseContentType$deleteNodeV1RuntimeClass = keyof Response$deleteNodeV1RuntimeClass$Status$200 | keyof Response$deleteNodeV1RuntimeClass$Status$202;
export interface Params$deleteNodeV1RuntimeClass<U extends ResponseContentType$deleteNodeV1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNodeV1RuntimeClass;
    requestBody: RequestBody$deleteNodeV1RuntimeClass["*/*"];
}
export declare type RequestContentType$patchNodeV1RuntimeClass = keyof RequestBody$patchNodeV1RuntimeClass;
export declare type ResponseContentType$patchNodeV1RuntimeClass = keyof Response$patchNodeV1RuntimeClass$Status$200 | keyof Response$patchNodeV1RuntimeClass$Status$201;
export interface Params$patchNodeV1RuntimeClass<T extends RequestContentType$patchNodeV1RuntimeClass, U extends ResponseContentType$patchNodeV1RuntimeClass> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchNodeV1RuntimeClass;
    requestBody: RequestBody$patchNodeV1RuntimeClass[T];
}
export declare type ResponseContentType$watchNodeV1RuntimeClassList = keyof Response$watchNodeV1RuntimeClassList$Status$200;
export interface Params$watchNodeV1RuntimeClassList<U extends ResponseContentType$watchNodeV1RuntimeClassList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNodeV1RuntimeClassList;
}
export declare type ResponseContentType$watchNodeV1RuntimeClass = keyof Response$watchNodeV1RuntimeClass$Status$200;
export interface Params$watchNodeV1RuntimeClass<U extends ResponseContentType$watchNodeV1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNodeV1RuntimeClass;
}
export declare type ResponseContentType$getNodeV1alpha1APIResources = keyof Response$getNodeV1alpha1APIResources$Status$200;
export interface Params$getNodeV1alpha1APIResources<U extends ResponseContentType$getNodeV1alpha1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listNodeV1alpha1RuntimeClass = keyof Response$listNodeV1alpha1RuntimeClass$Status$200;
export interface Params$listNodeV1alpha1RuntimeClass<U extends ResponseContentType$listNodeV1alpha1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listNodeV1alpha1RuntimeClass;
}
export declare type RequestContentType$createNodeV1alpha1RuntimeClass = keyof RequestBody$createNodeV1alpha1RuntimeClass;
export declare type ResponseContentType$createNodeV1alpha1RuntimeClass = keyof Response$createNodeV1alpha1RuntimeClass$Status$200 | keyof Response$createNodeV1alpha1RuntimeClass$Status$201 | keyof Response$createNodeV1alpha1RuntimeClass$Status$202;
export interface Params$createNodeV1alpha1RuntimeClass<U extends ResponseContentType$createNodeV1alpha1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createNodeV1alpha1RuntimeClass;
    requestBody: RequestBody$createNodeV1alpha1RuntimeClass["*/*"];
}
export declare type RequestContentType$deleteNodeV1alpha1CollectionRuntimeClass = keyof RequestBody$deleteNodeV1alpha1CollectionRuntimeClass;
export declare type ResponseContentType$deleteNodeV1alpha1CollectionRuntimeClass = keyof Response$deleteNodeV1alpha1CollectionRuntimeClass$Status$200;
export interface Params$deleteNodeV1alpha1CollectionRuntimeClass<U extends ResponseContentType$deleteNodeV1alpha1CollectionRuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNodeV1alpha1CollectionRuntimeClass;
    requestBody: RequestBody$deleteNodeV1alpha1CollectionRuntimeClass["*/*"];
}
export declare type ResponseContentType$readNodeV1alpha1RuntimeClass = keyof Response$readNodeV1alpha1RuntimeClass$Status$200;
export interface Params$readNodeV1alpha1RuntimeClass<U extends ResponseContentType$readNodeV1alpha1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readNodeV1alpha1RuntimeClass;
}
export declare type RequestContentType$replaceNodeV1alpha1RuntimeClass = keyof RequestBody$replaceNodeV1alpha1RuntimeClass;
export declare type ResponseContentType$replaceNodeV1alpha1RuntimeClass = keyof Response$replaceNodeV1alpha1RuntimeClass$Status$200 | keyof Response$replaceNodeV1alpha1RuntimeClass$Status$201;
export interface Params$replaceNodeV1alpha1RuntimeClass<U extends ResponseContentType$replaceNodeV1alpha1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceNodeV1alpha1RuntimeClass;
    requestBody: RequestBody$replaceNodeV1alpha1RuntimeClass["*/*"];
}
export declare type RequestContentType$deleteNodeV1alpha1RuntimeClass = keyof RequestBody$deleteNodeV1alpha1RuntimeClass;
export declare type ResponseContentType$deleteNodeV1alpha1RuntimeClass = keyof Response$deleteNodeV1alpha1RuntimeClass$Status$200 | keyof Response$deleteNodeV1alpha1RuntimeClass$Status$202;
export interface Params$deleteNodeV1alpha1RuntimeClass<U extends ResponseContentType$deleteNodeV1alpha1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNodeV1alpha1RuntimeClass;
    requestBody: RequestBody$deleteNodeV1alpha1RuntimeClass["*/*"];
}
export declare type RequestContentType$patchNodeV1alpha1RuntimeClass = keyof RequestBody$patchNodeV1alpha1RuntimeClass;
export declare type ResponseContentType$patchNodeV1alpha1RuntimeClass = keyof Response$patchNodeV1alpha1RuntimeClass$Status$200 | keyof Response$patchNodeV1alpha1RuntimeClass$Status$201;
export interface Params$patchNodeV1alpha1RuntimeClass<T extends RequestContentType$patchNodeV1alpha1RuntimeClass, U extends ResponseContentType$patchNodeV1alpha1RuntimeClass> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchNodeV1alpha1RuntimeClass;
    requestBody: RequestBody$patchNodeV1alpha1RuntimeClass[T];
}
export declare type ResponseContentType$watchNodeV1alpha1RuntimeClassList = keyof Response$watchNodeV1alpha1RuntimeClassList$Status$200;
export interface Params$watchNodeV1alpha1RuntimeClassList<U extends ResponseContentType$watchNodeV1alpha1RuntimeClassList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNodeV1alpha1RuntimeClassList;
}
export declare type ResponseContentType$watchNodeV1alpha1RuntimeClass = keyof Response$watchNodeV1alpha1RuntimeClass$Status$200;
export interface Params$watchNodeV1alpha1RuntimeClass<U extends ResponseContentType$watchNodeV1alpha1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNodeV1alpha1RuntimeClass;
}
export declare type ResponseContentType$getNodeV1beta1APIResources = keyof Response$getNodeV1beta1APIResources$Status$200;
export interface Params$getNodeV1beta1APIResources<U extends ResponseContentType$getNodeV1beta1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listNodeV1beta1RuntimeClass = keyof Response$listNodeV1beta1RuntimeClass$Status$200;
export interface Params$listNodeV1beta1RuntimeClass<U extends ResponseContentType$listNodeV1beta1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listNodeV1beta1RuntimeClass;
}
export declare type RequestContentType$createNodeV1beta1RuntimeClass = keyof RequestBody$createNodeV1beta1RuntimeClass;
export declare type ResponseContentType$createNodeV1beta1RuntimeClass = keyof Response$createNodeV1beta1RuntimeClass$Status$200 | keyof Response$createNodeV1beta1RuntimeClass$Status$201 | keyof Response$createNodeV1beta1RuntimeClass$Status$202;
export interface Params$createNodeV1beta1RuntimeClass<U extends ResponseContentType$createNodeV1beta1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createNodeV1beta1RuntimeClass;
    requestBody: RequestBody$createNodeV1beta1RuntimeClass["*/*"];
}
export declare type RequestContentType$deleteNodeV1beta1CollectionRuntimeClass = keyof RequestBody$deleteNodeV1beta1CollectionRuntimeClass;
export declare type ResponseContentType$deleteNodeV1beta1CollectionRuntimeClass = keyof Response$deleteNodeV1beta1CollectionRuntimeClass$Status$200;
export interface Params$deleteNodeV1beta1CollectionRuntimeClass<U extends ResponseContentType$deleteNodeV1beta1CollectionRuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNodeV1beta1CollectionRuntimeClass;
    requestBody: RequestBody$deleteNodeV1beta1CollectionRuntimeClass["*/*"];
}
export declare type ResponseContentType$readNodeV1beta1RuntimeClass = keyof Response$readNodeV1beta1RuntimeClass$Status$200;
export interface Params$readNodeV1beta1RuntimeClass<U extends ResponseContentType$readNodeV1beta1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readNodeV1beta1RuntimeClass;
}
export declare type RequestContentType$replaceNodeV1beta1RuntimeClass = keyof RequestBody$replaceNodeV1beta1RuntimeClass;
export declare type ResponseContentType$replaceNodeV1beta1RuntimeClass = keyof Response$replaceNodeV1beta1RuntimeClass$Status$200 | keyof Response$replaceNodeV1beta1RuntimeClass$Status$201;
export interface Params$replaceNodeV1beta1RuntimeClass<U extends ResponseContentType$replaceNodeV1beta1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceNodeV1beta1RuntimeClass;
    requestBody: RequestBody$replaceNodeV1beta1RuntimeClass["*/*"];
}
export declare type RequestContentType$deleteNodeV1beta1RuntimeClass = keyof RequestBody$deleteNodeV1beta1RuntimeClass;
export declare type ResponseContentType$deleteNodeV1beta1RuntimeClass = keyof Response$deleteNodeV1beta1RuntimeClass$Status$200 | keyof Response$deleteNodeV1beta1RuntimeClass$Status$202;
export interface Params$deleteNodeV1beta1RuntimeClass<U extends ResponseContentType$deleteNodeV1beta1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNodeV1beta1RuntimeClass;
    requestBody: RequestBody$deleteNodeV1beta1RuntimeClass["*/*"];
}
export declare type RequestContentType$patchNodeV1beta1RuntimeClass = keyof RequestBody$patchNodeV1beta1RuntimeClass;
export declare type ResponseContentType$patchNodeV1beta1RuntimeClass = keyof Response$patchNodeV1beta1RuntimeClass$Status$200 | keyof Response$patchNodeV1beta1RuntimeClass$Status$201;
export interface Params$patchNodeV1beta1RuntimeClass<T extends RequestContentType$patchNodeV1beta1RuntimeClass, U extends ResponseContentType$patchNodeV1beta1RuntimeClass> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchNodeV1beta1RuntimeClass;
    requestBody: RequestBody$patchNodeV1beta1RuntimeClass[T];
}
export declare type ResponseContentType$watchNodeV1beta1RuntimeClassList = keyof Response$watchNodeV1beta1RuntimeClassList$Status$200;
export interface Params$watchNodeV1beta1RuntimeClassList<U extends ResponseContentType$watchNodeV1beta1RuntimeClassList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNodeV1beta1RuntimeClassList;
}
export declare type ResponseContentType$watchNodeV1beta1RuntimeClass = keyof Response$watchNodeV1beta1RuntimeClass$Status$200;
export interface Params$watchNodeV1beta1RuntimeClass<U extends ResponseContentType$watchNodeV1beta1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNodeV1beta1RuntimeClass;
}
export declare type ResponseContentType$getPolicyAPIGroup = keyof Response$getPolicyAPIGroup$Status$200;
export interface Params$getPolicyAPIGroup<U extends ResponseContentType$getPolicyAPIGroup> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$getPolicyV1APIResources = keyof Response$getPolicyV1APIResources$Status$200;
export interface Params$getPolicyV1APIResources<U extends ResponseContentType$getPolicyV1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listPolicyV1NamespacedPodDisruptionBudget = keyof Response$listPolicyV1NamespacedPodDisruptionBudget$Status$200;
export interface Params$listPolicyV1NamespacedPodDisruptionBudget<U extends ResponseContentType$listPolicyV1NamespacedPodDisruptionBudget> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listPolicyV1NamespacedPodDisruptionBudget;
}
export declare type RequestContentType$createPolicyV1NamespacedPodDisruptionBudget = keyof RequestBody$createPolicyV1NamespacedPodDisruptionBudget;
export declare type ResponseContentType$createPolicyV1NamespacedPodDisruptionBudget = keyof Response$createPolicyV1NamespacedPodDisruptionBudget$Status$200 | keyof Response$createPolicyV1NamespacedPodDisruptionBudget$Status$201 | keyof Response$createPolicyV1NamespacedPodDisruptionBudget$Status$202;
export interface Params$createPolicyV1NamespacedPodDisruptionBudget<U extends ResponseContentType$createPolicyV1NamespacedPodDisruptionBudget> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createPolicyV1NamespacedPodDisruptionBudget;
    requestBody: RequestBody$createPolicyV1NamespacedPodDisruptionBudget["*/*"];
}
export declare type RequestContentType$deletePolicyV1CollectionNamespacedPodDisruptionBudget = keyof RequestBody$deletePolicyV1CollectionNamespacedPodDisruptionBudget;
export declare type ResponseContentType$deletePolicyV1CollectionNamespacedPodDisruptionBudget = keyof Response$deletePolicyV1CollectionNamespacedPodDisruptionBudget$Status$200;
export interface Params$deletePolicyV1CollectionNamespacedPodDisruptionBudget<U extends ResponseContentType$deletePolicyV1CollectionNamespacedPodDisruptionBudget> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deletePolicyV1CollectionNamespacedPodDisruptionBudget;
    requestBody: RequestBody$deletePolicyV1CollectionNamespacedPodDisruptionBudget["*/*"];
}
export declare type ResponseContentType$readPolicyV1NamespacedPodDisruptionBudget = keyof Response$readPolicyV1NamespacedPodDisruptionBudget$Status$200;
export interface Params$readPolicyV1NamespacedPodDisruptionBudget<U extends ResponseContentType$readPolicyV1NamespacedPodDisruptionBudget> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readPolicyV1NamespacedPodDisruptionBudget;
}
export declare type RequestContentType$replacePolicyV1NamespacedPodDisruptionBudget = keyof RequestBody$replacePolicyV1NamespacedPodDisruptionBudget;
export declare type ResponseContentType$replacePolicyV1NamespacedPodDisruptionBudget = keyof Response$replacePolicyV1NamespacedPodDisruptionBudget$Status$200 | keyof Response$replacePolicyV1NamespacedPodDisruptionBudget$Status$201;
export interface Params$replacePolicyV1NamespacedPodDisruptionBudget<U extends ResponseContentType$replacePolicyV1NamespacedPodDisruptionBudget> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replacePolicyV1NamespacedPodDisruptionBudget;
    requestBody: RequestBody$replacePolicyV1NamespacedPodDisruptionBudget["*/*"];
}
export declare type RequestContentType$deletePolicyV1NamespacedPodDisruptionBudget = keyof RequestBody$deletePolicyV1NamespacedPodDisruptionBudget;
export declare type ResponseContentType$deletePolicyV1NamespacedPodDisruptionBudget = keyof Response$deletePolicyV1NamespacedPodDisruptionBudget$Status$200 | keyof Response$deletePolicyV1NamespacedPodDisruptionBudget$Status$202;
export interface Params$deletePolicyV1NamespacedPodDisruptionBudget<U extends ResponseContentType$deletePolicyV1NamespacedPodDisruptionBudget> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deletePolicyV1NamespacedPodDisruptionBudget;
    requestBody: RequestBody$deletePolicyV1NamespacedPodDisruptionBudget["*/*"];
}
export declare type RequestContentType$patchPolicyV1NamespacedPodDisruptionBudget = keyof RequestBody$patchPolicyV1NamespacedPodDisruptionBudget;
export declare type ResponseContentType$patchPolicyV1NamespacedPodDisruptionBudget = keyof Response$patchPolicyV1NamespacedPodDisruptionBudget$Status$200 | keyof Response$patchPolicyV1NamespacedPodDisruptionBudget$Status$201;
export interface Params$patchPolicyV1NamespacedPodDisruptionBudget<T extends RequestContentType$patchPolicyV1NamespacedPodDisruptionBudget, U extends ResponseContentType$patchPolicyV1NamespacedPodDisruptionBudget> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchPolicyV1NamespacedPodDisruptionBudget;
    requestBody: RequestBody$patchPolicyV1NamespacedPodDisruptionBudget[T];
}
export declare type ResponseContentType$readPolicyV1NamespacedPodDisruptionBudgetStatus = keyof Response$readPolicyV1NamespacedPodDisruptionBudgetStatus$Status$200;
export interface Params$readPolicyV1NamespacedPodDisruptionBudgetStatus<U extends ResponseContentType$readPolicyV1NamespacedPodDisruptionBudgetStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readPolicyV1NamespacedPodDisruptionBudgetStatus;
}
export declare type RequestContentType$replacePolicyV1NamespacedPodDisruptionBudgetStatus = keyof RequestBody$replacePolicyV1NamespacedPodDisruptionBudgetStatus;
export declare type ResponseContentType$replacePolicyV1NamespacedPodDisruptionBudgetStatus = keyof Response$replacePolicyV1NamespacedPodDisruptionBudgetStatus$Status$200 | keyof Response$replacePolicyV1NamespacedPodDisruptionBudgetStatus$Status$201;
export interface Params$replacePolicyV1NamespacedPodDisruptionBudgetStatus<U extends ResponseContentType$replacePolicyV1NamespacedPodDisruptionBudgetStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replacePolicyV1NamespacedPodDisruptionBudgetStatus;
    requestBody: RequestBody$replacePolicyV1NamespacedPodDisruptionBudgetStatus["*/*"];
}
export declare type RequestContentType$patchPolicyV1NamespacedPodDisruptionBudgetStatus = keyof RequestBody$patchPolicyV1NamespacedPodDisruptionBudgetStatus;
export declare type ResponseContentType$patchPolicyV1NamespacedPodDisruptionBudgetStatus = keyof Response$patchPolicyV1NamespacedPodDisruptionBudgetStatus$Status$200 | keyof Response$patchPolicyV1NamespacedPodDisruptionBudgetStatus$Status$201;
export interface Params$patchPolicyV1NamespacedPodDisruptionBudgetStatus<T extends RequestContentType$patchPolicyV1NamespacedPodDisruptionBudgetStatus, U extends ResponseContentType$patchPolicyV1NamespacedPodDisruptionBudgetStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchPolicyV1NamespacedPodDisruptionBudgetStatus;
    requestBody: RequestBody$patchPolicyV1NamespacedPodDisruptionBudgetStatus[T];
}
export declare type ResponseContentType$listPolicyV1PodDisruptionBudgetForAllNamespaces = keyof Response$listPolicyV1PodDisruptionBudgetForAllNamespaces$Status$200;
export interface Params$listPolicyV1PodDisruptionBudgetForAllNamespaces<U extends ResponseContentType$listPolicyV1PodDisruptionBudgetForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listPolicyV1PodDisruptionBudgetForAllNamespaces;
}
export declare type ResponseContentType$watchPolicyV1NamespacedPodDisruptionBudgetList = keyof Response$watchPolicyV1NamespacedPodDisruptionBudgetList$Status$200;
export interface Params$watchPolicyV1NamespacedPodDisruptionBudgetList<U extends ResponseContentType$watchPolicyV1NamespacedPodDisruptionBudgetList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchPolicyV1NamespacedPodDisruptionBudgetList;
}
export declare type ResponseContentType$watchPolicyV1NamespacedPodDisruptionBudget = keyof Response$watchPolicyV1NamespacedPodDisruptionBudget$Status$200;
export interface Params$watchPolicyV1NamespacedPodDisruptionBudget<U extends ResponseContentType$watchPolicyV1NamespacedPodDisruptionBudget> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchPolicyV1NamespacedPodDisruptionBudget;
}
export declare type ResponseContentType$watchPolicyV1PodDisruptionBudgetListForAllNamespaces = keyof Response$watchPolicyV1PodDisruptionBudgetListForAllNamespaces$Status$200;
export interface Params$watchPolicyV1PodDisruptionBudgetListForAllNamespaces<U extends ResponseContentType$watchPolicyV1PodDisruptionBudgetListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchPolicyV1PodDisruptionBudgetListForAllNamespaces;
}
export declare type ResponseContentType$getPolicyV1beta1APIResources = keyof Response$getPolicyV1beta1APIResources$Status$200;
export interface Params$getPolicyV1beta1APIResources<U extends ResponseContentType$getPolicyV1beta1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listPolicyV1beta1NamespacedPodDisruptionBudget = keyof Response$listPolicyV1beta1NamespacedPodDisruptionBudget$Status$200;
export interface Params$listPolicyV1beta1NamespacedPodDisruptionBudget<U extends ResponseContentType$listPolicyV1beta1NamespacedPodDisruptionBudget> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listPolicyV1beta1NamespacedPodDisruptionBudget;
}
export declare type RequestContentType$createPolicyV1beta1NamespacedPodDisruptionBudget = keyof RequestBody$createPolicyV1beta1NamespacedPodDisruptionBudget;
export declare type ResponseContentType$createPolicyV1beta1NamespacedPodDisruptionBudget = keyof Response$createPolicyV1beta1NamespacedPodDisruptionBudget$Status$200 | keyof Response$createPolicyV1beta1NamespacedPodDisruptionBudget$Status$201 | keyof Response$createPolicyV1beta1NamespacedPodDisruptionBudget$Status$202;
export interface Params$createPolicyV1beta1NamespacedPodDisruptionBudget<U extends ResponseContentType$createPolicyV1beta1NamespacedPodDisruptionBudget> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createPolicyV1beta1NamespacedPodDisruptionBudget;
    requestBody: RequestBody$createPolicyV1beta1NamespacedPodDisruptionBudget["*/*"];
}
export declare type RequestContentType$deletePolicyV1beta1CollectionNamespacedPodDisruptionBudget = keyof RequestBody$deletePolicyV1beta1CollectionNamespacedPodDisruptionBudget;
export declare type ResponseContentType$deletePolicyV1beta1CollectionNamespacedPodDisruptionBudget = keyof Response$deletePolicyV1beta1CollectionNamespacedPodDisruptionBudget$Status$200;
export interface Params$deletePolicyV1beta1CollectionNamespacedPodDisruptionBudget<U extends ResponseContentType$deletePolicyV1beta1CollectionNamespacedPodDisruptionBudget> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deletePolicyV1beta1CollectionNamespacedPodDisruptionBudget;
    requestBody: RequestBody$deletePolicyV1beta1CollectionNamespacedPodDisruptionBudget["*/*"];
}
export declare type ResponseContentType$readPolicyV1beta1NamespacedPodDisruptionBudget = keyof Response$readPolicyV1beta1NamespacedPodDisruptionBudget$Status$200;
export interface Params$readPolicyV1beta1NamespacedPodDisruptionBudget<U extends ResponseContentType$readPolicyV1beta1NamespacedPodDisruptionBudget> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readPolicyV1beta1NamespacedPodDisruptionBudget;
}
export declare type RequestContentType$replacePolicyV1beta1NamespacedPodDisruptionBudget = keyof RequestBody$replacePolicyV1beta1NamespacedPodDisruptionBudget;
export declare type ResponseContentType$replacePolicyV1beta1NamespacedPodDisruptionBudget = keyof Response$replacePolicyV1beta1NamespacedPodDisruptionBudget$Status$200 | keyof Response$replacePolicyV1beta1NamespacedPodDisruptionBudget$Status$201;
export interface Params$replacePolicyV1beta1NamespacedPodDisruptionBudget<U extends ResponseContentType$replacePolicyV1beta1NamespacedPodDisruptionBudget> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replacePolicyV1beta1NamespacedPodDisruptionBudget;
    requestBody: RequestBody$replacePolicyV1beta1NamespacedPodDisruptionBudget["*/*"];
}
export declare type RequestContentType$deletePolicyV1beta1NamespacedPodDisruptionBudget = keyof RequestBody$deletePolicyV1beta1NamespacedPodDisruptionBudget;
export declare type ResponseContentType$deletePolicyV1beta1NamespacedPodDisruptionBudget = keyof Response$deletePolicyV1beta1NamespacedPodDisruptionBudget$Status$200 | keyof Response$deletePolicyV1beta1NamespacedPodDisruptionBudget$Status$202;
export interface Params$deletePolicyV1beta1NamespacedPodDisruptionBudget<U extends ResponseContentType$deletePolicyV1beta1NamespacedPodDisruptionBudget> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deletePolicyV1beta1NamespacedPodDisruptionBudget;
    requestBody: RequestBody$deletePolicyV1beta1NamespacedPodDisruptionBudget["*/*"];
}
export declare type RequestContentType$patchPolicyV1beta1NamespacedPodDisruptionBudget = keyof RequestBody$patchPolicyV1beta1NamespacedPodDisruptionBudget;
export declare type ResponseContentType$patchPolicyV1beta1NamespacedPodDisruptionBudget = keyof Response$patchPolicyV1beta1NamespacedPodDisruptionBudget$Status$200 | keyof Response$patchPolicyV1beta1NamespacedPodDisruptionBudget$Status$201;
export interface Params$patchPolicyV1beta1NamespacedPodDisruptionBudget<T extends RequestContentType$patchPolicyV1beta1NamespacedPodDisruptionBudget, U extends ResponseContentType$patchPolicyV1beta1NamespacedPodDisruptionBudget> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchPolicyV1beta1NamespacedPodDisruptionBudget;
    requestBody: RequestBody$patchPolicyV1beta1NamespacedPodDisruptionBudget[T];
}
export declare type ResponseContentType$readPolicyV1beta1NamespacedPodDisruptionBudgetStatus = keyof Response$readPolicyV1beta1NamespacedPodDisruptionBudgetStatus$Status$200;
export interface Params$readPolicyV1beta1NamespacedPodDisruptionBudgetStatus<U extends ResponseContentType$readPolicyV1beta1NamespacedPodDisruptionBudgetStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readPolicyV1beta1NamespacedPodDisruptionBudgetStatus;
}
export declare type RequestContentType$replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus = keyof RequestBody$replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus;
export declare type ResponseContentType$replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus = keyof Response$replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus$Status$200 | keyof Response$replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus$Status$201;
export interface Params$replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus<U extends ResponseContentType$replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus;
    requestBody: RequestBody$replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus["*/*"];
}
export declare type RequestContentType$patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus = keyof RequestBody$patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus;
export declare type ResponseContentType$patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus = keyof Response$patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus$Status$200 | keyof Response$patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus$Status$201;
export interface Params$patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus<T extends RequestContentType$patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus, U extends ResponseContentType$patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus;
    requestBody: RequestBody$patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus[T];
}
export declare type ResponseContentType$listPolicyV1beta1PodDisruptionBudgetForAllNamespaces = keyof Response$listPolicyV1beta1PodDisruptionBudgetForAllNamespaces$Status$200;
export interface Params$listPolicyV1beta1PodDisruptionBudgetForAllNamespaces<U extends ResponseContentType$listPolicyV1beta1PodDisruptionBudgetForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listPolicyV1beta1PodDisruptionBudgetForAllNamespaces;
}
export declare type ResponseContentType$listPolicyV1beta1PodSecurityPolicy = keyof Response$listPolicyV1beta1PodSecurityPolicy$Status$200;
export interface Params$listPolicyV1beta1PodSecurityPolicy<U extends ResponseContentType$listPolicyV1beta1PodSecurityPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listPolicyV1beta1PodSecurityPolicy;
}
export declare type RequestContentType$createPolicyV1beta1PodSecurityPolicy = keyof RequestBody$createPolicyV1beta1PodSecurityPolicy;
export declare type ResponseContentType$createPolicyV1beta1PodSecurityPolicy = keyof Response$createPolicyV1beta1PodSecurityPolicy$Status$200 | keyof Response$createPolicyV1beta1PodSecurityPolicy$Status$201 | keyof Response$createPolicyV1beta1PodSecurityPolicy$Status$202;
export interface Params$createPolicyV1beta1PodSecurityPolicy<U extends ResponseContentType$createPolicyV1beta1PodSecurityPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createPolicyV1beta1PodSecurityPolicy;
    requestBody: RequestBody$createPolicyV1beta1PodSecurityPolicy["*/*"];
}
export declare type RequestContentType$deletePolicyV1beta1CollectionPodSecurityPolicy = keyof RequestBody$deletePolicyV1beta1CollectionPodSecurityPolicy;
export declare type ResponseContentType$deletePolicyV1beta1CollectionPodSecurityPolicy = keyof Response$deletePolicyV1beta1CollectionPodSecurityPolicy$Status$200;
export interface Params$deletePolicyV1beta1CollectionPodSecurityPolicy<U extends ResponseContentType$deletePolicyV1beta1CollectionPodSecurityPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deletePolicyV1beta1CollectionPodSecurityPolicy;
    requestBody: RequestBody$deletePolicyV1beta1CollectionPodSecurityPolicy["*/*"];
}
export declare type ResponseContentType$readPolicyV1beta1PodSecurityPolicy = keyof Response$readPolicyV1beta1PodSecurityPolicy$Status$200;
export interface Params$readPolicyV1beta1PodSecurityPolicy<U extends ResponseContentType$readPolicyV1beta1PodSecurityPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readPolicyV1beta1PodSecurityPolicy;
}
export declare type RequestContentType$replacePolicyV1beta1PodSecurityPolicy = keyof RequestBody$replacePolicyV1beta1PodSecurityPolicy;
export declare type ResponseContentType$replacePolicyV1beta1PodSecurityPolicy = keyof Response$replacePolicyV1beta1PodSecurityPolicy$Status$200 | keyof Response$replacePolicyV1beta1PodSecurityPolicy$Status$201;
export interface Params$replacePolicyV1beta1PodSecurityPolicy<U extends ResponseContentType$replacePolicyV1beta1PodSecurityPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replacePolicyV1beta1PodSecurityPolicy;
    requestBody: RequestBody$replacePolicyV1beta1PodSecurityPolicy["*/*"];
}
export declare type RequestContentType$deletePolicyV1beta1PodSecurityPolicy = keyof RequestBody$deletePolicyV1beta1PodSecurityPolicy;
export declare type ResponseContentType$deletePolicyV1beta1PodSecurityPolicy = keyof Response$deletePolicyV1beta1PodSecurityPolicy$Status$200 | keyof Response$deletePolicyV1beta1PodSecurityPolicy$Status$202;
export interface Params$deletePolicyV1beta1PodSecurityPolicy<U extends ResponseContentType$deletePolicyV1beta1PodSecurityPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deletePolicyV1beta1PodSecurityPolicy;
    requestBody: RequestBody$deletePolicyV1beta1PodSecurityPolicy["*/*"];
}
export declare type RequestContentType$patchPolicyV1beta1PodSecurityPolicy = keyof RequestBody$patchPolicyV1beta1PodSecurityPolicy;
export declare type ResponseContentType$patchPolicyV1beta1PodSecurityPolicy = keyof Response$patchPolicyV1beta1PodSecurityPolicy$Status$200 | keyof Response$patchPolicyV1beta1PodSecurityPolicy$Status$201;
export interface Params$patchPolicyV1beta1PodSecurityPolicy<T extends RequestContentType$patchPolicyV1beta1PodSecurityPolicy, U extends ResponseContentType$patchPolicyV1beta1PodSecurityPolicy> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchPolicyV1beta1PodSecurityPolicy;
    requestBody: RequestBody$patchPolicyV1beta1PodSecurityPolicy[T];
}
export declare type ResponseContentType$watchPolicyV1beta1NamespacedPodDisruptionBudgetList = keyof Response$watchPolicyV1beta1NamespacedPodDisruptionBudgetList$Status$200;
export interface Params$watchPolicyV1beta1NamespacedPodDisruptionBudgetList<U extends ResponseContentType$watchPolicyV1beta1NamespacedPodDisruptionBudgetList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchPolicyV1beta1NamespacedPodDisruptionBudgetList;
}
export declare type ResponseContentType$watchPolicyV1beta1NamespacedPodDisruptionBudget = keyof Response$watchPolicyV1beta1NamespacedPodDisruptionBudget$Status$200;
export interface Params$watchPolicyV1beta1NamespacedPodDisruptionBudget<U extends ResponseContentType$watchPolicyV1beta1NamespacedPodDisruptionBudget> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchPolicyV1beta1NamespacedPodDisruptionBudget;
}
export declare type ResponseContentType$watchPolicyV1beta1PodDisruptionBudgetListForAllNamespaces = keyof Response$watchPolicyV1beta1PodDisruptionBudgetListForAllNamespaces$Status$200;
export interface Params$watchPolicyV1beta1PodDisruptionBudgetListForAllNamespaces<U extends ResponseContentType$watchPolicyV1beta1PodDisruptionBudgetListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchPolicyV1beta1PodDisruptionBudgetListForAllNamespaces;
}
export declare type ResponseContentType$watchPolicyV1beta1PodSecurityPolicyList = keyof Response$watchPolicyV1beta1PodSecurityPolicyList$Status$200;
export interface Params$watchPolicyV1beta1PodSecurityPolicyList<U extends ResponseContentType$watchPolicyV1beta1PodSecurityPolicyList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchPolicyV1beta1PodSecurityPolicyList;
}
export declare type ResponseContentType$watchPolicyV1beta1PodSecurityPolicy = keyof Response$watchPolicyV1beta1PodSecurityPolicy$Status$200;
export interface Params$watchPolicyV1beta1PodSecurityPolicy<U extends ResponseContentType$watchPolicyV1beta1PodSecurityPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchPolicyV1beta1PodSecurityPolicy;
}
export declare type ResponseContentType$getRbacAuthorizationAPIGroup = keyof Response$getRbacAuthorizationAPIGroup$Status$200;
export interface Params$getRbacAuthorizationAPIGroup<U extends ResponseContentType$getRbacAuthorizationAPIGroup> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$getRbacAuthorizationV1APIResources = keyof Response$getRbacAuthorizationV1APIResources$Status$200;
export interface Params$getRbacAuthorizationV1APIResources<U extends ResponseContentType$getRbacAuthorizationV1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listRbacAuthorizationV1ClusterRoleBinding = keyof Response$listRbacAuthorizationV1ClusterRoleBinding$Status$200;
export interface Params$listRbacAuthorizationV1ClusterRoleBinding<U extends ResponseContentType$listRbacAuthorizationV1ClusterRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listRbacAuthorizationV1ClusterRoleBinding;
}
export declare type RequestContentType$createRbacAuthorizationV1ClusterRoleBinding = keyof RequestBody$createRbacAuthorizationV1ClusterRoleBinding;
export declare type ResponseContentType$createRbacAuthorizationV1ClusterRoleBinding = keyof Response$createRbacAuthorizationV1ClusterRoleBinding$Status$200 | keyof Response$createRbacAuthorizationV1ClusterRoleBinding$Status$201 | keyof Response$createRbacAuthorizationV1ClusterRoleBinding$Status$202;
export interface Params$createRbacAuthorizationV1ClusterRoleBinding<U extends ResponseContentType$createRbacAuthorizationV1ClusterRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createRbacAuthorizationV1ClusterRoleBinding;
    requestBody: RequestBody$createRbacAuthorizationV1ClusterRoleBinding["*/*"];
}
export declare type RequestContentType$deleteRbacAuthorizationV1CollectionClusterRoleBinding = keyof RequestBody$deleteRbacAuthorizationV1CollectionClusterRoleBinding;
export declare type ResponseContentType$deleteRbacAuthorizationV1CollectionClusterRoleBinding = keyof Response$deleteRbacAuthorizationV1CollectionClusterRoleBinding$Status$200;
export interface Params$deleteRbacAuthorizationV1CollectionClusterRoleBinding<U extends ResponseContentType$deleteRbacAuthorizationV1CollectionClusterRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteRbacAuthorizationV1CollectionClusterRoleBinding;
    requestBody: RequestBody$deleteRbacAuthorizationV1CollectionClusterRoleBinding["*/*"];
}
export declare type ResponseContentType$readRbacAuthorizationV1ClusterRoleBinding = keyof Response$readRbacAuthorizationV1ClusterRoleBinding$Status$200;
export interface Params$readRbacAuthorizationV1ClusterRoleBinding<U extends ResponseContentType$readRbacAuthorizationV1ClusterRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readRbacAuthorizationV1ClusterRoleBinding;
}
export declare type RequestContentType$replaceRbacAuthorizationV1ClusterRoleBinding = keyof RequestBody$replaceRbacAuthorizationV1ClusterRoleBinding;
export declare type ResponseContentType$replaceRbacAuthorizationV1ClusterRoleBinding = keyof Response$replaceRbacAuthorizationV1ClusterRoleBinding$Status$200 | keyof Response$replaceRbacAuthorizationV1ClusterRoleBinding$Status$201;
export interface Params$replaceRbacAuthorizationV1ClusterRoleBinding<U extends ResponseContentType$replaceRbacAuthorizationV1ClusterRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceRbacAuthorizationV1ClusterRoleBinding;
    requestBody: RequestBody$replaceRbacAuthorizationV1ClusterRoleBinding["*/*"];
}
export declare type RequestContentType$deleteRbacAuthorizationV1ClusterRoleBinding = keyof RequestBody$deleteRbacAuthorizationV1ClusterRoleBinding;
export declare type ResponseContentType$deleteRbacAuthorizationV1ClusterRoleBinding = keyof Response$deleteRbacAuthorizationV1ClusterRoleBinding$Status$200 | keyof Response$deleteRbacAuthorizationV1ClusterRoleBinding$Status$202;
export interface Params$deleteRbacAuthorizationV1ClusterRoleBinding<U extends ResponseContentType$deleteRbacAuthorizationV1ClusterRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteRbacAuthorizationV1ClusterRoleBinding;
    requestBody: RequestBody$deleteRbacAuthorizationV1ClusterRoleBinding["*/*"];
}
export declare type RequestContentType$patchRbacAuthorizationV1ClusterRoleBinding = keyof RequestBody$patchRbacAuthorizationV1ClusterRoleBinding;
export declare type ResponseContentType$patchRbacAuthorizationV1ClusterRoleBinding = keyof Response$patchRbacAuthorizationV1ClusterRoleBinding$Status$200 | keyof Response$patchRbacAuthorizationV1ClusterRoleBinding$Status$201;
export interface Params$patchRbacAuthorizationV1ClusterRoleBinding<T extends RequestContentType$patchRbacAuthorizationV1ClusterRoleBinding, U extends ResponseContentType$patchRbacAuthorizationV1ClusterRoleBinding> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchRbacAuthorizationV1ClusterRoleBinding;
    requestBody: RequestBody$patchRbacAuthorizationV1ClusterRoleBinding[T];
}
export declare type ResponseContentType$listRbacAuthorizationV1ClusterRole = keyof Response$listRbacAuthorizationV1ClusterRole$Status$200;
export interface Params$listRbacAuthorizationV1ClusterRole<U extends ResponseContentType$listRbacAuthorizationV1ClusterRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listRbacAuthorizationV1ClusterRole;
}
export declare type RequestContentType$createRbacAuthorizationV1ClusterRole = keyof RequestBody$createRbacAuthorizationV1ClusterRole;
export declare type ResponseContentType$createRbacAuthorizationV1ClusterRole = keyof Response$createRbacAuthorizationV1ClusterRole$Status$200 | keyof Response$createRbacAuthorizationV1ClusterRole$Status$201 | keyof Response$createRbacAuthorizationV1ClusterRole$Status$202;
export interface Params$createRbacAuthorizationV1ClusterRole<U extends ResponseContentType$createRbacAuthorizationV1ClusterRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createRbacAuthorizationV1ClusterRole;
    requestBody: RequestBody$createRbacAuthorizationV1ClusterRole["*/*"];
}
export declare type RequestContentType$deleteRbacAuthorizationV1CollectionClusterRole = keyof RequestBody$deleteRbacAuthorizationV1CollectionClusterRole;
export declare type ResponseContentType$deleteRbacAuthorizationV1CollectionClusterRole = keyof Response$deleteRbacAuthorizationV1CollectionClusterRole$Status$200;
export interface Params$deleteRbacAuthorizationV1CollectionClusterRole<U extends ResponseContentType$deleteRbacAuthorizationV1CollectionClusterRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteRbacAuthorizationV1CollectionClusterRole;
    requestBody: RequestBody$deleteRbacAuthorizationV1CollectionClusterRole["*/*"];
}
export declare type ResponseContentType$readRbacAuthorizationV1ClusterRole = keyof Response$readRbacAuthorizationV1ClusterRole$Status$200;
export interface Params$readRbacAuthorizationV1ClusterRole<U extends ResponseContentType$readRbacAuthorizationV1ClusterRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readRbacAuthorizationV1ClusterRole;
}
export declare type RequestContentType$replaceRbacAuthorizationV1ClusterRole = keyof RequestBody$replaceRbacAuthorizationV1ClusterRole;
export declare type ResponseContentType$replaceRbacAuthorizationV1ClusterRole = keyof Response$replaceRbacAuthorizationV1ClusterRole$Status$200 | keyof Response$replaceRbacAuthorizationV1ClusterRole$Status$201;
export interface Params$replaceRbacAuthorizationV1ClusterRole<U extends ResponseContentType$replaceRbacAuthorizationV1ClusterRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceRbacAuthorizationV1ClusterRole;
    requestBody: RequestBody$replaceRbacAuthorizationV1ClusterRole["*/*"];
}
export declare type RequestContentType$deleteRbacAuthorizationV1ClusterRole = keyof RequestBody$deleteRbacAuthorizationV1ClusterRole;
export declare type ResponseContentType$deleteRbacAuthorizationV1ClusterRole = keyof Response$deleteRbacAuthorizationV1ClusterRole$Status$200 | keyof Response$deleteRbacAuthorizationV1ClusterRole$Status$202;
export interface Params$deleteRbacAuthorizationV1ClusterRole<U extends ResponseContentType$deleteRbacAuthorizationV1ClusterRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteRbacAuthorizationV1ClusterRole;
    requestBody: RequestBody$deleteRbacAuthorizationV1ClusterRole["*/*"];
}
export declare type RequestContentType$patchRbacAuthorizationV1ClusterRole = keyof RequestBody$patchRbacAuthorizationV1ClusterRole;
export declare type ResponseContentType$patchRbacAuthorizationV1ClusterRole = keyof Response$patchRbacAuthorizationV1ClusterRole$Status$200 | keyof Response$patchRbacAuthorizationV1ClusterRole$Status$201;
export interface Params$patchRbacAuthorizationV1ClusterRole<T extends RequestContentType$patchRbacAuthorizationV1ClusterRole, U extends ResponseContentType$patchRbacAuthorizationV1ClusterRole> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchRbacAuthorizationV1ClusterRole;
    requestBody: RequestBody$patchRbacAuthorizationV1ClusterRole[T];
}
export declare type ResponseContentType$listRbacAuthorizationV1NamespacedRoleBinding = keyof Response$listRbacAuthorizationV1NamespacedRoleBinding$Status$200;
export interface Params$listRbacAuthorizationV1NamespacedRoleBinding<U extends ResponseContentType$listRbacAuthorizationV1NamespacedRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listRbacAuthorizationV1NamespacedRoleBinding;
}
export declare type RequestContentType$createRbacAuthorizationV1NamespacedRoleBinding = keyof RequestBody$createRbacAuthorizationV1NamespacedRoleBinding;
export declare type ResponseContentType$createRbacAuthorizationV1NamespacedRoleBinding = keyof Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$200 | keyof Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$201 | keyof Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$202;
export interface Params$createRbacAuthorizationV1NamespacedRoleBinding<U extends ResponseContentType$createRbacAuthorizationV1NamespacedRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createRbacAuthorizationV1NamespacedRoleBinding;
    requestBody: RequestBody$createRbacAuthorizationV1NamespacedRoleBinding["*/*"];
}
export declare type RequestContentType$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding = keyof RequestBody$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding;
export declare type ResponseContentType$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding = keyof Response$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding$Status$200;
export interface Params$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding<U extends ResponseContentType$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding;
    requestBody: RequestBody$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding["*/*"];
}
export declare type ResponseContentType$readRbacAuthorizationV1NamespacedRoleBinding = keyof Response$readRbacAuthorizationV1NamespacedRoleBinding$Status$200;
export interface Params$readRbacAuthorizationV1NamespacedRoleBinding<U extends ResponseContentType$readRbacAuthorizationV1NamespacedRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readRbacAuthorizationV1NamespacedRoleBinding;
}
export declare type RequestContentType$replaceRbacAuthorizationV1NamespacedRoleBinding = keyof RequestBody$replaceRbacAuthorizationV1NamespacedRoleBinding;
export declare type ResponseContentType$replaceRbacAuthorizationV1NamespacedRoleBinding = keyof Response$replaceRbacAuthorizationV1NamespacedRoleBinding$Status$200 | keyof Response$replaceRbacAuthorizationV1NamespacedRoleBinding$Status$201;
export interface Params$replaceRbacAuthorizationV1NamespacedRoleBinding<U extends ResponseContentType$replaceRbacAuthorizationV1NamespacedRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceRbacAuthorizationV1NamespacedRoleBinding;
    requestBody: RequestBody$replaceRbacAuthorizationV1NamespacedRoleBinding["*/*"];
}
export declare type RequestContentType$deleteRbacAuthorizationV1NamespacedRoleBinding = keyof RequestBody$deleteRbacAuthorizationV1NamespacedRoleBinding;
export declare type ResponseContentType$deleteRbacAuthorizationV1NamespacedRoleBinding = keyof Response$deleteRbacAuthorizationV1NamespacedRoleBinding$Status$200 | keyof Response$deleteRbacAuthorizationV1NamespacedRoleBinding$Status$202;
export interface Params$deleteRbacAuthorizationV1NamespacedRoleBinding<U extends ResponseContentType$deleteRbacAuthorizationV1NamespacedRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteRbacAuthorizationV1NamespacedRoleBinding;
    requestBody: RequestBody$deleteRbacAuthorizationV1NamespacedRoleBinding["*/*"];
}
export declare type RequestContentType$patchRbacAuthorizationV1NamespacedRoleBinding = keyof RequestBody$patchRbacAuthorizationV1NamespacedRoleBinding;
export declare type ResponseContentType$patchRbacAuthorizationV1NamespacedRoleBinding = keyof Response$patchRbacAuthorizationV1NamespacedRoleBinding$Status$200 | keyof Response$patchRbacAuthorizationV1NamespacedRoleBinding$Status$201;
export interface Params$patchRbacAuthorizationV1NamespacedRoleBinding<T extends RequestContentType$patchRbacAuthorizationV1NamespacedRoleBinding, U extends ResponseContentType$patchRbacAuthorizationV1NamespacedRoleBinding> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchRbacAuthorizationV1NamespacedRoleBinding;
    requestBody: RequestBody$patchRbacAuthorizationV1NamespacedRoleBinding[T];
}
export declare type ResponseContentType$listRbacAuthorizationV1NamespacedRole = keyof Response$listRbacAuthorizationV1NamespacedRole$Status$200;
export interface Params$listRbacAuthorizationV1NamespacedRole<U extends ResponseContentType$listRbacAuthorizationV1NamespacedRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listRbacAuthorizationV1NamespacedRole;
}
export declare type RequestContentType$createRbacAuthorizationV1NamespacedRole = keyof RequestBody$createRbacAuthorizationV1NamespacedRole;
export declare type ResponseContentType$createRbacAuthorizationV1NamespacedRole = keyof Response$createRbacAuthorizationV1NamespacedRole$Status$200 | keyof Response$createRbacAuthorizationV1NamespacedRole$Status$201 | keyof Response$createRbacAuthorizationV1NamespacedRole$Status$202;
export interface Params$createRbacAuthorizationV1NamespacedRole<U extends ResponseContentType$createRbacAuthorizationV1NamespacedRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createRbacAuthorizationV1NamespacedRole;
    requestBody: RequestBody$createRbacAuthorizationV1NamespacedRole["*/*"];
}
export declare type RequestContentType$deleteRbacAuthorizationV1CollectionNamespacedRole = keyof RequestBody$deleteRbacAuthorizationV1CollectionNamespacedRole;
export declare type ResponseContentType$deleteRbacAuthorizationV1CollectionNamespacedRole = keyof Response$deleteRbacAuthorizationV1CollectionNamespacedRole$Status$200;
export interface Params$deleteRbacAuthorizationV1CollectionNamespacedRole<U extends ResponseContentType$deleteRbacAuthorizationV1CollectionNamespacedRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteRbacAuthorizationV1CollectionNamespacedRole;
    requestBody: RequestBody$deleteRbacAuthorizationV1CollectionNamespacedRole["*/*"];
}
export declare type ResponseContentType$readRbacAuthorizationV1NamespacedRole = keyof Response$readRbacAuthorizationV1NamespacedRole$Status$200;
export interface Params$readRbacAuthorizationV1NamespacedRole<U extends ResponseContentType$readRbacAuthorizationV1NamespacedRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readRbacAuthorizationV1NamespacedRole;
}
export declare type RequestContentType$replaceRbacAuthorizationV1NamespacedRole = keyof RequestBody$replaceRbacAuthorizationV1NamespacedRole;
export declare type ResponseContentType$replaceRbacAuthorizationV1NamespacedRole = keyof Response$replaceRbacAuthorizationV1NamespacedRole$Status$200 | keyof Response$replaceRbacAuthorizationV1NamespacedRole$Status$201;
export interface Params$replaceRbacAuthorizationV1NamespacedRole<U extends ResponseContentType$replaceRbacAuthorizationV1NamespacedRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceRbacAuthorizationV1NamespacedRole;
    requestBody: RequestBody$replaceRbacAuthorizationV1NamespacedRole["*/*"];
}
export declare type RequestContentType$deleteRbacAuthorizationV1NamespacedRole = keyof RequestBody$deleteRbacAuthorizationV1NamespacedRole;
export declare type ResponseContentType$deleteRbacAuthorizationV1NamespacedRole = keyof Response$deleteRbacAuthorizationV1NamespacedRole$Status$200 | keyof Response$deleteRbacAuthorizationV1NamespacedRole$Status$202;
export interface Params$deleteRbacAuthorizationV1NamespacedRole<U extends ResponseContentType$deleteRbacAuthorizationV1NamespacedRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteRbacAuthorizationV1NamespacedRole;
    requestBody: RequestBody$deleteRbacAuthorizationV1NamespacedRole["*/*"];
}
export declare type RequestContentType$patchRbacAuthorizationV1NamespacedRole = keyof RequestBody$patchRbacAuthorizationV1NamespacedRole;
export declare type ResponseContentType$patchRbacAuthorizationV1NamespacedRole = keyof Response$patchRbacAuthorizationV1NamespacedRole$Status$200 | keyof Response$patchRbacAuthorizationV1NamespacedRole$Status$201;
export interface Params$patchRbacAuthorizationV1NamespacedRole<T extends RequestContentType$patchRbacAuthorizationV1NamespacedRole, U extends ResponseContentType$patchRbacAuthorizationV1NamespacedRole> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchRbacAuthorizationV1NamespacedRole;
    requestBody: RequestBody$patchRbacAuthorizationV1NamespacedRole[T];
}
export declare type ResponseContentType$listRbacAuthorizationV1RoleBindingForAllNamespaces = keyof Response$listRbacAuthorizationV1RoleBindingForAllNamespaces$Status$200;
export interface Params$listRbacAuthorizationV1RoleBindingForAllNamespaces<U extends ResponseContentType$listRbacAuthorizationV1RoleBindingForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listRbacAuthorizationV1RoleBindingForAllNamespaces;
}
export declare type ResponseContentType$listRbacAuthorizationV1RoleForAllNamespaces = keyof Response$listRbacAuthorizationV1RoleForAllNamespaces$Status$200;
export interface Params$listRbacAuthorizationV1RoleForAllNamespaces<U extends ResponseContentType$listRbacAuthorizationV1RoleForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listRbacAuthorizationV1RoleForAllNamespaces;
}
export declare type ResponseContentType$watchRbacAuthorizationV1ClusterRoleBindingList = keyof Response$watchRbacAuthorizationV1ClusterRoleBindingList$Status$200;
export interface Params$watchRbacAuthorizationV1ClusterRoleBindingList<U extends ResponseContentType$watchRbacAuthorizationV1ClusterRoleBindingList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchRbacAuthorizationV1ClusterRoleBindingList;
}
export declare type ResponseContentType$watchRbacAuthorizationV1ClusterRoleBinding = keyof Response$watchRbacAuthorizationV1ClusterRoleBinding$Status$200;
export interface Params$watchRbacAuthorizationV1ClusterRoleBinding<U extends ResponseContentType$watchRbacAuthorizationV1ClusterRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchRbacAuthorizationV1ClusterRoleBinding;
}
export declare type ResponseContentType$watchRbacAuthorizationV1ClusterRoleList = keyof Response$watchRbacAuthorizationV1ClusterRoleList$Status$200;
export interface Params$watchRbacAuthorizationV1ClusterRoleList<U extends ResponseContentType$watchRbacAuthorizationV1ClusterRoleList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchRbacAuthorizationV1ClusterRoleList;
}
export declare type ResponseContentType$watchRbacAuthorizationV1ClusterRole = keyof Response$watchRbacAuthorizationV1ClusterRole$Status$200;
export interface Params$watchRbacAuthorizationV1ClusterRole<U extends ResponseContentType$watchRbacAuthorizationV1ClusterRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchRbacAuthorizationV1ClusterRole;
}
export declare type ResponseContentType$watchRbacAuthorizationV1NamespacedRoleBindingList = keyof Response$watchRbacAuthorizationV1NamespacedRoleBindingList$Status$200;
export interface Params$watchRbacAuthorizationV1NamespacedRoleBindingList<U extends ResponseContentType$watchRbacAuthorizationV1NamespacedRoleBindingList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchRbacAuthorizationV1NamespacedRoleBindingList;
}
export declare type ResponseContentType$watchRbacAuthorizationV1NamespacedRoleBinding = keyof Response$watchRbacAuthorizationV1NamespacedRoleBinding$Status$200;
export interface Params$watchRbacAuthorizationV1NamespacedRoleBinding<U extends ResponseContentType$watchRbacAuthorizationV1NamespacedRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchRbacAuthorizationV1NamespacedRoleBinding;
}
export declare type ResponseContentType$watchRbacAuthorizationV1NamespacedRoleList = keyof Response$watchRbacAuthorizationV1NamespacedRoleList$Status$200;
export interface Params$watchRbacAuthorizationV1NamespacedRoleList<U extends ResponseContentType$watchRbacAuthorizationV1NamespacedRoleList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchRbacAuthorizationV1NamespacedRoleList;
}
export declare type ResponseContentType$watchRbacAuthorizationV1NamespacedRole = keyof Response$watchRbacAuthorizationV1NamespacedRole$Status$200;
export interface Params$watchRbacAuthorizationV1NamespacedRole<U extends ResponseContentType$watchRbacAuthorizationV1NamespacedRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchRbacAuthorizationV1NamespacedRole;
}
export declare type ResponseContentType$watchRbacAuthorizationV1RoleBindingListForAllNamespaces = keyof Response$watchRbacAuthorizationV1RoleBindingListForAllNamespaces$Status$200;
export interface Params$watchRbacAuthorizationV1RoleBindingListForAllNamespaces<U extends ResponseContentType$watchRbacAuthorizationV1RoleBindingListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchRbacAuthorizationV1RoleBindingListForAllNamespaces;
}
export declare type ResponseContentType$watchRbacAuthorizationV1RoleListForAllNamespaces = keyof Response$watchRbacAuthorizationV1RoleListForAllNamespaces$Status$200;
export interface Params$watchRbacAuthorizationV1RoleListForAllNamespaces<U extends ResponseContentType$watchRbacAuthorizationV1RoleListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchRbacAuthorizationV1RoleListForAllNamespaces;
}
export declare type ResponseContentType$getSchedulingAPIGroup = keyof Response$getSchedulingAPIGroup$Status$200;
export interface Params$getSchedulingAPIGroup<U extends ResponseContentType$getSchedulingAPIGroup> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$getSchedulingV1APIResources = keyof Response$getSchedulingV1APIResources$Status$200;
export interface Params$getSchedulingV1APIResources<U extends ResponseContentType$getSchedulingV1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listSchedulingV1PriorityClass = keyof Response$listSchedulingV1PriorityClass$Status$200;
export interface Params$listSchedulingV1PriorityClass<U extends ResponseContentType$listSchedulingV1PriorityClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listSchedulingV1PriorityClass;
}
export declare type RequestContentType$createSchedulingV1PriorityClass = keyof RequestBody$createSchedulingV1PriorityClass;
export declare type ResponseContentType$createSchedulingV1PriorityClass = keyof Response$createSchedulingV1PriorityClass$Status$200 | keyof Response$createSchedulingV1PriorityClass$Status$201 | keyof Response$createSchedulingV1PriorityClass$Status$202;
export interface Params$createSchedulingV1PriorityClass<U extends ResponseContentType$createSchedulingV1PriorityClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createSchedulingV1PriorityClass;
    requestBody: RequestBody$createSchedulingV1PriorityClass["*/*"];
}
export declare type RequestContentType$deleteSchedulingV1CollectionPriorityClass = keyof RequestBody$deleteSchedulingV1CollectionPriorityClass;
export declare type ResponseContentType$deleteSchedulingV1CollectionPriorityClass = keyof Response$deleteSchedulingV1CollectionPriorityClass$Status$200;
export interface Params$deleteSchedulingV1CollectionPriorityClass<U extends ResponseContentType$deleteSchedulingV1CollectionPriorityClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteSchedulingV1CollectionPriorityClass;
    requestBody: RequestBody$deleteSchedulingV1CollectionPriorityClass["*/*"];
}
export declare type ResponseContentType$readSchedulingV1PriorityClass = keyof Response$readSchedulingV1PriorityClass$Status$200;
export interface Params$readSchedulingV1PriorityClass<U extends ResponseContentType$readSchedulingV1PriorityClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readSchedulingV1PriorityClass;
}
export declare type RequestContentType$replaceSchedulingV1PriorityClass = keyof RequestBody$replaceSchedulingV1PriorityClass;
export declare type ResponseContentType$replaceSchedulingV1PriorityClass = keyof Response$replaceSchedulingV1PriorityClass$Status$200 | keyof Response$replaceSchedulingV1PriorityClass$Status$201;
export interface Params$replaceSchedulingV1PriorityClass<U extends ResponseContentType$replaceSchedulingV1PriorityClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceSchedulingV1PriorityClass;
    requestBody: RequestBody$replaceSchedulingV1PriorityClass["*/*"];
}
export declare type RequestContentType$deleteSchedulingV1PriorityClass = keyof RequestBody$deleteSchedulingV1PriorityClass;
export declare type ResponseContentType$deleteSchedulingV1PriorityClass = keyof Response$deleteSchedulingV1PriorityClass$Status$200 | keyof Response$deleteSchedulingV1PriorityClass$Status$202;
export interface Params$deleteSchedulingV1PriorityClass<U extends ResponseContentType$deleteSchedulingV1PriorityClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteSchedulingV1PriorityClass;
    requestBody: RequestBody$deleteSchedulingV1PriorityClass["*/*"];
}
export declare type RequestContentType$patchSchedulingV1PriorityClass = keyof RequestBody$patchSchedulingV1PriorityClass;
export declare type ResponseContentType$patchSchedulingV1PriorityClass = keyof Response$patchSchedulingV1PriorityClass$Status$200 | keyof Response$patchSchedulingV1PriorityClass$Status$201;
export interface Params$patchSchedulingV1PriorityClass<T extends RequestContentType$patchSchedulingV1PriorityClass, U extends ResponseContentType$patchSchedulingV1PriorityClass> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchSchedulingV1PriorityClass;
    requestBody: RequestBody$patchSchedulingV1PriorityClass[T];
}
export declare type ResponseContentType$watchSchedulingV1PriorityClassList = keyof Response$watchSchedulingV1PriorityClassList$Status$200;
export interface Params$watchSchedulingV1PriorityClassList<U extends ResponseContentType$watchSchedulingV1PriorityClassList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchSchedulingV1PriorityClassList;
}
export declare type ResponseContentType$watchSchedulingV1PriorityClass = keyof Response$watchSchedulingV1PriorityClass$Status$200;
export interface Params$watchSchedulingV1PriorityClass<U extends ResponseContentType$watchSchedulingV1PriorityClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchSchedulingV1PriorityClass;
}
export declare type ResponseContentType$getStorageAPIGroup = keyof Response$getStorageAPIGroup$Status$200;
export interface Params$getStorageAPIGroup<U extends ResponseContentType$getStorageAPIGroup> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$getStorageV1APIResources = keyof Response$getStorageV1APIResources$Status$200;
export interface Params$getStorageV1APIResources<U extends ResponseContentType$getStorageV1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listStorageV1CSIDriver = keyof Response$listStorageV1CSIDriver$Status$200;
export interface Params$listStorageV1CSIDriver<U extends ResponseContentType$listStorageV1CSIDriver> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listStorageV1CSIDriver;
}
export declare type RequestContentType$createStorageV1CSIDriver = keyof RequestBody$createStorageV1CSIDriver;
export declare type ResponseContentType$createStorageV1CSIDriver = keyof Response$createStorageV1CSIDriver$Status$200 | keyof Response$createStorageV1CSIDriver$Status$201 | keyof Response$createStorageV1CSIDriver$Status$202;
export interface Params$createStorageV1CSIDriver<U extends ResponseContentType$createStorageV1CSIDriver> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createStorageV1CSIDriver;
    requestBody: RequestBody$createStorageV1CSIDriver["*/*"];
}
export declare type RequestContentType$deleteStorageV1CollectionCSIDriver = keyof RequestBody$deleteStorageV1CollectionCSIDriver;
export declare type ResponseContentType$deleteStorageV1CollectionCSIDriver = keyof Response$deleteStorageV1CollectionCSIDriver$Status$200;
export interface Params$deleteStorageV1CollectionCSIDriver<U extends ResponseContentType$deleteStorageV1CollectionCSIDriver> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteStorageV1CollectionCSIDriver;
    requestBody: RequestBody$deleteStorageV1CollectionCSIDriver["*/*"];
}
export declare type ResponseContentType$readStorageV1CSIDriver = keyof Response$readStorageV1CSIDriver$Status$200;
export interface Params$readStorageV1CSIDriver<U extends ResponseContentType$readStorageV1CSIDriver> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readStorageV1CSIDriver;
}
export declare type RequestContentType$replaceStorageV1CSIDriver = keyof RequestBody$replaceStorageV1CSIDriver;
export declare type ResponseContentType$replaceStorageV1CSIDriver = keyof Response$replaceStorageV1CSIDriver$Status$200 | keyof Response$replaceStorageV1CSIDriver$Status$201;
export interface Params$replaceStorageV1CSIDriver<U extends ResponseContentType$replaceStorageV1CSIDriver> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceStorageV1CSIDriver;
    requestBody: RequestBody$replaceStorageV1CSIDriver["*/*"];
}
export declare type RequestContentType$deleteStorageV1CSIDriver = keyof RequestBody$deleteStorageV1CSIDriver;
export declare type ResponseContentType$deleteStorageV1CSIDriver = keyof Response$deleteStorageV1CSIDriver$Status$200 | keyof Response$deleteStorageV1CSIDriver$Status$202;
export interface Params$deleteStorageV1CSIDriver<U extends ResponseContentType$deleteStorageV1CSIDriver> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteStorageV1CSIDriver;
    requestBody: RequestBody$deleteStorageV1CSIDriver["*/*"];
}
export declare type RequestContentType$patchStorageV1CSIDriver = keyof RequestBody$patchStorageV1CSIDriver;
export declare type ResponseContentType$patchStorageV1CSIDriver = keyof Response$patchStorageV1CSIDriver$Status$200 | keyof Response$patchStorageV1CSIDriver$Status$201;
export interface Params$patchStorageV1CSIDriver<T extends RequestContentType$patchStorageV1CSIDriver, U extends ResponseContentType$patchStorageV1CSIDriver> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchStorageV1CSIDriver;
    requestBody: RequestBody$patchStorageV1CSIDriver[T];
}
export declare type ResponseContentType$listStorageV1CSINode = keyof Response$listStorageV1CSINode$Status$200;
export interface Params$listStorageV1CSINode<U extends ResponseContentType$listStorageV1CSINode> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listStorageV1CSINode;
}
export declare type RequestContentType$createStorageV1CSINode = keyof RequestBody$createStorageV1CSINode;
export declare type ResponseContentType$createStorageV1CSINode = keyof Response$createStorageV1CSINode$Status$200 | keyof Response$createStorageV1CSINode$Status$201 | keyof Response$createStorageV1CSINode$Status$202;
export interface Params$createStorageV1CSINode<U extends ResponseContentType$createStorageV1CSINode> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createStorageV1CSINode;
    requestBody: RequestBody$createStorageV1CSINode["*/*"];
}
export declare type RequestContentType$deleteStorageV1CollectionCSINode = keyof RequestBody$deleteStorageV1CollectionCSINode;
export declare type ResponseContentType$deleteStorageV1CollectionCSINode = keyof Response$deleteStorageV1CollectionCSINode$Status$200;
export interface Params$deleteStorageV1CollectionCSINode<U extends ResponseContentType$deleteStorageV1CollectionCSINode> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteStorageV1CollectionCSINode;
    requestBody: RequestBody$deleteStorageV1CollectionCSINode["*/*"];
}
export declare type ResponseContentType$readStorageV1CSINode = keyof Response$readStorageV1CSINode$Status$200;
export interface Params$readStorageV1CSINode<U extends ResponseContentType$readStorageV1CSINode> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readStorageV1CSINode;
}
export declare type RequestContentType$replaceStorageV1CSINode = keyof RequestBody$replaceStorageV1CSINode;
export declare type ResponseContentType$replaceStorageV1CSINode = keyof Response$replaceStorageV1CSINode$Status$200 | keyof Response$replaceStorageV1CSINode$Status$201;
export interface Params$replaceStorageV1CSINode<U extends ResponseContentType$replaceStorageV1CSINode> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceStorageV1CSINode;
    requestBody: RequestBody$replaceStorageV1CSINode["*/*"];
}
export declare type RequestContentType$deleteStorageV1CSINode = keyof RequestBody$deleteStorageV1CSINode;
export declare type ResponseContentType$deleteStorageV1CSINode = keyof Response$deleteStorageV1CSINode$Status$200 | keyof Response$deleteStorageV1CSINode$Status$202;
export interface Params$deleteStorageV1CSINode<U extends ResponseContentType$deleteStorageV1CSINode> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteStorageV1CSINode;
    requestBody: RequestBody$deleteStorageV1CSINode["*/*"];
}
export declare type RequestContentType$patchStorageV1CSINode = keyof RequestBody$patchStorageV1CSINode;
export declare type ResponseContentType$patchStorageV1CSINode = keyof Response$patchStorageV1CSINode$Status$200 | keyof Response$patchStorageV1CSINode$Status$201;
export interface Params$patchStorageV1CSINode<T extends RequestContentType$patchStorageV1CSINode, U extends ResponseContentType$patchStorageV1CSINode> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchStorageV1CSINode;
    requestBody: RequestBody$patchStorageV1CSINode[T];
}
export declare type ResponseContentType$listStorageV1StorageClass = keyof Response$listStorageV1StorageClass$Status$200;
export interface Params$listStorageV1StorageClass<U extends ResponseContentType$listStorageV1StorageClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listStorageV1StorageClass;
}
export declare type RequestContentType$createStorageV1StorageClass = keyof RequestBody$createStorageV1StorageClass;
export declare type ResponseContentType$createStorageV1StorageClass = keyof Response$createStorageV1StorageClass$Status$200 | keyof Response$createStorageV1StorageClass$Status$201 | keyof Response$createStorageV1StorageClass$Status$202;
export interface Params$createStorageV1StorageClass<U extends ResponseContentType$createStorageV1StorageClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createStorageV1StorageClass;
    requestBody: RequestBody$createStorageV1StorageClass["*/*"];
}
export declare type RequestContentType$deleteStorageV1CollectionStorageClass = keyof RequestBody$deleteStorageV1CollectionStorageClass;
export declare type ResponseContentType$deleteStorageV1CollectionStorageClass = keyof Response$deleteStorageV1CollectionStorageClass$Status$200;
export interface Params$deleteStorageV1CollectionStorageClass<U extends ResponseContentType$deleteStorageV1CollectionStorageClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteStorageV1CollectionStorageClass;
    requestBody: RequestBody$deleteStorageV1CollectionStorageClass["*/*"];
}
export declare type ResponseContentType$readStorageV1StorageClass = keyof Response$readStorageV1StorageClass$Status$200;
export interface Params$readStorageV1StorageClass<U extends ResponseContentType$readStorageV1StorageClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readStorageV1StorageClass;
}
export declare type RequestContentType$replaceStorageV1StorageClass = keyof RequestBody$replaceStorageV1StorageClass;
export declare type ResponseContentType$replaceStorageV1StorageClass = keyof Response$replaceStorageV1StorageClass$Status$200 | keyof Response$replaceStorageV1StorageClass$Status$201;
export interface Params$replaceStorageV1StorageClass<U extends ResponseContentType$replaceStorageV1StorageClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceStorageV1StorageClass;
    requestBody: RequestBody$replaceStorageV1StorageClass["*/*"];
}
export declare type RequestContentType$deleteStorageV1StorageClass = keyof RequestBody$deleteStorageV1StorageClass;
export declare type ResponseContentType$deleteStorageV1StorageClass = keyof Response$deleteStorageV1StorageClass$Status$200 | keyof Response$deleteStorageV1StorageClass$Status$202;
export interface Params$deleteStorageV1StorageClass<U extends ResponseContentType$deleteStorageV1StorageClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteStorageV1StorageClass;
    requestBody: RequestBody$deleteStorageV1StorageClass["*/*"];
}
export declare type RequestContentType$patchStorageV1StorageClass = keyof RequestBody$patchStorageV1StorageClass;
export declare type ResponseContentType$patchStorageV1StorageClass = keyof Response$patchStorageV1StorageClass$Status$200 | keyof Response$patchStorageV1StorageClass$Status$201;
export interface Params$patchStorageV1StorageClass<T extends RequestContentType$patchStorageV1StorageClass, U extends ResponseContentType$patchStorageV1StorageClass> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchStorageV1StorageClass;
    requestBody: RequestBody$patchStorageV1StorageClass[T];
}
export declare type ResponseContentType$listStorageV1VolumeAttachment = keyof Response$listStorageV1VolumeAttachment$Status$200;
export interface Params$listStorageV1VolumeAttachment<U extends ResponseContentType$listStorageV1VolumeAttachment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listStorageV1VolumeAttachment;
}
export declare type RequestContentType$createStorageV1VolumeAttachment = keyof RequestBody$createStorageV1VolumeAttachment;
export declare type ResponseContentType$createStorageV1VolumeAttachment = keyof Response$createStorageV1VolumeAttachment$Status$200 | keyof Response$createStorageV1VolumeAttachment$Status$201 | keyof Response$createStorageV1VolumeAttachment$Status$202;
export interface Params$createStorageV1VolumeAttachment<U extends ResponseContentType$createStorageV1VolumeAttachment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createStorageV1VolumeAttachment;
    requestBody: RequestBody$createStorageV1VolumeAttachment["*/*"];
}
export declare type RequestContentType$deleteStorageV1CollectionVolumeAttachment = keyof RequestBody$deleteStorageV1CollectionVolumeAttachment;
export declare type ResponseContentType$deleteStorageV1CollectionVolumeAttachment = keyof Response$deleteStorageV1CollectionVolumeAttachment$Status$200;
export interface Params$deleteStorageV1CollectionVolumeAttachment<U extends ResponseContentType$deleteStorageV1CollectionVolumeAttachment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteStorageV1CollectionVolumeAttachment;
    requestBody: RequestBody$deleteStorageV1CollectionVolumeAttachment["*/*"];
}
export declare type ResponseContentType$readStorageV1VolumeAttachment = keyof Response$readStorageV1VolumeAttachment$Status$200;
export interface Params$readStorageV1VolumeAttachment<U extends ResponseContentType$readStorageV1VolumeAttachment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readStorageV1VolumeAttachment;
}
export declare type RequestContentType$replaceStorageV1VolumeAttachment = keyof RequestBody$replaceStorageV1VolumeAttachment;
export declare type ResponseContentType$replaceStorageV1VolumeAttachment = keyof Response$replaceStorageV1VolumeAttachment$Status$200 | keyof Response$replaceStorageV1VolumeAttachment$Status$201;
export interface Params$replaceStorageV1VolumeAttachment<U extends ResponseContentType$replaceStorageV1VolumeAttachment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceStorageV1VolumeAttachment;
    requestBody: RequestBody$replaceStorageV1VolumeAttachment["*/*"];
}
export declare type RequestContentType$deleteStorageV1VolumeAttachment = keyof RequestBody$deleteStorageV1VolumeAttachment;
export declare type ResponseContentType$deleteStorageV1VolumeAttachment = keyof Response$deleteStorageV1VolumeAttachment$Status$200 | keyof Response$deleteStorageV1VolumeAttachment$Status$202;
export interface Params$deleteStorageV1VolumeAttachment<U extends ResponseContentType$deleteStorageV1VolumeAttachment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteStorageV1VolumeAttachment;
    requestBody: RequestBody$deleteStorageV1VolumeAttachment["*/*"];
}
export declare type RequestContentType$patchStorageV1VolumeAttachment = keyof RequestBody$patchStorageV1VolumeAttachment;
export declare type ResponseContentType$patchStorageV1VolumeAttachment = keyof Response$patchStorageV1VolumeAttachment$Status$200 | keyof Response$patchStorageV1VolumeAttachment$Status$201;
export interface Params$patchStorageV1VolumeAttachment<T extends RequestContentType$patchStorageV1VolumeAttachment, U extends ResponseContentType$patchStorageV1VolumeAttachment> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchStorageV1VolumeAttachment;
    requestBody: RequestBody$patchStorageV1VolumeAttachment[T];
}
export declare type ResponseContentType$readStorageV1VolumeAttachmentStatus = keyof Response$readStorageV1VolumeAttachmentStatus$Status$200;
export interface Params$readStorageV1VolumeAttachmentStatus<U extends ResponseContentType$readStorageV1VolumeAttachmentStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readStorageV1VolumeAttachmentStatus;
}
export declare type RequestContentType$replaceStorageV1VolumeAttachmentStatus = keyof RequestBody$replaceStorageV1VolumeAttachmentStatus;
export declare type ResponseContentType$replaceStorageV1VolumeAttachmentStatus = keyof Response$replaceStorageV1VolumeAttachmentStatus$Status$200 | keyof Response$replaceStorageV1VolumeAttachmentStatus$Status$201;
export interface Params$replaceStorageV1VolumeAttachmentStatus<U extends ResponseContentType$replaceStorageV1VolumeAttachmentStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceStorageV1VolumeAttachmentStatus;
    requestBody: RequestBody$replaceStorageV1VolumeAttachmentStatus["*/*"];
}
export declare type RequestContentType$patchStorageV1VolumeAttachmentStatus = keyof RequestBody$patchStorageV1VolumeAttachmentStatus;
export declare type ResponseContentType$patchStorageV1VolumeAttachmentStatus = keyof Response$patchStorageV1VolumeAttachmentStatus$Status$200 | keyof Response$patchStorageV1VolumeAttachmentStatus$Status$201;
export interface Params$patchStorageV1VolumeAttachmentStatus<T extends RequestContentType$patchStorageV1VolumeAttachmentStatus, U extends ResponseContentType$patchStorageV1VolumeAttachmentStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchStorageV1VolumeAttachmentStatus;
    requestBody: RequestBody$patchStorageV1VolumeAttachmentStatus[T];
}
export declare type ResponseContentType$watchStorageV1CSIDriverList = keyof Response$watchStorageV1CSIDriverList$Status$200;
export interface Params$watchStorageV1CSIDriverList<U extends ResponseContentType$watchStorageV1CSIDriverList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1CSIDriverList;
}
export declare type ResponseContentType$watchStorageV1CSIDriver = keyof Response$watchStorageV1CSIDriver$Status$200;
export interface Params$watchStorageV1CSIDriver<U extends ResponseContentType$watchStorageV1CSIDriver> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1CSIDriver;
}
export declare type ResponseContentType$watchStorageV1CSINodeList = keyof Response$watchStorageV1CSINodeList$Status$200;
export interface Params$watchStorageV1CSINodeList<U extends ResponseContentType$watchStorageV1CSINodeList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1CSINodeList;
}
export declare type ResponseContentType$watchStorageV1CSINode = keyof Response$watchStorageV1CSINode$Status$200;
export interface Params$watchStorageV1CSINode<U extends ResponseContentType$watchStorageV1CSINode> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1CSINode;
}
export declare type ResponseContentType$watchStorageV1StorageClassList = keyof Response$watchStorageV1StorageClassList$Status$200;
export interface Params$watchStorageV1StorageClassList<U extends ResponseContentType$watchStorageV1StorageClassList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1StorageClassList;
}
export declare type ResponseContentType$watchStorageV1StorageClass = keyof Response$watchStorageV1StorageClass$Status$200;
export interface Params$watchStorageV1StorageClass<U extends ResponseContentType$watchStorageV1StorageClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1StorageClass;
}
export declare type ResponseContentType$watchStorageV1VolumeAttachmentList = keyof Response$watchStorageV1VolumeAttachmentList$Status$200;
export interface Params$watchStorageV1VolumeAttachmentList<U extends ResponseContentType$watchStorageV1VolumeAttachmentList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1VolumeAttachmentList;
}
export declare type ResponseContentType$watchStorageV1VolumeAttachment = keyof Response$watchStorageV1VolumeAttachment$Status$200;
export interface Params$watchStorageV1VolumeAttachment<U extends ResponseContentType$watchStorageV1VolumeAttachment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1VolumeAttachment;
}
export declare type ResponseContentType$getStorageV1alpha1APIResources = keyof Response$getStorageV1alpha1APIResources$Status$200;
export interface Params$getStorageV1alpha1APIResources<U extends ResponseContentType$getStorageV1alpha1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listStorageV1alpha1CSIStorageCapacityForAllNamespaces = keyof Response$listStorageV1alpha1CSIStorageCapacityForAllNamespaces$Status$200;
export interface Params$listStorageV1alpha1CSIStorageCapacityForAllNamespaces<U extends ResponseContentType$listStorageV1alpha1CSIStorageCapacityForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listStorageV1alpha1CSIStorageCapacityForAllNamespaces;
}
export declare type ResponseContentType$listStorageV1alpha1NamespacedCSIStorageCapacity = keyof Response$listStorageV1alpha1NamespacedCSIStorageCapacity$Status$200;
export interface Params$listStorageV1alpha1NamespacedCSIStorageCapacity<U extends ResponseContentType$listStorageV1alpha1NamespacedCSIStorageCapacity> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listStorageV1alpha1NamespacedCSIStorageCapacity;
}
export declare type RequestContentType$createStorageV1alpha1NamespacedCSIStorageCapacity = keyof RequestBody$createStorageV1alpha1NamespacedCSIStorageCapacity;
export declare type ResponseContentType$createStorageV1alpha1NamespacedCSIStorageCapacity = keyof Response$createStorageV1alpha1NamespacedCSIStorageCapacity$Status$200 | keyof Response$createStorageV1alpha1NamespacedCSIStorageCapacity$Status$201 | keyof Response$createStorageV1alpha1NamespacedCSIStorageCapacity$Status$202;
export interface Params$createStorageV1alpha1NamespacedCSIStorageCapacity<U extends ResponseContentType$createStorageV1alpha1NamespacedCSIStorageCapacity> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createStorageV1alpha1NamespacedCSIStorageCapacity;
    requestBody: RequestBody$createStorageV1alpha1NamespacedCSIStorageCapacity["*/*"];
}
export declare type RequestContentType$deleteStorageV1alpha1CollectionNamespacedCSIStorageCapacity = keyof RequestBody$deleteStorageV1alpha1CollectionNamespacedCSIStorageCapacity;
export declare type ResponseContentType$deleteStorageV1alpha1CollectionNamespacedCSIStorageCapacity = keyof Response$deleteStorageV1alpha1CollectionNamespacedCSIStorageCapacity$Status$200;
export interface Params$deleteStorageV1alpha1CollectionNamespacedCSIStorageCapacity<U extends ResponseContentType$deleteStorageV1alpha1CollectionNamespacedCSIStorageCapacity> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteStorageV1alpha1CollectionNamespacedCSIStorageCapacity;
    requestBody: RequestBody$deleteStorageV1alpha1CollectionNamespacedCSIStorageCapacity["*/*"];
}
export declare type ResponseContentType$readStorageV1alpha1NamespacedCSIStorageCapacity = keyof Response$readStorageV1alpha1NamespacedCSIStorageCapacity$Status$200;
export interface Params$readStorageV1alpha1NamespacedCSIStorageCapacity<U extends ResponseContentType$readStorageV1alpha1NamespacedCSIStorageCapacity> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readStorageV1alpha1NamespacedCSIStorageCapacity;
}
export declare type RequestContentType$replaceStorageV1alpha1NamespacedCSIStorageCapacity = keyof RequestBody$replaceStorageV1alpha1NamespacedCSIStorageCapacity;
export declare type ResponseContentType$replaceStorageV1alpha1NamespacedCSIStorageCapacity = keyof Response$replaceStorageV1alpha1NamespacedCSIStorageCapacity$Status$200 | keyof Response$replaceStorageV1alpha1NamespacedCSIStorageCapacity$Status$201;
export interface Params$replaceStorageV1alpha1NamespacedCSIStorageCapacity<U extends ResponseContentType$replaceStorageV1alpha1NamespacedCSIStorageCapacity> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceStorageV1alpha1NamespacedCSIStorageCapacity;
    requestBody: RequestBody$replaceStorageV1alpha1NamespacedCSIStorageCapacity["*/*"];
}
export declare type RequestContentType$deleteStorageV1alpha1NamespacedCSIStorageCapacity = keyof RequestBody$deleteStorageV1alpha1NamespacedCSIStorageCapacity;
export declare type ResponseContentType$deleteStorageV1alpha1NamespacedCSIStorageCapacity = keyof Response$deleteStorageV1alpha1NamespacedCSIStorageCapacity$Status$200 | keyof Response$deleteStorageV1alpha1NamespacedCSIStorageCapacity$Status$202;
export interface Params$deleteStorageV1alpha1NamespacedCSIStorageCapacity<U extends ResponseContentType$deleteStorageV1alpha1NamespacedCSIStorageCapacity> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteStorageV1alpha1NamespacedCSIStorageCapacity;
    requestBody: RequestBody$deleteStorageV1alpha1NamespacedCSIStorageCapacity["*/*"];
}
export declare type RequestContentType$patchStorageV1alpha1NamespacedCSIStorageCapacity = keyof RequestBody$patchStorageV1alpha1NamespacedCSIStorageCapacity;
export declare type ResponseContentType$patchStorageV1alpha1NamespacedCSIStorageCapacity = keyof Response$patchStorageV1alpha1NamespacedCSIStorageCapacity$Status$200 | keyof Response$patchStorageV1alpha1NamespacedCSIStorageCapacity$Status$201;
export interface Params$patchStorageV1alpha1NamespacedCSIStorageCapacity<T extends RequestContentType$patchStorageV1alpha1NamespacedCSIStorageCapacity, U extends ResponseContentType$patchStorageV1alpha1NamespacedCSIStorageCapacity> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchStorageV1alpha1NamespacedCSIStorageCapacity;
    requestBody: RequestBody$patchStorageV1alpha1NamespacedCSIStorageCapacity[T];
}
export declare type ResponseContentType$watchStorageV1alpha1CSIStorageCapacityListForAllNamespaces = keyof Response$watchStorageV1alpha1CSIStorageCapacityListForAllNamespaces$Status$200;
export interface Params$watchStorageV1alpha1CSIStorageCapacityListForAllNamespaces<U extends ResponseContentType$watchStorageV1alpha1CSIStorageCapacityListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1alpha1CSIStorageCapacityListForAllNamespaces;
}
export declare type ResponseContentType$watchStorageV1alpha1NamespacedCSIStorageCapacityList = keyof Response$watchStorageV1alpha1NamespacedCSIStorageCapacityList$Status$200;
export interface Params$watchStorageV1alpha1NamespacedCSIStorageCapacityList<U extends ResponseContentType$watchStorageV1alpha1NamespacedCSIStorageCapacityList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1alpha1NamespacedCSIStorageCapacityList;
}
export declare type ResponseContentType$watchStorageV1alpha1NamespacedCSIStorageCapacity = keyof Response$watchStorageV1alpha1NamespacedCSIStorageCapacity$Status$200;
export interface Params$watchStorageV1alpha1NamespacedCSIStorageCapacity<U extends ResponseContentType$watchStorageV1alpha1NamespacedCSIStorageCapacity> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1alpha1NamespacedCSIStorageCapacity;
}
export declare type ResponseContentType$getStorageV1beta1APIResources = keyof Response$getStorageV1beta1APIResources$Status$200;
export interface Params$getStorageV1beta1APIResources<U extends ResponseContentType$getStorageV1beta1APIResources> {
    headers: {
        Accept: U;
    };
}
export declare type ResponseContentType$listStorageV1beta1CSIStorageCapacityForAllNamespaces = keyof Response$listStorageV1beta1CSIStorageCapacityForAllNamespaces$Status$200;
export interface Params$listStorageV1beta1CSIStorageCapacityForAllNamespaces<U extends ResponseContentType$listStorageV1beta1CSIStorageCapacityForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listStorageV1beta1CSIStorageCapacityForAllNamespaces;
}
export declare type ResponseContentType$listStorageV1beta1NamespacedCSIStorageCapacity = keyof Response$listStorageV1beta1NamespacedCSIStorageCapacity$Status$200;
export interface Params$listStorageV1beta1NamespacedCSIStorageCapacity<U extends ResponseContentType$listStorageV1beta1NamespacedCSIStorageCapacity> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listStorageV1beta1NamespacedCSIStorageCapacity;
}
export declare type RequestContentType$createStorageV1beta1NamespacedCSIStorageCapacity = keyof RequestBody$createStorageV1beta1NamespacedCSIStorageCapacity;
export declare type ResponseContentType$createStorageV1beta1NamespacedCSIStorageCapacity = keyof Response$createStorageV1beta1NamespacedCSIStorageCapacity$Status$200 | keyof Response$createStorageV1beta1NamespacedCSIStorageCapacity$Status$201 | keyof Response$createStorageV1beta1NamespacedCSIStorageCapacity$Status$202;
export interface Params$createStorageV1beta1NamespacedCSIStorageCapacity<U extends ResponseContentType$createStorageV1beta1NamespacedCSIStorageCapacity> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createStorageV1beta1NamespacedCSIStorageCapacity;
    requestBody: RequestBody$createStorageV1beta1NamespacedCSIStorageCapacity["*/*"];
}
export declare type RequestContentType$deleteStorageV1beta1CollectionNamespacedCSIStorageCapacity = keyof RequestBody$deleteStorageV1beta1CollectionNamespacedCSIStorageCapacity;
export declare type ResponseContentType$deleteStorageV1beta1CollectionNamespacedCSIStorageCapacity = keyof Response$deleteStorageV1beta1CollectionNamespacedCSIStorageCapacity$Status$200;
export interface Params$deleteStorageV1beta1CollectionNamespacedCSIStorageCapacity<U extends ResponseContentType$deleteStorageV1beta1CollectionNamespacedCSIStorageCapacity> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteStorageV1beta1CollectionNamespacedCSIStorageCapacity;
    requestBody: RequestBody$deleteStorageV1beta1CollectionNamespacedCSIStorageCapacity["*/*"];
}
export declare type ResponseContentType$readStorageV1beta1NamespacedCSIStorageCapacity = keyof Response$readStorageV1beta1NamespacedCSIStorageCapacity$Status$200;
export interface Params$readStorageV1beta1NamespacedCSIStorageCapacity<U extends ResponseContentType$readStorageV1beta1NamespacedCSIStorageCapacity> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readStorageV1beta1NamespacedCSIStorageCapacity;
}
export declare type RequestContentType$replaceStorageV1beta1NamespacedCSIStorageCapacity = keyof RequestBody$replaceStorageV1beta1NamespacedCSIStorageCapacity;
export declare type ResponseContentType$replaceStorageV1beta1NamespacedCSIStorageCapacity = keyof Response$replaceStorageV1beta1NamespacedCSIStorageCapacity$Status$200 | keyof Response$replaceStorageV1beta1NamespacedCSIStorageCapacity$Status$201;
export interface Params$replaceStorageV1beta1NamespacedCSIStorageCapacity<U extends ResponseContentType$replaceStorageV1beta1NamespacedCSIStorageCapacity> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceStorageV1beta1NamespacedCSIStorageCapacity;
    requestBody: RequestBody$replaceStorageV1beta1NamespacedCSIStorageCapacity["*/*"];
}
export declare type RequestContentType$deleteStorageV1beta1NamespacedCSIStorageCapacity = keyof RequestBody$deleteStorageV1beta1NamespacedCSIStorageCapacity;
export declare type ResponseContentType$deleteStorageV1beta1NamespacedCSIStorageCapacity = keyof Response$deleteStorageV1beta1NamespacedCSIStorageCapacity$Status$200 | keyof Response$deleteStorageV1beta1NamespacedCSIStorageCapacity$Status$202;
export interface Params$deleteStorageV1beta1NamespacedCSIStorageCapacity<U extends ResponseContentType$deleteStorageV1beta1NamespacedCSIStorageCapacity> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteStorageV1beta1NamespacedCSIStorageCapacity;
    requestBody: RequestBody$deleteStorageV1beta1NamespacedCSIStorageCapacity["*/*"];
}
export declare type RequestContentType$patchStorageV1beta1NamespacedCSIStorageCapacity = keyof RequestBody$patchStorageV1beta1NamespacedCSIStorageCapacity;
export declare type ResponseContentType$patchStorageV1beta1NamespacedCSIStorageCapacity = keyof Response$patchStorageV1beta1NamespacedCSIStorageCapacity$Status$200 | keyof Response$patchStorageV1beta1NamespacedCSIStorageCapacity$Status$201;
export interface Params$patchStorageV1beta1NamespacedCSIStorageCapacity<T extends RequestContentType$patchStorageV1beta1NamespacedCSIStorageCapacity, U extends ResponseContentType$patchStorageV1beta1NamespacedCSIStorageCapacity> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchStorageV1beta1NamespacedCSIStorageCapacity;
    requestBody: RequestBody$patchStorageV1beta1NamespacedCSIStorageCapacity[T];
}
export declare type ResponseContentType$watchStorageV1beta1CSIStorageCapacityListForAllNamespaces = keyof Response$watchStorageV1beta1CSIStorageCapacityListForAllNamespaces$Status$200;
export interface Params$watchStorageV1beta1CSIStorageCapacityListForAllNamespaces<U extends ResponseContentType$watchStorageV1beta1CSIStorageCapacityListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1beta1CSIStorageCapacityListForAllNamespaces;
}
export declare type ResponseContentType$watchStorageV1beta1NamespacedCSIStorageCapacityList = keyof Response$watchStorageV1beta1NamespacedCSIStorageCapacityList$Status$200;
export interface Params$watchStorageV1beta1NamespacedCSIStorageCapacityList<U extends ResponseContentType$watchStorageV1beta1NamespacedCSIStorageCapacityList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1beta1NamespacedCSIStorageCapacityList;
}
export declare type ResponseContentType$watchStorageV1beta1NamespacedCSIStorageCapacity = keyof Response$watchStorageV1beta1NamespacedCSIStorageCapacity$Status$200;
export interface Params$watchStorageV1beta1NamespacedCSIStorageCapacity<U extends ResponseContentType$watchStorageV1beta1NamespacedCSIStorageCapacity> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1beta1NamespacedCSIStorageCapacity;
}
export interface Params$logFileHandler {
    parameter: Parameter$logFileHandler;
}
export declare type ResponseContentType$getServiceAccountIssuerOpenIDKeyset = keyof Response$getServiceAccountIssuerOpenIDKeyset$Status$200;
export declare type ResponseContentType$getCodeVersion = keyof Response$getCodeVersion$Status$200;
export declare type HttpMethod = "GET" | "PUT" | "POST" | "DELETE" | "OPTIONS" | "HEAD" | "PATCH" | "TRACE";
export interface ObjectLike {
    [key: string]: any;
}
export interface QueryParameter {
    value: any;
    style?: "form" | "spaceDelimited" | "pipeDelimited" | "deepObject";
    explode: boolean;
}
export interface QueryParameters {
    [key: string]: QueryParameter;
}
export declare type SuccessResponses = Response$getServiceAccountIssuerOpenIDConfiguration$Status$200 | Response$getCoreAPIVersions$Status$200 | Response$getCoreV1APIResources$Status$200 | Response$listCoreV1ComponentStatus$Status$200 | Response$readCoreV1ComponentStatus$Status$200 | Response$listCoreV1ConfigMapForAllNamespaces$Status$200 | Response$listCoreV1EndpointsForAllNamespaces$Status$200 | Response$listCoreV1EventForAllNamespaces$Status$200 | Response$listCoreV1LimitRangeForAllNamespaces$Status$200 | Response$listCoreV1Namespace$Status$200 | Response$createCoreV1Namespace$Status$200 | Response$createCoreV1Namespace$Status$201 | Response$createCoreV1Namespace$Status$202 | Response$createCoreV1NamespacedBinding$Status$200 | Response$createCoreV1NamespacedBinding$Status$201 | Response$createCoreV1NamespacedBinding$Status$202 | Response$listCoreV1NamespacedConfigMap$Status$200 | Response$createCoreV1NamespacedConfigMap$Status$200 | Response$createCoreV1NamespacedConfigMap$Status$201 | Response$createCoreV1NamespacedConfigMap$Status$202 | Response$deleteCoreV1CollectionNamespacedConfigMap$Status$200 | Response$readCoreV1NamespacedConfigMap$Status$200 | Response$replaceCoreV1NamespacedConfigMap$Status$200 | Response$replaceCoreV1NamespacedConfigMap$Status$201 | Response$deleteCoreV1NamespacedConfigMap$Status$200 | Response$deleteCoreV1NamespacedConfigMap$Status$202 | Response$patchCoreV1NamespacedConfigMap$Status$200 | Response$patchCoreV1NamespacedConfigMap$Status$201 | Response$listCoreV1NamespacedEndpoints$Status$200 | Response$createCoreV1NamespacedEndpoints$Status$200 | Response$createCoreV1NamespacedEndpoints$Status$201 | Response$createCoreV1NamespacedEndpoints$Status$202 | Response$deleteCoreV1CollectionNamespacedEndpoints$Status$200 | Response$readCoreV1NamespacedEndpoints$Status$200 | Response$replaceCoreV1NamespacedEndpoints$Status$200 | Response$replaceCoreV1NamespacedEndpoints$Status$201 | Response$deleteCoreV1NamespacedEndpoints$Status$200 | Response$deleteCoreV1NamespacedEndpoints$Status$202 | Response$patchCoreV1NamespacedEndpoints$Status$200 | Response$patchCoreV1NamespacedEndpoints$Status$201 | Response$listCoreV1NamespacedEvent$Status$200 | Response$createCoreV1NamespacedEvent$Status$200 | Response$createCoreV1NamespacedEvent$Status$201 | Response$createCoreV1NamespacedEvent$Status$202 | Response$deleteCoreV1CollectionNamespacedEvent$Status$200 | Response$readCoreV1NamespacedEvent$Status$200 | Response$replaceCoreV1NamespacedEvent$Status$200 | Response$replaceCoreV1NamespacedEvent$Status$201 | Response$deleteCoreV1NamespacedEvent$Status$200 | Response$deleteCoreV1NamespacedEvent$Status$202 | Response$patchCoreV1NamespacedEvent$Status$200 | Response$patchCoreV1NamespacedEvent$Status$201 | Response$listCoreV1NamespacedLimitRange$Status$200 | Response$createCoreV1NamespacedLimitRange$Status$200 | Response$createCoreV1NamespacedLimitRange$Status$201 | Response$createCoreV1NamespacedLimitRange$Status$202 | Response$deleteCoreV1CollectionNamespacedLimitRange$Status$200 | Response$readCoreV1NamespacedLimitRange$Status$200 | Response$replaceCoreV1NamespacedLimitRange$Status$200 | Response$replaceCoreV1NamespacedLimitRange$Status$201 | Response$deleteCoreV1NamespacedLimitRange$Status$200 | Response$deleteCoreV1NamespacedLimitRange$Status$202 | Response$patchCoreV1NamespacedLimitRange$Status$200 | Response$patchCoreV1NamespacedLimitRange$Status$201 | Response$listCoreV1NamespacedPersistentVolumeClaim$Status$200 | Response$createCoreV1NamespacedPersistentVolumeClaim$Status$200 | Response$createCoreV1NamespacedPersistentVolumeClaim$Status$201 | Response$createCoreV1NamespacedPersistentVolumeClaim$Status$202 | Response$deleteCoreV1CollectionNamespacedPersistentVolumeClaim$Status$200 | Response$readCoreV1NamespacedPersistentVolumeClaim$Status$200 | Response$replaceCoreV1NamespacedPersistentVolumeClaim$Status$200 | Response$replaceCoreV1NamespacedPersistentVolumeClaim$Status$201 | Response$deleteCoreV1NamespacedPersistentVolumeClaim$Status$200 | Response$deleteCoreV1NamespacedPersistentVolumeClaim$Status$202 | Response$patchCoreV1NamespacedPersistentVolumeClaim$Status$200 | Response$patchCoreV1NamespacedPersistentVolumeClaim$Status$201 | Response$readCoreV1NamespacedPersistentVolumeClaimStatus$Status$200 | Response$replaceCoreV1NamespacedPersistentVolumeClaimStatus$Status$200 | Response$replaceCoreV1NamespacedPersistentVolumeClaimStatus$Status$201 | Response$patchCoreV1NamespacedPersistentVolumeClaimStatus$Status$200 | Response$patchCoreV1NamespacedPersistentVolumeClaimStatus$Status$201 | Response$listCoreV1NamespacedPod$Status$200 | Response$createCoreV1NamespacedPod$Status$200 | Response$createCoreV1NamespacedPod$Status$201 | Response$createCoreV1NamespacedPod$Status$202 | Response$deleteCoreV1CollectionNamespacedPod$Status$200 | Response$readCoreV1NamespacedPod$Status$200 | Response$replaceCoreV1NamespacedPod$Status$200 | Response$replaceCoreV1NamespacedPod$Status$201 | Response$deleteCoreV1NamespacedPod$Status$200 | Response$deleteCoreV1NamespacedPod$Status$202 | Response$patchCoreV1NamespacedPod$Status$200 | Response$patchCoreV1NamespacedPod$Status$201 | Response$connectCoreV1GetNamespacedPodAttach$Status$200 | Response$connectCoreV1PostNamespacedPodAttach$Status$200 | Response$createCoreV1NamespacedPodBinding$Status$200 | Response$createCoreV1NamespacedPodBinding$Status$201 | Response$createCoreV1NamespacedPodBinding$Status$202 | Response$readCoreV1NamespacedPodEphemeralcontainers$Status$200 | Response$replaceCoreV1NamespacedPodEphemeralcontainers$Status$200 | Response$replaceCoreV1NamespacedPodEphemeralcontainers$Status$201 | Response$patchCoreV1NamespacedPodEphemeralcontainers$Status$200 | Response$patchCoreV1NamespacedPodEphemeralcontainers$Status$201 | Response$createCoreV1NamespacedPodEviction$Status$200 | Response$createCoreV1NamespacedPodEviction$Status$201 | Response$createCoreV1NamespacedPodEviction$Status$202 | Response$connectCoreV1GetNamespacedPodExec$Status$200 | Response$connectCoreV1PostNamespacedPodExec$Status$200 | Response$readCoreV1NamespacedPodLog$Status$200 | Response$connectCoreV1GetNamespacedPodPortforward$Status$200 | Response$connectCoreV1PostNamespacedPodPortforward$Status$200 | Response$connectCoreV1GetNamespacedPodProxy$Status$200 | Response$connectCoreV1PutNamespacedPodProxy$Status$200 | Response$connectCoreV1PostNamespacedPodProxy$Status$200 | Response$connectCoreV1DeleteNamespacedPodProxy$Status$200 | Response$connectCoreV1OptionsNamespacedPodProxy$Status$200 | Response$connectCoreV1HeadNamespacedPodProxy$Status$200 | Response$connectCoreV1PatchNamespacedPodProxy$Status$200 | Response$connectCoreV1GetNamespacedPodProxyWithPath$Status$200 | Response$connectCoreV1PutNamespacedPodProxyWithPath$Status$200 | Response$connectCoreV1PostNamespacedPodProxyWithPath$Status$200 | Response$connectCoreV1DeleteNamespacedPodProxyWithPath$Status$200 | Response$connectCoreV1OptionsNamespacedPodProxyWithPath$Status$200 | Response$connectCoreV1HeadNamespacedPodProxyWithPath$Status$200 | Response$connectCoreV1PatchNamespacedPodProxyWithPath$Status$200 | Response$readCoreV1NamespacedPodStatus$Status$200 | Response$replaceCoreV1NamespacedPodStatus$Status$200 | Response$replaceCoreV1NamespacedPodStatus$Status$201 | Response$patchCoreV1NamespacedPodStatus$Status$200 | Response$patchCoreV1NamespacedPodStatus$Status$201 | Response$listCoreV1NamespacedPodTemplate$Status$200 | Response$createCoreV1NamespacedPodTemplate$Status$200 | Response$createCoreV1NamespacedPodTemplate$Status$201 | Response$createCoreV1NamespacedPodTemplate$Status$202 | Response$deleteCoreV1CollectionNamespacedPodTemplate$Status$200 | Response$readCoreV1NamespacedPodTemplate$Status$200 | Response$replaceCoreV1NamespacedPodTemplate$Status$200 | Response$replaceCoreV1NamespacedPodTemplate$Status$201 | Response$deleteCoreV1NamespacedPodTemplate$Status$200 | Response$deleteCoreV1NamespacedPodTemplate$Status$202 | Response$patchCoreV1NamespacedPodTemplate$Status$200 | Response$patchCoreV1NamespacedPodTemplate$Status$201 | Response$listCoreV1NamespacedReplicationController$Status$200 | Response$createCoreV1NamespacedReplicationController$Status$200 | Response$createCoreV1NamespacedReplicationController$Status$201 | Response$createCoreV1NamespacedReplicationController$Status$202 | Response$deleteCoreV1CollectionNamespacedReplicationController$Status$200 | Response$readCoreV1NamespacedReplicationController$Status$200 | Response$replaceCoreV1NamespacedReplicationController$Status$200 | Response$replaceCoreV1NamespacedReplicationController$Status$201 | Response$deleteCoreV1NamespacedReplicationController$Status$200 | Response$deleteCoreV1NamespacedReplicationController$Status$202 | Response$patchCoreV1NamespacedReplicationController$Status$200 | Response$patchCoreV1NamespacedReplicationController$Status$201 | Response$readCoreV1NamespacedReplicationControllerScale$Status$200 | Response$replaceCoreV1NamespacedReplicationControllerScale$Status$200 | Response$replaceCoreV1NamespacedReplicationControllerScale$Status$201 | Response$patchCoreV1NamespacedReplicationControllerScale$Status$200 | Response$patchCoreV1NamespacedReplicationControllerScale$Status$201 | Response$readCoreV1NamespacedReplicationControllerStatus$Status$200 | Response$replaceCoreV1NamespacedReplicationControllerStatus$Status$200 | Response$replaceCoreV1NamespacedReplicationControllerStatus$Status$201 | Response$patchCoreV1NamespacedReplicationControllerStatus$Status$200 | Response$patchCoreV1NamespacedReplicationControllerStatus$Status$201 | Response$listCoreV1NamespacedResourceQuota$Status$200 | Response$createCoreV1NamespacedResourceQuota$Status$200 | Response$createCoreV1NamespacedResourceQuota$Status$201 | Response$createCoreV1NamespacedResourceQuota$Status$202 | Response$deleteCoreV1CollectionNamespacedResourceQuota$Status$200 | Response$readCoreV1NamespacedResourceQuota$Status$200 | Response$replaceCoreV1NamespacedResourceQuota$Status$200 | Response$replaceCoreV1NamespacedResourceQuota$Status$201 | Response$deleteCoreV1NamespacedResourceQuota$Status$200 | Response$deleteCoreV1NamespacedResourceQuota$Status$202 | Response$patchCoreV1NamespacedResourceQuota$Status$200 | Response$patchCoreV1NamespacedResourceQuota$Status$201 | Response$readCoreV1NamespacedResourceQuotaStatus$Status$200 | Response$replaceCoreV1NamespacedResourceQuotaStatus$Status$200 | Response$replaceCoreV1NamespacedResourceQuotaStatus$Status$201 | Response$patchCoreV1NamespacedResourceQuotaStatus$Status$200 | Response$patchCoreV1NamespacedResourceQuotaStatus$Status$201 | Response$listCoreV1NamespacedSecret$Status$200 | Response$createCoreV1NamespacedSecret$Status$200 | Response$createCoreV1NamespacedSecret$Status$201 | Response$createCoreV1NamespacedSecret$Status$202 | Response$deleteCoreV1CollectionNamespacedSecret$Status$200 | Response$readCoreV1NamespacedSecret$Status$200 | Response$replaceCoreV1NamespacedSecret$Status$200 | Response$replaceCoreV1NamespacedSecret$Status$201 | Response$deleteCoreV1NamespacedSecret$Status$200 | Response$deleteCoreV1NamespacedSecret$Status$202 | Response$patchCoreV1NamespacedSecret$Status$200 | Response$patchCoreV1NamespacedSecret$Status$201 | Response$listCoreV1NamespacedServiceAccount$Status$200 | Response$createCoreV1NamespacedServiceAccount$Status$200 | Response$createCoreV1NamespacedServiceAccount$Status$201 | Response$createCoreV1NamespacedServiceAccount$Status$202 | Response$deleteCoreV1CollectionNamespacedServiceAccount$Status$200 | Response$readCoreV1NamespacedServiceAccount$Status$200 | Response$replaceCoreV1NamespacedServiceAccount$Status$200 | Response$replaceCoreV1NamespacedServiceAccount$Status$201 | Response$deleteCoreV1NamespacedServiceAccount$Status$200 | Response$deleteCoreV1NamespacedServiceAccount$Status$202 | Response$patchCoreV1NamespacedServiceAccount$Status$200 | Response$patchCoreV1NamespacedServiceAccount$Status$201 | Response$createCoreV1NamespacedServiceAccountToken$Status$200 | Response$createCoreV1NamespacedServiceAccountToken$Status$201 | Response$createCoreV1NamespacedServiceAccountToken$Status$202 | Response$listCoreV1NamespacedService$Status$200 | Response$createCoreV1NamespacedService$Status$200 | Response$createCoreV1NamespacedService$Status$201 | Response$createCoreV1NamespacedService$Status$202 | Response$deleteCoreV1CollectionNamespacedService$Status$200 | Response$readCoreV1NamespacedService$Status$200 | Response$replaceCoreV1NamespacedService$Status$200 | Response$replaceCoreV1NamespacedService$Status$201 | Response$deleteCoreV1NamespacedService$Status$200 | Response$deleteCoreV1NamespacedService$Status$202 | Response$patchCoreV1NamespacedService$Status$200 | Response$patchCoreV1NamespacedService$Status$201 | Response$connectCoreV1GetNamespacedServiceProxy$Status$200 | Response$connectCoreV1PutNamespacedServiceProxy$Status$200 | Response$connectCoreV1PostNamespacedServiceProxy$Status$200 | Response$connectCoreV1DeleteNamespacedServiceProxy$Status$200 | Response$connectCoreV1OptionsNamespacedServiceProxy$Status$200 | Response$connectCoreV1HeadNamespacedServiceProxy$Status$200 | Response$connectCoreV1PatchNamespacedServiceProxy$Status$200 | Response$connectCoreV1GetNamespacedServiceProxyWithPath$Status$200 | Response$connectCoreV1PutNamespacedServiceProxyWithPath$Status$200 | Response$connectCoreV1PostNamespacedServiceProxyWithPath$Status$200 | Response$connectCoreV1DeleteNamespacedServiceProxyWithPath$Status$200 | Response$connectCoreV1OptionsNamespacedServiceProxyWithPath$Status$200 | Response$connectCoreV1HeadNamespacedServiceProxyWithPath$Status$200 | Response$connectCoreV1PatchNamespacedServiceProxyWithPath$Status$200 | Response$readCoreV1NamespacedServiceStatus$Status$200 | Response$replaceCoreV1NamespacedServiceStatus$Status$200 | Response$replaceCoreV1NamespacedServiceStatus$Status$201 | Response$patchCoreV1NamespacedServiceStatus$Status$200 | Response$patchCoreV1NamespacedServiceStatus$Status$201 | Response$readCoreV1Namespace$Status$200 | Response$replaceCoreV1Namespace$Status$200 | Response$replaceCoreV1Namespace$Status$201 | Response$deleteCoreV1Namespace$Status$200 | Response$deleteCoreV1Namespace$Status$202 | Response$patchCoreV1Namespace$Status$200 | Response$patchCoreV1Namespace$Status$201 | Response$replaceCoreV1NamespaceFinalize$Status$200 | Response$replaceCoreV1NamespaceFinalize$Status$201 | Response$readCoreV1NamespaceStatus$Status$200 | Response$replaceCoreV1NamespaceStatus$Status$200 | Response$replaceCoreV1NamespaceStatus$Status$201 | Response$patchCoreV1NamespaceStatus$Status$200 | Response$patchCoreV1NamespaceStatus$Status$201 | Response$listCoreV1Node$Status$200 | Response$createCoreV1Node$Status$200 | Response$createCoreV1Node$Status$201 | Response$createCoreV1Node$Status$202 | Response$deleteCoreV1CollectionNode$Status$200 | Response$readCoreV1Node$Status$200 | Response$replaceCoreV1Node$Status$200 | Response$replaceCoreV1Node$Status$201 | Response$deleteCoreV1Node$Status$200 | Response$deleteCoreV1Node$Status$202 | Response$patchCoreV1Node$Status$200 | Response$patchCoreV1Node$Status$201 | Response$connectCoreV1GetNodeProxy$Status$200 | Response$connectCoreV1PutNodeProxy$Status$200 | Response$connectCoreV1PostNodeProxy$Status$200 | Response$connectCoreV1DeleteNodeProxy$Status$200 | Response$connectCoreV1OptionsNodeProxy$Status$200 | Response$connectCoreV1HeadNodeProxy$Status$200 | Response$connectCoreV1PatchNodeProxy$Status$200 | Response$connectCoreV1GetNodeProxyWithPath$Status$200 | Response$connectCoreV1PutNodeProxyWithPath$Status$200 | Response$connectCoreV1PostNodeProxyWithPath$Status$200 | Response$connectCoreV1DeleteNodeProxyWithPath$Status$200 | Response$connectCoreV1OptionsNodeProxyWithPath$Status$200 | Response$connectCoreV1HeadNodeProxyWithPath$Status$200 | Response$connectCoreV1PatchNodeProxyWithPath$Status$200 | Response$readCoreV1NodeStatus$Status$200 | Response$replaceCoreV1NodeStatus$Status$200 | Response$replaceCoreV1NodeStatus$Status$201 | Response$patchCoreV1NodeStatus$Status$200 | Response$patchCoreV1NodeStatus$Status$201 | Response$listCoreV1PersistentVolumeClaimForAllNamespaces$Status$200 | Response$listCoreV1PersistentVolume$Status$200 | Response$createCoreV1PersistentVolume$Status$200 | Response$createCoreV1PersistentVolume$Status$201 | Response$createCoreV1PersistentVolume$Status$202 | Response$deleteCoreV1CollectionPersistentVolume$Status$200 | Response$readCoreV1PersistentVolume$Status$200 | Response$replaceCoreV1PersistentVolume$Status$200 | Response$replaceCoreV1PersistentVolume$Status$201 | Response$deleteCoreV1PersistentVolume$Status$200 | Response$deleteCoreV1PersistentVolume$Status$202 | Response$patchCoreV1PersistentVolume$Status$200 | Response$patchCoreV1PersistentVolume$Status$201 | Response$readCoreV1PersistentVolumeStatus$Status$200 | Response$replaceCoreV1PersistentVolumeStatus$Status$200 | Response$replaceCoreV1PersistentVolumeStatus$Status$201 | Response$patchCoreV1PersistentVolumeStatus$Status$200 | Response$patchCoreV1PersistentVolumeStatus$Status$201 | Response$listCoreV1PodForAllNamespaces$Status$200 | Response$listCoreV1PodTemplateForAllNamespaces$Status$200 | Response$listCoreV1ReplicationControllerForAllNamespaces$Status$200 | Response$listCoreV1ResourceQuotaForAllNamespaces$Status$200 | Response$listCoreV1SecretForAllNamespaces$Status$200 | Response$listCoreV1ServiceAccountForAllNamespaces$Status$200 | Response$listCoreV1ServiceForAllNamespaces$Status$200 | Response$watchCoreV1ConfigMapListForAllNamespaces$Status$200 | Response$watchCoreV1EndpointsListForAllNamespaces$Status$200 | Response$watchCoreV1EventListForAllNamespaces$Status$200 | Response$watchCoreV1LimitRangeListForAllNamespaces$Status$200 | Response$watchCoreV1NamespaceList$Status$200 | Response$watchCoreV1NamespacedConfigMapList$Status$200 | Response$watchCoreV1NamespacedConfigMap$Status$200 | Response$watchCoreV1NamespacedEndpointsList$Status$200 | Response$watchCoreV1NamespacedEndpoints$Status$200 | Response$watchCoreV1NamespacedEventList$Status$200 | Response$watchCoreV1NamespacedEvent$Status$200 | Response$watchCoreV1NamespacedLimitRangeList$Status$200 | Response$watchCoreV1NamespacedLimitRange$Status$200 | Response$watchCoreV1NamespacedPersistentVolumeClaimList$Status$200 | Response$watchCoreV1NamespacedPersistentVolumeClaim$Status$200 | Response$watchCoreV1NamespacedPodList$Status$200 | Response$watchCoreV1NamespacedPod$Status$200 | Response$watchCoreV1NamespacedPodTemplateList$Status$200 | Response$watchCoreV1NamespacedPodTemplate$Status$200 | Response$watchCoreV1NamespacedReplicationControllerList$Status$200 | Response$watchCoreV1NamespacedReplicationController$Status$200 | Response$watchCoreV1NamespacedResourceQuotaList$Status$200 | Response$watchCoreV1NamespacedResourceQuota$Status$200 | Response$watchCoreV1NamespacedSecretList$Status$200 | Response$watchCoreV1NamespacedSecret$Status$200 | Response$watchCoreV1NamespacedServiceAccountList$Status$200 | Response$watchCoreV1NamespacedServiceAccount$Status$200 | Response$watchCoreV1NamespacedServiceList$Status$200 | Response$watchCoreV1NamespacedService$Status$200 | Response$watchCoreV1Namespace$Status$200 | Response$watchCoreV1NodeList$Status$200 | Response$watchCoreV1Node$Status$200 | Response$watchCoreV1PersistentVolumeClaimListForAllNamespaces$Status$200 | Response$watchCoreV1PersistentVolumeList$Status$200 | Response$watchCoreV1PersistentVolume$Status$200 | Response$watchCoreV1PodListForAllNamespaces$Status$200 | Response$watchCoreV1PodTemplateListForAllNamespaces$Status$200 | Response$watchCoreV1ReplicationControllerListForAllNamespaces$Status$200 | Response$watchCoreV1ResourceQuotaListForAllNamespaces$Status$200 | Response$watchCoreV1SecretListForAllNamespaces$Status$200 | Response$watchCoreV1ServiceAccountListForAllNamespaces$Status$200 | Response$watchCoreV1ServiceListForAllNamespaces$Status$200 | Response$getAPIVersions$Status$200 | Response$getAdmissionregistrationAPIGroup$Status$200 | Response$getAdmissionregistrationV1APIResources$Status$200 | Response$listAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$201 | Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$202 | Response$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration$Status$200 | Response$readAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | Response$replaceAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | Response$replaceAdmissionregistrationV1MutatingWebhookConfiguration$Status$201 | Response$deleteAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | Response$deleteAdmissionregistrationV1MutatingWebhookConfiguration$Status$202 | Response$patchAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | Response$patchAdmissionregistrationV1MutatingWebhookConfiguration$Status$201 | Response$listAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201 | Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$202 | Response$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration$Status$200 | Response$readAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | Response$replaceAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | Response$replaceAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201 | Response$deleteAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | Response$deleteAdmissionregistrationV1ValidatingWebhookConfiguration$Status$202 | Response$patchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | Response$patchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201 | Response$watchAdmissionregistrationV1MutatingWebhookConfigurationList$Status$200 | Response$watchAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | Response$watchAdmissionregistrationV1ValidatingWebhookConfigurationList$Status$200 | Response$watchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | Response$getApiextensionsAPIGroup$Status$200 | Response$getApiextensionsV1APIResources$Status$200 | Response$listApiextensionsV1CustomResourceDefinition$Status$200 | Response$createApiextensionsV1CustomResourceDefinition$Status$200 | Response$createApiextensionsV1CustomResourceDefinition$Status$201 | Response$createApiextensionsV1CustomResourceDefinition$Status$202 | Response$deleteApiextensionsV1CollectionCustomResourceDefinition$Status$200 | Response$readApiextensionsV1CustomResourceDefinition$Status$200 | Response$replaceApiextensionsV1CustomResourceDefinition$Status$200 | Response$replaceApiextensionsV1CustomResourceDefinition$Status$201 | Response$deleteApiextensionsV1CustomResourceDefinition$Status$200 | Response$deleteApiextensionsV1CustomResourceDefinition$Status$202 | Response$patchApiextensionsV1CustomResourceDefinition$Status$200 | Response$patchApiextensionsV1CustomResourceDefinition$Status$201 | Response$readApiextensionsV1CustomResourceDefinitionStatus$Status$200 | Response$replaceApiextensionsV1CustomResourceDefinitionStatus$Status$200 | Response$replaceApiextensionsV1CustomResourceDefinitionStatus$Status$201 | Response$patchApiextensionsV1CustomResourceDefinitionStatus$Status$200 | Response$patchApiextensionsV1CustomResourceDefinitionStatus$Status$201 | Response$watchApiextensionsV1CustomResourceDefinitionList$Status$200 | Response$watchApiextensionsV1CustomResourceDefinition$Status$200 | Response$getApiregistrationAPIGroup$Status$200 | Response$getApiregistrationV1APIResources$Status$200 | Response$listApiregistrationV1APIService$Status$200 | Response$createApiregistrationV1APIService$Status$200 | Response$createApiregistrationV1APIService$Status$201 | Response$createApiregistrationV1APIService$Status$202 | Response$deleteApiregistrationV1CollectionAPIService$Status$200 | Response$readApiregistrationV1APIService$Status$200 | Response$replaceApiregistrationV1APIService$Status$200 | Response$replaceApiregistrationV1APIService$Status$201 | Response$deleteApiregistrationV1APIService$Status$200 | Response$deleteApiregistrationV1APIService$Status$202 | Response$patchApiregistrationV1APIService$Status$200 | Response$patchApiregistrationV1APIService$Status$201 | Response$readApiregistrationV1APIServiceStatus$Status$200 | Response$replaceApiregistrationV1APIServiceStatus$Status$200 | Response$replaceApiregistrationV1APIServiceStatus$Status$201 | Response$patchApiregistrationV1APIServiceStatus$Status$200 | Response$patchApiregistrationV1APIServiceStatus$Status$201 | Response$watchApiregistrationV1APIServiceList$Status$200 | Response$watchApiregistrationV1APIService$Status$200 | Response$getAppsAPIGroup$Status$200 | Response$getAppsV1APIResources$Status$200 | Response$listAppsV1ControllerRevisionForAllNamespaces$Status$200 | Response$listAppsV1DaemonSetForAllNamespaces$Status$200 | Response$listAppsV1DeploymentForAllNamespaces$Status$200 | Response$listAppsV1NamespacedControllerRevision$Status$200 | Response$createAppsV1NamespacedControllerRevision$Status$200 | Response$createAppsV1NamespacedControllerRevision$Status$201 | Response$createAppsV1NamespacedControllerRevision$Status$202 | Response$deleteAppsV1CollectionNamespacedControllerRevision$Status$200 | Response$readAppsV1NamespacedControllerRevision$Status$200 | Response$replaceAppsV1NamespacedControllerRevision$Status$200 | Response$replaceAppsV1NamespacedControllerRevision$Status$201 | Response$deleteAppsV1NamespacedControllerRevision$Status$200 | Response$deleteAppsV1NamespacedControllerRevision$Status$202 | Response$patchAppsV1NamespacedControllerRevision$Status$200 | Response$patchAppsV1NamespacedControllerRevision$Status$201 | Response$listAppsV1NamespacedDaemonSet$Status$200 | Response$createAppsV1NamespacedDaemonSet$Status$200 | Response$createAppsV1NamespacedDaemonSet$Status$201 | Response$createAppsV1NamespacedDaemonSet$Status$202 | Response$deleteAppsV1CollectionNamespacedDaemonSet$Status$200 | Response$readAppsV1NamespacedDaemonSet$Status$200 | Response$replaceAppsV1NamespacedDaemonSet$Status$200 | Response$replaceAppsV1NamespacedDaemonSet$Status$201 | Response$deleteAppsV1NamespacedDaemonSet$Status$200 | Response$deleteAppsV1NamespacedDaemonSet$Status$202 | Response$patchAppsV1NamespacedDaemonSet$Status$200 | Response$patchAppsV1NamespacedDaemonSet$Status$201 | Response$readAppsV1NamespacedDaemonSetStatus$Status$200 | Response$replaceAppsV1NamespacedDaemonSetStatus$Status$200 | Response$replaceAppsV1NamespacedDaemonSetStatus$Status$201 | Response$patchAppsV1NamespacedDaemonSetStatus$Status$200 | Response$patchAppsV1NamespacedDaemonSetStatus$Status$201 | Response$listAppsV1NamespacedDeployment$Status$200 | Response$createAppsV1NamespacedDeployment$Status$200 | Response$createAppsV1NamespacedDeployment$Status$201 | Response$createAppsV1NamespacedDeployment$Status$202 | Response$deleteAppsV1CollectionNamespacedDeployment$Status$200 | Response$readAppsV1NamespacedDeployment$Status$200 | Response$replaceAppsV1NamespacedDeployment$Status$200 | Response$replaceAppsV1NamespacedDeployment$Status$201 | Response$deleteAppsV1NamespacedDeployment$Status$200 | Response$deleteAppsV1NamespacedDeployment$Status$202 | Response$patchAppsV1NamespacedDeployment$Status$200 | Response$patchAppsV1NamespacedDeployment$Status$201 | Response$readAppsV1NamespacedDeploymentScale$Status$200 | Response$replaceAppsV1NamespacedDeploymentScale$Status$200 | Response$replaceAppsV1NamespacedDeploymentScale$Status$201 | Response$patchAppsV1NamespacedDeploymentScale$Status$200 | Response$patchAppsV1NamespacedDeploymentScale$Status$201 | Response$readAppsV1NamespacedDeploymentStatus$Status$200 | Response$replaceAppsV1NamespacedDeploymentStatus$Status$200 | Response$replaceAppsV1NamespacedDeploymentStatus$Status$201 | Response$patchAppsV1NamespacedDeploymentStatus$Status$200 | Response$patchAppsV1NamespacedDeploymentStatus$Status$201 | Response$listAppsV1NamespacedReplicaSet$Status$200 | Response$createAppsV1NamespacedReplicaSet$Status$200 | Response$createAppsV1NamespacedReplicaSet$Status$201 | Response$createAppsV1NamespacedReplicaSet$Status$202 | Response$deleteAppsV1CollectionNamespacedReplicaSet$Status$200 | Response$readAppsV1NamespacedReplicaSet$Status$200 | Response$replaceAppsV1NamespacedReplicaSet$Status$200 | Response$replaceAppsV1NamespacedReplicaSet$Status$201 | Response$deleteAppsV1NamespacedReplicaSet$Status$200 | Response$deleteAppsV1NamespacedReplicaSet$Status$202 | Response$patchAppsV1NamespacedReplicaSet$Status$200 | Response$patchAppsV1NamespacedReplicaSet$Status$201 | Response$readAppsV1NamespacedReplicaSetScale$Status$200 | Response$replaceAppsV1NamespacedReplicaSetScale$Status$200 | Response$replaceAppsV1NamespacedReplicaSetScale$Status$201 | Response$patchAppsV1NamespacedReplicaSetScale$Status$200 | Response$patchAppsV1NamespacedReplicaSetScale$Status$201 | Response$readAppsV1NamespacedReplicaSetStatus$Status$200 | Response$replaceAppsV1NamespacedReplicaSetStatus$Status$200 | Response$replaceAppsV1NamespacedReplicaSetStatus$Status$201 | Response$patchAppsV1NamespacedReplicaSetStatus$Status$200 | Response$patchAppsV1NamespacedReplicaSetStatus$Status$201 | Response$listAppsV1NamespacedStatefulSet$Status$200 | Response$createAppsV1NamespacedStatefulSet$Status$200 | Response$createAppsV1NamespacedStatefulSet$Status$201 | Response$createAppsV1NamespacedStatefulSet$Status$202 | Response$deleteAppsV1CollectionNamespacedStatefulSet$Status$200 | Response$readAppsV1NamespacedStatefulSet$Status$200 | Response$replaceAppsV1NamespacedStatefulSet$Status$200 | Response$replaceAppsV1NamespacedStatefulSet$Status$201 | Response$deleteAppsV1NamespacedStatefulSet$Status$200 | Response$deleteAppsV1NamespacedStatefulSet$Status$202 | Response$patchAppsV1NamespacedStatefulSet$Status$200 | Response$patchAppsV1NamespacedStatefulSet$Status$201 | Response$readAppsV1NamespacedStatefulSetScale$Status$200 | Response$replaceAppsV1NamespacedStatefulSetScale$Status$200 | Response$replaceAppsV1NamespacedStatefulSetScale$Status$201 | Response$patchAppsV1NamespacedStatefulSetScale$Status$200 | Response$patchAppsV1NamespacedStatefulSetScale$Status$201 | Response$readAppsV1NamespacedStatefulSetStatus$Status$200 | Response$replaceAppsV1NamespacedStatefulSetStatus$Status$200 | Response$replaceAppsV1NamespacedStatefulSetStatus$Status$201 | Response$patchAppsV1NamespacedStatefulSetStatus$Status$200 | Response$patchAppsV1NamespacedStatefulSetStatus$Status$201 | Response$listAppsV1ReplicaSetForAllNamespaces$Status$200 | Response$listAppsV1StatefulSetForAllNamespaces$Status$200 | Response$watchAppsV1ControllerRevisionListForAllNamespaces$Status$200 | Response$watchAppsV1DaemonSetListForAllNamespaces$Status$200 | Response$watchAppsV1DeploymentListForAllNamespaces$Status$200 | Response$watchAppsV1NamespacedControllerRevisionList$Status$200 | Response$watchAppsV1NamespacedControllerRevision$Status$200 | Response$watchAppsV1NamespacedDaemonSetList$Status$200 | Response$watchAppsV1NamespacedDaemonSet$Status$200 | Response$watchAppsV1NamespacedDeploymentList$Status$200 | Response$watchAppsV1NamespacedDeployment$Status$200 | Response$watchAppsV1NamespacedReplicaSetList$Status$200 | Response$watchAppsV1NamespacedReplicaSet$Status$200 | Response$watchAppsV1NamespacedStatefulSetList$Status$200 | Response$watchAppsV1NamespacedStatefulSet$Status$200 | Response$watchAppsV1ReplicaSetListForAllNamespaces$Status$200 | Response$watchAppsV1StatefulSetListForAllNamespaces$Status$200 | Response$getAuthenticationAPIGroup$Status$200 | Response$getAuthenticationV1APIResources$Status$200 | Response$createAuthenticationV1TokenReview$Status$200 | Response$createAuthenticationV1TokenReview$Status$201 | Response$createAuthenticationV1TokenReview$Status$202 | Response$getAuthorizationAPIGroup$Status$200 | Response$getAuthorizationV1APIResources$Status$200 | Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$200 | Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$201 | Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$202 | Response$createAuthorizationV1SelfSubjectAccessReview$Status$200 | Response$createAuthorizationV1SelfSubjectAccessReview$Status$201 | Response$createAuthorizationV1SelfSubjectAccessReview$Status$202 | Response$createAuthorizationV1SelfSubjectRulesReview$Status$200 | Response$createAuthorizationV1SelfSubjectRulesReview$Status$201 | Response$createAuthorizationV1SelfSubjectRulesReview$Status$202 | Response$createAuthorizationV1SubjectAccessReview$Status$200 | Response$createAuthorizationV1SubjectAccessReview$Status$201 | Response$createAuthorizationV1SubjectAccessReview$Status$202 | Response$getAutoscalingAPIGroup$Status$200 | Response$getAutoscalingV1APIResources$Status$200 | Response$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces$Status$200 | Response$listAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201 | Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$202 | Response$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler$Status$200 | Response$readAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201 | Response$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | Response$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$202 | Response$patchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | Response$patchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201 | Response$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$201 | Response$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$201 | Response$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces$Status$200 | Response$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList$Status$200 | Response$watchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | Response$getAutoscalingV2APIResources$Status$200 | Response$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces$Status$200 | Response$listAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201 | Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$202 | Response$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler$Status$200 | Response$readAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201 | Response$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | Response$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$202 | Response$patchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | Response$patchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201 | Response$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$201 | Response$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$201 | Response$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces$Status$200 | Response$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList$Status$200 | Response$watchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | Response$getAutoscalingV2beta1APIResources$Status$200 | Response$listAutoscalingV2beta1HorizontalPodAutoscalerForAllNamespaces$Status$200 | Response$listAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200 | Response$createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200 | Response$createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$201 | Response$createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$202 | Response$deleteAutoscalingV2beta1CollectionNamespacedHorizontalPodAutoscaler$Status$200 | Response$readAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200 | Response$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200 | Response$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$201 | Response$deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200 | Response$deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$202 | Response$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200 | Response$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$201 | Response$readAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus$Status$201 | Response$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus$Status$201 | Response$watchAutoscalingV2beta1HorizontalPodAutoscalerListForAllNamespaces$Status$200 | Response$watchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerList$Status$200 | Response$watchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200 | Response$getAutoscalingV2beta2APIResources$Status$200 | Response$listAutoscalingV2beta2HorizontalPodAutoscalerForAllNamespaces$Status$200 | Response$listAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200 | Response$createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200 | Response$createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$201 | Response$createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$202 | Response$deleteAutoscalingV2beta2CollectionNamespacedHorizontalPodAutoscaler$Status$200 | Response$readAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200 | Response$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200 | Response$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$201 | Response$deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200 | Response$deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$202 | Response$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200 | Response$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$201 | Response$readAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus$Status$201 | Response$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus$Status$201 | Response$watchAutoscalingV2beta2HorizontalPodAutoscalerListForAllNamespaces$Status$200 | Response$watchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerList$Status$200 | Response$watchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200 | Response$getBatchAPIGroup$Status$200 | Response$getBatchV1APIResources$Status$200 | Response$listBatchV1CronJobForAllNamespaces$Status$200 | Response$listBatchV1JobForAllNamespaces$Status$200 | Response$listBatchV1NamespacedCronJob$Status$200 | Response$createBatchV1NamespacedCronJob$Status$200 | Response$createBatchV1NamespacedCronJob$Status$201 | Response$createBatchV1NamespacedCronJob$Status$202 | Response$deleteBatchV1CollectionNamespacedCronJob$Status$200 | Response$readBatchV1NamespacedCronJob$Status$200 | Response$replaceBatchV1NamespacedCronJob$Status$200 | Response$replaceBatchV1NamespacedCronJob$Status$201 | Response$deleteBatchV1NamespacedCronJob$Status$200 | Response$deleteBatchV1NamespacedCronJob$Status$202 | Response$patchBatchV1NamespacedCronJob$Status$200 | Response$patchBatchV1NamespacedCronJob$Status$201 | Response$readBatchV1NamespacedCronJobStatus$Status$200 | Response$replaceBatchV1NamespacedCronJobStatus$Status$200 | Response$replaceBatchV1NamespacedCronJobStatus$Status$201 | Response$patchBatchV1NamespacedCronJobStatus$Status$200 | Response$patchBatchV1NamespacedCronJobStatus$Status$201 | Response$listBatchV1NamespacedJob$Status$200 | Response$createBatchV1NamespacedJob$Status$200 | Response$createBatchV1NamespacedJob$Status$201 | Response$createBatchV1NamespacedJob$Status$202 | Response$deleteBatchV1CollectionNamespacedJob$Status$200 | Response$readBatchV1NamespacedJob$Status$200 | Response$replaceBatchV1NamespacedJob$Status$200 | Response$replaceBatchV1NamespacedJob$Status$201 | Response$deleteBatchV1NamespacedJob$Status$200 | Response$deleteBatchV1NamespacedJob$Status$202 | Response$patchBatchV1NamespacedJob$Status$200 | Response$patchBatchV1NamespacedJob$Status$201 | Response$readBatchV1NamespacedJobStatus$Status$200 | Response$replaceBatchV1NamespacedJobStatus$Status$200 | Response$replaceBatchV1NamespacedJobStatus$Status$201 | Response$patchBatchV1NamespacedJobStatus$Status$200 | Response$patchBatchV1NamespacedJobStatus$Status$201 | Response$watchBatchV1CronJobListForAllNamespaces$Status$200 | Response$watchBatchV1JobListForAllNamespaces$Status$200 | Response$watchBatchV1NamespacedCronJobList$Status$200 | Response$watchBatchV1NamespacedCronJob$Status$200 | Response$watchBatchV1NamespacedJobList$Status$200 | Response$watchBatchV1NamespacedJob$Status$200 | Response$getBatchV1beta1APIResources$Status$200 | Response$listBatchV1beta1CronJobForAllNamespaces$Status$200 | Response$listBatchV1beta1NamespacedCronJob$Status$200 | Response$createBatchV1beta1NamespacedCronJob$Status$200 | Response$createBatchV1beta1NamespacedCronJob$Status$201 | Response$createBatchV1beta1NamespacedCronJob$Status$202 | Response$deleteBatchV1beta1CollectionNamespacedCronJob$Status$200 | Response$readBatchV1beta1NamespacedCronJob$Status$200 | Response$replaceBatchV1beta1NamespacedCronJob$Status$200 | Response$replaceBatchV1beta1NamespacedCronJob$Status$201 | Response$deleteBatchV1beta1NamespacedCronJob$Status$200 | Response$deleteBatchV1beta1NamespacedCronJob$Status$202 | Response$patchBatchV1beta1NamespacedCronJob$Status$200 | Response$patchBatchV1beta1NamespacedCronJob$Status$201 | Response$readBatchV1beta1NamespacedCronJobStatus$Status$200 | Response$replaceBatchV1beta1NamespacedCronJobStatus$Status$200 | Response$replaceBatchV1beta1NamespacedCronJobStatus$Status$201 | Response$patchBatchV1beta1NamespacedCronJobStatus$Status$200 | Response$patchBatchV1beta1NamespacedCronJobStatus$Status$201 | Response$watchBatchV1beta1CronJobListForAllNamespaces$Status$200 | Response$watchBatchV1beta1NamespacedCronJobList$Status$200 | Response$watchBatchV1beta1NamespacedCronJob$Status$200 | Response$getCertificatesAPIGroup$Status$200 | Response$getCertificatesV1APIResources$Status$200 | Response$listCertificatesV1CertificateSigningRequest$Status$200 | Response$createCertificatesV1CertificateSigningRequest$Status$200 | Response$createCertificatesV1CertificateSigningRequest$Status$201 | Response$createCertificatesV1CertificateSigningRequest$Status$202 | Response$deleteCertificatesV1CollectionCertificateSigningRequest$Status$200 | Response$readCertificatesV1CertificateSigningRequest$Status$200 | Response$replaceCertificatesV1CertificateSigningRequest$Status$200 | Response$replaceCertificatesV1CertificateSigningRequest$Status$201 | Response$deleteCertificatesV1CertificateSigningRequest$Status$200 | Response$deleteCertificatesV1CertificateSigningRequest$Status$202 | Response$patchCertificatesV1CertificateSigningRequest$Status$200 | Response$patchCertificatesV1CertificateSigningRequest$Status$201 | Response$readCertificatesV1CertificateSigningRequestApproval$Status$200 | Response$replaceCertificatesV1CertificateSigningRequestApproval$Status$200 | Response$replaceCertificatesV1CertificateSigningRequestApproval$Status$201 | Response$patchCertificatesV1CertificateSigningRequestApproval$Status$200 | Response$patchCertificatesV1CertificateSigningRequestApproval$Status$201 | Response$readCertificatesV1CertificateSigningRequestStatus$Status$200 | Response$replaceCertificatesV1CertificateSigningRequestStatus$Status$200 | Response$replaceCertificatesV1CertificateSigningRequestStatus$Status$201 | Response$patchCertificatesV1CertificateSigningRequestStatus$Status$200 | Response$patchCertificatesV1CertificateSigningRequestStatus$Status$201 | Response$watchCertificatesV1CertificateSigningRequestList$Status$200 | Response$watchCertificatesV1CertificateSigningRequest$Status$200 | Response$getCoordinationAPIGroup$Status$200 | Response$getCoordinationV1APIResources$Status$200 | Response$listCoordinationV1LeaseForAllNamespaces$Status$200 | Response$listCoordinationV1NamespacedLease$Status$200 | Response$createCoordinationV1NamespacedLease$Status$200 | Response$createCoordinationV1NamespacedLease$Status$201 | Response$createCoordinationV1NamespacedLease$Status$202 | Response$deleteCoordinationV1CollectionNamespacedLease$Status$200 | Response$readCoordinationV1NamespacedLease$Status$200 | Response$replaceCoordinationV1NamespacedLease$Status$200 | Response$replaceCoordinationV1NamespacedLease$Status$201 | Response$deleteCoordinationV1NamespacedLease$Status$200 | Response$deleteCoordinationV1NamespacedLease$Status$202 | Response$patchCoordinationV1NamespacedLease$Status$200 | Response$patchCoordinationV1NamespacedLease$Status$201 | Response$watchCoordinationV1LeaseListForAllNamespaces$Status$200 | Response$watchCoordinationV1NamespacedLeaseList$Status$200 | Response$watchCoordinationV1NamespacedLease$Status$200 | Response$getDiscoveryAPIGroup$Status$200 | Response$getDiscoveryV1APIResources$Status$200 | Response$listDiscoveryV1EndpointSliceForAllNamespaces$Status$200 | Response$listDiscoveryV1NamespacedEndpointSlice$Status$200 | Response$createDiscoveryV1NamespacedEndpointSlice$Status$200 | Response$createDiscoveryV1NamespacedEndpointSlice$Status$201 | Response$createDiscoveryV1NamespacedEndpointSlice$Status$202 | Response$deleteDiscoveryV1CollectionNamespacedEndpointSlice$Status$200 | Response$readDiscoveryV1NamespacedEndpointSlice$Status$200 | Response$replaceDiscoveryV1NamespacedEndpointSlice$Status$200 | Response$replaceDiscoveryV1NamespacedEndpointSlice$Status$201 | Response$deleteDiscoveryV1NamespacedEndpointSlice$Status$200 | Response$deleteDiscoveryV1NamespacedEndpointSlice$Status$202 | Response$patchDiscoveryV1NamespacedEndpointSlice$Status$200 | Response$patchDiscoveryV1NamespacedEndpointSlice$Status$201 | Response$watchDiscoveryV1EndpointSliceListForAllNamespaces$Status$200 | Response$watchDiscoveryV1NamespacedEndpointSliceList$Status$200 | Response$watchDiscoveryV1NamespacedEndpointSlice$Status$200 | Response$getDiscoveryV1beta1APIResources$Status$200 | Response$listDiscoveryV1beta1EndpointSliceForAllNamespaces$Status$200 | Response$listDiscoveryV1beta1NamespacedEndpointSlice$Status$200 | Response$createDiscoveryV1beta1NamespacedEndpointSlice$Status$200 | Response$createDiscoveryV1beta1NamespacedEndpointSlice$Status$201 | Response$createDiscoveryV1beta1NamespacedEndpointSlice$Status$202 | Response$deleteDiscoveryV1beta1CollectionNamespacedEndpointSlice$Status$200 | Response$readDiscoveryV1beta1NamespacedEndpointSlice$Status$200 | Response$replaceDiscoveryV1beta1NamespacedEndpointSlice$Status$200 | Response$replaceDiscoveryV1beta1NamespacedEndpointSlice$Status$201 | Response$deleteDiscoveryV1beta1NamespacedEndpointSlice$Status$200 | Response$deleteDiscoveryV1beta1NamespacedEndpointSlice$Status$202 | Response$patchDiscoveryV1beta1NamespacedEndpointSlice$Status$200 | Response$patchDiscoveryV1beta1NamespacedEndpointSlice$Status$201 | Response$watchDiscoveryV1beta1EndpointSliceListForAllNamespaces$Status$200 | Response$watchDiscoveryV1beta1NamespacedEndpointSliceList$Status$200 | Response$watchDiscoveryV1beta1NamespacedEndpointSlice$Status$200 | Response$getEventsAPIGroup$Status$200 | Response$getEventsV1APIResources$Status$200 | Response$listEventsV1EventForAllNamespaces$Status$200 | Response$listEventsV1NamespacedEvent$Status$200 | Response$createEventsV1NamespacedEvent$Status$200 | Response$createEventsV1NamespacedEvent$Status$201 | Response$createEventsV1NamespacedEvent$Status$202 | Response$deleteEventsV1CollectionNamespacedEvent$Status$200 | Response$readEventsV1NamespacedEvent$Status$200 | Response$replaceEventsV1NamespacedEvent$Status$200 | Response$replaceEventsV1NamespacedEvent$Status$201 | Response$deleteEventsV1NamespacedEvent$Status$200 | Response$deleteEventsV1NamespacedEvent$Status$202 | Response$patchEventsV1NamespacedEvent$Status$200 | Response$patchEventsV1NamespacedEvent$Status$201 | Response$watchEventsV1EventListForAllNamespaces$Status$200 | Response$watchEventsV1NamespacedEventList$Status$200 | Response$watchEventsV1NamespacedEvent$Status$200 | Response$getEventsV1beta1APIResources$Status$200 | Response$listEventsV1beta1EventForAllNamespaces$Status$200 | Response$listEventsV1beta1NamespacedEvent$Status$200 | Response$createEventsV1beta1NamespacedEvent$Status$200 | Response$createEventsV1beta1NamespacedEvent$Status$201 | Response$createEventsV1beta1NamespacedEvent$Status$202 | Response$deleteEventsV1beta1CollectionNamespacedEvent$Status$200 | Response$readEventsV1beta1NamespacedEvent$Status$200 | Response$replaceEventsV1beta1NamespacedEvent$Status$200 | Response$replaceEventsV1beta1NamespacedEvent$Status$201 | Response$deleteEventsV1beta1NamespacedEvent$Status$200 | Response$deleteEventsV1beta1NamespacedEvent$Status$202 | Response$patchEventsV1beta1NamespacedEvent$Status$200 | Response$patchEventsV1beta1NamespacedEvent$Status$201 | Response$watchEventsV1beta1EventListForAllNamespaces$Status$200 | Response$watchEventsV1beta1NamespacedEventList$Status$200 | Response$watchEventsV1beta1NamespacedEvent$Status$200 | Response$getFlowcontrolApiserverAPIGroup$Status$200 | Response$getFlowcontrolApiserverV1beta1APIResources$Status$200 | Response$listFlowcontrolApiserverV1beta1FlowSchema$Status$200 | Response$createFlowcontrolApiserverV1beta1FlowSchema$Status$200 | Response$createFlowcontrolApiserverV1beta1FlowSchema$Status$201 | Response$createFlowcontrolApiserverV1beta1FlowSchema$Status$202 | Response$deleteFlowcontrolApiserverV1beta1CollectionFlowSchema$Status$200 | Response$readFlowcontrolApiserverV1beta1FlowSchema$Status$200 | Response$replaceFlowcontrolApiserverV1beta1FlowSchema$Status$200 | Response$replaceFlowcontrolApiserverV1beta1FlowSchema$Status$201 | Response$deleteFlowcontrolApiserverV1beta1FlowSchema$Status$200 | Response$deleteFlowcontrolApiserverV1beta1FlowSchema$Status$202 | Response$patchFlowcontrolApiserverV1beta1FlowSchema$Status$200 | Response$patchFlowcontrolApiserverV1beta1FlowSchema$Status$201 | Response$readFlowcontrolApiserverV1beta1FlowSchemaStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta1FlowSchemaStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta1FlowSchemaStatus$Status$201 | Response$patchFlowcontrolApiserverV1beta1FlowSchemaStatus$Status$200 | Response$patchFlowcontrolApiserverV1beta1FlowSchemaStatus$Status$201 | Response$listFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200 | Response$createFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200 | Response$createFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$201 | Response$createFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$202 | Response$deleteFlowcontrolApiserverV1beta1CollectionPriorityLevelConfiguration$Status$200 | Response$readFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200 | Response$replaceFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200 | Response$replaceFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$201 | Response$deleteFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200 | Response$deleteFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$202 | Response$patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200 | Response$patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$201 | Response$readFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus$Status$201 | Response$patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus$Status$200 | Response$patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus$Status$201 | Response$watchFlowcontrolApiserverV1beta1FlowSchemaList$Status$200 | Response$watchFlowcontrolApiserverV1beta1FlowSchema$Status$200 | Response$watchFlowcontrolApiserverV1beta1PriorityLevelConfigurationList$Status$200 | Response$watchFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200 | Response$getFlowcontrolApiserverV1beta2APIResources$Status$200 | Response$listFlowcontrolApiserverV1beta2FlowSchema$Status$200 | Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$200 | Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$201 | Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$202 | Response$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema$Status$200 | Response$readFlowcontrolApiserverV1beta2FlowSchema$Status$200 | Response$replaceFlowcontrolApiserverV1beta2FlowSchema$Status$200 | Response$replaceFlowcontrolApiserverV1beta2FlowSchema$Status$201 | Response$deleteFlowcontrolApiserverV1beta2FlowSchema$Status$200 | Response$deleteFlowcontrolApiserverV1beta2FlowSchema$Status$202 | Response$patchFlowcontrolApiserverV1beta2FlowSchema$Status$200 | Response$patchFlowcontrolApiserverV1beta2FlowSchema$Status$201 | Response$readFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$201 | Response$patchFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200 | Response$patchFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$201 | Response$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201 | Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$202 | Response$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration$Status$200 | Response$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201 | Response$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | Response$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$202 | Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201 | Response$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$201 | Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200 | Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$201 | Response$watchFlowcontrolApiserverV1beta2FlowSchemaList$Status$200 | Response$watchFlowcontrolApiserverV1beta2FlowSchema$Status$200 | Response$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList$Status$200 | Response$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | Response$getInternalApiserverAPIGroup$Status$200 | Response$getInternalApiserverV1alpha1APIResources$Status$200 | Response$listInternalApiserverV1alpha1StorageVersion$Status$200 | Response$createInternalApiserverV1alpha1StorageVersion$Status$200 | Response$createInternalApiserverV1alpha1StorageVersion$Status$201 | Response$createInternalApiserverV1alpha1StorageVersion$Status$202 | Response$deleteInternalApiserverV1alpha1CollectionStorageVersion$Status$200 | Response$readInternalApiserverV1alpha1StorageVersion$Status$200 | Response$replaceInternalApiserverV1alpha1StorageVersion$Status$200 | Response$replaceInternalApiserverV1alpha1StorageVersion$Status$201 | Response$deleteInternalApiserverV1alpha1StorageVersion$Status$200 | Response$deleteInternalApiserverV1alpha1StorageVersion$Status$202 | Response$patchInternalApiserverV1alpha1StorageVersion$Status$200 | Response$patchInternalApiserverV1alpha1StorageVersion$Status$201 | Response$readInternalApiserverV1alpha1StorageVersionStatus$Status$200 | Response$replaceInternalApiserverV1alpha1StorageVersionStatus$Status$200 | Response$replaceInternalApiserverV1alpha1StorageVersionStatus$Status$201 | Response$patchInternalApiserverV1alpha1StorageVersionStatus$Status$200 | Response$patchInternalApiserverV1alpha1StorageVersionStatus$Status$201 | Response$watchInternalApiserverV1alpha1StorageVersionList$Status$200 | Response$watchInternalApiserverV1alpha1StorageVersion$Status$200 | Response$getNetworkingAPIGroup$Status$200 | Response$getNetworkingV1APIResources$Status$200 | Response$listNetworkingV1IngressClass$Status$200 | Response$createNetworkingV1IngressClass$Status$200 | Response$createNetworkingV1IngressClass$Status$201 | Response$createNetworkingV1IngressClass$Status$202 | Response$deleteNetworkingV1CollectionIngressClass$Status$200 | Response$readNetworkingV1IngressClass$Status$200 | Response$replaceNetworkingV1IngressClass$Status$200 | Response$replaceNetworkingV1IngressClass$Status$201 | Response$deleteNetworkingV1IngressClass$Status$200 | Response$deleteNetworkingV1IngressClass$Status$202 | Response$patchNetworkingV1IngressClass$Status$200 | Response$patchNetworkingV1IngressClass$Status$201 | Response$listNetworkingV1IngressForAllNamespaces$Status$200 | Response$listNetworkingV1NamespacedIngress$Status$200 | Response$createNetworkingV1NamespacedIngress$Status$200 | Response$createNetworkingV1NamespacedIngress$Status$201 | Response$createNetworkingV1NamespacedIngress$Status$202 | Response$deleteNetworkingV1CollectionNamespacedIngress$Status$200 | Response$readNetworkingV1NamespacedIngress$Status$200 | Response$replaceNetworkingV1NamespacedIngress$Status$200 | Response$replaceNetworkingV1NamespacedIngress$Status$201 | Response$deleteNetworkingV1NamespacedIngress$Status$200 | Response$deleteNetworkingV1NamespacedIngress$Status$202 | Response$patchNetworkingV1NamespacedIngress$Status$200 | Response$patchNetworkingV1NamespacedIngress$Status$201 | Response$readNetworkingV1NamespacedIngressStatus$Status$200 | Response$replaceNetworkingV1NamespacedIngressStatus$Status$200 | Response$replaceNetworkingV1NamespacedIngressStatus$Status$201 | Response$patchNetworkingV1NamespacedIngressStatus$Status$200 | Response$patchNetworkingV1NamespacedIngressStatus$Status$201 | Response$listNetworkingV1NamespacedNetworkPolicy$Status$200 | Response$createNetworkingV1NamespacedNetworkPolicy$Status$200 | Response$createNetworkingV1NamespacedNetworkPolicy$Status$201 | Response$createNetworkingV1NamespacedNetworkPolicy$Status$202 | Response$deleteNetworkingV1CollectionNamespacedNetworkPolicy$Status$200 | Response$readNetworkingV1NamespacedNetworkPolicy$Status$200 | Response$replaceNetworkingV1NamespacedNetworkPolicy$Status$200 | Response$replaceNetworkingV1NamespacedNetworkPolicy$Status$201 | Response$deleteNetworkingV1NamespacedNetworkPolicy$Status$200 | Response$deleteNetworkingV1NamespacedNetworkPolicy$Status$202 | Response$patchNetworkingV1NamespacedNetworkPolicy$Status$200 | Response$patchNetworkingV1NamespacedNetworkPolicy$Status$201 | Response$listNetworkingV1NetworkPolicyForAllNamespaces$Status$200 | Response$watchNetworkingV1IngressClassList$Status$200 | Response$watchNetworkingV1IngressClass$Status$200 | Response$watchNetworkingV1IngressListForAllNamespaces$Status$200 | Response$watchNetworkingV1NamespacedIngressList$Status$200 | Response$watchNetworkingV1NamespacedIngress$Status$200 | Response$watchNetworkingV1NamespacedNetworkPolicyList$Status$200 | Response$watchNetworkingV1NamespacedNetworkPolicy$Status$200 | Response$watchNetworkingV1NetworkPolicyListForAllNamespaces$Status$200 | Response$getNodeAPIGroup$Status$200 | Response$getNodeV1APIResources$Status$200 | Response$listNodeV1RuntimeClass$Status$200 | Response$createNodeV1RuntimeClass$Status$200 | Response$createNodeV1RuntimeClass$Status$201 | Response$createNodeV1RuntimeClass$Status$202 | Response$deleteNodeV1CollectionRuntimeClass$Status$200 | Response$readNodeV1RuntimeClass$Status$200 | Response$replaceNodeV1RuntimeClass$Status$200 | Response$replaceNodeV1RuntimeClass$Status$201 | Response$deleteNodeV1RuntimeClass$Status$200 | Response$deleteNodeV1RuntimeClass$Status$202 | Response$patchNodeV1RuntimeClass$Status$200 | Response$patchNodeV1RuntimeClass$Status$201 | Response$watchNodeV1RuntimeClassList$Status$200 | Response$watchNodeV1RuntimeClass$Status$200 | Response$getNodeV1alpha1APIResources$Status$200 | Response$listNodeV1alpha1RuntimeClass$Status$200 | Response$createNodeV1alpha1RuntimeClass$Status$200 | Response$createNodeV1alpha1RuntimeClass$Status$201 | Response$createNodeV1alpha1RuntimeClass$Status$202 | Response$deleteNodeV1alpha1CollectionRuntimeClass$Status$200 | Response$readNodeV1alpha1RuntimeClass$Status$200 | Response$replaceNodeV1alpha1RuntimeClass$Status$200 | Response$replaceNodeV1alpha1RuntimeClass$Status$201 | Response$deleteNodeV1alpha1RuntimeClass$Status$200 | Response$deleteNodeV1alpha1RuntimeClass$Status$202 | Response$patchNodeV1alpha1RuntimeClass$Status$200 | Response$patchNodeV1alpha1RuntimeClass$Status$201 | Response$watchNodeV1alpha1RuntimeClassList$Status$200 | Response$watchNodeV1alpha1RuntimeClass$Status$200 | Response$getNodeV1beta1APIResources$Status$200 | Response$listNodeV1beta1RuntimeClass$Status$200 | Response$createNodeV1beta1RuntimeClass$Status$200 | Response$createNodeV1beta1RuntimeClass$Status$201 | Response$createNodeV1beta1RuntimeClass$Status$202 | Response$deleteNodeV1beta1CollectionRuntimeClass$Status$200 | Response$readNodeV1beta1RuntimeClass$Status$200 | Response$replaceNodeV1beta1RuntimeClass$Status$200 | Response$replaceNodeV1beta1RuntimeClass$Status$201 | Response$deleteNodeV1beta1RuntimeClass$Status$200 | Response$deleteNodeV1beta1RuntimeClass$Status$202 | Response$patchNodeV1beta1RuntimeClass$Status$200 | Response$patchNodeV1beta1RuntimeClass$Status$201 | Response$watchNodeV1beta1RuntimeClassList$Status$200 | Response$watchNodeV1beta1RuntimeClass$Status$200 | Response$getPolicyAPIGroup$Status$200 | Response$getPolicyV1APIResources$Status$200 | Response$listPolicyV1NamespacedPodDisruptionBudget$Status$200 | Response$createPolicyV1NamespacedPodDisruptionBudget$Status$200 | Response$createPolicyV1NamespacedPodDisruptionBudget$Status$201 | Response$createPolicyV1NamespacedPodDisruptionBudget$Status$202 | Response$deletePolicyV1CollectionNamespacedPodDisruptionBudget$Status$200 | Response$readPolicyV1NamespacedPodDisruptionBudget$Status$200 | Response$replacePolicyV1NamespacedPodDisruptionBudget$Status$200 | Response$replacePolicyV1NamespacedPodDisruptionBudget$Status$201 | Response$deletePolicyV1NamespacedPodDisruptionBudget$Status$200 | Response$deletePolicyV1NamespacedPodDisruptionBudget$Status$202 | Response$patchPolicyV1NamespacedPodDisruptionBudget$Status$200 | Response$patchPolicyV1NamespacedPodDisruptionBudget$Status$201 | Response$readPolicyV1NamespacedPodDisruptionBudgetStatus$Status$200 | Response$replacePolicyV1NamespacedPodDisruptionBudgetStatus$Status$200 | Response$replacePolicyV1NamespacedPodDisruptionBudgetStatus$Status$201 | Response$patchPolicyV1NamespacedPodDisruptionBudgetStatus$Status$200 | Response$patchPolicyV1NamespacedPodDisruptionBudgetStatus$Status$201 | Response$listPolicyV1PodDisruptionBudgetForAllNamespaces$Status$200 | Response$watchPolicyV1NamespacedPodDisruptionBudgetList$Status$200 | Response$watchPolicyV1NamespacedPodDisruptionBudget$Status$200 | Response$watchPolicyV1PodDisruptionBudgetListForAllNamespaces$Status$200 | Response$getPolicyV1beta1APIResources$Status$200 | Response$listPolicyV1beta1NamespacedPodDisruptionBudget$Status$200 | Response$createPolicyV1beta1NamespacedPodDisruptionBudget$Status$200 | Response$createPolicyV1beta1NamespacedPodDisruptionBudget$Status$201 | Response$createPolicyV1beta1NamespacedPodDisruptionBudget$Status$202 | Response$deletePolicyV1beta1CollectionNamespacedPodDisruptionBudget$Status$200 | Response$readPolicyV1beta1NamespacedPodDisruptionBudget$Status$200 | Response$replacePolicyV1beta1NamespacedPodDisruptionBudget$Status$200 | Response$replacePolicyV1beta1NamespacedPodDisruptionBudget$Status$201 | Response$deletePolicyV1beta1NamespacedPodDisruptionBudget$Status$200 | Response$deletePolicyV1beta1NamespacedPodDisruptionBudget$Status$202 | Response$patchPolicyV1beta1NamespacedPodDisruptionBudget$Status$200 | Response$patchPolicyV1beta1NamespacedPodDisruptionBudget$Status$201 | Response$readPolicyV1beta1NamespacedPodDisruptionBudgetStatus$Status$200 | Response$replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus$Status$200 | Response$replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus$Status$201 | Response$patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus$Status$200 | Response$patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus$Status$201 | Response$listPolicyV1beta1PodDisruptionBudgetForAllNamespaces$Status$200 | Response$listPolicyV1beta1PodSecurityPolicy$Status$200 | Response$createPolicyV1beta1PodSecurityPolicy$Status$200 | Response$createPolicyV1beta1PodSecurityPolicy$Status$201 | Response$createPolicyV1beta1PodSecurityPolicy$Status$202 | Response$deletePolicyV1beta1CollectionPodSecurityPolicy$Status$200 | Response$readPolicyV1beta1PodSecurityPolicy$Status$200 | Response$replacePolicyV1beta1PodSecurityPolicy$Status$200 | Response$replacePolicyV1beta1PodSecurityPolicy$Status$201 | Response$deletePolicyV1beta1PodSecurityPolicy$Status$200 | Response$deletePolicyV1beta1PodSecurityPolicy$Status$202 | Response$patchPolicyV1beta1PodSecurityPolicy$Status$200 | Response$patchPolicyV1beta1PodSecurityPolicy$Status$201 | Response$watchPolicyV1beta1NamespacedPodDisruptionBudgetList$Status$200 | Response$watchPolicyV1beta1NamespacedPodDisruptionBudget$Status$200 | Response$watchPolicyV1beta1PodDisruptionBudgetListForAllNamespaces$Status$200 | Response$watchPolicyV1beta1PodSecurityPolicyList$Status$200 | Response$watchPolicyV1beta1PodSecurityPolicy$Status$200 | Response$getRbacAuthorizationAPIGroup$Status$200 | Response$getRbacAuthorizationV1APIResources$Status$200 | Response$listRbacAuthorizationV1ClusterRoleBinding$Status$200 | Response$createRbacAuthorizationV1ClusterRoleBinding$Status$200 | Response$createRbacAuthorizationV1ClusterRoleBinding$Status$201 | Response$createRbacAuthorizationV1ClusterRoleBinding$Status$202 | Response$deleteRbacAuthorizationV1CollectionClusterRoleBinding$Status$200 | Response$readRbacAuthorizationV1ClusterRoleBinding$Status$200 | Response$replaceRbacAuthorizationV1ClusterRoleBinding$Status$200 | Response$replaceRbacAuthorizationV1ClusterRoleBinding$Status$201 | Response$deleteRbacAuthorizationV1ClusterRoleBinding$Status$200 | Response$deleteRbacAuthorizationV1ClusterRoleBinding$Status$202 | Response$patchRbacAuthorizationV1ClusterRoleBinding$Status$200 | Response$patchRbacAuthorizationV1ClusterRoleBinding$Status$201 | Response$listRbacAuthorizationV1ClusterRole$Status$200 | Response$createRbacAuthorizationV1ClusterRole$Status$200 | Response$createRbacAuthorizationV1ClusterRole$Status$201 | Response$createRbacAuthorizationV1ClusterRole$Status$202 | Response$deleteRbacAuthorizationV1CollectionClusterRole$Status$200 | Response$readRbacAuthorizationV1ClusterRole$Status$200 | Response$replaceRbacAuthorizationV1ClusterRole$Status$200 | Response$replaceRbacAuthorizationV1ClusterRole$Status$201 | Response$deleteRbacAuthorizationV1ClusterRole$Status$200 | Response$deleteRbacAuthorizationV1ClusterRole$Status$202 | Response$patchRbacAuthorizationV1ClusterRole$Status$200 | Response$patchRbacAuthorizationV1ClusterRole$Status$201 | Response$listRbacAuthorizationV1NamespacedRoleBinding$Status$200 | Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$200 | Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$201 | Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$202 | Response$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding$Status$200 | Response$readRbacAuthorizationV1NamespacedRoleBinding$Status$200 | Response$replaceRbacAuthorizationV1NamespacedRoleBinding$Status$200 | Response$replaceRbacAuthorizationV1NamespacedRoleBinding$Status$201 | Response$deleteRbacAuthorizationV1NamespacedRoleBinding$Status$200 | Response$deleteRbacAuthorizationV1NamespacedRoleBinding$Status$202 | Response$patchRbacAuthorizationV1NamespacedRoleBinding$Status$200 | Response$patchRbacAuthorizationV1NamespacedRoleBinding$Status$201 | Response$listRbacAuthorizationV1NamespacedRole$Status$200 | Response$createRbacAuthorizationV1NamespacedRole$Status$200 | Response$createRbacAuthorizationV1NamespacedRole$Status$201 | Response$createRbacAuthorizationV1NamespacedRole$Status$202 | Response$deleteRbacAuthorizationV1CollectionNamespacedRole$Status$200 | Response$readRbacAuthorizationV1NamespacedRole$Status$200 | Response$replaceRbacAuthorizationV1NamespacedRole$Status$200 | Response$replaceRbacAuthorizationV1NamespacedRole$Status$201 | Response$deleteRbacAuthorizationV1NamespacedRole$Status$200 | Response$deleteRbacAuthorizationV1NamespacedRole$Status$202 | Response$patchRbacAuthorizationV1NamespacedRole$Status$200 | Response$patchRbacAuthorizationV1NamespacedRole$Status$201 | Response$listRbacAuthorizationV1RoleBindingForAllNamespaces$Status$200 | Response$listRbacAuthorizationV1RoleForAllNamespaces$Status$200 | Response$watchRbacAuthorizationV1ClusterRoleBindingList$Status$200 | Response$watchRbacAuthorizationV1ClusterRoleBinding$Status$200 | Response$watchRbacAuthorizationV1ClusterRoleList$Status$200 | Response$watchRbacAuthorizationV1ClusterRole$Status$200 | Response$watchRbacAuthorizationV1NamespacedRoleBindingList$Status$200 | Response$watchRbacAuthorizationV1NamespacedRoleBinding$Status$200 | Response$watchRbacAuthorizationV1NamespacedRoleList$Status$200 | Response$watchRbacAuthorizationV1NamespacedRole$Status$200 | Response$watchRbacAuthorizationV1RoleBindingListForAllNamespaces$Status$200 | Response$watchRbacAuthorizationV1RoleListForAllNamespaces$Status$200 | Response$getSchedulingAPIGroup$Status$200 | Response$getSchedulingV1APIResources$Status$200 | Response$listSchedulingV1PriorityClass$Status$200 | Response$createSchedulingV1PriorityClass$Status$200 | Response$createSchedulingV1PriorityClass$Status$201 | Response$createSchedulingV1PriorityClass$Status$202 | Response$deleteSchedulingV1CollectionPriorityClass$Status$200 | Response$readSchedulingV1PriorityClass$Status$200 | Response$replaceSchedulingV1PriorityClass$Status$200 | Response$replaceSchedulingV1PriorityClass$Status$201 | Response$deleteSchedulingV1PriorityClass$Status$200 | Response$deleteSchedulingV1PriorityClass$Status$202 | Response$patchSchedulingV1PriorityClass$Status$200 | Response$patchSchedulingV1PriorityClass$Status$201 | Response$watchSchedulingV1PriorityClassList$Status$200 | Response$watchSchedulingV1PriorityClass$Status$200 | Response$getStorageAPIGroup$Status$200 | Response$getStorageV1APIResources$Status$200 | Response$listStorageV1CSIDriver$Status$200 | Response$createStorageV1CSIDriver$Status$200 | Response$createStorageV1CSIDriver$Status$201 | Response$createStorageV1CSIDriver$Status$202 | Response$deleteStorageV1CollectionCSIDriver$Status$200 | Response$readStorageV1CSIDriver$Status$200 | Response$replaceStorageV1CSIDriver$Status$200 | Response$replaceStorageV1CSIDriver$Status$201 | Response$deleteStorageV1CSIDriver$Status$200 | Response$deleteStorageV1CSIDriver$Status$202 | Response$patchStorageV1CSIDriver$Status$200 | Response$patchStorageV1CSIDriver$Status$201 | Response$listStorageV1CSINode$Status$200 | Response$createStorageV1CSINode$Status$200 | Response$createStorageV1CSINode$Status$201 | Response$createStorageV1CSINode$Status$202 | Response$deleteStorageV1CollectionCSINode$Status$200 | Response$readStorageV1CSINode$Status$200 | Response$replaceStorageV1CSINode$Status$200 | Response$replaceStorageV1CSINode$Status$201 | Response$deleteStorageV1CSINode$Status$200 | Response$deleteStorageV1CSINode$Status$202 | Response$patchStorageV1CSINode$Status$200 | Response$patchStorageV1CSINode$Status$201 | Response$listStorageV1StorageClass$Status$200 | Response$createStorageV1StorageClass$Status$200 | Response$createStorageV1StorageClass$Status$201 | Response$createStorageV1StorageClass$Status$202 | Response$deleteStorageV1CollectionStorageClass$Status$200 | Response$readStorageV1StorageClass$Status$200 | Response$replaceStorageV1StorageClass$Status$200 | Response$replaceStorageV1StorageClass$Status$201 | Response$deleteStorageV1StorageClass$Status$200 | Response$deleteStorageV1StorageClass$Status$202 | Response$patchStorageV1StorageClass$Status$200 | Response$patchStorageV1StorageClass$Status$201 | Response$listStorageV1VolumeAttachment$Status$200 | Response$createStorageV1VolumeAttachment$Status$200 | Response$createStorageV1VolumeAttachment$Status$201 | Response$createStorageV1VolumeAttachment$Status$202 | Response$deleteStorageV1CollectionVolumeAttachment$Status$200 | Response$readStorageV1VolumeAttachment$Status$200 | Response$replaceStorageV1VolumeAttachment$Status$200 | Response$replaceStorageV1VolumeAttachment$Status$201 | Response$deleteStorageV1VolumeAttachment$Status$200 | Response$deleteStorageV1VolumeAttachment$Status$202 | Response$patchStorageV1VolumeAttachment$Status$200 | Response$patchStorageV1VolumeAttachment$Status$201 | Response$readStorageV1VolumeAttachmentStatus$Status$200 | Response$replaceStorageV1VolumeAttachmentStatus$Status$200 | Response$replaceStorageV1VolumeAttachmentStatus$Status$201 | Response$patchStorageV1VolumeAttachmentStatus$Status$200 | Response$patchStorageV1VolumeAttachmentStatus$Status$201 | Response$watchStorageV1CSIDriverList$Status$200 | Response$watchStorageV1CSIDriver$Status$200 | Response$watchStorageV1CSINodeList$Status$200 | Response$watchStorageV1CSINode$Status$200 | Response$watchStorageV1StorageClassList$Status$200 | Response$watchStorageV1StorageClass$Status$200 | Response$watchStorageV1VolumeAttachmentList$Status$200 | Response$watchStorageV1VolumeAttachment$Status$200 | Response$getStorageV1alpha1APIResources$Status$200 | Response$listStorageV1alpha1CSIStorageCapacityForAllNamespaces$Status$200 | Response$listStorageV1alpha1NamespacedCSIStorageCapacity$Status$200 | Response$createStorageV1alpha1NamespacedCSIStorageCapacity$Status$200 | Response$createStorageV1alpha1NamespacedCSIStorageCapacity$Status$201 | Response$createStorageV1alpha1NamespacedCSIStorageCapacity$Status$202 | Response$deleteStorageV1alpha1CollectionNamespacedCSIStorageCapacity$Status$200 | Response$readStorageV1alpha1NamespacedCSIStorageCapacity$Status$200 | Response$replaceStorageV1alpha1NamespacedCSIStorageCapacity$Status$200 | Response$replaceStorageV1alpha1NamespacedCSIStorageCapacity$Status$201 | Response$deleteStorageV1alpha1NamespacedCSIStorageCapacity$Status$200 | Response$deleteStorageV1alpha1NamespacedCSIStorageCapacity$Status$202 | Response$patchStorageV1alpha1NamespacedCSIStorageCapacity$Status$200 | Response$patchStorageV1alpha1NamespacedCSIStorageCapacity$Status$201 | Response$watchStorageV1alpha1CSIStorageCapacityListForAllNamespaces$Status$200 | Response$watchStorageV1alpha1NamespacedCSIStorageCapacityList$Status$200 | Response$watchStorageV1alpha1NamespacedCSIStorageCapacity$Status$200 | Response$getStorageV1beta1APIResources$Status$200 | Response$listStorageV1beta1CSIStorageCapacityForAllNamespaces$Status$200 | Response$listStorageV1beta1NamespacedCSIStorageCapacity$Status$200 | Response$createStorageV1beta1NamespacedCSIStorageCapacity$Status$200 | Response$createStorageV1beta1NamespacedCSIStorageCapacity$Status$201 | Response$createStorageV1beta1NamespacedCSIStorageCapacity$Status$202 | Response$deleteStorageV1beta1CollectionNamespacedCSIStorageCapacity$Status$200 | Response$readStorageV1beta1NamespacedCSIStorageCapacity$Status$200 | Response$replaceStorageV1beta1NamespacedCSIStorageCapacity$Status$200 | Response$replaceStorageV1beta1NamespacedCSIStorageCapacity$Status$201 | Response$deleteStorageV1beta1NamespacedCSIStorageCapacity$Status$200 | Response$deleteStorageV1beta1NamespacedCSIStorageCapacity$Status$202 | Response$patchStorageV1beta1NamespacedCSIStorageCapacity$Status$200 | Response$patchStorageV1beta1NamespacedCSIStorageCapacity$Status$201 | Response$watchStorageV1beta1CSIStorageCapacityListForAllNamespaces$Status$200 | Response$watchStorageV1beta1NamespacedCSIStorageCapacityList$Status$200 | Response$watchStorageV1beta1NamespacedCSIStorageCapacity$Status$200 | Response$getServiceAccountIssuerOpenIDKeyset$Status$200 | Response$getCodeVersion$Status$200;
export declare namespace ErrorResponse {
    type getServiceAccountIssuerOpenIDConfiguration = void;
    type getCoreAPIVersions = void;
    type getCoreV1APIResources = void;
    type listCoreV1ComponentStatus = void;
    type readCoreV1ComponentStatus = void;
    type listCoreV1ConfigMapForAllNamespaces = void;
    type listCoreV1EndpointsForAllNamespaces = void;
    type listCoreV1EventForAllNamespaces = void;
    type listCoreV1LimitRangeForAllNamespaces = void;
    type listCoreV1Namespace = void;
    type createCoreV1Namespace = void;
    type createCoreV1NamespacedBinding = void;
    type listCoreV1NamespacedConfigMap = void;
    type createCoreV1NamespacedConfigMap = void;
    type deleteCoreV1CollectionNamespacedConfigMap = void;
    type readCoreV1NamespacedConfigMap = void;
    type replaceCoreV1NamespacedConfigMap = void;
    type deleteCoreV1NamespacedConfigMap = void;
    type patchCoreV1NamespacedConfigMap = void;
    type listCoreV1NamespacedEndpoints = void;
    type createCoreV1NamespacedEndpoints = void;
    type deleteCoreV1CollectionNamespacedEndpoints = void;
    type readCoreV1NamespacedEndpoints = void;
    type replaceCoreV1NamespacedEndpoints = void;
    type deleteCoreV1NamespacedEndpoints = void;
    type patchCoreV1NamespacedEndpoints = void;
    type listCoreV1NamespacedEvent = void;
    type createCoreV1NamespacedEvent = void;
    type deleteCoreV1CollectionNamespacedEvent = void;
    type readCoreV1NamespacedEvent = void;
    type replaceCoreV1NamespacedEvent = void;
    type deleteCoreV1NamespacedEvent = void;
    type patchCoreV1NamespacedEvent = void;
    type listCoreV1NamespacedLimitRange = void;
    type createCoreV1NamespacedLimitRange = void;
    type deleteCoreV1CollectionNamespacedLimitRange = void;
    type readCoreV1NamespacedLimitRange = void;
    type replaceCoreV1NamespacedLimitRange = void;
    type deleteCoreV1NamespacedLimitRange = void;
    type patchCoreV1NamespacedLimitRange = void;
    type listCoreV1NamespacedPersistentVolumeClaim = void;
    type createCoreV1NamespacedPersistentVolumeClaim = void;
    type deleteCoreV1CollectionNamespacedPersistentVolumeClaim = void;
    type readCoreV1NamespacedPersistentVolumeClaim = void;
    type replaceCoreV1NamespacedPersistentVolumeClaim = void;
    type deleteCoreV1NamespacedPersistentVolumeClaim = void;
    type patchCoreV1NamespacedPersistentVolumeClaim = void;
    type readCoreV1NamespacedPersistentVolumeClaimStatus = void;
    type replaceCoreV1NamespacedPersistentVolumeClaimStatus = void;
    type patchCoreV1NamespacedPersistentVolumeClaimStatus = void;
    type listCoreV1NamespacedPod = void;
    type createCoreV1NamespacedPod = void;
    type deleteCoreV1CollectionNamespacedPod = void;
    type readCoreV1NamespacedPod = void;
    type replaceCoreV1NamespacedPod = void;
    type deleteCoreV1NamespacedPod = void;
    type patchCoreV1NamespacedPod = void;
    type connectCoreV1GetNamespacedPodAttach = void;
    type connectCoreV1PostNamespacedPodAttach = void;
    type createCoreV1NamespacedPodBinding = void;
    type readCoreV1NamespacedPodEphemeralcontainers = void;
    type replaceCoreV1NamespacedPodEphemeralcontainers = void;
    type patchCoreV1NamespacedPodEphemeralcontainers = void;
    type createCoreV1NamespacedPodEviction = void;
    type connectCoreV1GetNamespacedPodExec = void;
    type connectCoreV1PostNamespacedPodExec = void;
    type readCoreV1NamespacedPodLog = void;
    type connectCoreV1GetNamespacedPodPortforward = void;
    type connectCoreV1PostNamespacedPodPortforward = void;
    type connectCoreV1GetNamespacedPodProxy = void;
    type connectCoreV1PutNamespacedPodProxy = void;
    type connectCoreV1PostNamespacedPodProxy = void;
    type connectCoreV1DeleteNamespacedPodProxy = void;
    type connectCoreV1OptionsNamespacedPodProxy = void;
    type connectCoreV1HeadNamespacedPodProxy = void;
    type connectCoreV1PatchNamespacedPodProxy = void;
    type connectCoreV1GetNamespacedPodProxyWithPath = void;
    type connectCoreV1PutNamespacedPodProxyWithPath = void;
    type connectCoreV1PostNamespacedPodProxyWithPath = void;
    type connectCoreV1DeleteNamespacedPodProxyWithPath = void;
    type connectCoreV1OptionsNamespacedPodProxyWithPath = void;
    type connectCoreV1HeadNamespacedPodProxyWithPath = void;
    type connectCoreV1PatchNamespacedPodProxyWithPath = void;
    type readCoreV1NamespacedPodStatus = void;
    type replaceCoreV1NamespacedPodStatus = void;
    type patchCoreV1NamespacedPodStatus = void;
    type listCoreV1NamespacedPodTemplate = void;
    type createCoreV1NamespacedPodTemplate = void;
    type deleteCoreV1CollectionNamespacedPodTemplate = void;
    type readCoreV1NamespacedPodTemplate = void;
    type replaceCoreV1NamespacedPodTemplate = void;
    type deleteCoreV1NamespacedPodTemplate = void;
    type patchCoreV1NamespacedPodTemplate = void;
    type listCoreV1NamespacedReplicationController = void;
    type createCoreV1NamespacedReplicationController = void;
    type deleteCoreV1CollectionNamespacedReplicationController = void;
    type readCoreV1NamespacedReplicationController = void;
    type replaceCoreV1NamespacedReplicationController = void;
    type deleteCoreV1NamespacedReplicationController = void;
    type patchCoreV1NamespacedReplicationController = void;
    type readCoreV1NamespacedReplicationControllerScale = void;
    type replaceCoreV1NamespacedReplicationControllerScale = void;
    type patchCoreV1NamespacedReplicationControllerScale = void;
    type readCoreV1NamespacedReplicationControllerStatus = void;
    type replaceCoreV1NamespacedReplicationControllerStatus = void;
    type patchCoreV1NamespacedReplicationControllerStatus = void;
    type listCoreV1NamespacedResourceQuota = void;
    type createCoreV1NamespacedResourceQuota = void;
    type deleteCoreV1CollectionNamespacedResourceQuota = void;
    type readCoreV1NamespacedResourceQuota = void;
    type replaceCoreV1NamespacedResourceQuota = void;
    type deleteCoreV1NamespacedResourceQuota = void;
    type patchCoreV1NamespacedResourceQuota = void;
    type readCoreV1NamespacedResourceQuotaStatus = void;
    type replaceCoreV1NamespacedResourceQuotaStatus = void;
    type patchCoreV1NamespacedResourceQuotaStatus = void;
    type listCoreV1NamespacedSecret = void;
    type createCoreV1NamespacedSecret = void;
    type deleteCoreV1CollectionNamespacedSecret = void;
    type readCoreV1NamespacedSecret = void;
    type replaceCoreV1NamespacedSecret = void;
    type deleteCoreV1NamespacedSecret = void;
    type patchCoreV1NamespacedSecret = void;
    type listCoreV1NamespacedServiceAccount = void;
    type createCoreV1NamespacedServiceAccount = void;
    type deleteCoreV1CollectionNamespacedServiceAccount = void;
    type readCoreV1NamespacedServiceAccount = void;
    type replaceCoreV1NamespacedServiceAccount = void;
    type deleteCoreV1NamespacedServiceAccount = void;
    type patchCoreV1NamespacedServiceAccount = void;
    type createCoreV1NamespacedServiceAccountToken = void;
    type listCoreV1NamespacedService = void;
    type createCoreV1NamespacedService = void;
    type deleteCoreV1CollectionNamespacedService = void;
    type readCoreV1NamespacedService = void;
    type replaceCoreV1NamespacedService = void;
    type deleteCoreV1NamespacedService = void;
    type patchCoreV1NamespacedService = void;
    type connectCoreV1GetNamespacedServiceProxy = void;
    type connectCoreV1PutNamespacedServiceProxy = void;
    type connectCoreV1PostNamespacedServiceProxy = void;
    type connectCoreV1DeleteNamespacedServiceProxy = void;
    type connectCoreV1OptionsNamespacedServiceProxy = void;
    type connectCoreV1HeadNamespacedServiceProxy = void;
    type connectCoreV1PatchNamespacedServiceProxy = void;
    type connectCoreV1GetNamespacedServiceProxyWithPath = void;
    type connectCoreV1PutNamespacedServiceProxyWithPath = void;
    type connectCoreV1PostNamespacedServiceProxyWithPath = void;
    type connectCoreV1DeleteNamespacedServiceProxyWithPath = void;
    type connectCoreV1OptionsNamespacedServiceProxyWithPath = void;
    type connectCoreV1HeadNamespacedServiceProxyWithPath = void;
    type connectCoreV1PatchNamespacedServiceProxyWithPath = void;
    type readCoreV1NamespacedServiceStatus = void;
    type replaceCoreV1NamespacedServiceStatus = void;
    type patchCoreV1NamespacedServiceStatus = void;
    type readCoreV1Namespace = void;
    type replaceCoreV1Namespace = void;
    type deleteCoreV1Namespace = void;
    type patchCoreV1Namespace = void;
    type replaceCoreV1NamespaceFinalize = void;
    type readCoreV1NamespaceStatus = void;
    type replaceCoreV1NamespaceStatus = void;
    type patchCoreV1NamespaceStatus = void;
    type listCoreV1Node = void;
    type createCoreV1Node = void;
    type deleteCoreV1CollectionNode = void;
    type readCoreV1Node = void;
    type replaceCoreV1Node = void;
    type deleteCoreV1Node = void;
    type patchCoreV1Node = void;
    type connectCoreV1GetNodeProxy = void;
    type connectCoreV1PutNodeProxy = void;
    type connectCoreV1PostNodeProxy = void;
    type connectCoreV1DeleteNodeProxy = void;
    type connectCoreV1OptionsNodeProxy = void;
    type connectCoreV1HeadNodeProxy = void;
    type connectCoreV1PatchNodeProxy = void;
    type connectCoreV1GetNodeProxyWithPath = void;
    type connectCoreV1PutNodeProxyWithPath = void;
    type connectCoreV1PostNodeProxyWithPath = void;
    type connectCoreV1DeleteNodeProxyWithPath = void;
    type connectCoreV1OptionsNodeProxyWithPath = void;
    type connectCoreV1HeadNodeProxyWithPath = void;
    type connectCoreV1PatchNodeProxyWithPath = void;
    type readCoreV1NodeStatus = void;
    type replaceCoreV1NodeStatus = void;
    type patchCoreV1NodeStatus = void;
    type listCoreV1PersistentVolumeClaimForAllNamespaces = void;
    type listCoreV1PersistentVolume = void;
    type createCoreV1PersistentVolume = void;
    type deleteCoreV1CollectionPersistentVolume = void;
    type readCoreV1PersistentVolume = void;
    type replaceCoreV1PersistentVolume = void;
    type deleteCoreV1PersistentVolume = void;
    type patchCoreV1PersistentVolume = void;
    type readCoreV1PersistentVolumeStatus = void;
    type replaceCoreV1PersistentVolumeStatus = void;
    type patchCoreV1PersistentVolumeStatus = void;
    type listCoreV1PodForAllNamespaces = void;
    type listCoreV1PodTemplateForAllNamespaces = void;
    type listCoreV1ReplicationControllerForAllNamespaces = void;
    type listCoreV1ResourceQuotaForAllNamespaces = void;
    type listCoreV1SecretForAllNamespaces = void;
    type listCoreV1ServiceAccountForAllNamespaces = void;
    type listCoreV1ServiceForAllNamespaces = void;
    type watchCoreV1ConfigMapListForAllNamespaces = void;
    type watchCoreV1EndpointsListForAllNamespaces = void;
    type watchCoreV1EventListForAllNamespaces = void;
    type watchCoreV1LimitRangeListForAllNamespaces = void;
    type watchCoreV1NamespaceList = void;
    type watchCoreV1NamespacedConfigMapList = void;
    type watchCoreV1NamespacedConfigMap = void;
    type watchCoreV1NamespacedEndpointsList = void;
    type watchCoreV1NamespacedEndpoints = void;
    type watchCoreV1NamespacedEventList = void;
    type watchCoreV1NamespacedEvent = void;
    type watchCoreV1NamespacedLimitRangeList = void;
    type watchCoreV1NamespacedLimitRange = void;
    type watchCoreV1NamespacedPersistentVolumeClaimList = void;
    type watchCoreV1NamespacedPersistentVolumeClaim = void;
    type watchCoreV1NamespacedPodList = void;
    type watchCoreV1NamespacedPod = void;
    type watchCoreV1NamespacedPodTemplateList = void;
    type watchCoreV1NamespacedPodTemplate = void;
    type watchCoreV1NamespacedReplicationControllerList = void;
    type watchCoreV1NamespacedReplicationController = void;
    type watchCoreV1NamespacedResourceQuotaList = void;
    type watchCoreV1NamespacedResourceQuota = void;
    type watchCoreV1NamespacedSecretList = void;
    type watchCoreV1NamespacedSecret = void;
    type watchCoreV1NamespacedServiceAccountList = void;
    type watchCoreV1NamespacedServiceAccount = void;
    type watchCoreV1NamespacedServiceList = void;
    type watchCoreV1NamespacedService = void;
    type watchCoreV1Namespace = void;
    type watchCoreV1NodeList = void;
    type watchCoreV1Node = void;
    type watchCoreV1PersistentVolumeClaimListForAllNamespaces = void;
    type watchCoreV1PersistentVolumeList = void;
    type watchCoreV1PersistentVolume = void;
    type watchCoreV1PodListForAllNamespaces = void;
    type watchCoreV1PodTemplateListForAllNamespaces = void;
    type watchCoreV1ReplicationControllerListForAllNamespaces = void;
    type watchCoreV1ResourceQuotaListForAllNamespaces = void;
    type watchCoreV1SecretListForAllNamespaces = void;
    type watchCoreV1ServiceAccountListForAllNamespaces = void;
    type watchCoreV1ServiceListForAllNamespaces = void;
    type getAPIVersions = void;
    type getAdmissionregistrationAPIGroup = void;
    type getAdmissionregistrationV1APIResources = void;
    type listAdmissionregistrationV1MutatingWebhookConfiguration = void;
    type createAdmissionregistrationV1MutatingWebhookConfiguration = void;
    type deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration = void;
    type readAdmissionregistrationV1MutatingWebhookConfiguration = void;
    type replaceAdmissionregistrationV1MutatingWebhookConfiguration = void;
    type deleteAdmissionregistrationV1MutatingWebhookConfiguration = void;
    type patchAdmissionregistrationV1MutatingWebhookConfiguration = void;
    type listAdmissionregistrationV1ValidatingWebhookConfiguration = void;
    type createAdmissionregistrationV1ValidatingWebhookConfiguration = void;
    type deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration = void;
    type readAdmissionregistrationV1ValidatingWebhookConfiguration = void;
    type replaceAdmissionregistrationV1ValidatingWebhookConfiguration = void;
    type deleteAdmissionregistrationV1ValidatingWebhookConfiguration = void;
    type patchAdmissionregistrationV1ValidatingWebhookConfiguration = void;
    type watchAdmissionregistrationV1MutatingWebhookConfigurationList = void;
    type watchAdmissionregistrationV1MutatingWebhookConfiguration = void;
    type watchAdmissionregistrationV1ValidatingWebhookConfigurationList = void;
    type watchAdmissionregistrationV1ValidatingWebhookConfiguration = void;
    type getApiextensionsAPIGroup = void;
    type getApiextensionsV1APIResources = void;
    type listApiextensionsV1CustomResourceDefinition = void;
    type createApiextensionsV1CustomResourceDefinition = void;
    type deleteApiextensionsV1CollectionCustomResourceDefinition = void;
    type readApiextensionsV1CustomResourceDefinition = void;
    type replaceApiextensionsV1CustomResourceDefinition = void;
    type deleteApiextensionsV1CustomResourceDefinition = void;
    type patchApiextensionsV1CustomResourceDefinition = void;
    type readApiextensionsV1CustomResourceDefinitionStatus = void;
    type replaceApiextensionsV1CustomResourceDefinitionStatus = void;
    type patchApiextensionsV1CustomResourceDefinitionStatus = void;
    type watchApiextensionsV1CustomResourceDefinitionList = void;
    type watchApiextensionsV1CustomResourceDefinition = void;
    type getApiregistrationAPIGroup = void;
    type getApiregistrationV1APIResources = void;
    type listApiregistrationV1APIService = void;
    type createApiregistrationV1APIService = void;
    type deleteApiregistrationV1CollectionAPIService = void;
    type readApiregistrationV1APIService = void;
    type replaceApiregistrationV1APIService = void;
    type deleteApiregistrationV1APIService = void;
    type patchApiregistrationV1APIService = void;
    type readApiregistrationV1APIServiceStatus = void;
    type replaceApiregistrationV1APIServiceStatus = void;
    type patchApiregistrationV1APIServiceStatus = void;
    type watchApiregistrationV1APIServiceList = void;
    type watchApiregistrationV1APIService = void;
    type getAppsAPIGroup = void;
    type getAppsV1APIResources = void;
    type listAppsV1ControllerRevisionForAllNamespaces = void;
    type listAppsV1DaemonSetForAllNamespaces = void;
    type listAppsV1DeploymentForAllNamespaces = void;
    type listAppsV1NamespacedControllerRevision = void;
    type createAppsV1NamespacedControllerRevision = void;
    type deleteAppsV1CollectionNamespacedControllerRevision = void;
    type readAppsV1NamespacedControllerRevision = void;
    type replaceAppsV1NamespacedControllerRevision = void;
    type deleteAppsV1NamespacedControllerRevision = void;
    type patchAppsV1NamespacedControllerRevision = void;
    type listAppsV1NamespacedDaemonSet = void;
    type createAppsV1NamespacedDaemonSet = void;
    type deleteAppsV1CollectionNamespacedDaemonSet = void;
    type readAppsV1NamespacedDaemonSet = void;
    type replaceAppsV1NamespacedDaemonSet = void;
    type deleteAppsV1NamespacedDaemonSet = void;
    type patchAppsV1NamespacedDaemonSet = void;
    type readAppsV1NamespacedDaemonSetStatus = void;
    type replaceAppsV1NamespacedDaemonSetStatus = void;
    type patchAppsV1NamespacedDaemonSetStatus = void;
    type listAppsV1NamespacedDeployment = void;
    type createAppsV1NamespacedDeployment = void;
    type deleteAppsV1CollectionNamespacedDeployment = void;
    type readAppsV1NamespacedDeployment = void;
    type replaceAppsV1NamespacedDeployment = void;
    type deleteAppsV1NamespacedDeployment = void;
    type patchAppsV1NamespacedDeployment = void;
    type readAppsV1NamespacedDeploymentScale = void;
    type replaceAppsV1NamespacedDeploymentScale = void;
    type patchAppsV1NamespacedDeploymentScale = void;
    type readAppsV1NamespacedDeploymentStatus = void;
    type replaceAppsV1NamespacedDeploymentStatus = void;
    type patchAppsV1NamespacedDeploymentStatus = void;
    type listAppsV1NamespacedReplicaSet = void;
    type createAppsV1NamespacedReplicaSet = void;
    type deleteAppsV1CollectionNamespacedReplicaSet = void;
    type readAppsV1NamespacedReplicaSet = void;
    type replaceAppsV1NamespacedReplicaSet = void;
    type deleteAppsV1NamespacedReplicaSet = void;
    type patchAppsV1NamespacedReplicaSet = void;
    type readAppsV1NamespacedReplicaSetScale = void;
    type replaceAppsV1NamespacedReplicaSetScale = void;
    type patchAppsV1NamespacedReplicaSetScale = void;
    type readAppsV1NamespacedReplicaSetStatus = void;
    type replaceAppsV1NamespacedReplicaSetStatus = void;
    type patchAppsV1NamespacedReplicaSetStatus = void;
    type listAppsV1NamespacedStatefulSet = void;
    type createAppsV1NamespacedStatefulSet = void;
    type deleteAppsV1CollectionNamespacedStatefulSet = void;
    type readAppsV1NamespacedStatefulSet = void;
    type replaceAppsV1NamespacedStatefulSet = void;
    type deleteAppsV1NamespacedStatefulSet = void;
    type patchAppsV1NamespacedStatefulSet = void;
    type readAppsV1NamespacedStatefulSetScale = void;
    type replaceAppsV1NamespacedStatefulSetScale = void;
    type patchAppsV1NamespacedStatefulSetScale = void;
    type readAppsV1NamespacedStatefulSetStatus = void;
    type replaceAppsV1NamespacedStatefulSetStatus = void;
    type patchAppsV1NamespacedStatefulSetStatus = void;
    type listAppsV1ReplicaSetForAllNamespaces = void;
    type listAppsV1StatefulSetForAllNamespaces = void;
    type watchAppsV1ControllerRevisionListForAllNamespaces = void;
    type watchAppsV1DaemonSetListForAllNamespaces = void;
    type watchAppsV1DeploymentListForAllNamespaces = void;
    type watchAppsV1NamespacedControllerRevisionList = void;
    type watchAppsV1NamespacedControllerRevision = void;
    type watchAppsV1NamespacedDaemonSetList = void;
    type watchAppsV1NamespacedDaemonSet = void;
    type watchAppsV1NamespacedDeploymentList = void;
    type watchAppsV1NamespacedDeployment = void;
    type watchAppsV1NamespacedReplicaSetList = void;
    type watchAppsV1NamespacedReplicaSet = void;
    type watchAppsV1NamespacedStatefulSetList = void;
    type watchAppsV1NamespacedStatefulSet = void;
    type watchAppsV1ReplicaSetListForAllNamespaces = void;
    type watchAppsV1StatefulSetListForAllNamespaces = void;
    type getAuthenticationAPIGroup = void;
    type getAuthenticationV1APIResources = void;
    type createAuthenticationV1TokenReview = void;
    type getAuthorizationAPIGroup = void;
    type getAuthorizationV1APIResources = void;
    type createAuthorizationV1NamespacedLocalSubjectAccessReview = void;
    type createAuthorizationV1SelfSubjectAccessReview = void;
    type createAuthorizationV1SelfSubjectRulesReview = void;
    type createAuthorizationV1SubjectAccessReview = void;
    type getAutoscalingAPIGroup = void;
    type getAutoscalingV1APIResources = void;
    type listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces = void;
    type listAutoscalingV1NamespacedHorizontalPodAutoscaler = void;
    type createAutoscalingV1NamespacedHorizontalPodAutoscaler = void;
    type deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler = void;
    type readAutoscalingV1NamespacedHorizontalPodAutoscaler = void;
    type replaceAutoscalingV1NamespacedHorizontalPodAutoscaler = void;
    type deleteAutoscalingV1NamespacedHorizontalPodAutoscaler = void;
    type patchAutoscalingV1NamespacedHorizontalPodAutoscaler = void;
    type readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus = void;
    type replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus = void;
    type patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus = void;
    type watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces = void;
    type watchAutoscalingV1NamespacedHorizontalPodAutoscalerList = void;
    type watchAutoscalingV1NamespacedHorizontalPodAutoscaler = void;
    type getAutoscalingV2APIResources = void;
    type listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces = void;
    type listAutoscalingV2NamespacedHorizontalPodAutoscaler = void;
    type createAutoscalingV2NamespacedHorizontalPodAutoscaler = void;
    type deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler = void;
    type readAutoscalingV2NamespacedHorizontalPodAutoscaler = void;
    type replaceAutoscalingV2NamespacedHorizontalPodAutoscaler = void;
    type deleteAutoscalingV2NamespacedHorizontalPodAutoscaler = void;
    type patchAutoscalingV2NamespacedHorizontalPodAutoscaler = void;
    type readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus = void;
    type replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus = void;
    type patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus = void;
    type watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces = void;
    type watchAutoscalingV2NamespacedHorizontalPodAutoscalerList = void;
    type watchAutoscalingV2NamespacedHorizontalPodAutoscaler = void;
    type getAutoscalingV2beta1APIResources = void;
    type listAutoscalingV2beta1HorizontalPodAutoscalerForAllNamespaces = void;
    type listAutoscalingV2beta1NamespacedHorizontalPodAutoscaler = void;
    type createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler = void;
    type deleteAutoscalingV2beta1CollectionNamespacedHorizontalPodAutoscaler = void;
    type readAutoscalingV2beta1NamespacedHorizontalPodAutoscaler = void;
    type replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler = void;
    type deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler = void;
    type patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler = void;
    type readAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus = void;
    type replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus = void;
    type patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus = void;
    type watchAutoscalingV2beta1HorizontalPodAutoscalerListForAllNamespaces = void;
    type watchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerList = void;
    type watchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler = void;
    type getAutoscalingV2beta2APIResources = void;
    type listAutoscalingV2beta2HorizontalPodAutoscalerForAllNamespaces = void;
    type listAutoscalingV2beta2NamespacedHorizontalPodAutoscaler = void;
    type createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler = void;
    type deleteAutoscalingV2beta2CollectionNamespacedHorizontalPodAutoscaler = void;
    type readAutoscalingV2beta2NamespacedHorizontalPodAutoscaler = void;
    type replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler = void;
    type deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler = void;
    type patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler = void;
    type readAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus = void;
    type replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus = void;
    type patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus = void;
    type watchAutoscalingV2beta2HorizontalPodAutoscalerListForAllNamespaces = void;
    type watchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerList = void;
    type watchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler = void;
    type getBatchAPIGroup = void;
    type getBatchV1APIResources = void;
    type listBatchV1CronJobForAllNamespaces = void;
    type listBatchV1JobForAllNamespaces = void;
    type listBatchV1NamespacedCronJob = void;
    type createBatchV1NamespacedCronJob = void;
    type deleteBatchV1CollectionNamespacedCronJob = void;
    type readBatchV1NamespacedCronJob = void;
    type replaceBatchV1NamespacedCronJob = void;
    type deleteBatchV1NamespacedCronJob = void;
    type patchBatchV1NamespacedCronJob = void;
    type readBatchV1NamespacedCronJobStatus = void;
    type replaceBatchV1NamespacedCronJobStatus = void;
    type patchBatchV1NamespacedCronJobStatus = void;
    type listBatchV1NamespacedJob = void;
    type createBatchV1NamespacedJob = void;
    type deleteBatchV1CollectionNamespacedJob = void;
    type readBatchV1NamespacedJob = void;
    type replaceBatchV1NamespacedJob = void;
    type deleteBatchV1NamespacedJob = void;
    type patchBatchV1NamespacedJob = void;
    type readBatchV1NamespacedJobStatus = void;
    type replaceBatchV1NamespacedJobStatus = void;
    type patchBatchV1NamespacedJobStatus = void;
    type watchBatchV1CronJobListForAllNamespaces = void;
    type watchBatchV1JobListForAllNamespaces = void;
    type watchBatchV1NamespacedCronJobList = void;
    type watchBatchV1NamespacedCronJob = void;
    type watchBatchV1NamespacedJobList = void;
    type watchBatchV1NamespacedJob = void;
    type getBatchV1beta1APIResources = void;
    type listBatchV1beta1CronJobForAllNamespaces = void;
    type listBatchV1beta1NamespacedCronJob = void;
    type createBatchV1beta1NamespacedCronJob = void;
    type deleteBatchV1beta1CollectionNamespacedCronJob = void;
    type readBatchV1beta1NamespacedCronJob = void;
    type replaceBatchV1beta1NamespacedCronJob = void;
    type deleteBatchV1beta1NamespacedCronJob = void;
    type patchBatchV1beta1NamespacedCronJob = void;
    type readBatchV1beta1NamespacedCronJobStatus = void;
    type replaceBatchV1beta1NamespacedCronJobStatus = void;
    type patchBatchV1beta1NamespacedCronJobStatus = void;
    type watchBatchV1beta1CronJobListForAllNamespaces = void;
    type watchBatchV1beta1NamespacedCronJobList = void;
    type watchBatchV1beta1NamespacedCronJob = void;
    type getCertificatesAPIGroup = void;
    type getCertificatesV1APIResources = void;
    type listCertificatesV1CertificateSigningRequest = void;
    type createCertificatesV1CertificateSigningRequest = void;
    type deleteCertificatesV1CollectionCertificateSigningRequest = void;
    type readCertificatesV1CertificateSigningRequest = void;
    type replaceCertificatesV1CertificateSigningRequest = void;
    type deleteCertificatesV1CertificateSigningRequest = void;
    type patchCertificatesV1CertificateSigningRequest = void;
    type readCertificatesV1CertificateSigningRequestApproval = void;
    type replaceCertificatesV1CertificateSigningRequestApproval = void;
    type patchCertificatesV1CertificateSigningRequestApproval = void;
    type readCertificatesV1CertificateSigningRequestStatus = void;
    type replaceCertificatesV1CertificateSigningRequestStatus = void;
    type patchCertificatesV1CertificateSigningRequestStatus = void;
    type watchCertificatesV1CertificateSigningRequestList = void;
    type watchCertificatesV1CertificateSigningRequest = void;
    type getCoordinationAPIGroup = void;
    type getCoordinationV1APIResources = void;
    type listCoordinationV1LeaseForAllNamespaces = void;
    type listCoordinationV1NamespacedLease = void;
    type createCoordinationV1NamespacedLease = void;
    type deleteCoordinationV1CollectionNamespacedLease = void;
    type readCoordinationV1NamespacedLease = void;
    type replaceCoordinationV1NamespacedLease = void;
    type deleteCoordinationV1NamespacedLease = void;
    type patchCoordinationV1NamespacedLease = void;
    type watchCoordinationV1LeaseListForAllNamespaces = void;
    type watchCoordinationV1NamespacedLeaseList = void;
    type watchCoordinationV1NamespacedLease = void;
    type getDiscoveryAPIGroup = void;
    type getDiscoveryV1APIResources = void;
    type listDiscoveryV1EndpointSliceForAllNamespaces = void;
    type listDiscoveryV1NamespacedEndpointSlice = void;
    type createDiscoveryV1NamespacedEndpointSlice = void;
    type deleteDiscoveryV1CollectionNamespacedEndpointSlice = void;
    type readDiscoveryV1NamespacedEndpointSlice = void;
    type replaceDiscoveryV1NamespacedEndpointSlice = void;
    type deleteDiscoveryV1NamespacedEndpointSlice = void;
    type patchDiscoveryV1NamespacedEndpointSlice = void;
    type watchDiscoveryV1EndpointSliceListForAllNamespaces = void;
    type watchDiscoveryV1NamespacedEndpointSliceList = void;
    type watchDiscoveryV1NamespacedEndpointSlice = void;
    type getDiscoveryV1beta1APIResources = void;
    type listDiscoveryV1beta1EndpointSliceForAllNamespaces = void;
    type listDiscoveryV1beta1NamespacedEndpointSlice = void;
    type createDiscoveryV1beta1NamespacedEndpointSlice = void;
    type deleteDiscoveryV1beta1CollectionNamespacedEndpointSlice = void;
    type readDiscoveryV1beta1NamespacedEndpointSlice = void;
    type replaceDiscoveryV1beta1NamespacedEndpointSlice = void;
    type deleteDiscoveryV1beta1NamespacedEndpointSlice = void;
    type patchDiscoveryV1beta1NamespacedEndpointSlice = void;
    type watchDiscoveryV1beta1EndpointSliceListForAllNamespaces = void;
    type watchDiscoveryV1beta1NamespacedEndpointSliceList = void;
    type watchDiscoveryV1beta1NamespacedEndpointSlice = void;
    type getEventsAPIGroup = void;
    type getEventsV1APIResources = void;
    type listEventsV1EventForAllNamespaces = void;
    type listEventsV1NamespacedEvent = void;
    type createEventsV1NamespacedEvent = void;
    type deleteEventsV1CollectionNamespacedEvent = void;
    type readEventsV1NamespacedEvent = void;
    type replaceEventsV1NamespacedEvent = void;
    type deleteEventsV1NamespacedEvent = void;
    type patchEventsV1NamespacedEvent = void;
    type watchEventsV1EventListForAllNamespaces = void;
    type watchEventsV1NamespacedEventList = void;
    type watchEventsV1NamespacedEvent = void;
    type getEventsV1beta1APIResources = void;
    type listEventsV1beta1EventForAllNamespaces = void;
    type listEventsV1beta1NamespacedEvent = void;
    type createEventsV1beta1NamespacedEvent = void;
    type deleteEventsV1beta1CollectionNamespacedEvent = void;
    type readEventsV1beta1NamespacedEvent = void;
    type replaceEventsV1beta1NamespacedEvent = void;
    type deleteEventsV1beta1NamespacedEvent = void;
    type patchEventsV1beta1NamespacedEvent = void;
    type watchEventsV1beta1EventListForAllNamespaces = void;
    type watchEventsV1beta1NamespacedEventList = void;
    type watchEventsV1beta1NamespacedEvent = void;
    type getFlowcontrolApiserverAPIGroup = void;
    type getFlowcontrolApiserverV1beta1APIResources = void;
    type listFlowcontrolApiserverV1beta1FlowSchema = void;
    type createFlowcontrolApiserverV1beta1FlowSchema = void;
    type deleteFlowcontrolApiserverV1beta1CollectionFlowSchema = void;
    type readFlowcontrolApiserverV1beta1FlowSchema = void;
    type replaceFlowcontrolApiserverV1beta1FlowSchema = void;
    type deleteFlowcontrolApiserverV1beta1FlowSchema = void;
    type patchFlowcontrolApiserverV1beta1FlowSchema = void;
    type readFlowcontrolApiserverV1beta1FlowSchemaStatus = void;
    type replaceFlowcontrolApiserverV1beta1FlowSchemaStatus = void;
    type patchFlowcontrolApiserverV1beta1FlowSchemaStatus = void;
    type listFlowcontrolApiserverV1beta1PriorityLevelConfiguration = void;
    type createFlowcontrolApiserverV1beta1PriorityLevelConfiguration = void;
    type deleteFlowcontrolApiserverV1beta1CollectionPriorityLevelConfiguration = void;
    type readFlowcontrolApiserverV1beta1PriorityLevelConfiguration = void;
    type replaceFlowcontrolApiserverV1beta1PriorityLevelConfiguration = void;
    type deleteFlowcontrolApiserverV1beta1PriorityLevelConfiguration = void;
    type patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration = void;
    type readFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus = void;
    type replaceFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus = void;
    type patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus = void;
    type watchFlowcontrolApiserverV1beta1FlowSchemaList = void;
    type watchFlowcontrolApiserverV1beta1FlowSchema = void;
    type watchFlowcontrolApiserverV1beta1PriorityLevelConfigurationList = void;
    type watchFlowcontrolApiserverV1beta1PriorityLevelConfiguration = void;
    type getFlowcontrolApiserverV1beta2APIResources = void;
    type listFlowcontrolApiserverV1beta2FlowSchema = void;
    type createFlowcontrolApiserverV1beta2FlowSchema = void;
    type deleteFlowcontrolApiserverV1beta2CollectionFlowSchema = void;
    type readFlowcontrolApiserverV1beta2FlowSchema = void;
    type replaceFlowcontrolApiserverV1beta2FlowSchema = void;
    type deleteFlowcontrolApiserverV1beta2FlowSchema = void;
    type patchFlowcontrolApiserverV1beta2FlowSchema = void;
    type readFlowcontrolApiserverV1beta2FlowSchemaStatus = void;
    type replaceFlowcontrolApiserverV1beta2FlowSchemaStatus = void;
    type patchFlowcontrolApiserverV1beta2FlowSchemaStatus = void;
    type listFlowcontrolApiserverV1beta2PriorityLevelConfiguration = void;
    type createFlowcontrolApiserverV1beta2PriorityLevelConfiguration = void;
    type deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration = void;
    type readFlowcontrolApiserverV1beta2PriorityLevelConfiguration = void;
    type replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration = void;
    type deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration = void;
    type patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration = void;
    type readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus = void;
    type replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus = void;
    type patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus = void;
    type watchFlowcontrolApiserverV1beta2FlowSchemaList = void;
    type watchFlowcontrolApiserverV1beta2FlowSchema = void;
    type watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList = void;
    type watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration = void;
    type getInternalApiserverAPIGroup = void;
    type getInternalApiserverV1alpha1APIResources = void;
    type listInternalApiserverV1alpha1StorageVersion = void;
    type createInternalApiserverV1alpha1StorageVersion = void;
    type deleteInternalApiserverV1alpha1CollectionStorageVersion = void;
    type readInternalApiserverV1alpha1StorageVersion = void;
    type replaceInternalApiserverV1alpha1StorageVersion = void;
    type deleteInternalApiserverV1alpha1StorageVersion = void;
    type patchInternalApiserverV1alpha1StorageVersion = void;
    type readInternalApiserverV1alpha1StorageVersionStatus = void;
    type replaceInternalApiserverV1alpha1StorageVersionStatus = void;
    type patchInternalApiserverV1alpha1StorageVersionStatus = void;
    type watchInternalApiserverV1alpha1StorageVersionList = void;
    type watchInternalApiserverV1alpha1StorageVersion = void;
    type getNetworkingAPIGroup = void;
    type getNetworkingV1APIResources = void;
    type listNetworkingV1IngressClass = void;
    type createNetworkingV1IngressClass = void;
    type deleteNetworkingV1CollectionIngressClass = void;
    type readNetworkingV1IngressClass = void;
    type replaceNetworkingV1IngressClass = void;
    type deleteNetworkingV1IngressClass = void;
    type patchNetworkingV1IngressClass = void;
    type listNetworkingV1IngressForAllNamespaces = void;
    type listNetworkingV1NamespacedIngress = void;
    type createNetworkingV1NamespacedIngress = void;
    type deleteNetworkingV1CollectionNamespacedIngress = void;
    type readNetworkingV1NamespacedIngress = void;
    type replaceNetworkingV1NamespacedIngress = void;
    type deleteNetworkingV1NamespacedIngress = void;
    type patchNetworkingV1NamespacedIngress = void;
    type readNetworkingV1NamespacedIngressStatus = void;
    type replaceNetworkingV1NamespacedIngressStatus = void;
    type patchNetworkingV1NamespacedIngressStatus = void;
    type listNetworkingV1NamespacedNetworkPolicy = void;
    type createNetworkingV1NamespacedNetworkPolicy = void;
    type deleteNetworkingV1CollectionNamespacedNetworkPolicy = void;
    type readNetworkingV1NamespacedNetworkPolicy = void;
    type replaceNetworkingV1NamespacedNetworkPolicy = void;
    type deleteNetworkingV1NamespacedNetworkPolicy = void;
    type patchNetworkingV1NamespacedNetworkPolicy = void;
    type listNetworkingV1NetworkPolicyForAllNamespaces = void;
    type watchNetworkingV1IngressClassList = void;
    type watchNetworkingV1IngressClass = void;
    type watchNetworkingV1IngressListForAllNamespaces = void;
    type watchNetworkingV1NamespacedIngressList = void;
    type watchNetworkingV1NamespacedIngress = void;
    type watchNetworkingV1NamespacedNetworkPolicyList = void;
    type watchNetworkingV1NamespacedNetworkPolicy = void;
    type watchNetworkingV1NetworkPolicyListForAllNamespaces = void;
    type getNodeAPIGroup = void;
    type getNodeV1APIResources = void;
    type listNodeV1RuntimeClass = void;
    type createNodeV1RuntimeClass = void;
    type deleteNodeV1CollectionRuntimeClass = void;
    type readNodeV1RuntimeClass = void;
    type replaceNodeV1RuntimeClass = void;
    type deleteNodeV1RuntimeClass = void;
    type patchNodeV1RuntimeClass = void;
    type watchNodeV1RuntimeClassList = void;
    type watchNodeV1RuntimeClass = void;
    type getNodeV1alpha1APIResources = void;
    type listNodeV1alpha1RuntimeClass = void;
    type createNodeV1alpha1RuntimeClass = void;
    type deleteNodeV1alpha1CollectionRuntimeClass = void;
    type readNodeV1alpha1RuntimeClass = void;
    type replaceNodeV1alpha1RuntimeClass = void;
    type deleteNodeV1alpha1RuntimeClass = void;
    type patchNodeV1alpha1RuntimeClass = void;
    type watchNodeV1alpha1RuntimeClassList = void;
    type watchNodeV1alpha1RuntimeClass = void;
    type getNodeV1beta1APIResources = void;
    type listNodeV1beta1RuntimeClass = void;
    type createNodeV1beta1RuntimeClass = void;
    type deleteNodeV1beta1CollectionRuntimeClass = void;
    type readNodeV1beta1RuntimeClass = void;
    type replaceNodeV1beta1RuntimeClass = void;
    type deleteNodeV1beta1RuntimeClass = void;
    type patchNodeV1beta1RuntimeClass = void;
    type watchNodeV1beta1RuntimeClassList = void;
    type watchNodeV1beta1RuntimeClass = void;
    type getPolicyAPIGroup = void;
    type getPolicyV1APIResources = void;
    type listPolicyV1NamespacedPodDisruptionBudget = void;
    type createPolicyV1NamespacedPodDisruptionBudget = void;
    type deletePolicyV1CollectionNamespacedPodDisruptionBudget = void;
    type readPolicyV1NamespacedPodDisruptionBudget = void;
    type replacePolicyV1NamespacedPodDisruptionBudget = void;
    type deletePolicyV1NamespacedPodDisruptionBudget = void;
    type patchPolicyV1NamespacedPodDisruptionBudget = void;
    type readPolicyV1NamespacedPodDisruptionBudgetStatus = void;
    type replacePolicyV1NamespacedPodDisruptionBudgetStatus = void;
    type patchPolicyV1NamespacedPodDisruptionBudgetStatus = void;
    type listPolicyV1PodDisruptionBudgetForAllNamespaces = void;
    type watchPolicyV1NamespacedPodDisruptionBudgetList = void;
    type watchPolicyV1NamespacedPodDisruptionBudget = void;
    type watchPolicyV1PodDisruptionBudgetListForAllNamespaces = void;
    type getPolicyV1beta1APIResources = void;
    type listPolicyV1beta1NamespacedPodDisruptionBudget = void;
    type createPolicyV1beta1NamespacedPodDisruptionBudget = void;
    type deletePolicyV1beta1CollectionNamespacedPodDisruptionBudget = void;
    type readPolicyV1beta1NamespacedPodDisruptionBudget = void;
    type replacePolicyV1beta1NamespacedPodDisruptionBudget = void;
    type deletePolicyV1beta1NamespacedPodDisruptionBudget = void;
    type patchPolicyV1beta1NamespacedPodDisruptionBudget = void;
    type readPolicyV1beta1NamespacedPodDisruptionBudgetStatus = void;
    type replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus = void;
    type patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus = void;
    type listPolicyV1beta1PodDisruptionBudgetForAllNamespaces = void;
    type listPolicyV1beta1PodSecurityPolicy = void;
    type createPolicyV1beta1PodSecurityPolicy = void;
    type deletePolicyV1beta1CollectionPodSecurityPolicy = void;
    type readPolicyV1beta1PodSecurityPolicy = void;
    type replacePolicyV1beta1PodSecurityPolicy = void;
    type deletePolicyV1beta1PodSecurityPolicy = void;
    type patchPolicyV1beta1PodSecurityPolicy = void;
    type watchPolicyV1beta1NamespacedPodDisruptionBudgetList = void;
    type watchPolicyV1beta1NamespacedPodDisruptionBudget = void;
    type watchPolicyV1beta1PodDisruptionBudgetListForAllNamespaces = void;
    type watchPolicyV1beta1PodSecurityPolicyList = void;
    type watchPolicyV1beta1PodSecurityPolicy = void;
    type getRbacAuthorizationAPIGroup = void;
    type getRbacAuthorizationV1APIResources = void;
    type listRbacAuthorizationV1ClusterRoleBinding = void;
    type createRbacAuthorizationV1ClusterRoleBinding = void;
    type deleteRbacAuthorizationV1CollectionClusterRoleBinding = void;
    type readRbacAuthorizationV1ClusterRoleBinding = void;
    type replaceRbacAuthorizationV1ClusterRoleBinding = void;
    type deleteRbacAuthorizationV1ClusterRoleBinding = void;
    type patchRbacAuthorizationV1ClusterRoleBinding = void;
    type listRbacAuthorizationV1ClusterRole = void;
    type createRbacAuthorizationV1ClusterRole = void;
    type deleteRbacAuthorizationV1CollectionClusterRole = void;
    type readRbacAuthorizationV1ClusterRole = void;
    type replaceRbacAuthorizationV1ClusterRole = void;
    type deleteRbacAuthorizationV1ClusterRole = void;
    type patchRbacAuthorizationV1ClusterRole = void;
    type listRbacAuthorizationV1NamespacedRoleBinding = void;
    type createRbacAuthorizationV1NamespacedRoleBinding = void;
    type deleteRbacAuthorizationV1CollectionNamespacedRoleBinding = void;
    type readRbacAuthorizationV1NamespacedRoleBinding = void;
    type replaceRbacAuthorizationV1NamespacedRoleBinding = void;
    type deleteRbacAuthorizationV1NamespacedRoleBinding = void;
    type patchRbacAuthorizationV1NamespacedRoleBinding = void;
    type listRbacAuthorizationV1NamespacedRole = void;
    type createRbacAuthorizationV1NamespacedRole = void;
    type deleteRbacAuthorizationV1CollectionNamespacedRole = void;
    type readRbacAuthorizationV1NamespacedRole = void;
    type replaceRbacAuthorizationV1NamespacedRole = void;
    type deleteRbacAuthorizationV1NamespacedRole = void;
    type patchRbacAuthorizationV1NamespacedRole = void;
    type listRbacAuthorizationV1RoleBindingForAllNamespaces = void;
    type listRbacAuthorizationV1RoleForAllNamespaces = void;
    type watchRbacAuthorizationV1ClusterRoleBindingList = void;
    type watchRbacAuthorizationV1ClusterRoleBinding = void;
    type watchRbacAuthorizationV1ClusterRoleList = void;
    type watchRbacAuthorizationV1ClusterRole = void;
    type watchRbacAuthorizationV1NamespacedRoleBindingList = void;
    type watchRbacAuthorizationV1NamespacedRoleBinding = void;
    type watchRbacAuthorizationV1NamespacedRoleList = void;
    type watchRbacAuthorizationV1NamespacedRole = void;
    type watchRbacAuthorizationV1RoleBindingListForAllNamespaces = void;
    type watchRbacAuthorizationV1RoleListForAllNamespaces = void;
    type getSchedulingAPIGroup = void;
    type getSchedulingV1APIResources = void;
    type listSchedulingV1PriorityClass = void;
    type createSchedulingV1PriorityClass = void;
    type deleteSchedulingV1CollectionPriorityClass = void;
    type readSchedulingV1PriorityClass = void;
    type replaceSchedulingV1PriorityClass = void;
    type deleteSchedulingV1PriorityClass = void;
    type patchSchedulingV1PriorityClass = void;
    type watchSchedulingV1PriorityClassList = void;
    type watchSchedulingV1PriorityClass = void;
    type getStorageAPIGroup = void;
    type getStorageV1APIResources = void;
    type listStorageV1CSIDriver = void;
    type createStorageV1CSIDriver = void;
    type deleteStorageV1CollectionCSIDriver = void;
    type readStorageV1CSIDriver = void;
    type replaceStorageV1CSIDriver = void;
    type deleteStorageV1CSIDriver = void;
    type patchStorageV1CSIDriver = void;
    type listStorageV1CSINode = void;
    type createStorageV1CSINode = void;
    type deleteStorageV1CollectionCSINode = void;
    type readStorageV1CSINode = void;
    type replaceStorageV1CSINode = void;
    type deleteStorageV1CSINode = void;
    type patchStorageV1CSINode = void;
    type listStorageV1StorageClass = void;
    type createStorageV1StorageClass = void;
    type deleteStorageV1CollectionStorageClass = void;
    type readStorageV1StorageClass = void;
    type replaceStorageV1StorageClass = void;
    type deleteStorageV1StorageClass = void;
    type patchStorageV1StorageClass = void;
    type listStorageV1VolumeAttachment = void;
    type createStorageV1VolumeAttachment = void;
    type deleteStorageV1CollectionVolumeAttachment = void;
    type readStorageV1VolumeAttachment = void;
    type replaceStorageV1VolumeAttachment = void;
    type deleteStorageV1VolumeAttachment = void;
    type patchStorageV1VolumeAttachment = void;
    type readStorageV1VolumeAttachmentStatus = void;
    type replaceStorageV1VolumeAttachmentStatus = void;
    type patchStorageV1VolumeAttachmentStatus = void;
    type watchStorageV1CSIDriverList = void;
    type watchStorageV1CSIDriver = void;
    type watchStorageV1CSINodeList = void;
    type watchStorageV1CSINode = void;
    type watchStorageV1StorageClassList = void;
    type watchStorageV1StorageClass = void;
    type watchStorageV1VolumeAttachmentList = void;
    type watchStorageV1VolumeAttachment = void;
    type getStorageV1alpha1APIResources = void;
    type listStorageV1alpha1CSIStorageCapacityForAllNamespaces = void;
    type listStorageV1alpha1NamespacedCSIStorageCapacity = void;
    type createStorageV1alpha1NamespacedCSIStorageCapacity = void;
    type deleteStorageV1alpha1CollectionNamespacedCSIStorageCapacity = void;
    type readStorageV1alpha1NamespacedCSIStorageCapacity = void;
    type replaceStorageV1alpha1NamespacedCSIStorageCapacity = void;
    type deleteStorageV1alpha1NamespacedCSIStorageCapacity = void;
    type patchStorageV1alpha1NamespacedCSIStorageCapacity = void;
    type watchStorageV1alpha1CSIStorageCapacityListForAllNamespaces = void;
    type watchStorageV1alpha1NamespacedCSIStorageCapacityList = void;
    type watchStorageV1alpha1NamespacedCSIStorageCapacity = void;
    type getStorageV1beta1APIResources = void;
    type listStorageV1beta1CSIStorageCapacityForAllNamespaces = void;
    type listStorageV1beta1NamespacedCSIStorageCapacity = void;
    type createStorageV1beta1NamespacedCSIStorageCapacity = void;
    type deleteStorageV1beta1CollectionNamespacedCSIStorageCapacity = void;
    type readStorageV1beta1NamespacedCSIStorageCapacity = void;
    type replaceStorageV1beta1NamespacedCSIStorageCapacity = void;
    type deleteStorageV1beta1NamespacedCSIStorageCapacity = void;
    type patchStorageV1beta1NamespacedCSIStorageCapacity = void;
    type watchStorageV1beta1CSIStorageCapacityListForAllNamespaces = void;
    type watchStorageV1beta1NamespacedCSIStorageCapacityList = void;
    type watchStorageV1beta1NamespacedCSIStorageCapacity = void;
    type logFileListHandler = void;
    type logFileHandler = void;
    type getServiceAccountIssuerOpenIDKeyset = void;
    type getCodeVersion = void;
}
export interface ApiClient<RequestOption> {
    request: <T = SuccessResponses>(httpMethod: HttpMethod, url: string, headers: ObjectLike | any, requestBody: ObjectLike | any, queryParameters: QueryParameters | undefined, options?: RequestOption) => Promise<T>;
}
export declare class Client<RequestOption> {
    private apiClient;
    private baseUrl;
    constructor(apiClient: ApiClient<RequestOption>, baseUrl: string);
    /**
     * get service account issuer OpenID configuration, also known as the 'OIDC discovery doc'
     * operationId: getServiceAccountIssuerOpenIDConfiguration
     * Request URI: /.well-known/openid-configuration/
     */
    getServiceAccountIssuerOpenIDConfiguration(option?: RequestOption): Promise<Response$getServiceAccountIssuerOpenIDConfiguration$Status$200["application/json"]>;
    /**
     * get available API versions
     * operationId: getCoreAPIVersions
     * Request URI: /api/
     */
    getCoreAPIVersions<ResponseContentType extends ResponseContentType$getCoreAPIVersions>(params: Params$getCoreAPIVersions<ResponseContentType>, option?: RequestOption): Promise<Response$getCoreAPIVersions$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getCoreV1APIResources
     * Request URI: /api/v1/
     */
    getCoreV1APIResources<ResponseContentType extends ResponseContentType$getCoreV1APIResources>(params: Params$getCoreV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getCoreV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list objects of kind ComponentStatus
     * operationId: listCoreV1ComponentStatus
     * Request URI: /api/v1/componentstatuses
     */
    listCoreV1ComponentStatus<ResponseContentType extends ResponseContentType$listCoreV1ComponentStatus>(params: Params$listCoreV1ComponentStatus<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1ComponentStatus$Status$200[ResponseContentType]>;
    /**
     * read the specified ComponentStatus
     * operationId: readCoreV1ComponentStatus
     * Request URI: /api/v1/componentstatuses/{name}
     */
    readCoreV1ComponentStatus<ResponseContentType extends ResponseContentType$readCoreV1ComponentStatus>(params: Params$readCoreV1ComponentStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1ComponentStatus$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind ConfigMap
     * operationId: listCoreV1ConfigMapForAllNamespaces
     * Request URI: /api/v1/configmaps
     */
    listCoreV1ConfigMapForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1ConfigMapForAllNamespaces>(params: Params$listCoreV1ConfigMapForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1ConfigMapForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Endpoints
     * operationId: listCoreV1EndpointsForAllNamespaces
     * Request URI: /api/v1/endpoints
     */
    listCoreV1EndpointsForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1EndpointsForAllNamespaces>(params: Params$listCoreV1EndpointsForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1EndpointsForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Event
     * operationId: listCoreV1EventForAllNamespaces
     * Request URI: /api/v1/events
     */
    listCoreV1EventForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1EventForAllNamespaces>(params: Params$listCoreV1EventForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1EventForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind LimitRange
     * operationId: listCoreV1LimitRangeForAllNamespaces
     * Request URI: /api/v1/limitranges
     */
    listCoreV1LimitRangeForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1LimitRangeForAllNamespaces>(params: Params$listCoreV1LimitRangeForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1LimitRangeForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Namespace
     * operationId: listCoreV1Namespace
     * Request URI: /api/v1/namespaces
     */
    listCoreV1Namespace<ResponseContentType extends ResponseContentType$listCoreV1Namespace>(params: Params$listCoreV1Namespace<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1Namespace$Status$200[ResponseContentType]>;
    /**
     * create a Namespace
     * operationId: createCoreV1Namespace
     * Request URI: /api/v1/namespaces
     */
    createCoreV1Namespace<ResponseContentType extends ResponseContentType$createCoreV1Namespace>(params: Params$createCoreV1Namespace<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1Namespace$Status$200 | Response$createCoreV1Namespace$Status$201 | Response$createCoreV1Namespace$Status$202)[ResponseContentType]>;
    /**
     * create a Binding
     * operationId: createCoreV1NamespacedBinding
     * Request URI: /api/v1/namespaces/{namespace}/bindings
     */
    createCoreV1NamespacedBinding<ResponseContentType extends ResponseContentType$createCoreV1NamespacedBinding>(params: Params$createCoreV1NamespacedBinding<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedBinding$Status$200 | Response$createCoreV1NamespacedBinding$Status$201 | Response$createCoreV1NamespacedBinding$Status$202)[ResponseContentType]>;
    /**
     * list or watch objects of kind ConfigMap
     * operationId: listCoreV1NamespacedConfigMap
     * Request URI: /api/v1/namespaces/{namespace}/configmaps
     */
    listCoreV1NamespacedConfigMap<ResponseContentType extends ResponseContentType$listCoreV1NamespacedConfigMap>(params: Params$listCoreV1NamespacedConfigMap<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedConfigMap$Status$200[ResponseContentType]>;
    /**
     * create a ConfigMap
     * operationId: createCoreV1NamespacedConfigMap
     * Request URI: /api/v1/namespaces/{namespace}/configmaps
     */
    createCoreV1NamespacedConfigMap<ResponseContentType extends ResponseContentType$createCoreV1NamespacedConfigMap>(params: Params$createCoreV1NamespacedConfigMap<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedConfigMap$Status$200 | Response$createCoreV1NamespacedConfigMap$Status$201 | Response$createCoreV1NamespacedConfigMap$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ConfigMap
     * operationId: deleteCoreV1CollectionNamespacedConfigMap
     * Request URI: /api/v1/namespaces/{namespace}/configmaps
     */
    deleteCoreV1CollectionNamespacedConfigMap<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedConfigMap>(params: Params$deleteCoreV1CollectionNamespacedConfigMap<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedConfigMap$Status$200[ResponseContentType]>;
    /**
     * read the specified ConfigMap
     * operationId: readCoreV1NamespacedConfigMap
     * Request URI: /api/v1/namespaces/{namespace}/configmaps/{name}
     */
    readCoreV1NamespacedConfigMap<ResponseContentType extends ResponseContentType$readCoreV1NamespacedConfigMap>(params: Params$readCoreV1NamespacedConfigMap<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedConfigMap$Status$200[ResponseContentType]>;
    /**
     * replace the specified ConfigMap
     * operationId: replaceCoreV1NamespacedConfigMap
     * Request URI: /api/v1/namespaces/{namespace}/configmaps/{name}
     */
    replaceCoreV1NamespacedConfigMap<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedConfigMap>(params: Params$replaceCoreV1NamespacedConfigMap<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedConfigMap$Status$200 | Response$replaceCoreV1NamespacedConfigMap$Status$201)[ResponseContentType]>;
    /**
     * delete a ConfigMap
     * operationId: deleteCoreV1NamespacedConfigMap
     * Request URI: /api/v1/namespaces/{namespace}/configmaps/{name}
     */
    deleteCoreV1NamespacedConfigMap<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedConfigMap>(params: Params$deleteCoreV1NamespacedConfigMap<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedConfigMap$Status$200 | Response$deleteCoreV1NamespacedConfigMap$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ConfigMap
     * operationId: patchCoreV1NamespacedConfigMap
     * Request URI: /api/v1/namespaces/{namespace}/configmaps/{name}
     */
    patchCoreV1NamespacedConfigMap<RequestContentType extends RequestContentType$patchCoreV1NamespacedConfigMap, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedConfigMap>(params: Params$patchCoreV1NamespacedConfigMap<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedConfigMap$Status$200 | Response$patchCoreV1NamespacedConfigMap$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind Endpoints
     * operationId: listCoreV1NamespacedEndpoints
     * Request URI: /api/v1/namespaces/{namespace}/endpoints
     */
    listCoreV1NamespacedEndpoints<ResponseContentType extends ResponseContentType$listCoreV1NamespacedEndpoints>(params: Params$listCoreV1NamespacedEndpoints<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedEndpoints$Status$200[ResponseContentType]>;
    /**
     * create Endpoints
     * operationId: createCoreV1NamespacedEndpoints
     * Request URI: /api/v1/namespaces/{namespace}/endpoints
     */
    createCoreV1NamespacedEndpoints<ResponseContentType extends ResponseContentType$createCoreV1NamespacedEndpoints>(params: Params$createCoreV1NamespacedEndpoints<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedEndpoints$Status$200 | Response$createCoreV1NamespacedEndpoints$Status$201 | Response$createCoreV1NamespacedEndpoints$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Endpoints
     * operationId: deleteCoreV1CollectionNamespacedEndpoints
     * Request URI: /api/v1/namespaces/{namespace}/endpoints
     */
    deleteCoreV1CollectionNamespacedEndpoints<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedEndpoints>(params: Params$deleteCoreV1CollectionNamespacedEndpoints<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedEndpoints$Status$200[ResponseContentType]>;
    /**
     * read the specified Endpoints
     * operationId: readCoreV1NamespacedEndpoints
     * Request URI: /api/v1/namespaces/{namespace}/endpoints/{name}
     */
    readCoreV1NamespacedEndpoints<ResponseContentType extends ResponseContentType$readCoreV1NamespacedEndpoints>(params: Params$readCoreV1NamespacedEndpoints<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedEndpoints$Status$200[ResponseContentType]>;
    /**
     * replace the specified Endpoints
     * operationId: replaceCoreV1NamespacedEndpoints
     * Request URI: /api/v1/namespaces/{namespace}/endpoints/{name}
     */
    replaceCoreV1NamespacedEndpoints<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedEndpoints>(params: Params$replaceCoreV1NamespacedEndpoints<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedEndpoints$Status$200 | Response$replaceCoreV1NamespacedEndpoints$Status$201)[ResponseContentType]>;
    /**
     * delete Endpoints
     * operationId: deleteCoreV1NamespacedEndpoints
     * Request URI: /api/v1/namespaces/{namespace}/endpoints/{name}
     */
    deleteCoreV1NamespacedEndpoints<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedEndpoints>(params: Params$deleteCoreV1NamespacedEndpoints<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedEndpoints$Status$200 | Response$deleteCoreV1NamespacedEndpoints$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Endpoints
     * operationId: patchCoreV1NamespacedEndpoints
     * Request URI: /api/v1/namespaces/{namespace}/endpoints/{name}
     */
    patchCoreV1NamespacedEndpoints<RequestContentType extends RequestContentType$patchCoreV1NamespacedEndpoints, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedEndpoints>(params: Params$patchCoreV1NamespacedEndpoints<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedEndpoints$Status$200 | Response$patchCoreV1NamespacedEndpoints$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind Event
     * operationId: listCoreV1NamespacedEvent
     * Request URI: /api/v1/namespaces/{namespace}/events
     */
    listCoreV1NamespacedEvent<ResponseContentType extends ResponseContentType$listCoreV1NamespacedEvent>(params: Params$listCoreV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedEvent$Status$200[ResponseContentType]>;
    /**
     * create an Event
     * operationId: createCoreV1NamespacedEvent
     * Request URI: /api/v1/namespaces/{namespace}/events
     */
    createCoreV1NamespacedEvent<ResponseContentType extends ResponseContentType$createCoreV1NamespacedEvent>(params: Params$createCoreV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedEvent$Status$200 | Response$createCoreV1NamespacedEvent$Status$201 | Response$createCoreV1NamespacedEvent$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Event
     * operationId: deleteCoreV1CollectionNamespacedEvent
     * Request URI: /api/v1/namespaces/{namespace}/events
     */
    deleteCoreV1CollectionNamespacedEvent<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedEvent>(params: Params$deleteCoreV1CollectionNamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedEvent$Status$200[ResponseContentType]>;
    /**
     * read the specified Event
     * operationId: readCoreV1NamespacedEvent
     * Request URI: /api/v1/namespaces/{namespace}/events/{name}
     */
    readCoreV1NamespacedEvent<ResponseContentType extends ResponseContentType$readCoreV1NamespacedEvent>(params: Params$readCoreV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedEvent$Status$200[ResponseContentType]>;
    /**
     * replace the specified Event
     * operationId: replaceCoreV1NamespacedEvent
     * Request URI: /api/v1/namespaces/{namespace}/events/{name}
     */
    replaceCoreV1NamespacedEvent<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedEvent>(params: Params$replaceCoreV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedEvent$Status$200 | Response$replaceCoreV1NamespacedEvent$Status$201)[ResponseContentType]>;
    /**
     * delete an Event
     * operationId: deleteCoreV1NamespacedEvent
     * Request URI: /api/v1/namespaces/{namespace}/events/{name}
     */
    deleteCoreV1NamespacedEvent<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedEvent>(params: Params$deleteCoreV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedEvent$Status$200 | Response$deleteCoreV1NamespacedEvent$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Event
     * operationId: patchCoreV1NamespacedEvent
     * Request URI: /api/v1/namespaces/{namespace}/events/{name}
     */
    patchCoreV1NamespacedEvent<RequestContentType extends RequestContentType$patchCoreV1NamespacedEvent, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedEvent>(params: Params$patchCoreV1NamespacedEvent<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedEvent$Status$200 | Response$patchCoreV1NamespacedEvent$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind LimitRange
     * operationId: listCoreV1NamespacedLimitRange
     * Request URI: /api/v1/namespaces/{namespace}/limitranges
     */
    listCoreV1NamespacedLimitRange<ResponseContentType extends ResponseContentType$listCoreV1NamespacedLimitRange>(params: Params$listCoreV1NamespacedLimitRange<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedLimitRange$Status$200[ResponseContentType]>;
    /**
     * create a LimitRange
     * operationId: createCoreV1NamespacedLimitRange
     * Request URI: /api/v1/namespaces/{namespace}/limitranges
     */
    createCoreV1NamespacedLimitRange<ResponseContentType extends ResponseContentType$createCoreV1NamespacedLimitRange>(params: Params$createCoreV1NamespacedLimitRange<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedLimitRange$Status$200 | Response$createCoreV1NamespacedLimitRange$Status$201 | Response$createCoreV1NamespacedLimitRange$Status$202)[ResponseContentType]>;
    /**
     * delete collection of LimitRange
     * operationId: deleteCoreV1CollectionNamespacedLimitRange
     * Request URI: /api/v1/namespaces/{namespace}/limitranges
     */
    deleteCoreV1CollectionNamespacedLimitRange<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedLimitRange>(params: Params$deleteCoreV1CollectionNamespacedLimitRange<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedLimitRange$Status$200[ResponseContentType]>;
    /**
     * read the specified LimitRange
     * operationId: readCoreV1NamespacedLimitRange
     * Request URI: /api/v1/namespaces/{namespace}/limitranges/{name}
     */
    readCoreV1NamespacedLimitRange<ResponseContentType extends ResponseContentType$readCoreV1NamespacedLimitRange>(params: Params$readCoreV1NamespacedLimitRange<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedLimitRange$Status$200[ResponseContentType]>;
    /**
     * replace the specified LimitRange
     * operationId: replaceCoreV1NamespacedLimitRange
     * Request URI: /api/v1/namespaces/{namespace}/limitranges/{name}
     */
    replaceCoreV1NamespacedLimitRange<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedLimitRange>(params: Params$replaceCoreV1NamespacedLimitRange<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedLimitRange$Status$200 | Response$replaceCoreV1NamespacedLimitRange$Status$201)[ResponseContentType]>;
    /**
     * delete a LimitRange
     * operationId: deleteCoreV1NamespacedLimitRange
     * Request URI: /api/v1/namespaces/{namespace}/limitranges/{name}
     */
    deleteCoreV1NamespacedLimitRange<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedLimitRange>(params: Params$deleteCoreV1NamespacedLimitRange<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedLimitRange$Status$200 | Response$deleteCoreV1NamespacedLimitRange$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified LimitRange
     * operationId: patchCoreV1NamespacedLimitRange
     * Request URI: /api/v1/namespaces/{namespace}/limitranges/{name}
     */
    patchCoreV1NamespacedLimitRange<RequestContentType extends RequestContentType$patchCoreV1NamespacedLimitRange, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedLimitRange>(params: Params$patchCoreV1NamespacedLimitRange<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedLimitRange$Status$200 | Response$patchCoreV1NamespacedLimitRange$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind PersistentVolumeClaim
     * operationId: listCoreV1NamespacedPersistentVolumeClaim
     * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims
     */
    listCoreV1NamespacedPersistentVolumeClaim<ResponseContentType extends ResponseContentType$listCoreV1NamespacedPersistentVolumeClaim>(params: Params$listCoreV1NamespacedPersistentVolumeClaim<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedPersistentVolumeClaim$Status$200[ResponseContentType]>;
    /**
     * create a PersistentVolumeClaim
     * operationId: createCoreV1NamespacedPersistentVolumeClaim
     * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims
     */
    createCoreV1NamespacedPersistentVolumeClaim<ResponseContentType extends ResponseContentType$createCoreV1NamespacedPersistentVolumeClaim>(params: Params$createCoreV1NamespacedPersistentVolumeClaim<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedPersistentVolumeClaim$Status$200 | Response$createCoreV1NamespacedPersistentVolumeClaim$Status$201 | Response$createCoreV1NamespacedPersistentVolumeClaim$Status$202)[ResponseContentType]>;
    /**
     * delete collection of PersistentVolumeClaim
     * operationId: deleteCoreV1CollectionNamespacedPersistentVolumeClaim
     * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims
     */
    deleteCoreV1CollectionNamespacedPersistentVolumeClaim<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedPersistentVolumeClaim>(params: Params$deleteCoreV1CollectionNamespacedPersistentVolumeClaim<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedPersistentVolumeClaim$Status$200[ResponseContentType]>;
    /**
     * read the specified PersistentVolumeClaim
     * operationId: readCoreV1NamespacedPersistentVolumeClaim
     * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims/{name}
     */
    readCoreV1NamespacedPersistentVolumeClaim<ResponseContentType extends ResponseContentType$readCoreV1NamespacedPersistentVolumeClaim>(params: Params$readCoreV1NamespacedPersistentVolumeClaim<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedPersistentVolumeClaim$Status$200[ResponseContentType]>;
    /**
     * replace the specified PersistentVolumeClaim
     * operationId: replaceCoreV1NamespacedPersistentVolumeClaim
     * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims/{name}
     */
    replaceCoreV1NamespacedPersistentVolumeClaim<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedPersistentVolumeClaim>(params: Params$replaceCoreV1NamespacedPersistentVolumeClaim<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedPersistentVolumeClaim$Status$200 | Response$replaceCoreV1NamespacedPersistentVolumeClaim$Status$201)[ResponseContentType]>;
    /**
     * delete a PersistentVolumeClaim
     * operationId: deleteCoreV1NamespacedPersistentVolumeClaim
     * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims/{name}
     */
    deleteCoreV1NamespacedPersistentVolumeClaim<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedPersistentVolumeClaim>(params: Params$deleteCoreV1NamespacedPersistentVolumeClaim<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedPersistentVolumeClaim$Status$200 | Response$deleteCoreV1NamespacedPersistentVolumeClaim$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified PersistentVolumeClaim
     * operationId: patchCoreV1NamespacedPersistentVolumeClaim
     * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims/{name}
     */
    patchCoreV1NamespacedPersistentVolumeClaim<RequestContentType extends RequestContentType$patchCoreV1NamespacedPersistentVolumeClaim, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedPersistentVolumeClaim>(params: Params$patchCoreV1NamespacedPersistentVolumeClaim<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedPersistentVolumeClaim$Status$200 | Response$patchCoreV1NamespacedPersistentVolumeClaim$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified PersistentVolumeClaim
     * operationId: readCoreV1NamespacedPersistentVolumeClaimStatus
     * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims/{name}/status
     */
    readCoreV1NamespacedPersistentVolumeClaimStatus<ResponseContentType extends ResponseContentType$readCoreV1NamespacedPersistentVolumeClaimStatus>(params: Params$readCoreV1NamespacedPersistentVolumeClaimStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedPersistentVolumeClaimStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified PersistentVolumeClaim
     * operationId: replaceCoreV1NamespacedPersistentVolumeClaimStatus
     * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims/{name}/status
     */
    replaceCoreV1NamespacedPersistentVolumeClaimStatus<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedPersistentVolumeClaimStatus>(params: Params$replaceCoreV1NamespacedPersistentVolumeClaimStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedPersistentVolumeClaimStatus$Status$200 | Response$replaceCoreV1NamespacedPersistentVolumeClaimStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified PersistentVolumeClaim
     * operationId: patchCoreV1NamespacedPersistentVolumeClaimStatus
     * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims/{name}/status
     */
    patchCoreV1NamespacedPersistentVolumeClaimStatus<RequestContentType extends RequestContentType$patchCoreV1NamespacedPersistentVolumeClaimStatus, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedPersistentVolumeClaimStatus>(params: Params$patchCoreV1NamespacedPersistentVolumeClaimStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedPersistentVolumeClaimStatus$Status$200 | Response$patchCoreV1NamespacedPersistentVolumeClaimStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind Pod
     * operationId: listCoreV1NamespacedPod
     * Request URI: /api/v1/namespaces/{namespace}/pods
     */
    listCoreV1NamespacedPod<ResponseContentType extends ResponseContentType$listCoreV1NamespacedPod>(params: Params$listCoreV1NamespacedPod<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedPod$Status$200[ResponseContentType]>;
    /**
     * create a Pod
     * operationId: createCoreV1NamespacedPod
     * Request URI: /api/v1/namespaces/{namespace}/pods
     */
    createCoreV1NamespacedPod<ResponseContentType extends ResponseContentType$createCoreV1NamespacedPod>(params: Params$createCoreV1NamespacedPod<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedPod$Status$200 | Response$createCoreV1NamespacedPod$Status$201 | Response$createCoreV1NamespacedPod$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Pod
     * operationId: deleteCoreV1CollectionNamespacedPod
     * Request URI: /api/v1/namespaces/{namespace}/pods
     */
    deleteCoreV1CollectionNamespacedPod<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedPod>(params: Params$deleteCoreV1CollectionNamespacedPod<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedPod$Status$200[ResponseContentType]>;
    /**
     * read the specified Pod
     * operationId: readCoreV1NamespacedPod
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}
     */
    readCoreV1NamespacedPod<ResponseContentType extends ResponseContentType$readCoreV1NamespacedPod>(params: Params$readCoreV1NamespacedPod<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedPod$Status$200[ResponseContentType]>;
    /**
     * replace the specified Pod
     * operationId: replaceCoreV1NamespacedPod
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}
     */
    replaceCoreV1NamespacedPod<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedPod>(params: Params$replaceCoreV1NamespacedPod<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedPod$Status$200 | Response$replaceCoreV1NamespacedPod$Status$201)[ResponseContentType]>;
    /**
     * delete a Pod
     * operationId: deleteCoreV1NamespacedPod
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}
     */
    deleteCoreV1NamespacedPod<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedPod>(params: Params$deleteCoreV1NamespacedPod<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedPod$Status$200 | Response$deleteCoreV1NamespacedPod$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Pod
     * operationId: patchCoreV1NamespacedPod
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}
     */
    patchCoreV1NamespacedPod<RequestContentType extends RequestContentType$patchCoreV1NamespacedPod, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedPod>(params: Params$patchCoreV1NamespacedPod<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedPod$Status$200 | Response$patchCoreV1NamespacedPod$Status$201)[ResponseContentType]>;
    /**
     * connect GET requests to attach of Pod
     * operationId: connectCoreV1GetNamespacedPodAttach
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/attach
     */
    connectCoreV1GetNamespacedPodAttach(params: Params$connectCoreV1GetNamespacedPodAttach, option?: RequestOption): Promise<Response$connectCoreV1GetNamespacedPodAttach$Status$200["*/*"]>;
    /**
     * connect POST requests to attach of Pod
     * operationId: connectCoreV1PostNamespacedPodAttach
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/attach
     */
    connectCoreV1PostNamespacedPodAttach(params: Params$connectCoreV1PostNamespacedPodAttach, option?: RequestOption): Promise<Response$connectCoreV1PostNamespacedPodAttach$Status$200["*/*"]>;
    /**
     * create binding of a Pod
     * operationId: createCoreV1NamespacedPodBinding
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/binding
     */
    createCoreV1NamespacedPodBinding<ResponseContentType extends ResponseContentType$createCoreV1NamespacedPodBinding>(params: Params$createCoreV1NamespacedPodBinding<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedPodBinding$Status$200 | Response$createCoreV1NamespacedPodBinding$Status$201 | Response$createCoreV1NamespacedPodBinding$Status$202)[ResponseContentType]>;
    /**
     * read ephemeralcontainers of the specified Pod
     * operationId: readCoreV1NamespacedPodEphemeralcontainers
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/ephemeralcontainers
     */
    readCoreV1NamespacedPodEphemeralcontainers<ResponseContentType extends ResponseContentType$readCoreV1NamespacedPodEphemeralcontainers>(params: Params$readCoreV1NamespacedPodEphemeralcontainers<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedPodEphemeralcontainers$Status$200[ResponseContentType]>;
    /**
     * replace ephemeralcontainers of the specified Pod
     * operationId: replaceCoreV1NamespacedPodEphemeralcontainers
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/ephemeralcontainers
     */
    replaceCoreV1NamespacedPodEphemeralcontainers<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedPodEphemeralcontainers>(params: Params$replaceCoreV1NamespacedPodEphemeralcontainers<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedPodEphemeralcontainers$Status$200 | Response$replaceCoreV1NamespacedPodEphemeralcontainers$Status$201)[ResponseContentType]>;
    /**
     * partially update ephemeralcontainers of the specified Pod
     * operationId: patchCoreV1NamespacedPodEphemeralcontainers
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/ephemeralcontainers
     */
    patchCoreV1NamespacedPodEphemeralcontainers<RequestContentType extends RequestContentType$patchCoreV1NamespacedPodEphemeralcontainers, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedPodEphemeralcontainers>(params: Params$patchCoreV1NamespacedPodEphemeralcontainers<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedPodEphemeralcontainers$Status$200 | Response$patchCoreV1NamespacedPodEphemeralcontainers$Status$201)[ResponseContentType]>;
    /**
     * create eviction of a Pod
     * operationId: createCoreV1NamespacedPodEviction
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/eviction
     */
    createCoreV1NamespacedPodEviction<ResponseContentType extends ResponseContentType$createCoreV1NamespacedPodEviction>(params: Params$createCoreV1NamespacedPodEviction<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedPodEviction$Status$200 | Response$createCoreV1NamespacedPodEviction$Status$201 | Response$createCoreV1NamespacedPodEviction$Status$202)[ResponseContentType]>;
    /**
     * connect GET requests to exec of Pod
     * operationId: connectCoreV1GetNamespacedPodExec
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/exec
     */
    connectCoreV1GetNamespacedPodExec(params: Params$connectCoreV1GetNamespacedPodExec, option?: RequestOption): Promise<Response$connectCoreV1GetNamespacedPodExec$Status$200["*/*"]>;
    /**
     * connect POST requests to exec of Pod
     * operationId: connectCoreV1PostNamespacedPodExec
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/exec
     */
    connectCoreV1PostNamespacedPodExec(params: Params$connectCoreV1PostNamespacedPodExec, option?: RequestOption): Promise<Response$connectCoreV1PostNamespacedPodExec$Status$200["*/*"]>;
    /**
     * read log of the specified Pod
     * operationId: readCoreV1NamespacedPodLog
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/log
     */
    readCoreV1NamespacedPodLog<ResponseContentType extends ResponseContentType$readCoreV1NamespacedPodLog>(params: Params$readCoreV1NamespacedPodLog<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedPodLog$Status$200[ResponseContentType]>;
    /**
     * connect GET requests to portforward of Pod
     * operationId: connectCoreV1GetNamespacedPodPortforward
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/portforward
     */
    connectCoreV1GetNamespacedPodPortforward(params: Params$connectCoreV1GetNamespacedPodPortforward, option?: RequestOption): Promise<Response$connectCoreV1GetNamespacedPodPortforward$Status$200["*/*"]>;
    /**
     * connect POST requests to portforward of Pod
     * operationId: connectCoreV1PostNamespacedPodPortforward
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/portforward
     */
    connectCoreV1PostNamespacedPodPortforward(params: Params$connectCoreV1PostNamespacedPodPortforward, option?: RequestOption): Promise<Response$connectCoreV1PostNamespacedPodPortforward$Status$200["*/*"]>;
    /**
     * connect GET requests to proxy of Pod
     * operationId: connectCoreV1GetNamespacedPodProxy
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy
     */
    connectCoreV1GetNamespacedPodProxy(params: Params$connectCoreV1GetNamespacedPodProxy, option?: RequestOption): Promise<Response$connectCoreV1GetNamespacedPodProxy$Status$200["*/*"]>;
    /**
     * connect PUT requests to proxy of Pod
     * operationId: connectCoreV1PutNamespacedPodProxy
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy
     */
    connectCoreV1PutNamespacedPodProxy(params: Params$connectCoreV1PutNamespacedPodProxy, option?: RequestOption): Promise<Response$connectCoreV1PutNamespacedPodProxy$Status$200["*/*"]>;
    /**
     * connect POST requests to proxy of Pod
     * operationId: connectCoreV1PostNamespacedPodProxy
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy
     */
    connectCoreV1PostNamespacedPodProxy(params: Params$connectCoreV1PostNamespacedPodProxy, option?: RequestOption): Promise<Response$connectCoreV1PostNamespacedPodProxy$Status$200["*/*"]>;
    /**
     * connect DELETE requests to proxy of Pod
     * operationId: connectCoreV1DeleteNamespacedPodProxy
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy
     */
    connectCoreV1DeleteNamespacedPodProxy(params: Params$connectCoreV1DeleteNamespacedPodProxy, option?: RequestOption): Promise<Response$connectCoreV1DeleteNamespacedPodProxy$Status$200["*/*"]>;
    /**
     * connect OPTIONS requests to proxy of Pod
     * operationId: connectCoreV1OptionsNamespacedPodProxy
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy
     */
    connectCoreV1OptionsNamespacedPodProxy(params: Params$connectCoreV1OptionsNamespacedPodProxy, option?: RequestOption): Promise<Response$connectCoreV1OptionsNamespacedPodProxy$Status$200["*/*"]>;
    /**
     * connect HEAD requests to proxy of Pod
     * operationId: connectCoreV1HeadNamespacedPodProxy
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy
     */
    connectCoreV1HeadNamespacedPodProxy(params: Params$connectCoreV1HeadNamespacedPodProxy, option?: RequestOption): Promise<Response$connectCoreV1HeadNamespacedPodProxy$Status$200["*/*"]>;
    /**
     * connect PATCH requests to proxy of Pod
     * operationId: connectCoreV1PatchNamespacedPodProxy
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy
     */
    connectCoreV1PatchNamespacedPodProxy(params: Params$connectCoreV1PatchNamespacedPodProxy, option?: RequestOption): Promise<Response$connectCoreV1PatchNamespacedPodProxy$Status$200["*/*"]>;
    /**
     * connect GET requests to proxy of Pod
     * operationId: connectCoreV1GetNamespacedPodProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy/{path}
     */
    connectCoreV1GetNamespacedPodProxyWithPath(params: Params$connectCoreV1GetNamespacedPodProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1GetNamespacedPodProxyWithPath$Status$200["*/*"]>;
    /**
     * connect PUT requests to proxy of Pod
     * operationId: connectCoreV1PutNamespacedPodProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy/{path}
     */
    connectCoreV1PutNamespacedPodProxyWithPath(params: Params$connectCoreV1PutNamespacedPodProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1PutNamespacedPodProxyWithPath$Status$200["*/*"]>;
    /**
     * connect POST requests to proxy of Pod
     * operationId: connectCoreV1PostNamespacedPodProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy/{path}
     */
    connectCoreV1PostNamespacedPodProxyWithPath(params: Params$connectCoreV1PostNamespacedPodProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1PostNamespacedPodProxyWithPath$Status$200["*/*"]>;
    /**
     * connect DELETE requests to proxy of Pod
     * operationId: connectCoreV1DeleteNamespacedPodProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy/{path}
     */
    connectCoreV1DeleteNamespacedPodProxyWithPath(params: Params$connectCoreV1DeleteNamespacedPodProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1DeleteNamespacedPodProxyWithPath$Status$200["*/*"]>;
    /**
     * connect OPTIONS requests to proxy of Pod
     * operationId: connectCoreV1OptionsNamespacedPodProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy/{path}
     */
    connectCoreV1OptionsNamespacedPodProxyWithPath(params: Params$connectCoreV1OptionsNamespacedPodProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1OptionsNamespacedPodProxyWithPath$Status$200["*/*"]>;
    /**
     * connect HEAD requests to proxy of Pod
     * operationId: connectCoreV1HeadNamespacedPodProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy/{path}
     */
    connectCoreV1HeadNamespacedPodProxyWithPath(params: Params$connectCoreV1HeadNamespacedPodProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1HeadNamespacedPodProxyWithPath$Status$200["*/*"]>;
    /**
     * connect PATCH requests to proxy of Pod
     * operationId: connectCoreV1PatchNamespacedPodProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy/{path}
     */
    connectCoreV1PatchNamespacedPodProxyWithPath(params: Params$connectCoreV1PatchNamespacedPodProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1PatchNamespacedPodProxyWithPath$Status$200["*/*"]>;
    /**
     * read status of the specified Pod
     * operationId: readCoreV1NamespacedPodStatus
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/status
     */
    readCoreV1NamespacedPodStatus<ResponseContentType extends ResponseContentType$readCoreV1NamespacedPodStatus>(params: Params$readCoreV1NamespacedPodStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedPodStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified Pod
     * operationId: replaceCoreV1NamespacedPodStatus
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/status
     */
    replaceCoreV1NamespacedPodStatus<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedPodStatus>(params: Params$replaceCoreV1NamespacedPodStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedPodStatus$Status$200 | Response$replaceCoreV1NamespacedPodStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified Pod
     * operationId: patchCoreV1NamespacedPodStatus
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/status
     */
    patchCoreV1NamespacedPodStatus<RequestContentType extends RequestContentType$patchCoreV1NamespacedPodStatus, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedPodStatus>(params: Params$patchCoreV1NamespacedPodStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedPodStatus$Status$200 | Response$patchCoreV1NamespacedPodStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind PodTemplate
     * operationId: listCoreV1NamespacedPodTemplate
     * Request URI: /api/v1/namespaces/{namespace}/podtemplates
     */
    listCoreV1NamespacedPodTemplate<ResponseContentType extends ResponseContentType$listCoreV1NamespacedPodTemplate>(params: Params$listCoreV1NamespacedPodTemplate<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedPodTemplate$Status$200[ResponseContentType]>;
    /**
     * create a PodTemplate
     * operationId: createCoreV1NamespacedPodTemplate
     * Request URI: /api/v1/namespaces/{namespace}/podtemplates
     */
    createCoreV1NamespacedPodTemplate<ResponseContentType extends ResponseContentType$createCoreV1NamespacedPodTemplate>(params: Params$createCoreV1NamespacedPodTemplate<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedPodTemplate$Status$200 | Response$createCoreV1NamespacedPodTemplate$Status$201 | Response$createCoreV1NamespacedPodTemplate$Status$202)[ResponseContentType]>;
    /**
     * delete collection of PodTemplate
     * operationId: deleteCoreV1CollectionNamespacedPodTemplate
     * Request URI: /api/v1/namespaces/{namespace}/podtemplates
     */
    deleteCoreV1CollectionNamespacedPodTemplate<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedPodTemplate>(params: Params$deleteCoreV1CollectionNamespacedPodTemplate<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedPodTemplate$Status$200[ResponseContentType]>;
    /**
     * read the specified PodTemplate
     * operationId: readCoreV1NamespacedPodTemplate
     * Request URI: /api/v1/namespaces/{namespace}/podtemplates/{name}
     */
    readCoreV1NamespacedPodTemplate<ResponseContentType extends ResponseContentType$readCoreV1NamespacedPodTemplate>(params: Params$readCoreV1NamespacedPodTemplate<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedPodTemplate$Status$200[ResponseContentType]>;
    /**
     * replace the specified PodTemplate
     * operationId: replaceCoreV1NamespacedPodTemplate
     * Request URI: /api/v1/namespaces/{namespace}/podtemplates/{name}
     */
    replaceCoreV1NamespacedPodTemplate<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedPodTemplate>(params: Params$replaceCoreV1NamespacedPodTemplate<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedPodTemplate$Status$200 | Response$replaceCoreV1NamespacedPodTemplate$Status$201)[ResponseContentType]>;
    /**
     * delete a PodTemplate
     * operationId: deleteCoreV1NamespacedPodTemplate
     * Request URI: /api/v1/namespaces/{namespace}/podtemplates/{name}
     */
    deleteCoreV1NamespacedPodTemplate<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedPodTemplate>(params: Params$deleteCoreV1NamespacedPodTemplate<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedPodTemplate$Status$200 | Response$deleteCoreV1NamespacedPodTemplate$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified PodTemplate
     * operationId: patchCoreV1NamespacedPodTemplate
     * Request URI: /api/v1/namespaces/{namespace}/podtemplates/{name}
     */
    patchCoreV1NamespacedPodTemplate<RequestContentType extends RequestContentType$patchCoreV1NamespacedPodTemplate, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedPodTemplate>(params: Params$patchCoreV1NamespacedPodTemplate<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedPodTemplate$Status$200 | Response$patchCoreV1NamespacedPodTemplate$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind ReplicationController
     * operationId: listCoreV1NamespacedReplicationController
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers
     */
    listCoreV1NamespacedReplicationController<ResponseContentType extends ResponseContentType$listCoreV1NamespacedReplicationController>(params: Params$listCoreV1NamespacedReplicationController<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedReplicationController$Status$200[ResponseContentType]>;
    /**
     * create a ReplicationController
     * operationId: createCoreV1NamespacedReplicationController
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers
     */
    createCoreV1NamespacedReplicationController<ResponseContentType extends ResponseContentType$createCoreV1NamespacedReplicationController>(params: Params$createCoreV1NamespacedReplicationController<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedReplicationController$Status$200 | Response$createCoreV1NamespacedReplicationController$Status$201 | Response$createCoreV1NamespacedReplicationController$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ReplicationController
     * operationId: deleteCoreV1CollectionNamespacedReplicationController
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers
     */
    deleteCoreV1CollectionNamespacedReplicationController<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedReplicationController>(params: Params$deleteCoreV1CollectionNamespacedReplicationController<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedReplicationController$Status$200[ResponseContentType]>;
    /**
     * read the specified ReplicationController
     * operationId: readCoreV1NamespacedReplicationController
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}
     */
    readCoreV1NamespacedReplicationController<ResponseContentType extends ResponseContentType$readCoreV1NamespacedReplicationController>(params: Params$readCoreV1NamespacedReplicationController<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedReplicationController$Status$200[ResponseContentType]>;
    /**
     * replace the specified ReplicationController
     * operationId: replaceCoreV1NamespacedReplicationController
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}
     */
    replaceCoreV1NamespacedReplicationController<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedReplicationController>(params: Params$replaceCoreV1NamespacedReplicationController<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedReplicationController$Status$200 | Response$replaceCoreV1NamespacedReplicationController$Status$201)[ResponseContentType]>;
    /**
     * delete a ReplicationController
     * operationId: deleteCoreV1NamespacedReplicationController
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}
     */
    deleteCoreV1NamespacedReplicationController<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedReplicationController>(params: Params$deleteCoreV1NamespacedReplicationController<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedReplicationController$Status$200 | Response$deleteCoreV1NamespacedReplicationController$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ReplicationController
     * operationId: patchCoreV1NamespacedReplicationController
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}
     */
    patchCoreV1NamespacedReplicationController<RequestContentType extends RequestContentType$patchCoreV1NamespacedReplicationController, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedReplicationController>(params: Params$patchCoreV1NamespacedReplicationController<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedReplicationController$Status$200 | Response$patchCoreV1NamespacedReplicationController$Status$201)[ResponseContentType]>;
    /**
     * read scale of the specified ReplicationController
     * operationId: readCoreV1NamespacedReplicationControllerScale
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}/scale
     */
    readCoreV1NamespacedReplicationControllerScale<ResponseContentType extends ResponseContentType$readCoreV1NamespacedReplicationControllerScale>(params: Params$readCoreV1NamespacedReplicationControllerScale<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedReplicationControllerScale$Status$200[ResponseContentType]>;
    /**
     * replace scale of the specified ReplicationController
     * operationId: replaceCoreV1NamespacedReplicationControllerScale
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}/scale
     */
    replaceCoreV1NamespacedReplicationControllerScale<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedReplicationControllerScale>(params: Params$replaceCoreV1NamespacedReplicationControllerScale<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedReplicationControllerScale$Status$200 | Response$replaceCoreV1NamespacedReplicationControllerScale$Status$201)[ResponseContentType]>;
    /**
     * partially update scale of the specified ReplicationController
     * operationId: patchCoreV1NamespacedReplicationControllerScale
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}/scale
     */
    patchCoreV1NamespacedReplicationControllerScale<RequestContentType extends RequestContentType$patchCoreV1NamespacedReplicationControllerScale, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedReplicationControllerScale>(params: Params$patchCoreV1NamespacedReplicationControllerScale<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedReplicationControllerScale$Status$200 | Response$patchCoreV1NamespacedReplicationControllerScale$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified ReplicationController
     * operationId: readCoreV1NamespacedReplicationControllerStatus
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}/status
     */
    readCoreV1NamespacedReplicationControllerStatus<ResponseContentType extends ResponseContentType$readCoreV1NamespacedReplicationControllerStatus>(params: Params$readCoreV1NamespacedReplicationControllerStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedReplicationControllerStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified ReplicationController
     * operationId: replaceCoreV1NamespacedReplicationControllerStatus
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}/status
     */
    replaceCoreV1NamespacedReplicationControllerStatus<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedReplicationControllerStatus>(params: Params$replaceCoreV1NamespacedReplicationControllerStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedReplicationControllerStatus$Status$200 | Response$replaceCoreV1NamespacedReplicationControllerStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified ReplicationController
     * operationId: patchCoreV1NamespacedReplicationControllerStatus
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}/status
     */
    patchCoreV1NamespacedReplicationControllerStatus<RequestContentType extends RequestContentType$patchCoreV1NamespacedReplicationControllerStatus, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedReplicationControllerStatus>(params: Params$patchCoreV1NamespacedReplicationControllerStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedReplicationControllerStatus$Status$200 | Response$patchCoreV1NamespacedReplicationControllerStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind ResourceQuota
     * operationId: listCoreV1NamespacedResourceQuota
     * Request URI: /api/v1/namespaces/{namespace}/resourcequotas
     */
    listCoreV1NamespacedResourceQuota<ResponseContentType extends ResponseContentType$listCoreV1NamespacedResourceQuota>(params: Params$listCoreV1NamespacedResourceQuota<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedResourceQuota$Status$200[ResponseContentType]>;
    /**
     * create a ResourceQuota
     * operationId: createCoreV1NamespacedResourceQuota
     * Request URI: /api/v1/namespaces/{namespace}/resourcequotas
     */
    createCoreV1NamespacedResourceQuota<ResponseContentType extends ResponseContentType$createCoreV1NamespacedResourceQuota>(params: Params$createCoreV1NamespacedResourceQuota<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedResourceQuota$Status$200 | Response$createCoreV1NamespacedResourceQuota$Status$201 | Response$createCoreV1NamespacedResourceQuota$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ResourceQuota
     * operationId: deleteCoreV1CollectionNamespacedResourceQuota
     * Request URI: /api/v1/namespaces/{namespace}/resourcequotas
     */
    deleteCoreV1CollectionNamespacedResourceQuota<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedResourceQuota>(params: Params$deleteCoreV1CollectionNamespacedResourceQuota<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedResourceQuota$Status$200[ResponseContentType]>;
    /**
     * read the specified ResourceQuota
     * operationId: readCoreV1NamespacedResourceQuota
     * Request URI: /api/v1/namespaces/{namespace}/resourcequotas/{name}
     */
    readCoreV1NamespacedResourceQuota<ResponseContentType extends ResponseContentType$readCoreV1NamespacedResourceQuota>(params: Params$readCoreV1NamespacedResourceQuota<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedResourceQuota$Status$200[ResponseContentType]>;
    /**
     * replace the specified ResourceQuota
     * operationId: replaceCoreV1NamespacedResourceQuota
     * Request URI: /api/v1/namespaces/{namespace}/resourcequotas/{name}
     */
    replaceCoreV1NamespacedResourceQuota<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedResourceQuota>(params: Params$replaceCoreV1NamespacedResourceQuota<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedResourceQuota$Status$200 | Response$replaceCoreV1NamespacedResourceQuota$Status$201)[ResponseContentType]>;
    /**
     * delete a ResourceQuota
     * operationId: deleteCoreV1NamespacedResourceQuota
     * Request URI: /api/v1/namespaces/{namespace}/resourcequotas/{name}
     */
    deleteCoreV1NamespacedResourceQuota<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedResourceQuota>(params: Params$deleteCoreV1NamespacedResourceQuota<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedResourceQuota$Status$200 | Response$deleteCoreV1NamespacedResourceQuota$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ResourceQuota
     * operationId: patchCoreV1NamespacedResourceQuota
     * Request URI: /api/v1/namespaces/{namespace}/resourcequotas/{name}
     */
    patchCoreV1NamespacedResourceQuota<RequestContentType extends RequestContentType$patchCoreV1NamespacedResourceQuota, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedResourceQuota>(params: Params$patchCoreV1NamespacedResourceQuota<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedResourceQuota$Status$200 | Response$patchCoreV1NamespacedResourceQuota$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified ResourceQuota
     * operationId: readCoreV1NamespacedResourceQuotaStatus
     * Request URI: /api/v1/namespaces/{namespace}/resourcequotas/{name}/status
     */
    readCoreV1NamespacedResourceQuotaStatus<ResponseContentType extends ResponseContentType$readCoreV1NamespacedResourceQuotaStatus>(params: Params$readCoreV1NamespacedResourceQuotaStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedResourceQuotaStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified ResourceQuota
     * operationId: replaceCoreV1NamespacedResourceQuotaStatus
     * Request URI: /api/v1/namespaces/{namespace}/resourcequotas/{name}/status
     */
    replaceCoreV1NamespacedResourceQuotaStatus<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedResourceQuotaStatus>(params: Params$replaceCoreV1NamespacedResourceQuotaStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedResourceQuotaStatus$Status$200 | Response$replaceCoreV1NamespacedResourceQuotaStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified ResourceQuota
     * operationId: patchCoreV1NamespacedResourceQuotaStatus
     * Request URI: /api/v1/namespaces/{namespace}/resourcequotas/{name}/status
     */
    patchCoreV1NamespacedResourceQuotaStatus<RequestContentType extends RequestContentType$patchCoreV1NamespacedResourceQuotaStatus, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedResourceQuotaStatus>(params: Params$patchCoreV1NamespacedResourceQuotaStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedResourceQuotaStatus$Status$200 | Response$patchCoreV1NamespacedResourceQuotaStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind Secret
     * operationId: listCoreV1NamespacedSecret
     * Request URI: /api/v1/namespaces/{namespace}/secrets
     */
    listCoreV1NamespacedSecret<ResponseContentType extends ResponseContentType$listCoreV1NamespacedSecret>(params: Params$listCoreV1NamespacedSecret<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedSecret$Status$200[ResponseContentType]>;
    /**
     * create a Secret
     * operationId: createCoreV1NamespacedSecret
     * Request URI: /api/v1/namespaces/{namespace}/secrets
     */
    createCoreV1NamespacedSecret<ResponseContentType extends ResponseContentType$createCoreV1NamespacedSecret>(params: Params$createCoreV1NamespacedSecret<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedSecret$Status$200 | Response$createCoreV1NamespacedSecret$Status$201 | Response$createCoreV1NamespacedSecret$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Secret
     * operationId: deleteCoreV1CollectionNamespacedSecret
     * Request URI: /api/v1/namespaces/{namespace}/secrets
     */
    deleteCoreV1CollectionNamespacedSecret<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedSecret>(params: Params$deleteCoreV1CollectionNamespacedSecret<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedSecret$Status$200[ResponseContentType]>;
    /**
     * read the specified Secret
     * operationId: readCoreV1NamespacedSecret
     * Request URI: /api/v1/namespaces/{namespace}/secrets/{name}
     */
    readCoreV1NamespacedSecret<ResponseContentType extends ResponseContentType$readCoreV1NamespacedSecret>(params: Params$readCoreV1NamespacedSecret<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedSecret$Status$200[ResponseContentType]>;
    /**
     * replace the specified Secret
     * operationId: replaceCoreV1NamespacedSecret
     * Request URI: /api/v1/namespaces/{namespace}/secrets/{name}
     */
    replaceCoreV1NamespacedSecret<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedSecret>(params: Params$replaceCoreV1NamespacedSecret<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedSecret$Status$200 | Response$replaceCoreV1NamespacedSecret$Status$201)[ResponseContentType]>;
    /**
     * delete a Secret
     * operationId: deleteCoreV1NamespacedSecret
     * Request URI: /api/v1/namespaces/{namespace}/secrets/{name}
     */
    deleteCoreV1NamespacedSecret<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedSecret>(params: Params$deleteCoreV1NamespacedSecret<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedSecret$Status$200 | Response$deleteCoreV1NamespacedSecret$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Secret
     * operationId: patchCoreV1NamespacedSecret
     * Request URI: /api/v1/namespaces/{namespace}/secrets/{name}
     */
    patchCoreV1NamespacedSecret<RequestContentType extends RequestContentType$patchCoreV1NamespacedSecret, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedSecret>(params: Params$patchCoreV1NamespacedSecret<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedSecret$Status$200 | Response$patchCoreV1NamespacedSecret$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind ServiceAccount
     * operationId: listCoreV1NamespacedServiceAccount
     * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts
     */
    listCoreV1NamespacedServiceAccount<ResponseContentType extends ResponseContentType$listCoreV1NamespacedServiceAccount>(params: Params$listCoreV1NamespacedServiceAccount<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedServiceAccount$Status$200[ResponseContentType]>;
    /**
     * create a ServiceAccount
     * operationId: createCoreV1NamespacedServiceAccount
     * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts
     */
    createCoreV1NamespacedServiceAccount<ResponseContentType extends ResponseContentType$createCoreV1NamespacedServiceAccount>(params: Params$createCoreV1NamespacedServiceAccount<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedServiceAccount$Status$200 | Response$createCoreV1NamespacedServiceAccount$Status$201 | Response$createCoreV1NamespacedServiceAccount$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ServiceAccount
     * operationId: deleteCoreV1CollectionNamespacedServiceAccount
     * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts
     */
    deleteCoreV1CollectionNamespacedServiceAccount<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedServiceAccount>(params: Params$deleteCoreV1CollectionNamespacedServiceAccount<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedServiceAccount$Status$200[ResponseContentType]>;
    /**
     * read the specified ServiceAccount
     * operationId: readCoreV1NamespacedServiceAccount
     * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts/{name}
     */
    readCoreV1NamespacedServiceAccount<ResponseContentType extends ResponseContentType$readCoreV1NamespacedServiceAccount>(params: Params$readCoreV1NamespacedServiceAccount<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedServiceAccount$Status$200[ResponseContentType]>;
    /**
     * replace the specified ServiceAccount
     * operationId: replaceCoreV1NamespacedServiceAccount
     * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts/{name}
     */
    replaceCoreV1NamespacedServiceAccount<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedServiceAccount>(params: Params$replaceCoreV1NamespacedServiceAccount<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedServiceAccount$Status$200 | Response$replaceCoreV1NamespacedServiceAccount$Status$201)[ResponseContentType]>;
    /**
     * delete a ServiceAccount
     * operationId: deleteCoreV1NamespacedServiceAccount
     * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts/{name}
     */
    deleteCoreV1NamespacedServiceAccount<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedServiceAccount>(params: Params$deleteCoreV1NamespacedServiceAccount<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedServiceAccount$Status$200 | Response$deleteCoreV1NamespacedServiceAccount$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ServiceAccount
     * operationId: patchCoreV1NamespacedServiceAccount
     * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts/{name}
     */
    patchCoreV1NamespacedServiceAccount<RequestContentType extends RequestContentType$patchCoreV1NamespacedServiceAccount, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedServiceAccount>(params: Params$patchCoreV1NamespacedServiceAccount<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedServiceAccount$Status$200 | Response$patchCoreV1NamespacedServiceAccount$Status$201)[ResponseContentType]>;
    /**
     * create token of a ServiceAccount
     * operationId: createCoreV1NamespacedServiceAccountToken
     * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts/{name}/token
     */
    createCoreV1NamespacedServiceAccountToken<ResponseContentType extends ResponseContentType$createCoreV1NamespacedServiceAccountToken>(params: Params$createCoreV1NamespacedServiceAccountToken<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedServiceAccountToken$Status$200 | Response$createCoreV1NamespacedServiceAccountToken$Status$201 | Response$createCoreV1NamespacedServiceAccountToken$Status$202)[ResponseContentType]>;
    /**
     * list or watch objects of kind Service
     * operationId: listCoreV1NamespacedService
     * Request URI: /api/v1/namespaces/{namespace}/services
     */
    listCoreV1NamespacedService<ResponseContentType extends ResponseContentType$listCoreV1NamespacedService>(params: Params$listCoreV1NamespacedService<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedService$Status$200[ResponseContentType]>;
    /**
     * create a Service
     * operationId: createCoreV1NamespacedService
     * Request URI: /api/v1/namespaces/{namespace}/services
     */
    createCoreV1NamespacedService<ResponseContentType extends ResponseContentType$createCoreV1NamespacedService>(params: Params$createCoreV1NamespacedService<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedService$Status$200 | Response$createCoreV1NamespacedService$Status$201 | Response$createCoreV1NamespacedService$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Service
     * operationId: deleteCoreV1CollectionNamespacedService
     * Request URI: /api/v1/namespaces/{namespace}/services
     */
    deleteCoreV1CollectionNamespacedService<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedService>(params: Params$deleteCoreV1CollectionNamespacedService<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedService$Status$200[ResponseContentType]>;
    /**
     * read the specified Service
     * operationId: readCoreV1NamespacedService
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}
     */
    readCoreV1NamespacedService<ResponseContentType extends ResponseContentType$readCoreV1NamespacedService>(params: Params$readCoreV1NamespacedService<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedService$Status$200[ResponseContentType]>;
    /**
     * replace the specified Service
     * operationId: replaceCoreV1NamespacedService
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}
     */
    replaceCoreV1NamespacedService<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedService>(params: Params$replaceCoreV1NamespacedService<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedService$Status$200 | Response$replaceCoreV1NamespacedService$Status$201)[ResponseContentType]>;
    /**
     * delete a Service
     * operationId: deleteCoreV1NamespacedService
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}
     */
    deleteCoreV1NamespacedService<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedService>(params: Params$deleteCoreV1NamespacedService<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedService$Status$200 | Response$deleteCoreV1NamespacedService$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Service
     * operationId: patchCoreV1NamespacedService
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}
     */
    patchCoreV1NamespacedService<RequestContentType extends RequestContentType$patchCoreV1NamespacedService, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedService>(params: Params$patchCoreV1NamespacedService<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedService$Status$200 | Response$patchCoreV1NamespacedService$Status$201)[ResponseContentType]>;
    /**
     * connect GET requests to proxy of Service
     * operationId: connectCoreV1GetNamespacedServiceProxy
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy
     */
    connectCoreV1GetNamespacedServiceProxy(params: Params$connectCoreV1GetNamespacedServiceProxy, option?: RequestOption): Promise<Response$connectCoreV1GetNamespacedServiceProxy$Status$200["*/*"]>;
    /**
     * connect PUT requests to proxy of Service
     * operationId: connectCoreV1PutNamespacedServiceProxy
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy
     */
    connectCoreV1PutNamespacedServiceProxy(params: Params$connectCoreV1PutNamespacedServiceProxy, option?: RequestOption): Promise<Response$connectCoreV1PutNamespacedServiceProxy$Status$200["*/*"]>;
    /**
     * connect POST requests to proxy of Service
     * operationId: connectCoreV1PostNamespacedServiceProxy
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy
     */
    connectCoreV1PostNamespacedServiceProxy(params: Params$connectCoreV1PostNamespacedServiceProxy, option?: RequestOption): Promise<Response$connectCoreV1PostNamespacedServiceProxy$Status$200["*/*"]>;
    /**
     * connect DELETE requests to proxy of Service
     * operationId: connectCoreV1DeleteNamespacedServiceProxy
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy
     */
    connectCoreV1DeleteNamespacedServiceProxy(params: Params$connectCoreV1DeleteNamespacedServiceProxy, option?: RequestOption): Promise<Response$connectCoreV1DeleteNamespacedServiceProxy$Status$200["*/*"]>;
    /**
     * connect OPTIONS requests to proxy of Service
     * operationId: connectCoreV1OptionsNamespacedServiceProxy
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy
     */
    connectCoreV1OptionsNamespacedServiceProxy(params: Params$connectCoreV1OptionsNamespacedServiceProxy, option?: RequestOption): Promise<Response$connectCoreV1OptionsNamespacedServiceProxy$Status$200["*/*"]>;
    /**
     * connect HEAD requests to proxy of Service
     * operationId: connectCoreV1HeadNamespacedServiceProxy
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy
     */
    connectCoreV1HeadNamespacedServiceProxy(params: Params$connectCoreV1HeadNamespacedServiceProxy, option?: RequestOption): Promise<Response$connectCoreV1HeadNamespacedServiceProxy$Status$200["*/*"]>;
    /**
     * connect PATCH requests to proxy of Service
     * operationId: connectCoreV1PatchNamespacedServiceProxy
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy
     */
    connectCoreV1PatchNamespacedServiceProxy(params: Params$connectCoreV1PatchNamespacedServiceProxy, option?: RequestOption): Promise<Response$connectCoreV1PatchNamespacedServiceProxy$Status$200["*/*"]>;
    /**
     * connect GET requests to proxy of Service
     * operationId: connectCoreV1GetNamespacedServiceProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy/{path}
     */
    connectCoreV1GetNamespacedServiceProxyWithPath(params: Params$connectCoreV1GetNamespacedServiceProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1GetNamespacedServiceProxyWithPath$Status$200["*/*"]>;
    /**
     * connect PUT requests to proxy of Service
     * operationId: connectCoreV1PutNamespacedServiceProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy/{path}
     */
    connectCoreV1PutNamespacedServiceProxyWithPath(params: Params$connectCoreV1PutNamespacedServiceProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1PutNamespacedServiceProxyWithPath$Status$200["*/*"]>;
    /**
     * connect POST requests to proxy of Service
     * operationId: connectCoreV1PostNamespacedServiceProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy/{path}
     */
    connectCoreV1PostNamespacedServiceProxyWithPath(params: Params$connectCoreV1PostNamespacedServiceProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1PostNamespacedServiceProxyWithPath$Status$200["*/*"]>;
    /**
     * connect DELETE requests to proxy of Service
     * operationId: connectCoreV1DeleteNamespacedServiceProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy/{path}
     */
    connectCoreV1DeleteNamespacedServiceProxyWithPath(params: Params$connectCoreV1DeleteNamespacedServiceProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1DeleteNamespacedServiceProxyWithPath$Status$200["*/*"]>;
    /**
     * connect OPTIONS requests to proxy of Service
     * operationId: connectCoreV1OptionsNamespacedServiceProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy/{path}
     */
    connectCoreV1OptionsNamespacedServiceProxyWithPath(params: Params$connectCoreV1OptionsNamespacedServiceProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1OptionsNamespacedServiceProxyWithPath$Status$200["*/*"]>;
    /**
     * connect HEAD requests to proxy of Service
     * operationId: connectCoreV1HeadNamespacedServiceProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy/{path}
     */
    connectCoreV1HeadNamespacedServiceProxyWithPath(params: Params$connectCoreV1HeadNamespacedServiceProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1HeadNamespacedServiceProxyWithPath$Status$200["*/*"]>;
    /**
     * connect PATCH requests to proxy of Service
     * operationId: connectCoreV1PatchNamespacedServiceProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy/{path}
     */
    connectCoreV1PatchNamespacedServiceProxyWithPath(params: Params$connectCoreV1PatchNamespacedServiceProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1PatchNamespacedServiceProxyWithPath$Status$200["*/*"]>;
    /**
     * read status of the specified Service
     * operationId: readCoreV1NamespacedServiceStatus
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/status
     */
    readCoreV1NamespacedServiceStatus<ResponseContentType extends ResponseContentType$readCoreV1NamespacedServiceStatus>(params: Params$readCoreV1NamespacedServiceStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedServiceStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified Service
     * operationId: replaceCoreV1NamespacedServiceStatus
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/status
     */
    replaceCoreV1NamespacedServiceStatus<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedServiceStatus>(params: Params$replaceCoreV1NamespacedServiceStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedServiceStatus$Status$200 | Response$replaceCoreV1NamespacedServiceStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified Service
     * operationId: patchCoreV1NamespacedServiceStatus
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/status
     */
    patchCoreV1NamespacedServiceStatus<RequestContentType extends RequestContentType$patchCoreV1NamespacedServiceStatus, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedServiceStatus>(params: Params$patchCoreV1NamespacedServiceStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedServiceStatus$Status$200 | Response$patchCoreV1NamespacedServiceStatus$Status$201)[ResponseContentType]>;
    /**
     * read the specified Namespace
     * operationId: readCoreV1Namespace
     * Request URI: /api/v1/namespaces/{name}
     */
    readCoreV1Namespace<ResponseContentType extends ResponseContentType$readCoreV1Namespace>(params: Params$readCoreV1Namespace<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1Namespace$Status$200[ResponseContentType]>;
    /**
     * replace the specified Namespace
     * operationId: replaceCoreV1Namespace
     * Request URI: /api/v1/namespaces/{name}
     */
    replaceCoreV1Namespace<ResponseContentType extends ResponseContentType$replaceCoreV1Namespace>(params: Params$replaceCoreV1Namespace<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1Namespace$Status$200 | Response$replaceCoreV1Namespace$Status$201)[ResponseContentType]>;
    /**
     * delete a Namespace
     * operationId: deleteCoreV1Namespace
     * Request URI: /api/v1/namespaces/{name}
     */
    deleteCoreV1Namespace<ResponseContentType extends ResponseContentType$deleteCoreV1Namespace>(params: Params$deleteCoreV1Namespace<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1Namespace$Status$200 | Response$deleteCoreV1Namespace$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Namespace
     * operationId: patchCoreV1Namespace
     * Request URI: /api/v1/namespaces/{name}
     */
    patchCoreV1Namespace<RequestContentType extends RequestContentType$patchCoreV1Namespace, ResponseContentType extends ResponseContentType$patchCoreV1Namespace>(params: Params$patchCoreV1Namespace<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1Namespace$Status$200 | Response$patchCoreV1Namespace$Status$201)[ResponseContentType]>;
    /**
     * replace finalize of the specified Namespace
     * operationId: replaceCoreV1NamespaceFinalize
     * Request URI: /api/v1/namespaces/{name}/finalize
     */
    replaceCoreV1NamespaceFinalize<ResponseContentType extends ResponseContentType$replaceCoreV1NamespaceFinalize>(params: Params$replaceCoreV1NamespaceFinalize<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespaceFinalize$Status$200 | Response$replaceCoreV1NamespaceFinalize$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified Namespace
     * operationId: readCoreV1NamespaceStatus
     * Request URI: /api/v1/namespaces/{name}/status
     */
    readCoreV1NamespaceStatus<ResponseContentType extends ResponseContentType$readCoreV1NamespaceStatus>(params: Params$readCoreV1NamespaceStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespaceStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified Namespace
     * operationId: replaceCoreV1NamespaceStatus
     * Request URI: /api/v1/namespaces/{name}/status
     */
    replaceCoreV1NamespaceStatus<ResponseContentType extends ResponseContentType$replaceCoreV1NamespaceStatus>(params: Params$replaceCoreV1NamespaceStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespaceStatus$Status$200 | Response$replaceCoreV1NamespaceStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified Namespace
     * operationId: patchCoreV1NamespaceStatus
     * Request URI: /api/v1/namespaces/{name}/status
     */
    patchCoreV1NamespaceStatus<RequestContentType extends RequestContentType$patchCoreV1NamespaceStatus, ResponseContentType extends ResponseContentType$patchCoreV1NamespaceStatus>(params: Params$patchCoreV1NamespaceStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespaceStatus$Status$200 | Response$patchCoreV1NamespaceStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind Node
     * operationId: listCoreV1Node
     * Request URI: /api/v1/nodes
     */
    listCoreV1Node<ResponseContentType extends ResponseContentType$listCoreV1Node>(params: Params$listCoreV1Node<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1Node$Status$200[ResponseContentType]>;
    /**
     * create a Node
     * operationId: createCoreV1Node
     * Request URI: /api/v1/nodes
     */
    createCoreV1Node<ResponseContentType extends ResponseContentType$createCoreV1Node>(params: Params$createCoreV1Node<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1Node$Status$200 | Response$createCoreV1Node$Status$201 | Response$createCoreV1Node$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Node
     * operationId: deleteCoreV1CollectionNode
     * Request URI: /api/v1/nodes
     */
    deleteCoreV1CollectionNode<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNode>(params: Params$deleteCoreV1CollectionNode<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNode$Status$200[ResponseContentType]>;
    /**
     * read the specified Node
     * operationId: readCoreV1Node
     * Request URI: /api/v1/nodes/{name}
     */
    readCoreV1Node<ResponseContentType extends ResponseContentType$readCoreV1Node>(params: Params$readCoreV1Node<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1Node$Status$200[ResponseContentType]>;
    /**
     * replace the specified Node
     * operationId: replaceCoreV1Node
     * Request URI: /api/v1/nodes/{name}
     */
    replaceCoreV1Node<ResponseContentType extends ResponseContentType$replaceCoreV1Node>(params: Params$replaceCoreV1Node<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1Node$Status$200 | Response$replaceCoreV1Node$Status$201)[ResponseContentType]>;
    /**
     * delete a Node
     * operationId: deleteCoreV1Node
     * Request URI: /api/v1/nodes/{name}
     */
    deleteCoreV1Node<ResponseContentType extends ResponseContentType$deleteCoreV1Node>(params: Params$deleteCoreV1Node<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1Node$Status$200 | Response$deleteCoreV1Node$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Node
     * operationId: patchCoreV1Node
     * Request URI: /api/v1/nodes/{name}
     */
    patchCoreV1Node<RequestContentType extends RequestContentType$patchCoreV1Node, ResponseContentType extends ResponseContentType$patchCoreV1Node>(params: Params$patchCoreV1Node<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1Node$Status$200 | Response$patchCoreV1Node$Status$201)[ResponseContentType]>;
    /**
     * connect GET requests to proxy of Node
     * operationId: connectCoreV1GetNodeProxy
     * Request URI: /api/v1/nodes/{name}/proxy
     */
    connectCoreV1GetNodeProxy(params: Params$connectCoreV1GetNodeProxy, option?: RequestOption): Promise<Response$connectCoreV1GetNodeProxy$Status$200["*/*"]>;
    /**
     * connect PUT requests to proxy of Node
     * operationId: connectCoreV1PutNodeProxy
     * Request URI: /api/v1/nodes/{name}/proxy
     */
    connectCoreV1PutNodeProxy(params: Params$connectCoreV1PutNodeProxy, option?: RequestOption): Promise<Response$connectCoreV1PutNodeProxy$Status$200["*/*"]>;
    /**
     * connect POST requests to proxy of Node
     * operationId: connectCoreV1PostNodeProxy
     * Request URI: /api/v1/nodes/{name}/proxy
     */
    connectCoreV1PostNodeProxy(params: Params$connectCoreV1PostNodeProxy, option?: RequestOption): Promise<Response$connectCoreV1PostNodeProxy$Status$200["*/*"]>;
    /**
     * connect DELETE requests to proxy of Node
     * operationId: connectCoreV1DeleteNodeProxy
     * Request URI: /api/v1/nodes/{name}/proxy
     */
    connectCoreV1DeleteNodeProxy(params: Params$connectCoreV1DeleteNodeProxy, option?: RequestOption): Promise<Response$connectCoreV1DeleteNodeProxy$Status$200["*/*"]>;
    /**
     * connect OPTIONS requests to proxy of Node
     * operationId: connectCoreV1OptionsNodeProxy
     * Request URI: /api/v1/nodes/{name}/proxy
     */
    connectCoreV1OptionsNodeProxy(params: Params$connectCoreV1OptionsNodeProxy, option?: RequestOption): Promise<Response$connectCoreV1OptionsNodeProxy$Status$200["*/*"]>;
    /**
     * connect HEAD requests to proxy of Node
     * operationId: connectCoreV1HeadNodeProxy
     * Request URI: /api/v1/nodes/{name}/proxy
     */
    connectCoreV1HeadNodeProxy(params: Params$connectCoreV1HeadNodeProxy, option?: RequestOption): Promise<Response$connectCoreV1HeadNodeProxy$Status$200["*/*"]>;
    /**
     * connect PATCH requests to proxy of Node
     * operationId: connectCoreV1PatchNodeProxy
     * Request URI: /api/v1/nodes/{name}/proxy
     */
    connectCoreV1PatchNodeProxy(params: Params$connectCoreV1PatchNodeProxy, option?: RequestOption): Promise<Response$connectCoreV1PatchNodeProxy$Status$200["*/*"]>;
    /**
     * connect GET requests to proxy of Node
     * operationId: connectCoreV1GetNodeProxyWithPath
     * Request URI: /api/v1/nodes/{name}/proxy/{path}
     */
    connectCoreV1GetNodeProxyWithPath(params: Params$connectCoreV1GetNodeProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1GetNodeProxyWithPath$Status$200["*/*"]>;
    /**
     * connect PUT requests to proxy of Node
     * operationId: connectCoreV1PutNodeProxyWithPath
     * Request URI: /api/v1/nodes/{name}/proxy/{path}
     */
    connectCoreV1PutNodeProxyWithPath(params: Params$connectCoreV1PutNodeProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1PutNodeProxyWithPath$Status$200["*/*"]>;
    /**
     * connect POST requests to proxy of Node
     * operationId: connectCoreV1PostNodeProxyWithPath
     * Request URI: /api/v1/nodes/{name}/proxy/{path}
     */
    connectCoreV1PostNodeProxyWithPath(params: Params$connectCoreV1PostNodeProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1PostNodeProxyWithPath$Status$200["*/*"]>;
    /**
     * connect DELETE requests to proxy of Node
     * operationId: connectCoreV1DeleteNodeProxyWithPath
     * Request URI: /api/v1/nodes/{name}/proxy/{path}
     */
    connectCoreV1DeleteNodeProxyWithPath(params: Params$connectCoreV1DeleteNodeProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1DeleteNodeProxyWithPath$Status$200["*/*"]>;
    /**
     * connect OPTIONS requests to proxy of Node
     * operationId: connectCoreV1OptionsNodeProxyWithPath
     * Request URI: /api/v1/nodes/{name}/proxy/{path}
     */
    connectCoreV1OptionsNodeProxyWithPath(params: Params$connectCoreV1OptionsNodeProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1OptionsNodeProxyWithPath$Status$200["*/*"]>;
    /**
     * connect HEAD requests to proxy of Node
     * operationId: connectCoreV1HeadNodeProxyWithPath
     * Request URI: /api/v1/nodes/{name}/proxy/{path}
     */
    connectCoreV1HeadNodeProxyWithPath(params: Params$connectCoreV1HeadNodeProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1HeadNodeProxyWithPath$Status$200["*/*"]>;
    /**
     * connect PATCH requests to proxy of Node
     * operationId: connectCoreV1PatchNodeProxyWithPath
     * Request URI: /api/v1/nodes/{name}/proxy/{path}
     */
    connectCoreV1PatchNodeProxyWithPath(params: Params$connectCoreV1PatchNodeProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1PatchNodeProxyWithPath$Status$200["*/*"]>;
    /**
     * read status of the specified Node
     * operationId: readCoreV1NodeStatus
     * Request URI: /api/v1/nodes/{name}/status
     */
    readCoreV1NodeStatus<ResponseContentType extends ResponseContentType$readCoreV1NodeStatus>(params: Params$readCoreV1NodeStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NodeStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified Node
     * operationId: replaceCoreV1NodeStatus
     * Request URI: /api/v1/nodes/{name}/status
     */
    replaceCoreV1NodeStatus<ResponseContentType extends ResponseContentType$replaceCoreV1NodeStatus>(params: Params$replaceCoreV1NodeStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NodeStatus$Status$200 | Response$replaceCoreV1NodeStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified Node
     * operationId: patchCoreV1NodeStatus
     * Request URI: /api/v1/nodes/{name}/status
     */
    patchCoreV1NodeStatus<RequestContentType extends RequestContentType$patchCoreV1NodeStatus, ResponseContentType extends ResponseContentType$patchCoreV1NodeStatus>(params: Params$patchCoreV1NodeStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NodeStatus$Status$200 | Response$patchCoreV1NodeStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind PersistentVolumeClaim
     * operationId: listCoreV1PersistentVolumeClaimForAllNamespaces
     * Request URI: /api/v1/persistentvolumeclaims
     */
    listCoreV1PersistentVolumeClaimForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1PersistentVolumeClaimForAllNamespaces>(params: Params$listCoreV1PersistentVolumeClaimForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1PersistentVolumeClaimForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind PersistentVolume
     * operationId: listCoreV1PersistentVolume
     * Request URI: /api/v1/persistentvolumes
     */
    listCoreV1PersistentVolume<ResponseContentType extends ResponseContentType$listCoreV1PersistentVolume>(params: Params$listCoreV1PersistentVolume<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1PersistentVolume$Status$200[ResponseContentType]>;
    /**
     * create a PersistentVolume
     * operationId: createCoreV1PersistentVolume
     * Request URI: /api/v1/persistentvolumes
     */
    createCoreV1PersistentVolume<ResponseContentType extends ResponseContentType$createCoreV1PersistentVolume>(params: Params$createCoreV1PersistentVolume<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1PersistentVolume$Status$200 | Response$createCoreV1PersistentVolume$Status$201 | Response$createCoreV1PersistentVolume$Status$202)[ResponseContentType]>;
    /**
     * delete collection of PersistentVolume
     * operationId: deleteCoreV1CollectionPersistentVolume
     * Request URI: /api/v1/persistentvolumes
     */
    deleteCoreV1CollectionPersistentVolume<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionPersistentVolume>(params: Params$deleteCoreV1CollectionPersistentVolume<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionPersistentVolume$Status$200[ResponseContentType]>;
    /**
     * read the specified PersistentVolume
     * operationId: readCoreV1PersistentVolume
     * Request URI: /api/v1/persistentvolumes/{name}
     */
    readCoreV1PersistentVolume<ResponseContentType extends ResponseContentType$readCoreV1PersistentVolume>(params: Params$readCoreV1PersistentVolume<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1PersistentVolume$Status$200[ResponseContentType]>;
    /**
     * replace the specified PersistentVolume
     * operationId: replaceCoreV1PersistentVolume
     * Request URI: /api/v1/persistentvolumes/{name}
     */
    replaceCoreV1PersistentVolume<ResponseContentType extends ResponseContentType$replaceCoreV1PersistentVolume>(params: Params$replaceCoreV1PersistentVolume<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1PersistentVolume$Status$200 | Response$replaceCoreV1PersistentVolume$Status$201)[ResponseContentType]>;
    /**
     * delete a PersistentVolume
     * operationId: deleteCoreV1PersistentVolume
     * Request URI: /api/v1/persistentvolumes/{name}
     */
    deleteCoreV1PersistentVolume<ResponseContentType extends ResponseContentType$deleteCoreV1PersistentVolume>(params: Params$deleteCoreV1PersistentVolume<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1PersistentVolume$Status$200 | Response$deleteCoreV1PersistentVolume$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified PersistentVolume
     * operationId: patchCoreV1PersistentVolume
     * Request URI: /api/v1/persistentvolumes/{name}
     */
    patchCoreV1PersistentVolume<RequestContentType extends RequestContentType$patchCoreV1PersistentVolume, ResponseContentType extends ResponseContentType$patchCoreV1PersistentVolume>(params: Params$patchCoreV1PersistentVolume<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1PersistentVolume$Status$200 | Response$patchCoreV1PersistentVolume$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified PersistentVolume
     * operationId: readCoreV1PersistentVolumeStatus
     * Request URI: /api/v1/persistentvolumes/{name}/status
     */
    readCoreV1PersistentVolumeStatus<ResponseContentType extends ResponseContentType$readCoreV1PersistentVolumeStatus>(params: Params$readCoreV1PersistentVolumeStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1PersistentVolumeStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified PersistentVolume
     * operationId: replaceCoreV1PersistentVolumeStatus
     * Request URI: /api/v1/persistentvolumes/{name}/status
     */
    replaceCoreV1PersistentVolumeStatus<ResponseContentType extends ResponseContentType$replaceCoreV1PersistentVolumeStatus>(params: Params$replaceCoreV1PersistentVolumeStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1PersistentVolumeStatus$Status$200 | Response$replaceCoreV1PersistentVolumeStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified PersistentVolume
     * operationId: patchCoreV1PersistentVolumeStatus
     * Request URI: /api/v1/persistentvolumes/{name}/status
     */
    patchCoreV1PersistentVolumeStatus<RequestContentType extends RequestContentType$patchCoreV1PersistentVolumeStatus, ResponseContentType extends ResponseContentType$patchCoreV1PersistentVolumeStatus>(params: Params$patchCoreV1PersistentVolumeStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1PersistentVolumeStatus$Status$200 | Response$patchCoreV1PersistentVolumeStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind Pod
     * operationId: listCoreV1PodForAllNamespaces
     * Request URI: /api/v1/pods
     */
    listCoreV1PodForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1PodForAllNamespaces>(params: Params$listCoreV1PodForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1PodForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind PodTemplate
     * operationId: listCoreV1PodTemplateForAllNamespaces
     * Request URI: /api/v1/podtemplates
     */
    listCoreV1PodTemplateForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1PodTemplateForAllNamespaces>(params: Params$listCoreV1PodTemplateForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1PodTemplateForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind ReplicationController
     * operationId: listCoreV1ReplicationControllerForAllNamespaces
     * Request URI: /api/v1/replicationcontrollers
     */
    listCoreV1ReplicationControllerForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1ReplicationControllerForAllNamespaces>(params: Params$listCoreV1ReplicationControllerForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1ReplicationControllerForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind ResourceQuota
     * operationId: listCoreV1ResourceQuotaForAllNamespaces
     * Request URI: /api/v1/resourcequotas
     */
    listCoreV1ResourceQuotaForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1ResourceQuotaForAllNamespaces>(params: Params$listCoreV1ResourceQuotaForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1ResourceQuotaForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Secret
     * operationId: listCoreV1SecretForAllNamespaces
     * Request URI: /api/v1/secrets
     */
    listCoreV1SecretForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1SecretForAllNamespaces>(params: Params$listCoreV1SecretForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1SecretForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind ServiceAccount
     * operationId: listCoreV1ServiceAccountForAllNamespaces
     * Request URI: /api/v1/serviceaccounts
     */
    listCoreV1ServiceAccountForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1ServiceAccountForAllNamespaces>(params: Params$listCoreV1ServiceAccountForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1ServiceAccountForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Service
     * operationId: listCoreV1ServiceForAllNamespaces
     * Request URI: /api/v1/services
     */
    listCoreV1ServiceForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1ServiceForAllNamespaces>(params: Params$listCoreV1ServiceForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1ServiceForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ConfigMap. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1ConfigMapListForAllNamespaces
     * Request URI: /api/v1/watch/configmaps
     */
    watchCoreV1ConfigMapListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1ConfigMapListForAllNamespaces>(params: Params$watchCoreV1ConfigMapListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1ConfigMapListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Endpoints. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1EndpointsListForAllNamespaces
     * Request URI: /api/v1/watch/endpoints
     */
    watchCoreV1EndpointsListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1EndpointsListForAllNamespaces>(params: Params$watchCoreV1EndpointsListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1EndpointsListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Event. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1EventListForAllNamespaces
     * Request URI: /api/v1/watch/events
     */
    watchCoreV1EventListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1EventListForAllNamespaces>(params: Params$watchCoreV1EventListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1EventListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of LimitRange. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1LimitRangeListForAllNamespaces
     * Request URI: /api/v1/watch/limitranges
     */
    watchCoreV1LimitRangeListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1LimitRangeListForAllNamespaces>(params: Params$watchCoreV1LimitRangeListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1LimitRangeListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Namespace. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespaceList
     * Request URI: /api/v1/watch/namespaces
     */
    watchCoreV1NamespaceList<ResponseContentType extends ResponseContentType$watchCoreV1NamespaceList>(params: Params$watchCoreV1NamespaceList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespaceList$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ConfigMap. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedConfigMapList
     * Request URI: /api/v1/watch/namespaces/{namespace}/configmaps
     */
    watchCoreV1NamespacedConfigMapList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedConfigMapList>(params: Params$watchCoreV1NamespacedConfigMapList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedConfigMapList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ConfigMap. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedConfigMap
     * Request URI: /api/v1/watch/namespaces/{namespace}/configmaps/{name}
     */
    watchCoreV1NamespacedConfigMap<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedConfigMap>(params: Params$watchCoreV1NamespacedConfigMap<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedConfigMap$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Endpoints. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedEndpointsList
     * Request URI: /api/v1/watch/namespaces/{namespace}/endpoints
     */
    watchCoreV1NamespacedEndpointsList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedEndpointsList>(params: Params$watchCoreV1NamespacedEndpointsList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedEndpointsList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Endpoints. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedEndpoints
     * Request URI: /api/v1/watch/namespaces/{namespace}/endpoints/{name}
     */
    watchCoreV1NamespacedEndpoints<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedEndpoints>(params: Params$watchCoreV1NamespacedEndpoints<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedEndpoints$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Event. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedEventList
     * Request URI: /api/v1/watch/namespaces/{namespace}/events
     */
    watchCoreV1NamespacedEventList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedEventList>(params: Params$watchCoreV1NamespacedEventList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedEventList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Event. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedEvent
     * Request URI: /api/v1/watch/namespaces/{namespace}/events/{name}
     */
    watchCoreV1NamespacedEvent<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedEvent>(params: Params$watchCoreV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedEvent$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of LimitRange. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedLimitRangeList
     * Request URI: /api/v1/watch/namespaces/{namespace}/limitranges
     */
    watchCoreV1NamespacedLimitRangeList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedLimitRangeList>(params: Params$watchCoreV1NamespacedLimitRangeList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedLimitRangeList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind LimitRange. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedLimitRange
     * Request URI: /api/v1/watch/namespaces/{namespace}/limitranges/{name}
     */
    watchCoreV1NamespacedLimitRange<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedLimitRange>(params: Params$watchCoreV1NamespacedLimitRange<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedLimitRange$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of PersistentVolumeClaim. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedPersistentVolumeClaimList
     * Request URI: /api/v1/watch/namespaces/{namespace}/persistentvolumeclaims
     */
    watchCoreV1NamespacedPersistentVolumeClaimList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedPersistentVolumeClaimList>(params: Params$watchCoreV1NamespacedPersistentVolumeClaimList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedPersistentVolumeClaimList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind PersistentVolumeClaim. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedPersistentVolumeClaim
     * Request URI: /api/v1/watch/namespaces/{namespace}/persistentvolumeclaims/{name}
     */
    watchCoreV1NamespacedPersistentVolumeClaim<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedPersistentVolumeClaim>(params: Params$watchCoreV1NamespacedPersistentVolumeClaim<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedPersistentVolumeClaim$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Pod. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedPodList
     * Request URI: /api/v1/watch/namespaces/{namespace}/pods
     */
    watchCoreV1NamespacedPodList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedPodList>(params: Params$watchCoreV1NamespacedPodList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedPodList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Pod. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedPod
     * Request URI: /api/v1/watch/namespaces/{namespace}/pods/{name}
     */
    watchCoreV1NamespacedPod<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedPod>(params: Params$watchCoreV1NamespacedPod<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedPod$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of PodTemplate. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedPodTemplateList
     * Request URI: /api/v1/watch/namespaces/{namespace}/podtemplates
     */
    watchCoreV1NamespacedPodTemplateList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedPodTemplateList>(params: Params$watchCoreV1NamespacedPodTemplateList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedPodTemplateList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind PodTemplate. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedPodTemplate
     * Request URI: /api/v1/watch/namespaces/{namespace}/podtemplates/{name}
     */
    watchCoreV1NamespacedPodTemplate<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedPodTemplate>(params: Params$watchCoreV1NamespacedPodTemplate<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedPodTemplate$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ReplicationController. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedReplicationControllerList
     * Request URI: /api/v1/watch/namespaces/{namespace}/replicationcontrollers
     */
    watchCoreV1NamespacedReplicationControllerList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedReplicationControllerList>(params: Params$watchCoreV1NamespacedReplicationControllerList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedReplicationControllerList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ReplicationController. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedReplicationController
     * Request URI: /api/v1/watch/namespaces/{namespace}/replicationcontrollers/{name}
     */
    watchCoreV1NamespacedReplicationController<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedReplicationController>(params: Params$watchCoreV1NamespacedReplicationController<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedReplicationController$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ResourceQuota. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedResourceQuotaList
     * Request URI: /api/v1/watch/namespaces/{namespace}/resourcequotas
     */
    watchCoreV1NamespacedResourceQuotaList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedResourceQuotaList>(params: Params$watchCoreV1NamespacedResourceQuotaList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedResourceQuotaList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ResourceQuota. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedResourceQuota
     * Request URI: /api/v1/watch/namespaces/{namespace}/resourcequotas/{name}
     */
    watchCoreV1NamespacedResourceQuota<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedResourceQuota>(params: Params$watchCoreV1NamespacedResourceQuota<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedResourceQuota$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Secret. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedSecretList
     * Request URI: /api/v1/watch/namespaces/{namespace}/secrets
     */
    watchCoreV1NamespacedSecretList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedSecretList>(params: Params$watchCoreV1NamespacedSecretList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedSecretList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Secret. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedSecret
     * Request URI: /api/v1/watch/namespaces/{namespace}/secrets/{name}
     */
    watchCoreV1NamespacedSecret<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedSecret>(params: Params$watchCoreV1NamespacedSecret<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedSecret$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ServiceAccount. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedServiceAccountList
     * Request URI: /api/v1/watch/namespaces/{namespace}/serviceaccounts
     */
    watchCoreV1NamespacedServiceAccountList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedServiceAccountList>(params: Params$watchCoreV1NamespacedServiceAccountList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedServiceAccountList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ServiceAccount. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedServiceAccount
     * Request URI: /api/v1/watch/namespaces/{namespace}/serviceaccounts/{name}
     */
    watchCoreV1NamespacedServiceAccount<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedServiceAccount>(params: Params$watchCoreV1NamespacedServiceAccount<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedServiceAccount$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Service. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedServiceList
     * Request URI: /api/v1/watch/namespaces/{namespace}/services
     */
    watchCoreV1NamespacedServiceList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedServiceList>(params: Params$watchCoreV1NamespacedServiceList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedServiceList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Service. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedService
     * Request URI: /api/v1/watch/namespaces/{namespace}/services/{name}
     */
    watchCoreV1NamespacedService<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedService>(params: Params$watchCoreV1NamespacedService<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedService$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Namespace. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1Namespace
     * Request URI: /api/v1/watch/namespaces/{name}
     */
    watchCoreV1Namespace<ResponseContentType extends ResponseContentType$watchCoreV1Namespace>(params: Params$watchCoreV1Namespace<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1Namespace$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Node. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NodeList
     * Request URI: /api/v1/watch/nodes
     */
    watchCoreV1NodeList<ResponseContentType extends ResponseContentType$watchCoreV1NodeList>(params: Params$watchCoreV1NodeList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NodeList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Node. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1Node
     * Request URI: /api/v1/watch/nodes/{name}
     */
    watchCoreV1Node<ResponseContentType extends ResponseContentType$watchCoreV1Node>(params: Params$watchCoreV1Node<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1Node$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of PersistentVolumeClaim. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1PersistentVolumeClaimListForAllNamespaces
     * Request URI: /api/v1/watch/persistentvolumeclaims
     */
    watchCoreV1PersistentVolumeClaimListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1PersistentVolumeClaimListForAllNamespaces>(params: Params$watchCoreV1PersistentVolumeClaimListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1PersistentVolumeClaimListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of PersistentVolume. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1PersistentVolumeList
     * Request URI: /api/v1/watch/persistentvolumes
     */
    watchCoreV1PersistentVolumeList<ResponseContentType extends ResponseContentType$watchCoreV1PersistentVolumeList>(params: Params$watchCoreV1PersistentVolumeList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1PersistentVolumeList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind PersistentVolume. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1PersistentVolume
     * Request URI: /api/v1/watch/persistentvolumes/{name}
     */
    watchCoreV1PersistentVolume<ResponseContentType extends ResponseContentType$watchCoreV1PersistentVolume>(params: Params$watchCoreV1PersistentVolume<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1PersistentVolume$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Pod. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1PodListForAllNamespaces
     * Request URI: /api/v1/watch/pods
     */
    watchCoreV1PodListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1PodListForAllNamespaces>(params: Params$watchCoreV1PodListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1PodListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of PodTemplate. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1PodTemplateListForAllNamespaces
     * Request URI: /api/v1/watch/podtemplates
     */
    watchCoreV1PodTemplateListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1PodTemplateListForAllNamespaces>(params: Params$watchCoreV1PodTemplateListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1PodTemplateListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ReplicationController. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1ReplicationControllerListForAllNamespaces
     * Request URI: /api/v1/watch/replicationcontrollers
     */
    watchCoreV1ReplicationControllerListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1ReplicationControllerListForAllNamespaces>(params: Params$watchCoreV1ReplicationControllerListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1ReplicationControllerListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ResourceQuota. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1ResourceQuotaListForAllNamespaces
     * Request URI: /api/v1/watch/resourcequotas
     */
    watchCoreV1ResourceQuotaListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1ResourceQuotaListForAllNamespaces>(params: Params$watchCoreV1ResourceQuotaListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1ResourceQuotaListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Secret. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1SecretListForAllNamespaces
     * Request URI: /api/v1/watch/secrets
     */
    watchCoreV1SecretListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1SecretListForAllNamespaces>(params: Params$watchCoreV1SecretListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1SecretListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ServiceAccount. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1ServiceAccountListForAllNamespaces
     * Request URI: /api/v1/watch/serviceaccounts
     */
    watchCoreV1ServiceAccountListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1ServiceAccountListForAllNamespaces>(params: Params$watchCoreV1ServiceAccountListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1ServiceAccountListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Service. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1ServiceListForAllNamespaces
     * Request URI: /api/v1/watch/services
     */
    watchCoreV1ServiceListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1ServiceListForAllNamespaces>(params: Params$watchCoreV1ServiceListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1ServiceListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * get available API versions
     * operationId: getAPIVersions
     * Request URI: /apis/
     */
    getAPIVersions<ResponseContentType extends ResponseContentType$getAPIVersions>(params: Params$getAPIVersions<ResponseContentType>, option?: RequestOption): Promise<Response$getAPIVersions$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getAdmissionregistrationAPIGroup
     * Request URI: /apis/admissionregistration.k8s.io/
     */
    getAdmissionregistrationAPIGroup<ResponseContentType extends ResponseContentType$getAdmissionregistrationAPIGroup>(params: Params$getAdmissionregistrationAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getAdmissionregistrationAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getAdmissionregistrationV1APIResources
     * Request URI: /apis/admissionregistration.k8s.io/v1/
     */
    getAdmissionregistrationV1APIResources<ResponseContentType extends ResponseContentType$getAdmissionregistrationV1APIResources>(params: Params$getAdmissionregistrationV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getAdmissionregistrationV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind MutatingWebhookConfiguration
     * operationId: listAdmissionregistrationV1MutatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations
     */
    listAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType extends ResponseContentType$listAdmissionregistrationV1MutatingWebhookConfiguration>(params: Params$listAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$listAdmissionregistrationV1MutatingWebhookConfiguration$Status$200[ResponseContentType]>;
    /**
     * create a MutatingWebhookConfiguration
     * operationId: createAdmissionregistrationV1MutatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations
     */
    createAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType extends ResponseContentType$createAdmissionregistrationV1MutatingWebhookConfiguration>(params: Params$createAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$201 | Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$202)[ResponseContentType]>;
    /**
     * delete collection of MutatingWebhookConfiguration
     * operationId: deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations
     */
    deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration<ResponseContentType extends ResponseContentType$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration>(params: Params$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration$Status$200[ResponseContentType]>;
    /**
     * read the specified MutatingWebhookConfiguration
     * operationId: readAdmissionregistrationV1MutatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations/{name}
     */
    readAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType extends ResponseContentType$readAdmissionregistrationV1MutatingWebhookConfiguration>(params: Params$readAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$readAdmissionregistrationV1MutatingWebhookConfiguration$Status$200[ResponseContentType]>;
    /**
     * replace the specified MutatingWebhookConfiguration
     * operationId: replaceAdmissionregistrationV1MutatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations/{name}
     */
    replaceAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType extends ResponseContentType$replaceAdmissionregistrationV1MutatingWebhookConfiguration>(params: Params$replaceAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | Response$replaceAdmissionregistrationV1MutatingWebhookConfiguration$Status$201)[ResponseContentType]>;
    /**
     * delete a MutatingWebhookConfiguration
     * operationId: deleteAdmissionregistrationV1MutatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations/{name}
     */
    deleteAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType extends ResponseContentType$deleteAdmissionregistrationV1MutatingWebhookConfiguration>(params: Params$deleteAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | Response$deleteAdmissionregistrationV1MutatingWebhookConfiguration$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified MutatingWebhookConfiguration
     * operationId: patchAdmissionregistrationV1MutatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations/{name}
     */
    patchAdmissionregistrationV1MutatingWebhookConfiguration<RequestContentType extends RequestContentType$patchAdmissionregistrationV1MutatingWebhookConfiguration, ResponseContentType extends ResponseContentType$patchAdmissionregistrationV1MutatingWebhookConfiguration>(params: Params$patchAdmissionregistrationV1MutatingWebhookConfiguration<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | Response$patchAdmissionregistrationV1MutatingWebhookConfiguration$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind ValidatingWebhookConfiguration
     * operationId: listAdmissionregistrationV1ValidatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations
     */
    listAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType extends ResponseContentType$listAdmissionregistrationV1ValidatingWebhookConfiguration>(params: Params$listAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$listAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200[ResponseContentType]>;
    /**
     * create a ValidatingWebhookConfiguration
     * operationId: createAdmissionregistrationV1ValidatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations
     */
    createAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType extends ResponseContentType$createAdmissionregistrationV1ValidatingWebhookConfiguration>(params: Params$createAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201 | Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ValidatingWebhookConfiguration
     * operationId: deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations
     */
    deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration<ResponseContentType extends ResponseContentType$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration>(params: Params$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration$Status$200[ResponseContentType]>;
    /**
     * read the specified ValidatingWebhookConfiguration
     * operationId: readAdmissionregistrationV1ValidatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations/{name}
     */
    readAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType extends ResponseContentType$readAdmissionregistrationV1ValidatingWebhookConfiguration>(params: Params$readAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$readAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200[ResponseContentType]>;
    /**
     * replace the specified ValidatingWebhookConfiguration
     * operationId: replaceAdmissionregistrationV1ValidatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations/{name}
     */
    replaceAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType extends ResponseContentType$replaceAdmissionregistrationV1ValidatingWebhookConfiguration>(params: Params$replaceAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | Response$replaceAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201)[ResponseContentType]>;
    /**
     * delete a ValidatingWebhookConfiguration
     * operationId: deleteAdmissionregistrationV1ValidatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations/{name}
     */
    deleteAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType extends ResponseContentType$deleteAdmissionregistrationV1ValidatingWebhookConfiguration>(params: Params$deleteAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | Response$deleteAdmissionregistrationV1ValidatingWebhookConfiguration$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ValidatingWebhookConfiguration
     * operationId: patchAdmissionregistrationV1ValidatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations/{name}
     */
    patchAdmissionregistrationV1ValidatingWebhookConfiguration<RequestContentType extends RequestContentType$patchAdmissionregistrationV1ValidatingWebhookConfiguration, ResponseContentType extends ResponseContentType$patchAdmissionregistrationV1ValidatingWebhookConfiguration>(params: Params$patchAdmissionregistrationV1ValidatingWebhookConfiguration<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | Response$patchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of MutatingWebhookConfiguration. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAdmissionregistrationV1MutatingWebhookConfigurationList
     * Request URI: /apis/admissionregistration.k8s.io/v1/watch/mutatingwebhookconfigurations
     */
    watchAdmissionregistrationV1MutatingWebhookConfigurationList<ResponseContentType extends ResponseContentType$watchAdmissionregistrationV1MutatingWebhookConfigurationList>(params: Params$watchAdmissionregistrationV1MutatingWebhookConfigurationList<ResponseContentType>, option?: RequestOption): Promise<Response$watchAdmissionregistrationV1MutatingWebhookConfigurationList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind MutatingWebhookConfiguration. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchAdmissionregistrationV1MutatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/watch/mutatingwebhookconfigurations/{name}
     */
    watchAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType extends ResponseContentType$watchAdmissionregistrationV1MutatingWebhookConfiguration>(params: Params$watchAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$watchAdmissionregistrationV1MutatingWebhookConfiguration$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ValidatingWebhookConfiguration. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAdmissionregistrationV1ValidatingWebhookConfigurationList
     * Request URI: /apis/admissionregistration.k8s.io/v1/watch/validatingwebhookconfigurations
     */
    watchAdmissionregistrationV1ValidatingWebhookConfigurationList<ResponseContentType extends ResponseContentType$watchAdmissionregistrationV1ValidatingWebhookConfigurationList>(params: Params$watchAdmissionregistrationV1ValidatingWebhookConfigurationList<ResponseContentType>, option?: RequestOption): Promise<Response$watchAdmissionregistrationV1ValidatingWebhookConfigurationList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ValidatingWebhookConfiguration. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchAdmissionregistrationV1ValidatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/watch/validatingwebhookconfigurations/{name}
     */
    watchAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType extends ResponseContentType$watchAdmissionregistrationV1ValidatingWebhookConfiguration>(params: Params$watchAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$watchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getApiextensionsAPIGroup
     * Request URI: /apis/apiextensions.k8s.io/
     */
    getApiextensionsAPIGroup<ResponseContentType extends ResponseContentType$getApiextensionsAPIGroup>(params: Params$getApiextensionsAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getApiextensionsAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getApiextensionsV1APIResources
     * Request URI: /apis/apiextensions.k8s.io/v1/
     */
    getApiextensionsV1APIResources<ResponseContentType extends ResponseContentType$getApiextensionsV1APIResources>(params: Params$getApiextensionsV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getApiextensionsV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind CustomResourceDefinition
     * operationId: listApiextensionsV1CustomResourceDefinition
     * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions
     */
    listApiextensionsV1CustomResourceDefinition<ResponseContentType extends ResponseContentType$listApiextensionsV1CustomResourceDefinition>(params: Params$listApiextensionsV1CustomResourceDefinition<ResponseContentType>, option?: RequestOption): Promise<Response$listApiextensionsV1CustomResourceDefinition$Status$200[ResponseContentType]>;
    /**
     * create a CustomResourceDefinition
     * operationId: createApiextensionsV1CustomResourceDefinition
     * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions
     */
    createApiextensionsV1CustomResourceDefinition<ResponseContentType extends ResponseContentType$createApiextensionsV1CustomResourceDefinition>(params: Params$createApiextensionsV1CustomResourceDefinition<ResponseContentType>, option?: RequestOption): Promise<(Response$createApiextensionsV1CustomResourceDefinition$Status$200 | Response$createApiextensionsV1CustomResourceDefinition$Status$201 | Response$createApiextensionsV1CustomResourceDefinition$Status$202)[ResponseContentType]>;
    /**
     * delete collection of CustomResourceDefinition
     * operationId: deleteApiextensionsV1CollectionCustomResourceDefinition
     * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions
     */
    deleteApiextensionsV1CollectionCustomResourceDefinition<ResponseContentType extends ResponseContentType$deleteApiextensionsV1CollectionCustomResourceDefinition>(params: Params$deleteApiextensionsV1CollectionCustomResourceDefinition<ResponseContentType>, option?: RequestOption): Promise<Response$deleteApiextensionsV1CollectionCustomResourceDefinition$Status$200[ResponseContentType]>;
    /**
     * read the specified CustomResourceDefinition
     * operationId: readApiextensionsV1CustomResourceDefinition
     * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions/{name}
     */
    readApiextensionsV1CustomResourceDefinition<ResponseContentType extends ResponseContentType$readApiextensionsV1CustomResourceDefinition>(params: Params$readApiextensionsV1CustomResourceDefinition<ResponseContentType>, option?: RequestOption): Promise<Response$readApiextensionsV1CustomResourceDefinition$Status$200[ResponseContentType]>;
    /**
     * replace the specified CustomResourceDefinition
     * operationId: replaceApiextensionsV1CustomResourceDefinition
     * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions/{name}
     */
    replaceApiextensionsV1CustomResourceDefinition<ResponseContentType extends ResponseContentType$replaceApiextensionsV1CustomResourceDefinition>(params: Params$replaceApiextensionsV1CustomResourceDefinition<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceApiextensionsV1CustomResourceDefinition$Status$200 | Response$replaceApiextensionsV1CustomResourceDefinition$Status$201)[ResponseContentType]>;
    /**
     * delete a CustomResourceDefinition
     * operationId: deleteApiextensionsV1CustomResourceDefinition
     * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions/{name}
     */
    deleteApiextensionsV1CustomResourceDefinition<ResponseContentType extends ResponseContentType$deleteApiextensionsV1CustomResourceDefinition>(params: Params$deleteApiextensionsV1CustomResourceDefinition<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteApiextensionsV1CustomResourceDefinition$Status$200 | Response$deleteApiextensionsV1CustomResourceDefinition$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified CustomResourceDefinition
     * operationId: patchApiextensionsV1CustomResourceDefinition
     * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions/{name}
     */
    patchApiextensionsV1CustomResourceDefinition<RequestContentType extends RequestContentType$patchApiextensionsV1CustomResourceDefinition, ResponseContentType extends ResponseContentType$patchApiextensionsV1CustomResourceDefinition>(params: Params$patchApiextensionsV1CustomResourceDefinition<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchApiextensionsV1CustomResourceDefinition$Status$200 | Response$patchApiextensionsV1CustomResourceDefinition$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified CustomResourceDefinition
     * operationId: readApiextensionsV1CustomResourceDefinitionStatus
     * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions/{name}/status
     */
    readApiextensionsV1CustomResourceDefinitionStatus<ResponseContentType extends ResponseContentType$readApiextensionsV1CustomResourceDefinitionStatus>(params: Params$readApiextensionsV1CustomResourceDefinitionStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readApiextensionsV1CustomResourceDefinitionStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified CustomResourceDefinition
     * operationId: replaceApiextensionsV1CustomResourceDefinitionStatus
     * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions/{name}/status
     */
    replaceApiextensionsV1CustomResourceDefinitionStatus<ResponseContentType extends ResponseContentType$replaceApiextensionsV1CustomResourceDefinitionStatus>(params: Params$replaceApiextensionsV1CustomResourceDefinitionStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceApiextensionsV1CustomResourceDefinitionStatus$Status$200 | Response$replaceApiextensionsV1CustomResourceDefinitionStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified CustomResourceDefinition
     * operationId: patchApiextensionsV1CustomResourceDefinitionStatus
     * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions/{name}/status
     */
    patchApiextensionsV1CustomResourceDefinitionStatus<RequestContentType extends RequestContentType$patchApiextensionsV1CustomResourceDefinitionStatus, ResponseContentType extends ResponseContentType$patchApiextensionsV1CustomResourceDefinitionStatus>(params: Params$patchApiextensionsV1CustomResourceDefinitionStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchApiextensionsV1CustomResourceDefinitionStatus$Status$200 | Response$patchApiextensionsV1CustomResourceDefinitionStatus$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of CustomResourceDefinition. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchApiextensionsV1CustomResourceDefinitionList
     * Request URI: /apis/apiextensions.k8s.io/v1/watch/customresourcedefinitions
     */
    watchApiextensionsV1CustomResourceDefinitionList<ResponseContentType extends ResponseContentType$watchApiextensionsV1CustomResourceDefinitionList>(params: Params$watchApiextensionsV1CustomResourceDefinitionList<ResponseContentType>, option?: RequestOption): Promise<Response$watchApiextensionsV1CustomResourceDefinitionList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind CustomResourceDefinition. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchApiextensionsV1CustomResourceDefinition
     * Request URI: /apis/apiextensions.k8s.io/v1/watch/customresourcedefinitions/{name}
     */
    watchApiextensionsV1CustomResourceDefinition<ResponseContentType extends ResponseContentType$watchApiextensionsV1CustomResourceDefinition>(params: Params$watchApiextensionsV1CustomResourceDefinition<ResponseContentType>, option?: RequestOption): Promise<Response$watchApiextensionsV1CustomResourceDefinition$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getApiregistrationAPIGroup
     * Request URI: /apis/apiregistration.k8s.io/
     */
    getApiregistrationAPIGroup<ResponseContentType extends ResponseContentType$getApiregistrationAPIGroup>(params: Params$getApiregistrationAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getApiregistrationAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getApiregistrationV1APIResources
     * Request URI: /apis/apiregistration.k8s.io/v1/
     */
    getApiregistrationV1APIResources<ResponseContentType extends ResponseContentType$getApiregistrationV1APIResources>(params: Params$getApiregistrationV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getApiregistrationV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind APIService
     * operationId: listApiregistrationV1APIService
     * Request URI: /apis/apiregistration.k8s.io/v1/apiservices
     */
    listApiregistrationV1APIService<ResponseContentType extends ResponseContentType$listApiregistrationV1APIService>(params: Params$listApiregistrationV1APIService<ResponseContentType>, option?: RequestOption): Promise<Response$listApiregistrationV1APIService$Status$200[ResponseContentType]>;
    /**
     * create an APIService
     * operationId: createApiregistrationV1APIService
     * Request URI: /apis/apiregistration.k8s.io/v1/apiservices
     */
    createApiregistrationV1APIService<ResponseContentType extends ResponseContentType$createApiregistrationV1APIService>(params: Params$createApiregistrationV1APIService<ResponseContentType>, option?: RequestOption): Promise<(Response$createApiregistrationV1APIService$Status$200 | Response$createApiregistrationV1APIService$Status$201 | Response$createApiregistrationV1APIService$Status$202)[ResponseContentType]>;
    /**
     * delete collection of APIService
     * operationId: deleteApiregistrationV1CollectionAPIService
     * Request URI: /apis/apiregistration.k8s.io/v1/apiservices
     */
    deleteApiregistrationV1CollectionAPIService<ResponseContentType extends ResponseContentType$deleteApiregistrationV1CollectionAPIService>(params: Params$deleteApiregistrationV1CollectionAPIService<ResponseContentType>, option?: RequestOption): Promise<Response$deleteApiregistrationV1CollectionAPIService$Status$200[ResponseContentType]>;
    /**
     * read the specified APIService
     * operationId: readApiregistrationV1APIService
     * Request URI: /apis/apiregistration.k8s.io/v1/apiservices/{name}
     */
    readApiregistrationV1APIService<ResponseContentType extends ResponseContentType$readApiregistrationV1APIService>(params: Params$readApiregistrationV1APIService<ResponseContentType>, option?: RequestOption): Promise<Response$readApiregistrationV1APIService$Status$200[ResponseContentType]>;
    /**
     * replace the specified APIService
     * operationId: replaceApiregistrationV1APIService
     * Request URI: /apis/apiregistration.k8s.io/v1/apiservices/{name}
     */
    replaceApiregistrationV1APIService<ResponseContentType extends ResponseContentType$replaceApiregistrationV1APIService>(params: Params$replaceApiregistrationV1APIService<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceApiregistrationV1APIService$Status$200 | Response$replaceApiregistrationV1APIService$Status$201)[ResponseContentType]>;
    /**
     * delete an APIService
     * operationId: deleteApiregistrationV1APIService
     * Request URI: /apis/apiregistration.k8s.io/v1/apiservices/{name}
     */
    deleteApiregistrationV1APIService<ResponseContentType extends ResponseContentType$deleteApiregistrationV1APIService>(params: Params$deleteApiregistrationV1APIService<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteApiregistrationV1APIService$Status$200 | Response$deleteApiregistrationV1APIService$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified APIService
     * operationId: patchApiregistrationV1APIService
     * Request URI: /apis/apiregistration.k8s.io/v1/apiservices/{name}
     */
    patchApiregistrationV1APIService<RequestContentType extends RequestContentType$patchApiregistrationV1APIService, ResponseContentType extends ResponseContentType$patchApiregistrationV1APIService>(params: Params$patchApiregistrationV1APIService<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchApiregistrationV1APIService$Status$200 | Response$patchApiregistrationV1APIService$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified APIService
     * operationId: readApiregistrationV1APIServiceStatus
     * Request URI: /apis/apiregistration.k8s.io/v1/apiservices/{name}/status
     */
    readApiregistrationV1APIServiceStatus<ResponseContentType extends ResponseContentType$readApiregistrationV1APIServiceStatus>(params: Params$readApiregistrationV1APIServiceStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readApiregistrationV1APIServiceStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified APIService
     * operationId: replaceApiregistrationV1APIServiceStatus
     * Request URI: /apis/apiregistration.k8s.io/v1/apiservices/{name}/status
     */
    replaceApiregistrationV1APIServiceStatus<ResponseContentType extends ResponseContentType$replaceApiregistrationV1APIServiceStatus>(params: Params$replaceApiregistrationV1APIServiceStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceApiregistrationV1APIServiceStatus$Status$200 | Response$replaceApiregistrationV1APIServiceStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified APIService
     * operationId: patchApiregistrationV1APIServiceStatus
     * Request URI: /apis/apiregistration.k8s.io/v1/apiservices/{name}/status
     */
    patchApiregistrationV1APIServiceStatus<RequestContentType extends RequestContentType$patchApiregistrationV1APIServiceStatus, ResponseContentType extends ResponseContentType$patchApiregistrationV1APIServiceStatus>(params: Params$patchApiregistrationV1APIServiceStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchApiregistrationV1APIServiceStatus$Status$200 | Response$patchApiregistrationV1APIServiceStatus$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of APIService. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchApiregistrationV1APIServiceList
     * Request URI: /apis/apiregistration.k8s.io/v1/watch/apiservices
     */
    watchApiregistrationV1APIServiceList<ResponseContentType extends ResponseContentType$watchApiregistrationV1APIServiceList>(params: Params$watchApiregistrationV1APIServiceList<ResponseContentType>, option?: RequestOption): Promise<Response$watchApiregistrationV1APIServiceList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind APIService. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchApiregistrationV1APIService
     * Request URI: /apis/apiregistration.k8s.io/v1/watch/apiservices/{name}
     */
    watchApiregistrationV1APIService<ResponseContentType extends ResponseContentType$watchApiregistrationV1APIService>(params: Params$watchApiregistrationV1APIService<ResponseContentType>, option?: RequestOption): Promise<Response$watchApiregistrationV1APIService$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getAppsAPIGroup
     * Request URI: /apis/apps/
     */
    getAppsAPIGroup<ResponseContentType extends ResponseContentType$getAppsAPIGroup>(params: Params$getAppsAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getAppsAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getAppsV1APIResources
     * Request URI: /apis/apps/v1/
     */
    getAppsV1APIResources<ResponseContentType extends ResponseContentType$getAppsV1APIResources>(params: Params$getAppsV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getAppsV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind ControllerRevision
     * operationId: listAppsV1ControllerRevisionForAllNamespaces
     * Request URI: /apis/apps/v1/controllerrevisions
     */
    listAppsV1ControllerRevisionForAllNamespaces<ResponseContentType extends ResponseContentType$listAppsV1ControllerRevisionForAllNamespaces>(params: Params$listAppsV1ControllerRevisionForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listAppsV1ControllerRevisionForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind DaemonSet
     * operationId: listAppsV1DaemonSetForAllNamespaces
     * Request URI: /apis/apps/v1/daemonsets
     */
    listAppsV1DaemonSetForAllNamespaces<ResponseContentType extends ResponseContentType$listAppsV1DaemonSetForAllNamespaces>(params: Params$listAppsV1DaemonSetForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listAppsV1DaemonSetForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Deployment
     * operationId: listAppsV1DeploymentForAllNamespaces
     * Request URI: /apis/apps/v1/deployments
     */
    listAppsV1DeploymentForAllNamespaces<ResponseContentType extends ResponseContentType$listAppsV1DeploymentForAllNamespaces>(params: Params$listAppsV1DeploymentForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listAppsV1DeploymentForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind ControllerRevision
     * operationId: listAppsV1NamespacedControllerRevision
     * Request URI: /apis/apps/v1/namespaces/{namespace}/controllerrevisions
     */
    listAppsV1NamespacedControllerRevision<ResponseContentType extends ResponseContentType$listAppsV1NamespacedControllerRevision>(params: Params$listAppsV1NamespacedControllerRevision<ResponseContentType>, option?: RequestOption): Promise<Response$listAppsV1NamespacedControllerRevision$Status$200[ResponseContentType]>;
    /**
     * create a ControllerRevision
     * operationId: createAppsV1NamespacedControllerRevision
     * Request URI: /apis/apps/v1/namespaces/{namespace}/controllerrevisions
     */
    createAppsV1NamespacedControllerRevision<ResponseContentType extends ResponseContentType$createAppsV1NamespacedControllerRevision>(params: Params$createAppsV1NamespacedControllerRevision<ResponseContentType>, option?: RequestOption): Promise<(Response$createAppsV1NamespacedControllerRevision$Status$200 | Response$createAppsV1NamespacedControllerRevision$Status$201 | Response$createAppsV1NamespacedControllerRevision$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ControllerRevision
     * operationId: deleteAppsV1CollectionNamespacedControllerRevision
     * Request URI: /apis/apps/v1/namespaces/{namespace}/controllerrevisions
     */
    deleteAppsV1CollectionNamespacedControllerRevision<ResponseContentType extends ResponseContentType$deleteAppsV1CollectionNamespacedControllerRevision>(params: Params$deleteAppsV1CollectionNamespacedControllerRevision<ResponseContentType>, option?: RequestOption): Promise<Response$deleteAppsV1CollectionNamespacedControllerRevision$Status$200[ResponseContentType]>;
    /**
     * read the specified ControllerRevision
     * operationId: readAppsV1NamespacedControllerRevision
     * Request URI: /apis/apps/v1/namespaces/{namespace}/controllerrevisions/{name}
     */
    readAppsV1NamespacedControllerRevision<ResponseContentType extends ResponseContentType$readAppsV1NamespacedControllerRevision>(params: Params$readAppsV1NamespacedControllerRevision<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedControllerRevision$Status$200[ResponseContentType]>;
    /**
     * replace the specified ControllerRevision
     * operationId: replaceAppsV1NamespacedControllerRevision
     * Request URI: /apis/apps/v1/namespaces/{namespace}/controllerrevisions/{name}
     */
    replaceAppsV1NamespacedControllerRevision<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedControllerRevision>(params: Params$replaceAppsV1NamespacedControllerRevision<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedControllerRevision$Status$200 | Response$replaceAppsV1NamespacedControllerRevision$Status$201)[ResponseContentType]>;
    /**
     * delete a ControllerRevision
     * operationId: deleteAppsV1NamespacedControllerRevision
     * Request URI: /apis/apps/v1/namespaces/{namespace}/controllerrevisions/{name}
     */
    deleteAppsV1NamespacedControllerRevision<ResponseContentType extends ResponseContentType$deleteAppsV1NamespacedControllerRevision>(params: Params$deleteAppsV1NamespacedControllerRevision<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteAppsV1NamespacedControllerRevision$Status$200 | Response$deleteAppsV1NamespacedControllerRevision$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ControllerRevision
     * operationId: patchAppsV1NamespacedControllerRevision
     * Request URI: /apis/apps/v1/namespaces/{namespace}/controllerrevisions/{name}
     */
    patchAppsV1NamespacedControllerRevision<RequestContentType extends RequestContentType$patchAppsV1NamespacedControllerRevision, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedControllerRevision>(params: Params$patchAppsV1NamespacedControllerRevision<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedControllerRevision$Status$200 | Response$patchAppsV1NamespacedControllerRevision$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind DaemonSet
     * operationId: listAppsV1NamespacedDaemonSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets
     */
    listAppsV1NamespacedDaemonSet<ResponseContentType extends ResponseContentType$listAppsV1NamespacedDaemonSet>(params: Params$listAppsV1NamespacedDaemonSet<ResponseContentType>, option?: RequestOption): Promise<Response$listAppsV1NamespacedDaemonSet$Status$200[ResponseContentType]>;
    /**
     * create a DaemonSet
     * operationId: createAppsV1NamespacedDaemonSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets
     */
    createAppsV1NamespacedDaemonSet<ResponseContentType extends ResponseContentType$createAppsV1NamespacedDaemonSet>(params: Params$createAppsV1NamespacedDaemonSet<ResponseContentType>, option?: RequestOption): Promise<(Response$createAppsV1NamespacedDaemonSet$Status$200 | Response$createAppsV1NamespacedDaemonSet$Status$201 | Response$createAppsV1NamespacedDaemonSet$Status$202)[ResponseContentType]>;
    /**
     * delete collection of DaemonSet
     * operationId: deleteAppsV1CollectionNamespacedDaemonSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets
     */
    deleteAppsV1CollectionNamespacedDaemonSet<ResponseContentType extends ResponseContentType$deleteAppsV1CollectionNamespacedDaemonSet>(params: Params$deleteAppsV1CollectionNamespacedDaemonSet<ResponseContentType>, option?: RequestOption): Promise<Response$deleteAppsV1CollectionNamespacedDaemonSet$Status$200[ResponseContentType]>;
    /**
     * read the specified DaemonSet
     * operationId: readAppsV1NamespacedDaemonSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets/{name}
     */
    readAppsV1NamespacedDaemonSet<ResponseContentType extends ResponseContentType$readAppsV1NamespacedDaemonSet>(params: Params$readAppsV1NamespacedDaemonSet<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedDaemonSet$Status$200[ResponseContentType]>;
    /**
     * replace the specified DaemonSet
     * operationId: replaceAppsV1NamespacedDaemonSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets/{name}
     */
    replaceAppsV1NamespacedDaemonSet<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedDaemonSet>(params: Params$replaceAppsV1NamespacedDaemonSet<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedDaemonSet$Status$200 | Response$replaceAppsV1NamespacedDaemonSet$Status$201)[ResponseContentType]>;
    /**
     * delete a DaemonSet
     * operationId: deleteAppsV1NamespacedDaemonSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets/{name}
     */
    deleteAppsV1NamespacedDaemonSet<ResponseContentType extends ResponseContentType$deleteAppsV1NamespacedDaemonSet>(params: Params$deleteAppsV1NamespacedDaemonSet<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteAppsV1NamespacedDaemonSet$Status$200 | Response$deleteAppsV1NamespacedDaemonSet$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified DaemonSet
     * operationId: patchAppsV1NamespacedDaemonSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets/{name}
     */
    patchAppsV1NamespacedDaemonSet<RequestContentType extends RequestContentType$patchAppsV1NamespacedDaemonSet, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedDaemonSet>(params: Params$patchAppsV1NamespacedDaemonSet<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedDaemonSet$Status$200 | Response$patchAppsV1NamespacedDaemonSet$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified DaemonSet
     * operationId: readAppsV1NamespacedDaemonSetStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets/{name}/status
     */
    readAppsV1NamespacedDaemonSetStatus<ResponseContentType extends ResponseContentType$readAppsV1NamespacedDaemonSetStatus>(params: Params$readAppsV1NamespacedDaemonSetStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedDaemonSetStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified DaemonSet
     * operationId: replaceAppsV1NamespacedDaemonSetStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets/{name}/status
     */
    replaceAppsV1NamespacedDaemonSetStatus<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedDaemonSetStatus>(params: Params$replaceAppsV1NamespacedDaemonSetStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedDaemonSetStatus$Status$200 | Response$replaceAppsV1NamespacedDaemonSetStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified DaemonSet
     * operationId: patchAppsV1NamespacedDaemonSetStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets/{name}/status
     */
    patchAppsV1NamespacedDaemonSetStatus<RequestContentType extends RequestContentType$patchAppsV1NamespacedDaemonSetStatus, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedDaemonSetStatus>(params: Params$patchAppsV1NamespacedDaemonSetStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedDaemonSetStatus$Status$200 | Response$patchAppsV1NamespacedDaemonSetStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind Deployment
     * operationId: listAppsV1NamespacedDeployment
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments
     */
    listAppsV1NamespacedDeployment<ResponseContentType extends ResponseContentType$listAppsV1NamespacedDeployment>(params: Params$listAppsV1NamespacedDeployment<ResponseContentType>, option?: RequestOption): Promise<Response$listAppsV1NamespacedDeployment$Status$200[ResponseContentType]>;
    /**
     * create a Deployment
     * operationId: createAppsV1NamespacedDeployment
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments
     */
    createAppsV1NamespacedDeployment<ResponseContentType extends ResponseContentType$createAppsV1NamespacedDeployment>(params: Params$createAppsV1NamespacedDeployment<ResponseContentType>, option?: RequestOption): Promise<(Response$createAppsV1NamespacedDeployment$Status$200 | Response$createAppsV1NamespacedDeployment$Status$201 | Response$createAppsV1NamespacedDeployment$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Deployment
     * operationId: deleteAppsV1CollectionNamespacedDeployment
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments
     */
    deleteAppsV1CollectionNamespacedDeployment<ResponseContentType extends ResponseContentType$deleteAppsV1CollectionNamespacedDeployment>(params: Params$deleteAppsV1CollectionNamespacedDeployment<ResponseContentType>, option?: RequestOption): Promise<Response$deleteAppsV1CollectionNamespacedDeployment$Status$200[ResponseContentType]>;
    /**
     * read the specified Deployment
     * operationId: readAppsV1NamespacedDeployment
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}
     */
    readAppsV1NamespacedDeployment<ResponseContentType extends ResponseContentType$readAppsV1NamespacedDeployment>(params: Params$readAppsV1NamespacedDeployment<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedDeployment$Status$200[ResponseContentType]>;
    /**
     * replace the specified Deployment
     * operationId: replaceAppsV1NamespacedDeployment
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}
     */
    replaceAppsV1NamespacedDeployment<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedDeployment>(params: Params$replaceAppsV1NamespacedDeployment<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedDeployment$Status$200 | Response$replaceAppsV1NamespacedDeployment$Status$201)[ResponseContentType]>;
    /**
     * delete a Deployment
     * operationId: deleteAppsV1NamespacedDeployment
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}
     */
    deleteAppsV1NamespacedDeployment<ResponseContentType extends ResponseContentType$deleteAppsV1NamespacedDeployment>(params: Params$deleteAppsV1NamespacedDeployment<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteAppsV1NamespacedDeployment$Status$200 | Response$deleteAppsV1NamespacedDeployment$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Deployment
     * operationId: patchAppsV1NamespacedDeployment
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}
     */
    patchAppsV1NamespacedDeployment<RequestContentType extends RequestContentType$patchAppsV1NamespacedDeployment, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedDeployment>(params: Params$patchAppsV1NamespacedDeployment<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedDeployment$Status$200 | Response$patchAppsV1NamespacedDeployment$Status$201)[ResponseContentType]>;
    /**
     * read scale of the specified Deployment
     * operationId: readAppsV1NamespacedDeploymentScale
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}/scale
     */
    readAppsV1NamespacedDeploymentScale<ResponseContentType extends ResponseContentType$readAppsV1NamespacedDeploymentScale>(params: Params$readAppsV1NamespacedDeploymentScale<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedDeploymentScale$Status$200[ResponseContentType]>;
    /**
     * replace scale of the specified Deployment
     * operationId: replaceAppsV1NamespacedDeploymentScale
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}/scale
     */
    replaceAppsV1NamespacedDeploymentScale<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedDeploymentScale>(params: Params$replaceAppsV1NamespacedDeploymentScale<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedDeploymentScale$Status$200 | Response$replaceAppsV1NamespacedDeploymentScale$Status$201)[ResponseContentType]>;
    /**
     * partially update scale of the specified Deployment
     * operationId: patchAppsV1NamespacedDeploymentScale
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}/scale
     */
    patchAppsV1NamespacedDeploymentScale<RequestContentType extends RequestContentType$patchAppsV1NamespacedDeploymentScale, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedDeploymentScale>(params: Params$patchAppsV1NamespacedDeploymentScale<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedDeploymentScale$Status$200 | Response$patchAppsV1NamespacedDeploymentScale$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified Deployment
     * operationId: readAppsV1NamespacedDeploymentStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}/status
     */
    readAppsV1NamespacedDeploymentStatus<ResponseContentType extends ResponseContentType$readAppsV1NamespacedDeploymentStatus>(params: Params$readAppsV1NamespacedDeploymentStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedDeploymentStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified Deployment
     * operationId: replaceAppsV1NamespacedDeploymentStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}/status
     */
    replaceAppsV1NamespacedDeploymentStatus<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedDeploymentStatus>(params: Params$replaceAppsV1NamespacedDeploymentStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedDeploymentStatus$Status$200 | Response$replaceAppsV1NamespacedDeploymentStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified Deployment
     * operationId: patchAppsV1NamespacedDeploymentStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}/status
     */
    patchAppsV1NamespacedDeploymentStatus<RequestContentType extends RequestContentType$patchAppsV1NamespacedDeploymentStatus, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedDeploymentStatus>(params: Params$patchAppsV1NamespacedDeploymentStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedDeploymentStatus$Status$200 | Response$patchAppsV1NamespacedDeploymentStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind ReplicaSet
     * operationId: listAppsV1NamespacedReplicaSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets
     */
    listAppsV1NamespacedReplicaSet<ResponseContentType extends ResponseContentType$listAppsV1NamespacedReplicaSet>(params: Params$listAppsV1NamespacedReplicaSet<ResponseContentType>, option?: RequestOption): Promise<Response$listAppsV1NamespacedReplicaSet$Status$200[ResponseContentType]>;
    /**
     * create a ReplicaSet
     * operationId: createAppsV1NamespacedReplicaSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets
     */
    createAppsV1NamespacedReplicaSet<ResponseContentType extends ResponseContentType$createAppsV1NamespacedReplicaSet>(params: Params$createAppsV1NamespacedReplicaSet<ResponseContentType>, option?: RequestOption): Promise<(Response$createAppsV1NamespacedReplicaSet$Status$200 | Response$createAppsV1NamespacedReplicaSet$Status$201 | Response$createAppsV1NamespacedReplicaSet$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ReplicaSet
     * operationId: deleteAppsV1CollectionNamespacedReplicaSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets
     */
    deleteAppsV1CollectionNamespacedReplicaSet<ResponseContentType extends ResponseContentType$deleteAppsV1CollectionNamespacedReplicaSet>(params: Params$deleteAppsV1CollectionNamespacedReplicaSet<ResponseContentType>, option?: RequestOption): Promise<Response$deleteAppsV1CollectionNamespacedReplicaSet$Status$200[ResponseContentType]>;
    /**
     * read the specified ReplicaSet
     * operationId: readAppsV1NamespacedReplicaSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}
     */
    readAppsV1NamespacedReplicaSet<ResponseContentType extends ResponseContentType$readAppsV1NamespacedReplicaSet>(params: Params$readAppsV1NamespacedReplicaSet<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedReplicaSet$Status$200[ResponseContentType]>;
    /**
     * replace the specified ReplicaSet
     * operationId: replaceAppsV1NamespacedReplicaSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}
     */
    replaceAppsV1NamespacedReplicaSet<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedReplicaSet>(params: Params$replaceAppsV1NamespacedReplicaSet<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedReplicaSet$Status$200 | Response$replaceAppsV1NamespacedReplicaSet$Status$201)[ResponseContentType]>;
    /**
     * delete a ReplicaSet
     * operationId: deleteAppsV1NamespacedReplicaSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}
     */
    deleteAppsV1NamespacedReplicaSet<ResponseContentType extends ResponseContentType$deleteAppsV1NamespacedReplicaSet>(params: Params$deleteAppsV1NamespacedReplicaSet<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteAppsV1NamespacedReplicaSet$Status$200 | Response$deleteAppsV1NamespacedReplicaSet$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ReplicaSet
     * operationId: patchAppsV1NamespacedReplicaSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}
     */
    patchAppsV1NamespacedReplicaSet<RequestContentType extends RequestContentType$patchAppsV1NamespacedReplicaSet, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedReplicaSet>(params: Params$patchAppsV1NamespacedReplicaSet<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedReplicaSet$Status$200 | Response$patchAppsV1NamespacedReplicaSet$Status$201)[ResponseContentType]>;
    /**
     * read scale of the specified ReplicaSet
     * operationId: readAppsV1NamespacedReplicaSetScale
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}/scale
     */
    readAppsV1NamespacedReplicaSetScale<ResponseContentType extends ResponseContentType$readAppsV1NamespacedReplicaSetScale>(params: Params$readAppsV1NamespacedReplicaSetScale<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedReplicaSetScale$Status$200[ResponseContentType]>;
    /**
     * replace scale of the specified ReplicaSet
     * operationId: replaceAppsV1NamespacedReplicaSetScale
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}/scale
     */
    replaceAppsV1NamespacedReplicaSetScale<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedReplicaSetScale>(params: Params$replaceAppsV1NamespacedReplicaSetScale<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedReplicaSetScale$Status$200 | Response$replaceAppsV1NamespacedReplicaSetScale$Status$201)[ResponseContentType]>;
    /**
     * partially update scale of the specified ReplicaSet
     * operationId: patchAppsV1NamespacedReplicaSetScale
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}/scale
     */
    patchAppsV1NamespacedReplicaSetScale<RequestContentType extends RequestContentType$patchAppsV1NamespacedReplicaSetScale, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedReplicaSetScale>(params: Params$patchAppsV1NamespacedReplicaSetScale<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedReplicaSetScale$Status$200 | Response$patchAppsV1NamespacedReplicaSetScale$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified ReplicaSet
     * operationId: readAppsV1NamespacedReplicaSetStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}/status
     */
    readAppsV1NamespacedReplicaSetStatus<ResponseContentType extends ResponseContentType$readAppsV1NamespacedReplicaSetStatus>(params: Params$readAppsV1NamespacedReplicaSetStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedReplicaSetStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified ReplicaSet
     * operationId: replaceAppsV1NamespacedReplicaSetStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}/status
     */
    replaceAppsV1NamespacedReplicaSetStatus<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedReplicaSetStatus>(params: Params$replaceAppsV1NamespacedReplicaSetStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedReplicaSetStatus$Status$200 | Response$replaceAppsV1NamespacedReplicaSetStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified ReplicaSet
     * operationId: patchAppsV1NamespacedReplicaSetStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}/status
     */
    patchAppsV1NamespacedReplicaSetStatus<RequestContentType extends RequestContentType$patchAppsV1NamespacedReplicaSetStatus, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedReplicaSetStatus>(params: Params$patchAppsV1NamespacedReplicaSetStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedReplicaSetStatus$Status$200 | Response$patchAppsV1NamespacedReplicaSetStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind StatefulSet
     * operationId: listAppsV1NamespacedStatefulSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets
     */
    listAppsV1NamespacedStatefulSet<ResponseContentType extends ResponseContentType$listAppsV1NamespacedStatefulSet>(params: Params$listAppsV1NamespacedStatefulSet<ResponseContentType>, option?: RequestOption): Promise<Response$listAppsV1NamespacedStatefulSet$Status$200[ResponseContentType]>;
    /**
     * create a StatefulSet
     * operationId: createAppsV1NamespacedStatefulSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets
     */
    createAppsV1NamespacedStatefulSet<ResponseContentType extends ResponseContentType$createAppsV1NamespacedStatefulSet>(params: Params$createAppsV1NamespacedStatefulSet<ResponseContentType>, option?: RequestOption): Promise<(Response$createAppsV1NamespacedStatefulSet$Status$200 | Response$createAppsV1NamespacedStatefulSet$Status$201 | Response$createAppsV1NamespacedStatefulSet$Status$202)[ResponseContentType]>;
    /**
     * delete collection of StatefulSet
     * operationId: deleteAppsV1CollectionNamespacedStatefulSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets
     */
    deleteAppsV1CollectionNamespacedStatefulSet<ResponseContentType extends ResponseContentType$deleteAppsV1CollectionNamespacedStatefulSet>(params: Params$deleteAppsV1CollectionNamespacedStatefulSet<ResponseContentType>, option?: RequestOption): Promise<Response$deleteAppsV1CollectionNamespacedStatefulSet$Status$200[ResponseContentType]>;
    /**
     * read the specified StatefulSet
     * operationId: readAppsV1NamespacedStatefulSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}
     */
    readAppsV1NamespacedStatefulSet<ResponseContentType extends ResponseContentType$readAppsV1NamespacedStatefulSet>(params: Params$readAppsV1NamespacedStatefulSet<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedStatefulSet$Status$200[ResponseContentType]>;
    /**
     * replace the specified StatefulSet
     * operationId: replaceAppsV1NamespacedStatefulSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}
     */
    replaceAppsV1NamespacedStatefulSet<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedStatefulSet>(params: Params$replaceAppsV1NamespacedStatefulSet<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedStatefulSet$Status$200 | Response$replaceAppsV1NamespacedStatefulSet$Status$201)[ResponseContentType]>;
    /**
     * delete a StatefulSet
     * operationId: deleteAppsV1NamespacedStatefulSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}
     */
    deleteAppsV1NamespacedStatefulSet<ResponseContentType extends ResponseContentType$deleteAppsV1NamespacedStatefulSet>(params: Params$deleteAppsV1NamespacedStatefulSet<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteAppsV1NamespacedStatefulSet$Status$200 | Response$deleteAppsV1NamespacedStatefulSet$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified StatefulSet
     * operationId: patchAppsV1NamespacedStatefulSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}
     */
    patchAppsV1NamespacedStatefulSet<RequestContentType extends RequestContentType$patchAppsV1NamespacedStatefulSet, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedStatefulSet>(params: Params$patchAppsV1NamespacedStatefulSet<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedStatefulSet$Status$200 | Response$patchAppsV1NamespacedStatefulSet$Status$201)[ResponseContentType]>;
    /**
     * read scale of the specified StatefulSet
     * operationId: readAppsV1NamespacedStatefulSetScale
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}/scale
     */
    readAppsV1NamespacedStatefulSetScale<ResponseContentType extends ResponseContentType$readAppsV1NamespacedStatefulSetScale>(params: Params$readAppsV1NamespacedStatefulSetScale<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedStatefulSetScale$Status$200[ResponseContentType]>;
    /**
     * replace scale of the specified StatefulSet
     * operationId: replaceAppsV1NamespacedStatefulSetScale
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}/scale
     */
    replaceAppsV1NamespacedStatefulSetScale<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedStatefulSetScale>(params: Params$replaceAppsV1NamespacedStatefulSetScale<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedStatefulSetScale$Status$200 | Response$replaceAppsV1NamespacedStatefulSetScale$Status$201)[ResponseContentType]>;
    /**
     * partially update scale of the specified StatefulSet
     * operationId: patchAppsV1NamespacedStatefulSetScale
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}/scale
     */
    patchAppsV1NamespacedStatefulSetScale<RequestContentType extends RequestContentType$patchAppsV1NamespacedStatefulSetScale, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedStatefulSetScale>(params: Params$patchAppsV1NamespacedStatefulSetScale<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedStatefulSetScale$Status$200 | Response$patchAppsV1NamespacedStatefulSetScale$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified StatefulSet
     * operationId: readAppsV1NamespacedStatefulSetStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}/status
     */
    readAppsV1NamespacedStatefulSetStatus<ResponseContentType extends ResponseContentType$readAppsV1NamespacedStatefulSetStatus>(params: Params$readAppsV1NamespacedStatefulSetStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedStatefulSetStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified StatefulSet
     * operationId: replaceAppsV1NamespacedStatefulSetStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}/status
     */
    replaceAppsV1NamespacedStatefulSetStatus<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedStatefulSetStatus>(params: Params$replaceAppsV1NamespacedStatefulSetStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedStatefulSetStatus$Status$200 | Response$replaceAppsV1NamespacedStatefulSetStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified StatefulSet
     * operationId: patchAppsV1NamespacedStatefulSetStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}/status
     */
    patchAppsV1NamespacedStatefulSetStatus<RequestContentType extends RequestContentType$patchAppsV1NamespacedStatefulSetStatus, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedStatefulSetStatus>(params: Params$patchAppsV1NamespacedStatefulSetStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedStatefulSetStatus$Status$200 | Response$patchAppsV1NamespacedStatefulSetStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind ReplicaSet
     * operationId: listAppsV1ReplicaSetForAllNamespaces
     * Request URI: /apis/apps/v1/replicasets
     */
    listAppsV1ReplicaSetForAllNamespaces<ResponseContentType extends ResponseContentType$listAppsV1ReplicaSetForAllNamespaces>(params: Params$listAppsV1ReplicaSetForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listAppsV1ReplicaSetForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind StatefulSet
     * operationId: listAppsV1StatefulSetForAllNamespaces
     * Request URI: /apis/apps/v1/statefulsets
     */
    listAppsV1StatefulSetForAllNamespaces<ResponseContentType extends ResponseContentType$listAppsV1StatefulSetForAllNamespaces>(params: Params$listAppsV1StatefulSetForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listAppsV1StatefulSetForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ControllerRevision. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAppsV1ControllerRevisionListForAllNamespaces
     * Request URI: /apis/apps/v1/watch/controllerrevisions
     */
    watchAppsV1ControllerRevisionListForAllNamespaces<ResponseContentType extends ResponseContentType$watchAppsV1ControllerRevisionListForAllNamespaces>(params: Params$watchAppsV1ControllerRevisionListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1ControllerRevisionListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of DaemonSet. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAppsV1DaemonSetListForAllNamespaces
     * Request URI: /apis/apps/v1/watch/daemonsets
     */
    watchAppsV1DaemonSetListForAllNamespaces<ResponseContentType extends ResponseContentType$watchAppsV1DaemonSetListForAllNamespaces>(params: Params$watchAppsV1DaemonSetListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1DaemonSetListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Deployment. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAppsV1DeploymentListForAllNamespaces
     * Request URI: /apis/apps/v1/watch/deployments
     */
    watchAppsV1DeploymentListForAllNamespaces<ResponseContentType extends ResponseContentType$watchAppsV1DeploymentListForAllNamespaces>(params: Params$watchAppsV1DeploymentListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1DeploymentListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ControllerRevision. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAppsV1NamespacedControllerRevisionList
     * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/controllerrevisions
     */
    watchAppsV1NamespacedControllerRevisionList<ResponseContentType extends ResponseContentType$watchAppsV1NamespacedControllerRevisionList>(params: Params$watchAppsV1NamespacedControllerRevisionList<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1NamespacedControllerRevisionList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ControllerRevision. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchAppsV1NamespacedControllerRevision
     * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/controllerrevisions/{name}
     */
    watchAppsV1NamespacedControllerRevision<ResponseContentType extends ResponseContentType$watchAppsV1NamespacedControllerRevision>(params: Params$watchAppsV1NamespacedControllerRevision<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1NamespacedControllerRevision$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of DaemonSet. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAppsV1NamespacedDaemonSetList
     * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/daemonsets
     */
    watchAppsV1NamespacedDaemonSetList<ResponseContentType extends ResponseContentType$watchAppsV1NamespacedDaemonSetList>(params: Params$watchAppsV1NamespacedDaemonSetList<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1NamespacedDaemonSetList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind DaemonSet. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchAppsV1NamespacedDaemonSet
     * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/daemonsets/{name}
     */
    watchAppsV1NamespacedDaemonSet<ResponseContentType extends ResponseContentType$watchAppsV1NamespacedDaemonSet>(params: Params$watchAppsV1NamespacedDaemonSet<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1NamespacedDaemonSet$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Deployment. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAppsV1NamespacedDeploymentList
     * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/deployments
     */
    watchAppsV1NamespacedDeploymentList<ResponseContentType extends ResponseContentType$watchAppsV1NamespacedDeploymentList>(params: Params$watchAppsV1NamespacedDeploymentList<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1NamespacedDeploymentList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Deployment. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchAppsV1NamespacedDeployment
     * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/deployments/{name}
     */
    watchAppsV1NamespacedDeployment<ResponseContentType extends ResponseContentType$watchAppsV1NamespacedDeployment>(params: Params$watchAppsV1NamespacedDeployment<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1NamespacedDeployment$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ReplicaSet. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAppsV1NamespacedReplicaSetList
     * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/replicasets
     */
    watchAppsV1NamespacedReplicaSetList<ResponseContentType extends ResponseContentType$watchAppsV1NamespacedReplicaSetList>(params: Params$watchAppsV1NamespacedReplicaSetList<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1NamespacedReplicaSetList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ReplicaSet. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchAppsV1NamespacedReplicaSet
     * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/replicasets/{name}
     */
    watchAppsV1NamespacedReplicaSet<ResponseContentType extends ResponseContentType$watchAppsV1NamespacedReplicaSet>(params: Params$watchAppsV1NamespacedReplicaSet<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1NamespacedReplicaSet$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of StatefulSet. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAppsV1NamespacedStatefulSetList
     * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/statefulsets
     */
    watchAppsV1NamespacedStatefulSetList<ResponseContentType extends ResponseContentType$watchAppsV1NamespacedStatefulSetList>(params: Params$watchAppsV1NamespacedStatefulSetList<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1NamespacedStatefulSetList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind StatefulSet. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchAppsV1NamespacedStatefulSet
     * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/statefulsets/{name}
     */
    watchAppsV1NamespacedStatefulSet<ResponseContentType extends ResponseContentType$watchAppsV1NamespacedStatefulSet>(params: Params$watchAppsV1NamespacedStatefulSet<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1NamespacedStatefulSet$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ReplicaSet. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAppsV1ReplicaSetListForAllNamespaces
     * Request URI: /apis/apps/v1/watch/replicasets
     */
    watchAppsV1ReplicaSetListForAllNamespaces<ResponseContentType extends ResponseContentType$watchAppsV1ReplicaSetListForAllNamespaces>(params: Params$watchAppsV1ReplicaSetListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1ReplicaSetListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of StatefulSet. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAppsV1StatefulSetListForAllNamespaces
     * Request URI: /apis/apps/v1/watch/statefulsets
     */
    watchAppsV1StatefulSetListForAllNamespaces<ResponseContentType extends ResponseContentType$watchAppsV1StatefulSetListForAllNamespaces>(params: Params$watchAppsV1StatefulSetListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1StatefulSetListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getAuthenticationAPIGroup
     * Request URI: /apis/authentication.k8s.io/
     */
    getAuthenticationAPIGroup<ResponseContentType extends ResponseContentType$getAuthenticationAPIGroup>(params: Params$getAuthenticationAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getAuthenticationAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getAuthenticationV1APIResources
     * Request URI: /apis/authentication.k8s.io/v1/
     */
    getAuthenticationV1APIResources<ResponseContentType extends ResponseContentType$getAuthenticationV1APIResources>(params: Params$getAuthenticationV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getAuthenticationV1APIResources$Status$200[ResponseContentType]>;
    /**
     * create a TokenReview
     * operationId: createAuthenticationV1TokenReview
     * Request URI: /apis/authentication.k8s.io/v1/tokenreviews
     */
    createAuthenticationV1TokenReview<ResponseContentType extends ResponseContentType$createAuthenticationV1TokenReview>(params: Params$createAuthenticationV1TokenReview<ResponseContentType>, option?: RequestOption): Promise<(Response$createAuthenticationV1TokenReview$Status$200 | Response$createAuthenticationV1TokenReview$Status$201 | Response$createAuthenticationV1TokenReview$Status$202)[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getAuthorizationAPIGroup
     * Request URI: /apis/authorization.k8s.io/
     */
    getAuthorizationAPIGroup<ResponseContentType extends ResponseContentType$getAuthorizationAPIGroup>(params: Params$getAuthorizationAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getAuthorizationAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getAuthorizationV1APIResources
     * Request URI: /apis/authorization.k8s.io/v1/
     */
    getAuthorizationV1APIResources<ResponseContentType extends ResponseContentType$getAuthorizationV1APIResources>(params: Params$getAuthorizationV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getAuthorizationV1APIResources$Status$200[ResponseContentType]>;
    /**
     * create a LocalSubjectAccessReview
     * operationId: createAuthorizationV1NamespacedLocalSubjectAccessReview
     * Request URI: /apis/authorization.k8s.io/v1/namespaces/{namespace}/localsubjectaccessreviews
     */
    createAuthorizationV1NamespacedLocalSubjectAccessReview<ResponseContentType extends ResponseContentType$createAuthorizationV1NamespacedLocalSubjectAccessReview>(params: Params$createAuthorizationV1NamespacedLocalSubjectAccessReview<ResponseContentType>, option?: RequestOption): Promise<(Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$200 | Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$201 | Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$202)[ResponseContentType]>;
    /**
     * create a SelfSubjectAccessReview
     * operationId: createAuthorizationV1SelfSubjectAccessReview
     * Request URI: /apis/authorization.k8s.io/v1/selfsubjectaccessreviews
     */
    createAuthorizationV1SelfSubjectAccessReview<ResponseContentType extends ResponseContentType$createAuthorizationV1SelfSubjectAccessReview>(params: Params$createAuthorizationV1SelfSubjectAccessReview<ResponseContentType>, option?: RequestOption): Promise<(Response$createAuthorizationV1SelfSubjectAccessReview$Status$200 | Response$createAuthorizationV1SelfSubjectAccessReview$Status$201 | Response$createAuthorizationV1SelfSubjectAccessReview$Status$202)[ResponseContentType]>;
    /**
     * create a SelfSubjectRulesReview
     * operationId: createAuthorizationV1SelfSubjectRulesReview
     * Request URI: /apis/authorization.k8s.io/v1/selfsubjectrulesreviews
     */
    createAuthorizationV1SelfSubjectRulesReview<ResponseContentType extends ResponseContentType$createAuthorizationV1SelfSubjectRulesReview>(params: Params$createAuthorizationV1SelfSubjectRulesReview<ResponseContentType>, option?: RequestOption): Promise<(Response$createAuthorizationV1SelfSubjectRulesReview$Status$200 | Response$createAuthorizationV1SelfSubjectRulesReview$Status$201 | Response$createAuthorizationV1SelfSubjectRulesReview$Status$202)[ResponseContentType]>;
    /**
     * create a SubjectAccessReview
     * operationId: createAuthorizationV1SubjectAccessReview
     * Request URI: /apis/authorization.k8s.io/v1/subjectaccessreviews
     */
    createAuthorizationV1SubjectAccessReview<ResponseContentType extends ResponseContentType$createAuthorizationV1SubjectAccessReview>(params: Params$createAuthorizationV1SubjectAccessReview<ResponseContentType>, option?: RequestOption): Promise<(Response$createAuthorizationV1SubjectAccessReview$Status$200 | Response$createAuthorizationV1SubjectAccessReview$Status$201 | Response$createAuthorizationV1SubjectAccessReview$Status$202)[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getAutoscalingAPIGroup
     * Request URI: /apis/autoscaling/
     */
    getAutoscalingAPIGroup<ResponseContentType extends ResponseContentType$getAutoscalingAPIGroup>(params: Params$getAutoscalingAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getAutoscalingAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getAutoscalingV1APIResources
     * Request URI: /apis/autoscaling/v1/
     */
    getAutoscalingV1APIResources<ResponseContentType extends ResponseContentType$getAutoscalingV1APIResources>(params: Params$getAutoscalingV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getAutoscalingV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind HorizontalPodAutoscaler
     * operationId: listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces
     * Request URI: /apis/autoscaling/v1/horizontalpodautoscalers
     */
    listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces<ResponseContentType extends ResponseContentType$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces>(params: Params$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind HorizontalPodAutoscaler
     * operationId: listAutoscalingV1NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers
     */
    listAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$listAutoscalingV1NamespacedHorizontalPodAutoscaler>(params: Params$listAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$listAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * create a HorizontalPodAutoscaler
     * operationId: createAutoscalingV1NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers
     */
    createAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$createAutoscalingV1NamespacedHorizontalPodAutoscaler>(params: Params$createAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<(Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201 | Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$202)[ResponseContentType]>;
    /**
     * delete collection of HorizontalPodAutoscaler
     * operationId: deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers
     */
    deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler>(params: Params$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * read the specified HorizontalPodAutoscaler
     * operationId: readAutoscalingV1NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    readAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$readAutoscalingV1NamespacedHorizontalPodAutoscaler>(params: Params$readAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$readAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * replace the specified HorizontalPodAutoscaler
     * operationId: replaceAutoscalingV1NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    replaceAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler>(params: Params$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201)[ResponseContentType]>;
    /**
     * delete a HorizontalPodAutoscaler
     * operationId: deleteAutoscalingV1NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    deleteAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler>(params: Params$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | Response$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified HorizontalPodAutoscaler
     * operationId: patchAutoscalingV1NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    patchAutoscalingV1NamespacedHorizontalPodAutoscaler<RequestContentType extends RequestContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscaler, ResponseContentType extends ResponseContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscaler>(params: Params$patchAutoscalingV1NamespacedHorizontalPodAutoscaler<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | Response$patchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified HorizontalPodAutoscaler
     * operationId: readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus
     * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
     */
    readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus<ResponseContentType extends ResponseContentType$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus>(params: Params$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified HorizontalPodAutoscaler
     * operationId: replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus
     * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
     */
    replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus<ResponseContentType extends ResponseContentType$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus>(params: Params$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified HorizontalPodAutoscaler
     * operationId: patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus
     * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
     */
    patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus<RequestContentType extends RequestContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus, ResponseContentType extends ResponseContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus>(params: Params$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces
     * Request URI: /apis/autoscaling/v1/watch/horizontalpodautoscalers
     */
    watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces<ResponseContentType extends ResponseContentType$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces>(params: Params$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAutoscalingV1NamespacedHorizontalPodAutoscalerList
     * Request URI: /apis/autoscaling/v1/watch/namespaces/{namespace}/horizontalpodautoscalers
     */
    watchAutoscalingV1NamespacedHorizontalPodAutoscalerList<ResponseContentType extends ResponseContentType$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList>(params: Params$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList<ResponseContentType>, option?: RequestOption): Promise<Response$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchAutoscalingV1NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v1/watch/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    watchAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$watchAutoscalingV1NamespacedHorizontalPodAutoscaler>(params: Params$watchAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$watchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getAutoscalingV2APIResources
     * Request URI: /apis/autoscaling/v2/
     */
    getAutoscalingV2APIResources<ResponseContentType extends ResponseContentType$getAutoscalingV2APIResources>(params: Params$getAutoscalingV2APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getAutoscalingV2APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind HorizontalPodAutoscaler
     * operationId: listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces
     * Request URI: /apis/autoscaling/v2/horizontalpodautoscalers
     */
    listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces<ResponseContentType extends ResponseContentType$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces>(params: Params$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind HorizontalPodAutoscaler
     * operationId: listAutoscalingV2NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2/namespaces/{namespace}/horizontalpodautoscalers
     */
    listAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$listAutoscalingV2NamespacedHorizontalPodAutoscaler>(params: Params$listAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$listAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * create a HorizontalPodAutoscaler
     * operationId: createAutoscalingV2NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2/namespaces/{namespace}/horizontalpodautoscalers
     */
    createAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$createAutoscalingV2NamespacedHorizontalPodAutoscaler>(params: Params$createAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<(Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201 | Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$202)[ResponseContentType]>;
    /**
     * delete collection of HorizontalPodAutoscaler
     * operationId: deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2/namespaces/{namespace}/horizontalpodautoscalers
     */
    deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler>(params: Params$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * read the specified HorizontalPodAutoscaler
     * operationId: readAutoscalingV2NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    readAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$readAutoscalingV2NamespacedHorizontalPodAutoscaler>(params: Params$readAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$readAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * replace the specified HorizontalPodAutoscaler
     * operationId: replaceAutoscalingV2NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    replaceAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler>(params: Params$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201)[ResponseContentType]>;
    /**
     * delete a HorizontalPodAutoscaler
     * operationId: deleteAutoscalingV2NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    deleteAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler>(params: Params$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | Response$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified HorizontalPodAutoscaler
     * operationId: patchAutoscalingV2NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    patchAutoscalingV2NamespacedHorizontalPodAutoscaler<RequestContentType extends RequestContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscaler, ResponseContentType extends ResponseContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscaler>(params: Params$patchAutoscalingV2NamespacedHorizontalPodAutoscaler<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | Response$patchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified HorizontalPodAutoscaler
     * operationId: readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus
     * Request URI: /apis/autoscaling/v2/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
     */
    readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus<ResponseContentType extends ResponseContentType$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus>(params: Params$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified HorizontalPodAutoscaler
     * operationId: replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus
     * Request URI: /apis/autoscaling/v2/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
     */
    replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus<ResponseContentType extends ResponseContentType$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus>(params: Params$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified HorizontalPodAutoscaler
     * operationId: patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus
     * Request URI: /apis/autoscaling/v2/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
     */
    patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus<RequestContentType extends RequestContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus, ResponseContentType extends ResponseContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus>(params: Params$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces
     * Request URI: /apis/autoscaling/v2/watch/horizontalpodautoscalers
     */
    watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces<ResponseContentType extends ResponseContentType$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces>(params: Params$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAutoscalingV2NamespacedHorizontalPodAutoscalerList
     * Request URI: /apis/autoscaling/v2/watch/namespaces/{namespace}/horizontalpodautoscalers
     */
    watchAutoscalingV2NamespacedHorizontalPodAutoscalerList<ResponseContentType extends ResponseContentType$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList>(params: Params$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList<ResponseContentType>, option?: RequestOption): Promise<Response$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchAutoscalingV2NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2/watch/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    watchAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$watchAutoscalingV2NamespacedHorizontalPodAutoscaler>(params: Params$watchAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$watchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getAutoscalingV2beta1APIResources
     * Request URI: /apis/autoscaling/v2beta1/
     */
    getAutoscalingV2beta1APIResources<ResponseContentType extends ResponseContentType$getAutoscalingV2beta1APIResources>(params: Params$getAutoscalingV2beta1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getAutoscalingV2beta1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind HorizontalPodAutoscaler
     * operationId: listAutoscalingV2beta1HorizontalPodAutoscalerForAllNamespaces
     * Request URI: /apis/autoscaling/v2beta1/horizontalpodautoscalers
     */
    listAutoscalingV2beta1HorizontalPodAutoscalerForAllNamespaces<ResponseContentType extends ResponseContentType$listAutoscalingV2beta1HorizontalPodAutoscalerForAllNamespaces>(params: Params$listAutoscalingV2beta1HorizontalPodAutoscalerForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listAutoscalingV2beta1HorizontalPodAutoscalerForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind HorizontalPodAutoscaler
     * operationId: listAutoscalingV2beta1NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2beta1/namespaces/{namespace}/horizontalpodautoscalers
     */
    listAutoscalingV2beta1NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$listAutoscalingV2beta1NamespacedHorizontalPodAutoscaler>(params: Params$listAutoscalingV2beta1NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$listAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * create a HorizontalPodAutoscaler
     * operationId: createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2beta1/namespaces/{namespace}/horizontalpodautoscalers
     */
    createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler>(params: Params$createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<(Response$createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200 | Response$createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$201 | Response$createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$202)[ResponseContentType]>;
    /**
     * delete collection of HorizontalPodAutoscaler
     * operationId: deleteAutoscalingV2beta1CollectionNamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2beta1/namespaces/{namespace}/horizontalpodautoscalers
     */
    deleteAutoscalingV2beta1CollectionNamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$deleteAutoscalingV2beta1CollectionNamespacedHorizontalPodAutoscaler>(params: Params$deleteAutoscalingV2beta1CollectionNamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$deleteAutoscalingV2beta1CollectionNamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * read the specified HorizontalPodAutoscaler
     * operationId: readAutoscalingV2beta1NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2beta1/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    readAutoscalingV2beta1NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$readAutoscalingV2beta1NamespacedHorizontalPodAutoscaler>(params: Params$readAutoscalingV2beta1NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$readAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * replace the specified HorizontalPodAutoscaler
     * operationId: replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2beta1/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler>(params: Params$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200 | Response$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$201)[ResponseContentType]>;
    /**
     * delete a HorizontalPodAutoscaler
     * operationId: deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2beta1/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler>(params: Params$deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200 | Response$deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified HorizontalPodAutoscaler
     * operationId: patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2beta1/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler<RequestContentType extends RequestContentType$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler, ResponseContentType extends ResponseContentType$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler>(params: Params$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200 | Response$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified HorizontalPodAutoscaler
     * operationId: readAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus
     * Request URI: /apis/autoscaling/v2beta1/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
     */
    readAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus<ResponseContentType extends ResponseContentType$readAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus>(params: Params$readAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified HorizontalPodAutoscaler
     * operationId: replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus
     * Request URI: /apis/autoscaling/v2beta1/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
     */
    replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus<ResponseContentType extends ResponseContentType$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus>(params: Params$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified HorizontalPodAutoscaler
     * operationId: patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus
     * Request URI: /apis/autoscaling/v2beta1/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
     */
    patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus<RequestContentType extends RequestContentType$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus, ResponseContentType extends ResponseContentType$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus>(params: Params$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAutoscalingV2beta1HorizontalPodAutoscalerListForAllNamespaces
     * Request URI: /apis/autoscaling/v2beta1/watch/horizontalpodautoscalers
     */
    watchAutoscalingV2beta1HorizontalPodAutoscalerListForAllNamespaces<ResponseContentType extends ResponseContentType$watchAutoscalingV2beta1HorizontalPodAutoscalerListForAllNamespaces>(params: Params$watchAutoscalingV2beta1HorizontalPodAutoscalerListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchAutoscalingV2beta1HorizontalPodAutoscalerListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerList
     * Request URI: /apis/autoscaling/v2beta1/watch/namespaces/{namespace}/horizontalpodautoscalers
     */
    watchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerList<ResponseContentType extends ResponseContentType$watchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerList>(params: Params$watchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerList<ResponseContentType>, option?: RequestOption): Promise<Response$watchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2beta1/watch/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    watchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$watchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler>(params: Params$watchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$watchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getAutoscalingV2beta2APIResources
     * Request URI: /apis/autoscaling/v2beta2/
     */
    getAutoscalingV2beta2APIResources<ResponseContentType extends ResponseContentType$getAutoscalingV2beta2APIResources>(params: Params$getAutoscalingV2beta2APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getAutoscalingV2beta2APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind HorizontalPodAutoscaler
     * operationId: listAutoscalingV2beta2HorizontalPodAutoscalerForAllNamespaces
     * Request URI: /apis/autoscaling/v2beta2/horizontalpodautoscalers
     */
    listAutoscalingV2beta2HorizontalPodAutoscalerForAllNamespaces<ResponseContentType extends ResponseContentType$listAutoscalingV2beta2HorizontalPodAutoscalerForAllNamespaces>(params: Params$listAutoscalingV2beta2HorizontalPodAutoscalerForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listAutoscalingV2beta2HorizontalPodAutoscalerForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind HorizontalPodAutoscaler
     * operationId: listAutoscalingV2beta2NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2beta2/namespaces/{namespace}/horizontalpodautoscalers
     */
    listAutoscalingV2beta2NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$listAutoscalingV2beta2NamespacedHorizontalPodAutoscaler>(params: Params$listAutoscalingV2beta2NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$listAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * create a HorizontalPodAutoscaler
     * operationId: createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2beta2/namespaces/{namespace}/horizontalpodautoscalers
     */
    createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler>(params: Params$createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<(Response$createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200 | Response$createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$201 | Response$createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$202)[ResponseContentType]>;
    /**
     * delete collection of HorizontalPodAutoscaler
     * operationId: deleteAutoscalingV2beta2CollectionNamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2beta2/namespaces/{namespace}/horizontalpodautoscalers
     */
    deleteAutoscalingV2beta2CollectionNamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$deleteAutoscalingV2beta2CollectionNamespacedHorizontalPodAutoscaler>(params: Params$deleteAutoscalingV2beta2CollectionNamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$deleteAutoscalingV2beta2CollectionNamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * read the specified HorizontalPodAutoscaler
     * operationId: readAutoscalingV2beta2NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2beta2/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    readAutoscalingV2beta2NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$readAutoscalingV2beta2NamespacedHorizontalPodAutoscaler>(params: Params$readAutoscalingV2beta2NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$readAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * replace the specified HorizontalPodAutoscaler
     * operationId: replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2beta2/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler>(params: Params$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200 | Response$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$201)[ResponseContentType]>;
    /**
     * delete a HorizontalPodAutoscaler
     * operationId: deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2beta2/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler>(params: Params$deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200 | Response$deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified HorizontalPodAutoscaler
     * operationId: patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2beta2/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler<RequestContentType extends RequestContentType$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler, ResponseContentType extends ResponseContentType$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler>(params: Params$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200 | Response$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified HorizontalPodAutoscaler
     * operationId: readAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus
     * Request URI: /apis/autoscaling/v2beta2/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
     */
    readAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus<ResponseContentType extends ResponseContentType$readAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus>(params: Params$readAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified HorizontalPodAutoscaler
     * operationId: replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus
     * Request URI: /apis/autoscaling/v2beta2/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
     */
    replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus<ResponseContentType extends ResponseContentType$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus>(params: Params$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified HorizontalPodAutoscaler
     * operationId: patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus
     * Request URI: /apis/autoscaling/v2beta2/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
     */
    patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus<RequestContentType extends RequestContentType$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus, ResponseContentType extends ResponseContentType$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus>(params: Params$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAutoscalingV2beta2HorizontalPodAutoscalerListForAllNamespaces
     * Request URI: /apis/autoscaling/v2beta2/watch/horizontalpodautoscalers
     */
    watchAutoscalingV2beta2HorizontalPodAutoscalerListForAllNamespaces<ResponseContentType extends ResponseContentType$watchAutoscalingV2beta2HorizontalPodAutoscalerListForAllNamespaces>(params: Params$watchAutoscalingV2beta2HorizontalPodAutoscalerListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchAutoscalingV2beta2HorizontalPodAutoscalerListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerList
     * Request URI: /apis/autoscaling/v2beta2/watch/namespaces/{namespace}/horizontalpodautoscalers
     */
    watchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerList<ResponseContentType extends ResponseContentType$watchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerList>(params: Params$watchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerList<ResponseContentType>, option?: RequestOption): Promise<Response$watchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2beta2/watch/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    watchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$watchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler>(params: Params$watchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$watchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getBatchAPIGroup
     * Request URI: /apis/batch/
     */
    getBatchAPIGroup<ResponseContentType extends ResponseContentType$getBatchAPIGroup>(params: Params$getBatchAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getBatchAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getBatchV1APIResources
     * Request URI: /apis/batch/v1/
     */
    getBatchV1APIResources<ResponseContentType extends ResponseContentType$getBatchV1APIResources>(params: Params$getBatchV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getBatchV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind CronJob
     * operationId: listBatchV1CronJobForAllNamespaces
     * Request URI: /apis/batch/v1/cronjobs
     */
    listBatchV1CronJobForAllNamespaces<ResponseContentType extends ResponseContentType$listBatchV1CronJobForAllNamespaces>(params: Params$listBatchV1CronJobForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listBatchV1CronJobForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Job
     * operationId: listBatchV1JobForAllNamespaces
     * Request URI: /apis/batch/v1/jobs
     */
    listBatchV1JobForAllNamespaces<ResponseContentType extends ResponseContentType$listBatchV1JobForAllNamespaces>(params: Params$listBatchV1JobForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listBatchV1JobForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind CronJob
     * operationId: listBatchV1NamespacedCronJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/cronjobs
     */
    listBatchV1NamespacedCronJob<ResponseContentType extends ResponseContentType$listBatchV1NamespacedCronJob>(params: Params$listBatchV1NamespacedCronJob<ResponseContentType>, option?: RequestOption): Promise<Response$listBatchV1NamespacedCronJob$Status$200[ResponseContentType]>;
    /**
     * create a CronJob
     * operationId: createBatchV1NamespacedCronJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/cronjobs
     */
    createBatchV1NamespacedCronJob<ResponseContentType extends ResponseContentType$createBatchV1NamespacedCronJob>(params: Params$createBatchV1NamespacedCronJob<ResponseContentType>, option?: RequestOption): Promise<(Response$createBatchV1NamespacedCronJob$Status$200 | Response$createBatchV1NamespacedCronJob$Status$201 | Response$createBatchV1NamespacedCronJob$Status$202)[ResponseContentType]>;
    /**
     * delete collection of CronJob
     * operationId: deleteBatchV1CollectionNamespacedCronJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/cronjobs
     */
    deleteBatchV1CollectionNamespacedCronJob<ResponseContentType extends ResponseContentType$deleteBatchV1CollectionNamespacedCronJob>(params: Params$deleteBatchV1CollectionNamespacedCronJob<ResponseContentType>, option?: RequestOption): Promise<Response$deleteBatchV1CollectionNamespacedCronJob$Status$200[ResponseContentType]>;
    /**
     * read the specified CronJob
     * operationId: readBatchV1NamespacedCronJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/cronjobs/{name}
     */
    readBatchV1NamespacedCronJob<ResponseContentType extends ResponseContentType$readBatchV1NamespacedCronJob>(params: Params$readBatchV1NamespacedCronJob<ResponseContentType>, option?: RequestOption): Promise<Response$readBatchV1NamespacedCronJob$Status$200[ResponseContentType]>;
    /**
     * replace the specified CronJob
     * operationId: replaceBatchV1NamespacedCronJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/cronjobs/{name}
     */
    replaceBatchV1NamespacedCronJob<ResponseContentType extends ResponseContentType$replaceBatchV1NamespacedCronJob>(params: Params$replaceBatchV1NamespacedCronJob<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceBatchV1NamespacedCronJob$Status$200 | Response$replaceBatchV1NamespacedCronJob$Status$201)[ResponseContentType]>;
    /**
     * delete a CronJob
     * operationId: deleteBatchV1NamespacedCronJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/cronjobs/{name}
     */
    deleteBatchV1NamespacedCronJob<ResponseContentType extends ResponseContentType$deleteBatchV1NamespacedCronJob>(params: Params$deleteBatchV1NamespacedCronJob<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteBatchV1NamespacedCronJob$Status$200 | Response$deleteBatchV1NamespacedCronJob$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified CronJob
     * operationId: patchBatchV1NamespacedCronJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/cronjobs/{name}
     */
    patchBatchV1NamespacedCronJob<RequestContentType extends RequestContentType$patchBatchV1NamespacedCronJob, ResponseContentType extends ResponseContentType$patchBatchV1NamespacedCronJob>(params: Params$patchBatchV1NamespacedCronJob<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchBatchV1NamespacedCronJob$Status$200 | Response$patchBatchV1NamespacedCronJob$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified CronJob
     * operationId: readBatchV1NamespacedCronJobStatus
     * Request URI: /apis/batch/v1/namespaces/{namespace}/cronjobs/{name}/status
     */
    readBatchV1NamespacedCronJobStatus<ResponseContentType extends ResponseContentType$readBatchV1NamespacedCronJobStatus>(params: Params$readBatchV1NamespacedCronJobStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readBatchV1NamespacedCronJobStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified CronJob
     * operationId: replaceBatchV1NamespacedCronJobStatus
     * Request URI: /apis/batch/v1/namespaces/{namespace}/cronjobs/{name}/status
     */
    replaceBatchV1NamespacedCronJobStatus<ResponseContentType extends ResponseContentType$replaceBatchV1NamespacedCronJobStatus>(params: Params$replaceBatchV1NamespacedCronJobStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceBatchV1NamespacedCronJobStatus$Status$200 | Response$replaceBatchV1NamespacedCronJobStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified CronJob
     * operationId: patchBatchV1NamespacedCronJobStatus
     * Request URI: /apis/batch/v1/namespaces/{namespace}/cronjobs/{name}/status
     */
    patchBatchV1NamespacedCronJobStatus<RequestContentType extends RequestContentType$patchBatchV1NamespacedCronJobStatus, ResponseContentType extends ResponseContentType$patchBatchV1NamespacedCronJobStatus>(params: Params$patchBatchV1NamespacedCronJobStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchBatchV1NamespacedCronJobStatus$Status$200 | Response$patchBatchV1NamespacedCronJobStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind Job
     * operationId: listBatchV1NamespacedJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs
     */
    listBatchV1NamespacedJob<ResponseContentType extends ResponseContentType$listBatchV1NamespacedJob>(params: Params$listBatchV1NamespacedJob<ResponseContentType>, option?: RequestOption): Promise<Response$listBatchV1NamespacedJob$Status$200[ResponseContentType]>;
    /**
     * create a Job
     * operationId: createBatchV1NamespacedJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs
     */
    createBatchV1NamespacedJob<ResponseContentType extends ResponseContentType$createBatchV1NamespacedJob>(params: Params$createBatchV1NamespacedJob<ResponseContentType>, option?: RequestOption): Promise<(Response$createBatchV1NamespacedJob$Status$200 | Response$createBatchV1NamespacedJob$Status$201 | Response$createBatchV1NamespacedJob$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Job
     * operationId: deleteBatchV1CollectionNamespacedJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs
     */
    deleteBatchV1CollectionNamespacedJob<ResponseContentType extends ResponseContentType$deleteBatchV1CollectionNamespacedJob>(params: Params$deleteBatchV1CollectionNamespacedJob<ResponseContentType>, option?: RequestOption): Promise<Response$deleteBatchV1CollectionNamespacedJob$Status$200[ResponseContentType]>;
    /**
     * read the specified Job
     * operationId: readBatchV1NamespacedJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs/{name}
     */
    readBatchV1NamespacedJob<ResponseContentType extends ResponseContentType$readBatchV1NamespacedJob>(params: Params$readBatchV1NamespacedJob<ResponseContentType>, option?: RequestOption): Promise<Response$readBatchV1NamespacedJob$Status$200[ResponseContentType]>;
    /**
     * replace the specified Job
     * operationId: replaceBatchV1NamespacedJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs/{name}
     */
    replaceBatchV1NamespacedJob<ResponseContentType extends ResponseContentType$replaceBatchV1NamespacedJob>(params: Params$replaceBatchV1NamespacedJob<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceBatchV1NamespacedJob$Status$200 | Response$replaceBatchV1NamespacedJob$Status$201)[ResponseContentType]>;
    /**
     * delete a Job
     * operationId: deleteBatchV1NamespacedJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs/{name}
     */
    deleteBatchV1NamespacedJob<ResponseContentType extends ResponseContentType$deleteBatchV1NamespacedJob>(params: Params$deleteBatchV1NamespacedJob<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteBatchV1NamespacedJob$Status$200 | Response$deleteBatchV1NamespacedJob$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Job
     * operationId: patchBatchV1NamespacedJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs/{name}
     */
    patchBatchV1NamespacedJob<RequestContentType extends RequestContentType$patchBatchV1NamespacedJob, ResponseContentType extends ResponseContentType$patchBatchV1NamespacedJob>(params: Params$patchBatchV1NamespacedJob<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchBatchV1NamespacedJob$Status$200 | Response$patchBatchV1NamespacedJob$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified Job
     * operationId: readBatchV1NamespacedJobStatus
     * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs/{name}/status
     */
    readBatchV1NamespacedJobStatus<ResponseContentType extends ResponseContentType$readBatchV1NamespacedJobStatus>(params: Params$readBatchV1NamespacedJobStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readBatchV1NamespacedJobStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified Job
     * operationId: replaceBatchV1NamespacedJobStatus
     * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs/{name}/status
     */
    replaceBatchV1NamespacedJobStatus<ResponseContentType extends ResponseContentType$replaceBatchV1NamespacedJobStatus>(params: Params$replaceBatchV1NamespacedJobStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceBatchV1NamespacedJobStatus$Status$200 | Response$replaceBatchV1NamespacedJobStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified Job
     * operationId: patchBatchV1NamespacedJobStatus
     * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs/{name}/status
     */
    patchBatchV1NamespacedJobStatus<RequestContentType extends RequestContentType$patchBatchV1NamespacedJobStatus, ResponseContentType extends ResponseContentType$patchBatchV1NamespacedJobStatus>(params: Params$patchBatchV1NamespacedJobStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchBatchV1NamespacedJobStatus$Status$200 | Response$patchBatchV1NamespacedJobStatus$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of CronJob. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchBatchV1CronJobListForAllNamespaces
     * Request URI: /apis/batch/v1/watch/cronjobs
     */
    watchBatchV1CronJobListForAllNamespaces<ResponseContentType extends ResponseContentType$watchBatchV1CronJobListForAllNamespaces>(params: Params$watchBatchV1CronJobListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchBatchV1CronJobListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Job. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchBatchV1JobListForAllNamespaces
     * Request URI: /apis/batch/v1/watch/jobs
     */
    watchBatchV1JobListForAllNamespaces<ResponseContentType extends ResponseContentType$watchBatchV1JobListForAllNamespaces>(params: Params$watchBatchV1JobListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchBatchV1JobListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of CronJob. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchBatchV1NamespacedCronJobList
     * Request URI: /apis/batch/v1/watch/namespaces/{namespace}/cronjobs
     */
    watchBatchV1NamespacedCronJobList<ResponseContentType extends ResponseContentType$watchBatchV1NamespacedCronJobList>(params: Params$watchBatchV1NamespacedCronJobList<ResponseContentType>, option?: RequestOption): Promise<Response$watchBatchV1NamespacedCronJobList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind CronJob. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchBatchV1NamespacedCronJob
     * Request URI: /apis/batch/v1/watch/namespaces/{namespace}/cronjobs/{name}
     */
    watchBatchV1NamespacedCronJob<ResponseContentType extends ResponseContentType$watchBatchV1NamespacedCronJob>(params: Params$watchBatchV1NamespacedCronJob<ResponseContentType>, option?: RequestOption): Promise<Response$watchBatchV1NamespacedCronJob$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Job. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchBatchV1NamespacedJobList
     * Request URI: /apis/batch/v1/watch/namespaces/{namespace}/jobs
     */
    watchBatchV1NamespacedJobList<ResponseContentType extends ResponseContentType$watchBatchV1NamespacedJobList>(params: Params$watchBatchV1NamespacedJobList<ResponseContentType>, option?: RequestOption): Promise<Response$watchBatchV1NamespacedJobList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Job. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchBatchV1NamespacedJob
     * Request URI: /apis/batch/v1/watch/namespaces/{namespace}/jobs/{name}
     */
    watchBatchV1NamespacedJob<ResponseContentType extends ResponseContentType$watchBatchV1NamespacedJob>(params: Params$watchBatchV1NamespacedJob<ResponseContentType>, option?: RequestOption): Promise<Response$watchBatchV1NamespacedJob$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getBatchV1beta1APIResources
     * Request URI: /apis/batch/v1beta1/
     */
    getBatchV1beta1APIResources<ResponseContentType extends ResponseContentType$getBatchV1beta1APIResources>(params: Params$getBatchV1beta1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getBatchV1beta1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind CronJob
     * operationId: listBatchV1beta1CronJobForAllNamespaces
     * Request URI: /apis/batch/v1beta1/cronjobs
     */
    listBatchV1beta1CronJobForAllNamespaces<ResponseContentType extends ResponseContentType$listBatchV1beta1CronJobForAllNamespaces>(params: Params$listBatchV1beta1CronJobForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listBatchV1beta1CronJobForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind CronJob
     * operationId: listBatchV1beta1NamespacedCronJob
     * Request URI: /apis/batch/v1beta1/namespaces/{namespace}/cronjobs
     */
    listBatchV1beta1NamespacedCronJob<ResponseContentType extends ResponseContentType$listBatchV1beta1NamespacedCronJob>(params: Params$listBatchV1beta1NamespacedCronJob<ResponseContentType>, option?: RequestOption): Promise<Response$listBatchV1beta1NamespacedCronJob$Status$200[ResponseContentType]>;
    /**
     * create a CronJob
     * operationId: createBatchV1beta1NamespacedCronJob
     * Request URI: /apis/batch/v1beta1/namespaces/{namespace}/cronjobs
     */
    createBatchV1beta1NamespacedCronJob<ResponseContentType extends ResponseContentType$createBatchV1beta1NamespacedCronJob>(params: Params$createBatchV1beta1NamespacedCronJob<ResponseContentType>, option?: RequestOption): Promise<(Response$createBatchV1beta1NamespacedCronJob$Status$200 | Response$createBatchV1beta1NamespacedCronJob$Status$201 | Response$createBatchV1beta1NamespacedCronJob$Status$202)[ResponseContentType]>;
    /**
     * delete collection of CronJob
     * operationId: deleteBatchV1beta1CollectionNamespacedCronJob
     * Request URI: /apis/batch/v1beta1/namespaces/{namespace}/cronjobs
     */
    deleteBatchV1beta1CollectionNamespacedCronJob<ResponseContentType extends ResponseContentType$deleteBatchV1beta1CollectionNamespacedCronJob>(params: Params$deleteBatchV1beta1CollectionNamespacedCronJob<ResponseContentType>, option?: RequestOption): Promise<Response$deleteBatchV1beta1CollectionNamespacedCronJob$Status$200[ResponseContentType]>;
    /**
     * read the specified CronJob
     * operationId: readBatchV1beta1NamespacedCronJob
     * Request URI: /apis/batch/v1beta1/namespaces/{namespace}/cronjobs/{name}
     */
    readBatchV1beta1NamespacedCronJob<ResponseContentType extends ResponseContentType$readBatchV1beta1NamespacedCronJob>(params: Params$readBatchV1beta1NamespacedCronJob<ResponseContentType>, option?: RequestOption): Promise<Response$readBatchV1beta1NamespacedCronJob$Status$200[ResponseContentType]>;
    /**
     * replace the specified CronJob
     * operationId: replaceBatchV1beta1NamespacedCronJob
     * Request URI: /apis/batch/v1beta1/namespaces/{namespace}/cronjobs/{name}
     */
    replaceBatchV1beta1NamespacedCronJob<ResponseContentType extends ResponseContentType$replaceBatchV1beta1NamespacedCronJob>(params: Params$replaceBatchV1beta1NamespacedCronJob<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceBatchV1beta1NamespacedCronJob$Status$200 | Response$replaceBatchV1beta1NamespacedCronJob$Status$201)[ResponseContentType]>;
    /**
     * delete a CronJob
     * operationId: deleteBatchV1beta1NamespacedCronJob
     * Request URI: /apis/batch/v1beta1/namespaces/{namespace}/cronjobs/{name}
     */
    deleteBatchV1beta1NamespacedCronJob<ResponseContentType extends ResponseContentType$deleteBatchV1beta1NamespacedCronJob>(params: Params$deleteBatchV1beta1NamespacedCronJob<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteBatchV1beta1NamespacedCronJob$Status$200 | Response$deleteBatchV1beta1NamespacedCronJob$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified CronJob
     * operationId: patchBatchV1beta1NamespacedCronJob
     * Request URI: /apis/batch/v1beta1/namespaces/{namespace}/cronjobs/{name}
     */
    patchBatchV1beta1NamespacedCronJob<RequestContentType extends RequestContentType$patchBatchV1beta1NamespacedCronJob, ResponseContentType extends ResponseContentType$patchBatchV1beta1NamespacedCronJob>(params: Params$patchBatchV1beta1NamespacedCronJob<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchBatchV1beta1NamespacedCronJob$Status$200 | Response$patchBatchV1beta1NamespacedCronJob$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified CronJob
     * operationId: readBatchV1beta1NamespacedCronJobStatus
     * Request URI: /apis/batch/v1beta1/namespaces/{namespace}/cronjobs/{name}/status
     */
    readBatchV1beta1NamespacedCronJobStatus<ResponseContentType extends ResponseContentType$readBatchV1beta1NamespacedCronJobStatus>(params: Params$readBatchV1beta1NamespacedCronJobStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readBatchV1beta1NamespacedCronJobStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified CronJob
     * operationId: replaceBatchV1beta1NamespacedCronJobStatus
     * Request URI: /apis/batch/v1beta1/namespaces/{namespace}/cronjobs/{name}/status
     */
    replaceBatchV1beta1NamespacedCronJobStatus<ResponseContentType extends ResponseContentType$replaceBatchV1beta1NamespacedCronJobStatus>(params: Params$replaceBatchV1beta1NamespacedCronJobStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceBatchV1beta1NamespacedCronJobStatus$Status$200 | Response$replaceBatchV1beta1NamespacedCronJobStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified CronJob
     * operationId: patchBatchV1beta1NamespacedCronJobStatus
     * Request URI: /apis/batch/v1beta1/namespaces/{namespace}/cronjobs/{name}/status
     */
    patchBatchV1beta1NamespacedCronJobStatus<RequestContentType extends RequestContentType$patchBatchV1beta1NamespacedCronJobStatus, ResponseContentType extends ResponseContentType$patchBatchV1beta1NamespacedCronJobStatus>(params: Params$patchBatchV1beta1NamespacedCronJobStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchBatchV1beta1NamespacedCronJobStatus$Status$200 | Response$patchBatchV1beta1NamespacedCronJobStatus$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of CronJob. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchBatchV1beta1CronJobListForAllNamespaces
     * Request URI: /apis/batch/v1beta1/watch/cronjobs
     */
    watchBatchV1beta1CronJobListForAllNamespaces<ResponseContentType extends ResponseContentType$watchBatchV1beta1CronJobListForAllNamespaces>(params: Params$watchBatchV1beta1CronJobListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchBatchV1beta1CronJobListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of CronJob. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchBatchV1beta1NamespacedCronJobList
     * Request URI: /apis/batch/v1beta1/watch/namespaces/{namespace}/cronjobs
     */
    watchBatchV1beta1NamespacedCronJobList<ResponseContentType extends ResponseContentType$watchBatchV1beta1NamespacedCronJobList>(params: Params$watchBatchV1beta1NamespacedCronJobList<ResponseContentType>, option?: RequestOption): Promise<Response$watchBatchV1beta1NamespacedCronJobList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind CronJob. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchBatchV1beta1NamespacedCronJob
     * Request URI: /apis/batch/v1beta1/watch/namespaces/{namespace}/cronjobs/{name}
     */
    watchBatchV1beta1NamespacedCronJob<ResponseContentType extends ResponseContentType$watchBatchV1beta1NamespacedCronJob>(params: Params$watchBatchV1beta1NamespacedCronJob<ResponseContentType>, option?: RequestOption): Promise<Response$watchBatchV1beta1NamespacedCronJob$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getCertificatesAPIGroup
     * Request URI: /apis/certificates.k8s.io/
     */
    getCertificatesAPIGroup<ResponseContentType extends ResponseContentType$getCertificatesAPIGroup>(params: Params$getCertificatesAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getCertificatesAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getCertificatesV1APIResources
     * Request URI: /apis/certificates.k8s.io/v1/
     */
    getCertificatesV1APIResources<ResponseContentType extends ResponseContentType$getCertificatesV1APIResources>(params: Params$getCertificatesV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getCertificatesV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind CertificateSigningRequest
     * operationId: listCertificatesV1CertificateSigningRequest
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests
     */
    listCertificatesV1CertificateSigningRequest<ResponseContentType extends ResponseContentType$listCertificatesV1CertificateSigningRequest>(params: Params$listCertificatesV1CertificateSigningRequest<ResponseContentType>, option?: RequestOption): Promise<Response$listCertificatesV1CertificateSigningRequest$Status$200[ResponseContentType]>;
    /**
     * create a CertificateSigningRequest
     * operationId: createCertificatesV1CertificateSigningRequest
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests
     */
    createCertificatesV1CertificateSigningRequest<ResponseContentType extends ResponseContentType$createCertificatesV1CertificateSigningRequest>(params: Params$createCertificatesV1CertificateSigningRequest<ResponseContentType>, option?: RequestOption): Promise<(Response$createCertificatesV1CertificateSigningRequest$Status$200 | Response$createCertificatesV1CertificateSigningRequest$Status$201 | Response$createCertificatesV1CertificateSigningRequest$Status$202)[ResponseContentType]>;
    /**
     * delete collection of CertificateSigningRequest
     * operationId: deleteCertificatesV1CollectionCertificateSigningRequest
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests
     */
    deleteCertificatesV1CollectionCertificateSigningRequest<ResponseContentType extends ResponseContentType$deleteCertificatesV1CollectionCertificateSigningRequest>(params: Params$deleteCertificatesV1CollectionCertificateSigningRequest<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCertificatesV1CollectionCertificateSigningRequest$Status$200[ResponseContentType]>;
    /**
     * read the specified CertificateSigningRequest
     * operationId: readCertificatesV1CertificateSigningRequest
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests/{name}
     */
    readCertificatesV1CertificateSigningRequest<ResponseContentType extends ResponseContentType$readCertificatesV1CertificateSigningRequest>(params: Params$readCertificatesV1CertificateSigningRequest<ResponseContentType>, option?: RequestOption): Promise<Response$readCertificatesV1CertificateSigningRequest$Status$200[ResponseContentType]>;
    /**
     * replace the specified CertificateSigningRequest
     * operationId: replaceCertificatesV1CertificateSigningRequest
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests/{name}
     */
    replaceCertificatesV1CertificateSigningRequest<ResponseContentType extends ResponseContentType$replaceCertificatesV1CertificateSigningRequest>(params: Params$replaceCertificatesV1CertificateSigningRequest<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCertificatesV1CertificateSigningRequest$Status$200 | Response$replaceCertificatesV1CertificateSigningRequest$Status$201)[ResponseContentType]>;
    /**
     * delete a CertificateSigningRequest
     * operationId: deleteCertificatesV1CertificateSigningRequest
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests/{name}
     */
    deleteCertificatesV1CertificateSigningRequest<ResponseContentType extends ResponseContentType$deleteCertificatesV1CertificateSigningRequest>(params: Params$deleteCertificatesV1CertificateSigningRequest<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCertificatesV1CertificateSigningRequest$Status$200 | Response$deleteCertificatesV1CertificateSigningRequest$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified CertificateSigningRequest
     * operationId: patchCertificatesV1CertificateSigningRequest
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests/{name}
     */
    patchCertificatesV1CertificateSigningRequest<RequestContentType extends RequestContentType$patchCertificatesV1CertificateSigningRequest, ResponseContentType extends ResponseContentType$patchCertificatesV1CertificateSigningRequest>(params: Params$patchCertificatesV1CertificateSigningRequest<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCertificatesV1CertificateSigningRequest$Status$200 | Response$patchCertificatesV1CertificateSigningRequest$Status$201)[ResponseContentType]>;
    /**
     * read approval of the specified CertificateSigningRequest
     * operationId: readCertificatesV1CertificateSigningRequestApproval
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests/{name}/approval
     */
    readCertificatesV1CertificateSigningRequestApproval<ResponseContentType extends ResponseContentType$readCertificatesV1CertificateSigningRequestApproval>(params: Params$readCertificatesV1CertificateSigningRequestApproval<ResponseContentType>, option?: RequestOption): Promise<Response$readCertificatesV1CertificateSigningRequestApproval$Status$200[ResponseContentType]>;
    /**
     * replace approval of the specified CertificateSigningRequest
     * operationId: replaceCertificatesV1CertificateSigningRequestApproval
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests/{name}/approval
     */
    replaceCertificatesV1CertificateSigningRequestApproval<ResponseContentType extends ResponseContentType$replaceCertificatesV1CertificateSigningRequestApproval>(params: Params$replaceCertificatesV1CertificateSigningRequestApproval<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCertificatesV1CertificateSigningRequestApproval$Status$200 | Response$replaceCertificatesV1CertificateSigningRequestApproval$Status$201)[ResponseContentType]>;
    /**
     * partially update approval of the specified CertificateSigningRequest
     * operationId: patchCertificatesV1CertificateSigningRequestApproval
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests/{name}/approval
     */
    patchCertificatesV1CertificateSigningRequestApproval<RequestContentType extends RequestContentType$patchCertificatesV1CertificateSigningRequestApproval, ResponseContentType extends ResponseContentType$patchCertificatesV1CertificateSigningRequestApproval>(params: Params$patchCertificatesV1CertificateSigningRequestApproval<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCertificatesV1CertificateSigningRequestApproval$Status$200 | Response$patchCertificatesV1CertificateSigningRequestApproval$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified CertificateSigningRequest
     * operationId: readCertificatesV1CertificateSigningRequestStatus
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests/{name}/status
     */
    readCertificatesV1CertificateSigningRequestStatus<ResponseContentType extends ResponseContentType$readCertificatesV1CertificateSigningRequestStatus>(params: Params$readCertificatesV1CertificateSigningRequestStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readCertificatesV1CertificateSigningRequestStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified CertificateSigningRequest
     * operationId: replaceCertificatesV1CertificateSigningRequestStatus
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests/{name}/status
     */
    replaceCertificatesV1CertificateSigningRequestStatus<ResponseContentType extends ResponseContentType$replaceCertificatesV1CertificateSigningRequestStatus>(params: Params$replaceCertificatesV1CertificateSigningRequestStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCertificatesV1CertificateSigningRequestStatus$Status$200 | Response$replaceCertificatesV1CertificateSigningRequestStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified CertificateSigningRequest
     * operationId: patchCertificatesV1CertificateSigningRequestStatus
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests/{name}/status
     */
    patchCertificatesV1CertificateSigningRequestStatus<RequestContentType extends RequestContentType$patchCertificatesV1CertificateSigningRequestStatus, ResponseContentType extends ResponseContentType$patchCertificatesV1CertificateSigningRequestStatus>(params: Params$patchCertificatesV1CertificateSigningRequestStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCertificatesV1CertificateSigningRequestStatus$Status$200 | Response$patchCertificatesV1CertificateSigningRequestStatus$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of CertificateSigningRequest. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCertificatesV1CertificateSigningRequestList
     * Request URI: /apis/certificates.k8s.io/v1/watch/certificatesigningrequests
     */
    watchCertificatesV1CertificateSigningRequestList<ResponseContentType extends ResponseContentType$watchCertificatesV1CertificateSigningRequestList>(params: Params$watchCertificatesV1CertificateSigningRequestList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCertificatesV1CertificateSigningRequestList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind CertificateSigningRequest. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCertificatesV1CertificateSigningRequest
     * Request URI: /apis/certificates.k8s.io/v1/watch/certificatesigningrequests/{name}
     */
    watchCertificatesV1CertificateSigningRequest<ResponseContentType extends ResponseContentType$watchCertificatesV1CertificateSigningRequest>(params: Params$watchCertificatesV1CertificateSigningRequest<ResponseContentType>, option?: RequestOption): Promise<Response$watchCertificatesV1CertificateSigningRequest$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getCoordinationAPIGroup
     * Request URI: /apis/coordination.k8s.io/
     */
    getCoordinationAPIGroup<ResponseContentType extends ResponseContentType$getCoordinationAPIGroup>(params: Params$getCoordinationAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getCoordinationAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getCoordinationV1APIResources
     * Request URI: /apis/coordination.k8s.io/v1/
     */
    getCoordinationV1APIResources<ResponseContentType extends ResponseContentType$getCoordinationV1APIResources>(params: Params$getCoordinationV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getCoordinationV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Lease
     * operationId: listCoordinationV1LeaseForAllNamespaces
     * Request URI: /apis/coordination.k8s.io/v1/leases
     */
    listCoordinationV1LeaseForAllNamespaces<ResponseContentType extends ResponseContentType$listCoordinationV1LeaseForAllNamespaces>(params: Params$listCoordinationV1LeaseForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoordinationV1LeaseForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Lease
     * operationId: listCoordinationV1NamespacedLease
     * Request URI: /apis/coordination.k8s.io/v1/namespaces/{namespace}/leases
     */
    listCoordinationV1NamespacedLease<ResponseContentType extends ResponseContentType$listCoordinationV1NamespacedLease>(params: Params$listCoordinationV1NamespacedLease<ResponseContentType>, option?: RequestOption): Promise<Response$listCoordinationV1NamespacedLease$Status$200[ResponseContentType]>;
    /**
     * create a Lease
     * operationId: createCoordinationV1NamespacedLease
     * Request URI: /apis/coordination.k8s.io/v1/namespaces/{namespace}/leases
     */
    createCoordinationV1NamespacedLease<ResponseContentType extends ResponseContentType$createCoordinationV1NamespacedLease>(params: Params$createCoordinationV1NamespacedLease<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoordinationV1NamespacedLease$Status$200 | Response$createCoordinationV1NamespacedLease$Status$201 | Response$createCoordinationV1NamespacedLease$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Lease
     * operationId: deleteCoordinationV1CollectionNamespacedLease
     * Request URI: /apis/coordination.k8s.io/v1/namespaces/{namespace}/leases
     */
    deleteCoordinationV1CollectionNamespacedLease<ResponseContentType extends ResponseContentType$deleteCoordinationV1CollectionNamespacedLease>(params: Params$deleteCoordinationV1CollectionNamespacedLease<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoordinationV1CollectionNamespacedLease$Status$200[ResponseContentType]>;
    /**
     * read the specified Lease
     * operationId: readCoordinationV1NamespacedLease
     * Request URI: /apis/coordination.k8s.io/v1/namespaces/{namespace}/leases/{name}
     */
    readCoordinationV1NamespacedLease<ResponseContentType extends ResponseContentType$readCoordinationV1NamespacedLease>(params: Params$readCoordinationV1NamespacedLease<ResponseContentType>, option?: RequestOption): Promise<Response$readCoordinationV1NamespacedLease$Status$200[ResponseContentType]>;
    /**
     * replace the specified Lease
     * operationId: replaceCoordinationV1NamespacedLease
     * Request URI: /apis/coordination.k8s.io/v1/namespaces/{namespace}/leases/{name}
     */
    replaceCoordinationV1NamespacedLease<ResponseContentType extends ResponseContentType$replaceCoordinationV1NamespacedLease>(params: Params$replaceCoordinationV1NamespacedLease<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoordinationV1NamespacedLease$Status$200 | Response$replaceCoordinationV1NamespacedLease$Status$201)[ResponseContentType]>;
    /**
     * delete a Lease
     * operationId: deleteCoordinationV1NamespacedLease
     * Request URI: /apis/coordination.k8s.io/v1/namespaces/{namespace}/leases/{name}
     */
    deleteCoordinationV1NamespacedLease<ResponseContentType extends ResponseContentType$deleteCoordinationV1NamespacedLease>(params: Params$deleteCoordinationV1NamespacedLease<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoordinationV1NamespacedLease$Status$200 | Response$deleteCoordinationV1NamespacedLease$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Lease
     * operationId: patchCoordinationV1NamespacedLease
     * Request URI: /apis/coordination.k8s.io/v1/namespaces/{namespace}/leases/{name}
     */
    patchCoordinationV1NamespacedLease<RequestContentType extends RequestContentType$patchCoordinationV1NamespacedLease, ResponseContentType extends ResponseContentType$patchCoordinationV1NamespacedLease>(params: Params$patchCoordinationV1NamespacedLease<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoordinationV1NamespacedLease$Status$200 | Response$patchCoordinationV1NamespacedLease$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of Lease. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoordinationV1LeaseListForAllNamespaces
     * Request URI: /apis/coordination.k8s.io/v1/watch/leases
     */
    watchCoordinationV1LeaseListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoordinationV1LeaseListForAllNamespaces>(params: Params$watchCoordinationV1LeaseListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoordinationV1LeaseListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Lease. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoordinationV1NamespacedLeaseList
     * Request URI: /apis/coordination.k8s.io/v1/watch/namespaces/{namespace}/leases
     */
    watchCoordinationV1NamespacedLeaseList<ResponseContentType extends ResponseContentType$watchCoordinationV1NamespacedLeaseList>(params: Params$watchCoordinationV1NamespacedLeaseList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoordinationV1NamespacedLeaseList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Lease. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoordinationV1NamespacedLease
     * Request URI: /apis/coordination.k8s.io/v1/watch/namespaces/{namespace}/leases/{name}
     */
    watchCoordinationV1NamespacedLease<ResponseContentType extends ResponseContentType$watchCoordinationV1NamespacedLease>(params: Params$watchCoordinationV1NamespacedLease<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoordinationV1NamespacedLease$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getDiscoveryAPIGroup
     * Request URI: /apis/discovery.k8s.io/
     */
    getDiscoveryAPIGroup<ResponseContentType extends ResponseContentType$getDiscoveryAPIGroup>(params: Params$getDiscoveryAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getDiscoveryAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getDiscoveryV1APIResources
     * Request URI: /apis/discovery.k8s.io/v1/
     */
    getDiscoveryV1APIResources<ResponseContentType extends ResponseContentType$getDiscoveryV1APIResources>(params: Params$getDiscoveryV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getDiscoveryV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind EndpointSlice
     * operationId: listDiscoveryV1EndpointSliceForAllNamespaces
     * Request URI: /apis/discovery.k8s.io/v1/endpointslices
     */
    listDiscoveryV1EndpointSliceForAllNamespaces<ResponseContentType extends ResponseContentType$listDiscoveryV1EndpointSliceForAllNamespaces>(params: Params$listDiscoveryV1EndpointSliceForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listDiscoveryV1EndpointSliceForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind EndpointSlice
     * operationId: listDiscoveryV1NamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1/namespaces/{namespace}/endpointslices
     */
    listDiscoveryV1NamespacedEndpointSlice<ResponseContentType extends ResponseContentType$listDiscoveryV1NamespacedEndpointSlice>(params: Params$listDiscoveryV1NamespacedEndpointSlice<ResponseContentType>, option?: RequestOption): Promise<Response$listDiscoveryV1NamespacedEndpointSlice$Status$200[ResponseContentType]>;
    /**
     * create an EndpointSlice
     * operationId: createDiscoveryV1NamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1/namespaces/{namespace}/endpointslices
     */
    createDiscoveryV1NamespacedEndpointSlice<ResponseContentType extends ResponseContentType$createDiscoveryV1NamespacedEndpointSlice>(params: Params$createDiscoveryV1NamespacedEndpointSlice<ResponseContentType>, option?: RequestOption): Promise<(Response$createDiscoveryV1NamespacedEndpointSlice$Status$200 | Response$createDiscoveryV1NamespacedEndpointSlice$Status$201 | Response$createDiscoveryV1NamespacedEndpointSlice$Status$202)[ResponseContentType]>;
    /**
     * delete collection of EndpointSlice
     * operationId: deleteDiscoveryV1CollectionNamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1/namespaces/{namespace}/endpointslices
     */
    deleteDiscoveryV1CollectionNamespacedEndpointSlice<ResponseContentType extends ResponseContentType$deleteDiscoveryV1CollectionNamespacedEndpointSlice>(params: Params$deleteDiscoveryV1CollectionNamespacedEndpointSlice<ResponseContentType>, option?: RequestOption): Promise<Response$deleteDiscoveryV1CollectionNamespacedEndpointSlice$Status$200[ResponseContentType]>;
    /**
     * read the specified EndpointSlice
     * operationId: readDiscoveryV1NamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1/namespaces/{namespace}/endpointslices/{name}
     */
    readDiscoveryV1NamespacedEndpointSlice<ResponseContentType extends ResponseContentType$readDiscoveryV1NamespacedEndpointSlice>(params: Params$readDiscoveryV1NamespacedEndpointSlice<ResponseContentType>, option?: RequestOption): Promise<Response$readDiscoveryV1NamespacedEndpointSlice$Status$200[ResponseContentType]>;
    /**
     * replace the specified EndpointSlice
     * operationId: replaceDiscoveryV1NamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1/namespaces/{namespace}/endpointslices/{name}
     */
    replaceDiscoveryV1NamespacedEndpointSlice<ResponseContentType extends ResponseContentType$replaceDiscoveryV1NamespacedEndpointSlice>(params: Params$replaceDiscoveryV1NamespacedEndpointSlice<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceDiscoveryV1NamespacedEndpointSlice$Status$200 | Response$replaceDiscoveryV1NamespacedEndpointSlice$Status$201)[ResponseContentType]>;
    /**
     * delete an EndpointSlice
     * operationId: deleteDiscoveryV1NamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1/namespaces/{namespace}/endpointslices/{name}
     */
    deleteDiscoveryV1NamespacedEndpointSlice<ResponseContentType extends ResponseContentType$deleteDiscoveryV1NamespacedEndpointSlice>(params: Params$deleteDiscoveryV1NamespacedEndpointSlice<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteDiscoveryV1NamespacedEndpointSlice$Status$200 | Response$deleteDiscoveryV1NamespacedEndpointSlice$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified EndpointSlice
     * operationId: patchDiscoveryV1NamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1/namespaces/{namespace}/endpointslices/{name}
     */
    patchDiscoveryV1NamespacedEndpointSlice<RequestContentType extends RequestContentType$patchDiscoveryV1NamespacedEndpointSlice, ResponseContentType extends ResponseContentType$patchDiscoveryV1NamespacedEndpointSlice>(params: Params$patchDiscoveryV1NamespacedEndpointSlice<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchDiscoveryV1NamespacedEndpointSlice$Status$200 | Response$patchDiscoveryV1NamespacedEndpointSlice$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of EndpointSlice. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchDiscoveryV1EndpointSliceListForAllNamespaces
     * Request URI: /apis/discovery.k8s.io/v1/watch/endpointslices
     */
    watchDiscoveryV1EndpointSliceListForAllNamespaces<ResponseContentType extends ResponseContentType$watchDiscoveryV1EndpointSliceListForAllNamespaces>(params: Params$watchDiscoveryV1EndpointSliceListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchDiscoveryV1EndpointSliceListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of EndpointSlice. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchDiscoveryV1NamespacedEndpointSliceList
     * Request URI: /apis/discovery.k8s.io/v1/watch/namespaces/{namespace}/endpointslices
     */
    watchDiscoveryV1NamespacedEndpointSliceList<ResponseContentType extends ResponseContentType$watchDiscoveryV1NamespacedEndpointSliceList>(params: Params$watchDiscoveryV1NamespacedEndpointSliceList<ResponseContentType>, option?: RequestOption): Promise<Response$watchDiscoveryV1NamespacedEndpointSliceList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind EndpointSlice. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchDiscoveryV1NamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1/watch/namespaces/{namespace}/endpointslices/{name}
     */
    watchDiscoveryV1NamespacedEndpointSlice<ResponseContentType extends ResponseContentType$watchDiscoveryV1NamespacedEndpointSlice>(params: Params$watchDiscoveryV1NamespacedEndpointSlice<ResponseContentType>, option?: RequestOption): Promise<Response$watchDiscoveryV1NamespacedEndpointSlice$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getDiscoveryV1beta1APIResources
     * Request URI: /apis/discovery.k8s.io/v1beta1/
     */
    getDiscoveryV1beta1APIResources<ResponseContentType extends ResponseContentType$getDiscoveryV1beta1APIResources>(params: Params$getDiscoveryV1beta1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getDiscoveryV1beta1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind EndpointSlice
     * operationId: listDiscoveryV1beta1EndpointSliceForAllNamespaces
     * Request URI: /apis/discovery.k8s.io/v1beta1/endpointslices
     */
    listDiscoveryV1beta1EndpointSliceForAllNamespaces<ResponseContentType extends ResponseContentType$listDiscoveryV1beta1EndpointSliceForAllNamespaces>(params: Params$listDiscoveryV1beta1EndpointSliceForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listDiscoveryV1beta1EndpointSliceForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind EndpointSlice
     * operationId: listDiscoveryV1beta1NamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1beta1/namespaces/{namespace}/endpointslices
     */
    listDiscoveryV1beta1NamespacedEndpointSlice<ResponseContentType extends ResponseContentType$listDiscoveryV1beta1NamespacedEndpointSlice>(params: Params$listDiscoveryV1beta1NamespacedEndpointSlice<ResponseContentType>, option?: RequestOption): Promise<Response$listDiscoveryV1beta1NamespacedEndpointSlice$Status$200[ResponseContentType]>;
    /**
     * create an EndpointSlice
     * operationId: createDiscoveryV1beta1NamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1beta1/namespaces/{namespace}/endpointslices
     */
    createDiscoveryV1beta1NamespacedEndpointSlice<ResponseContentType extends ResponseContentType$createDiscoveryV1beta1NamespacedEndpointSlice>(params: Params$createDiscoveryV1beta1NamespacedEndpointSlice<ResponseContentType>, option?: RequestOption): Promise<(Response$createDiscoveryV1beta1NamespacedEndpointSlice$Status$200 | Response$createDiscoveryV1beta1NamespacedEndpointSlice$Status$201 | Response$createDiscoveryV1beta1NamespacedEndpointSlice$Status$202)[ResponseContentType]>;
    /**
     * delete collection of EndpointSlice
     * operationId: deleteDiscoveryV1beta1CollectionNamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1beta1/namespaces/{namespace}/endpointslices
     */
    deleteDiscoveryV1beta1CollectionNamespacedEndpointSlice<ResponseContentType extends ResponseContentType$deleteDiscoveryV1beta1CollectionNamespacedEndpointSlice>(params: Params$deleteDiscoveryV1beta1CollectionNamespacedEndpointSlice<ResponseContentType>, option?: RequestOption): Promise<Response$deleteDiscoveryV1beta1CollectionNamespacedEndpointSlice$Status$200[ResponseContentType]>;
    /**
     * read the specified EndpointSlice
     * operationId: readDiscoveryV1beta1NamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1beta1/namespaces/{namespace}/endpointslices/{name}
     */
    readDiscoveryV1beta1NamespacedEndpointSlice<ResponseContentType extends ResponseContentType$readDiscoveryV1beta1NamespacedEndpointSlice>(params: Params$readDiscoveryV1beta1NamespacedEndpointSlice<ResponseContentType>, option?: RequestOption): Promise<Response$readDiscoveryV1beta1NamespacedEndpointSlice$Status$200[ResponseContentType]>;
    /**
     * replace the specified EndpointSlice
     * operationId: replaceDiscoveryV1beta1NamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1beta1/namespaces/{namespace}/endpointslices/{name}
     */
    replaceDiscoveryV1beta1NamespacedEndpointSlice<ResponseContentType extends ResponseContentType$replaceDiscoveryV1beta1NamespacedEndpointSlice>(params: Params$replaceDiscoveryV1beta1NamespacedEndpointSlice<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceDiscoveryV1beta1NamespacedEndpointSlice$Status$200 | Response$replaceDiscoveryV1beta1NamespacedEndpointSlice$Status$201)[ResponseContentType]>;
    /**
     * delete an EndpointSlice
     * operationId: deleteDiscoveryV1beta1NamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1beta1/namespaces/{namespace}/endpointslices/{name}
     */
    deleteDiscoveryV1beta1NamespacedEndpointSlice<ResponseContentType extends ResponseContentType$deleteDiscoveryV1beta1NamespacedEndpointSlice>(params: Params$deleteDiscoveryV1beta1NamespacedEndpointSlice<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteDiscoveryV1beta1NamespacedEndpointSlice$Status$200 | Response$deleteDiscoveryV1beta1NamespacedEndpointSlice$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified EndpointSlice
     * operationId: patchDiscoveryV1beta1NamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1beta1/namespaces/{namespace}/endpointslices/{name}
     */
    patchDiscoveryV1beta1NamespacedEndpointSlice<RequestContentType extends RequestContentType$patchDiscoveryV1beta1NamespacedEndpointSlice, ResponseContentType extends ResponseContentType$patchDiscoveryV1beta1NamespacedEndpointSlice>(params: Params$patchDiscoveryV1beta1NamespacedEndpointSlice<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchDiscoveryV1beta1NamespacedEndpointSlice$Status$200 | Response$patchDiscoveryV1beta1NamespacedEndpointSlice$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of EndpointSlice. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchDiscoveryV1beta1EndpointSliceListForAllNamespaces
     * Request URI: /apis/discovery.k8s.io/v1beta1/watch/endpointslices
     */
    watchDiscoveryV1beta1EndpointSliceListForAllNamespaces<ResponseContentType extends ResponseContentType$watchDiscoveryV1beta1EndpointSliceListForAllNamespaces>(params: Params$watchDiscoveryV1beta1EndpointSliceListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchDiscoveryV1beta1EndpointSliceListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of EndpointSlice. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchDiscoveryV1beta1NamespacedEndpointSliceList
     * Request URI: /apis/discovery.k8s.io/v1beta1/watch/namespaces/{namespace}/endpointslices
     */
    watchDiscoveryV1beta1NamespacedEndpointSliceList<ResponseContentType extends ResponseContentType$watchDiscoveryV1beta1NamespacedEndpointSliceList>(params: Params$watchDiscoveryV1beta1NamespacedEndpointSliceList<ResponseContentType>, option?: RequestOption): Promise<Response$watchDiscoveryV1beta1NamespacedEndpointSliceList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind EndpointSlice. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchDiscoveryV1beta1NamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1beta1/watch/namespaces/{namespace}/endpointslices/{name}
     */
    watchDiscoveryV1beta1NamespacedEndpointSlice<ResponseContentType extends ResponseContentType$watchDiscoveryV1beta1NamespacedEndpointSlice>(params: Params$watchDiscoveryV1beta1NamespacedEndpointSlice<ResponseContentType>, option?: RequestOption): Promise<Response$watchDiscoveryV1beta1NamespacedEndpointSlice$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getEventsAPIGroup
     * Request URI: /apis/events.k8s.io/
     */
    getEventsAPIGroup<ResponseContentType extends ResponseContentType$getEventsAPIGroup>(params: Params$getEventsAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getEventsAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getEventsV1APIResources
     * Request URI: /apis/events.k8s.io/v1/
     */
    getEventsV1APIResources<ResponseContentType extends ResponseContentType$getEventsV1APIResources>(params: Params$getEventsV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getEventsV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Event
     * operationId: listEventsV1EventForAllNamespaces
     * Request URI: /apis/events.k8s.io/v1/events
     */
    listEventsV1EventForAllNamespaces<ResponseContentType extends ResponseContentType$listEventsV1EventForAllNamespaces>(params: Params$listEventsV1EventForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listEventsV1EventForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Event
     * operationId: listEventsV1NamespacedEvent
     * Request URI: /apis/events.k8s.io/v1/namespaces/{namespace}/events
     */
    listEventsV1NamespacedEvent<ResponseContentType extends ResponseContentType$listEventsV1NamespacedEvent>(params: Params$listEventsV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<Response$listEventsV1NamespacedEvent$Status$200[ResponseContentType]>;
    /**
     * create an Event
     * operationId: createEventsV1NamespacedEvent
     * Request URI: /apis/events.k8s.io/v1/namespaces/{namespace}/events
     */
    createEventsV1NamespacedEvent<ResponseContentType extends ResponseContentType$createEventsV1NamespacedEvent>(params: Params$createEventsV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<(Response$createEventsV1NamespacedEvent$Status$200 | Response$createEventsV1NamespacedEvent$Status$201 | Response$createEventsV1NamespacedEvent$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Event
     * operationId: deleteEventsV1CollectionNamespacedEvent
     * Request URI: /apis/events.k8s.io/v1/namespaces/{namespace}/events
     */
    deleteEventsV1CollectionNamespacedEvent<ResponseContentType extends ResponseContentType$deleteEventsV1CollectionNamespacedEvent>(params: Params$deleteEventsV1CollectionNamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<Response$deleteEventsV1CollectionNamespacedEvent$Status$200[ResponseContentType]>;
    /**
     * read the specified Event
     * operationId: readEventsV1NamespacedEvent
     * Request URI: /apis/events.k8s.io/v1/namespaces/{namespace}/events/{name}
     */
    readEventsV1NamespacedEvent<ResponseContentType extends ResponseContentType$readEventsV1NamespacedEvent>(params: Params$readEventsV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<Response$readEventsV1NamespacedEvent$Status$200[ResponseContentType]>;
    /**
     * replace the specified Event
     * operationId: replaceEventsV1NamespacedEvent
     * Request URI: /apis/events.k8s.io/v1/namespaces/{namespace}/events/{name}
     */
    replaceEventsV1NamespacedEvent<ResponseContentType extends ResponseContentType$replaceEventsV1NamespacedEvent>(params: Params$replaceEventsV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceEventsV1NamespacedEvent$Status$200 | Response$replaceEventsV1NamespacedEvent$Status$201)[ResponseContentType]>;
    /**
     * delete an Event
     * operationId: deleteEventsV1NamespacedEvent
     * Request URI: /apis/events.k8s.io/v1/namespaces/{namespace}/events/{name}
     */
    deleteEventsV1NamespacedEvent<ResponseContentType extends ResponseContentType$deleteEventsV1NamespacedEvent>(params: Params$deleteEventsV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteEventsV1NamespacedEvent$Status$200 | Response$deleteEventsV1NamespacedEvent$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Event
     * operationId: patchEventsV1NamespacedEvent
     * Request URI: /apis/events.k8s.io/v1/namespaces/{namespace}/events/{name}
     */
    patchEventsV1NamespacedEvent<RequestContentType extends RequestContentType$patchEventsV1NamespacedEvent, ResponseContentType extends ResponseContentType$patchEventsV1NamespacedEvent>(params: Params$patchEventsV1NamespacedEvent<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchEventsV1NamespacedEvent$Status$200 | Response$patchEventsV1NamespacedEvent$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of Event. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchEventsV1EventListForAllNamespaces
     * Request URI: /apis/events.k8s.io/v1/watch/events
     */
    watchEventsV1EventListForAllNamespaces<ResponseContentType extends ResponseContentType$watchEventsV1EventListForAllNamespaces>(params: Params$watchEventsV1EventListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchEventsV1EventListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Event. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchEventsV1NamespacedEventList
     * Request URI: /apis/events.k8s.io/v1/watch/namespaces/{namespace}/events
     */
    watchEventsV1NamespacedEventList<ResponseContentType extends ResponseContentType$watchEventsV1NamespacedEventList>(params: Params$watchEventsV1NamespacedEventList<ResponseContentType>, option?: RequestOption): Promise<Response$watchEventsV1NamespacedEventList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Event. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchEventsV1NamespacedEvent
     * Request URI: /apis/events.k8s.io/v1/watch/namespaces/{namespace}/events/{name}
     */
    watchEventsV1NamespacedEvent<ResponseContentType extends ResponseContentType$watchEventsV1NamespacedEvent>(params: Params$watchEventsV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<Response$watchEventsV1NamespacedEvent$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getEventsV1beta1APIResources
     * Request URI: /apis/events.k8s.io/v1beta1/
     */
    getEventsV1beta1APIResources<ResponseContentType extends ResponseContentType$getEventsV1beta1APIResources>(params: Params$getEventsV1beta1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getEventsV1beta1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Event
     * operationId: listEventsV1beta1EventForAllNamespaces
     * Request URI: /apis/events.k8s.io/v1beta1/events
     */
    listEventsV1beta1EventForAllNamespaces<ResponseContentType extends ResponseContentType$listEventsV1beta1EventForAllNamespaces>(params: Params$listEventsV1beta1EventForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listEventsV1beta1EventForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Event
     * operationId: listEventsV1beta1NamespacedEvent
     * Request URI: /apis/events.k8s.io/v1beta1/namespaces/{namespace}/events
     */
    listEventsV1beta1NamespacedEvent<ResponseContentType extends ResponseContentType$listEventsV1beta1NamespacedEvent>(params: Params$listEventsV1beta1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<Response$listEventsV1beta1NamespacedEvent$Status$200[ResponseContentType]>;
    /**
     * create an Event
     * operationId: createEventsV1beta1NamespacedEvent
     * Request URI: /apis/events.k8s.io/v1beta1/namespaces/{namespace}/events
     */
    createEventsV1beta1NamespacedEvent<ResponseContentType extends ResponseContentType$createEventsV1beta1NamespacedEvent>(params: Params$createEventsV1beta1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<(Response$createEventsV1beta1NamespacedEvent$Status$200 | Response$createEventsV1beta1NamespacedEvent$Status$201 | Response$createEventsV1beta1NamespacedEvent$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Event
     * operationId: deleteEventsV1beta1CollectionNamespacedEvent
     * Request URI: /apis/events.k8s.io/v1beta1/namespaces/{namespace}/events
     */
    deleteEventsV1beta1CollectionNamespacedEvent<ResponseContentType extends ResponseContentType$deleteEventsV1beta1CollectionNamespacedEvent>(params: Params$deleteEventsV1beta1CollectionNamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<Response$deleteEventsV1beta1CollectionNamespacedEvent$Status$200[ResponseContentType]>;
    /**
     * read the specified Event
     * operationId: readEventsV1beta1NamespacedEvent
     * Request URI: /apis/events.k8s.io/v1beta1/namespaces/{namespace}/events/{name}
     */
    readEventsV1beta1NamespacedEvent<ResponseContentType extends ResponseContentType$readEventsV1beta1NamespacedEvent>(params: Params$readEventsV1beta1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<Response$readEventsV1beta1NamespacedEvent$Status$200[ResponseContentType]>;
    /**
     * replace the specified Event
     * operationId: replaceEventsV1beta1NamespacedEvent
     * Request URI: /apis/events.k8s.io/v1beta1/namespaces/{namespace}/events/{name}
     */
    replaceEventsV1beta1NamespacedEvent<ResponseContentType extends ResponseContentType$replaceEventsV1beta1NamespacedEvent>(params: Params$replaceEventsV1beta1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceEventsV1beta1NamespacedEvent$Status$200 | Response$replaceEventsV1beta1NamespacedEvent$Status$201)[ResponseContentType]>;
    /**
     * delete an Event
     * operationId: deleteEventsV1beta1NamespacedEvent
     * Request URI: /apis/events.k8s.io/v1beta1/namespaces/{namespace}/events/{name}
     */
    deleteEventsV1beta1NamespacedEvent<ResponseContentType extends ResponseContentType$deleteEventsV1beta1NamespacedEvent>(params: Params$deleteEventsV1beta1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteEventsV1beta1NamespacedEvent$Status$200 | Response$deleteEventsV1beta1NamespacedEvent$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Event
     * operationId: patchEventsV1beta1NamespacedEvent
     * Request URI: /apis/events.k8s.io/v1beta1/namespaces/{namespace}/events/{name}
     */
    patchEventsV1beta1NamespacedEvent<RequestContentType extends RequestContentType$patchEventsV1beta1NamespacedEvent, ResponseContentType extends ResponseContentType$patchEventsV1beta1NamespacedEvent>(params: Params$patchEventsV1beta1NamespacedEvent<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchEventsV1beta1NamespacedEvent$Status$200 | Response$patchEventsV1beta1NamespacedEvent$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of Event. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchEventsV1beta1EventListForAllNamespaces
     * Request URI: /apis/events.k8s.io/v1beta1/watch/events
     */
    watchEventsV1beta1EventListForAllNamespaces<ResponseContentType extends ResponseContentType$watchEventsV1beta1EventListForAllNamespaces>(params: Params$watchEventsV1beta1EventListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchEventsV1beta1EventListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Event. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchEventsV1beta1NamespacedEventList
     * Request URI: /apis/events.k8s.io/v1beta1/watch/namespaces/{namespace}/events
     */
    watchEventsV1beta1NamespacedEventList<ResponseContentType extends ResponseContentType$watchEventsV1beta1NamespacedEventList>(params: Params$watchEventsV1beta1NamespacedEventList<ResponseContentType>, option?: RequestOption): Promise<Response$watchEventsV1beta1NamespacedEventList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Event. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchEventsV1beta1NamespacedEvent
     * Request URI: /apis/events.k8s.io/v1beta1/watch/namespaces/{namespace}/events/{name}
     */
    watchEventsV1beta1NamespacedEvent<ResponseContentType extends ResponseContentType$watchEventsV1beta1NamespacedEvent>(params: Params$watchEventsV1beta1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<Response$watchEventsV1beta1NamespacedEvent$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getFlowcontrolApiserverAPIGroup
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/
     */
    getFlowcontrolApiserverAPIGroup<ResponseContentType extends ResponseContentType$getFlowcontrolApiserverAPIGroup>(params: Params$getFlowcontrolApiserverAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getFlowcontrolApiserverAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getFlowcontrolApiserverV1beta1APIResources
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/
     */
    getFlowcontrolApiserverV1beta1APIResources<ResponseContentType extends ResponseContentType$getFlowcontrolApiserverV1beta1APIResources>(params: Params$getFlowcontrolApiserverV1beta1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getFlowcontrolApiserverV1beta1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind FlowSchema
     * operationId: listFlowcontrolApiserverV1beta1FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/flowschemas
     */
    listFlowcontrolApiserverV1beta1FlowSchema<ResponseContentType extends ResponseContentType$listFlowcontrolApiserverV1beta1FlowSchema>(params: Params$listFlowcontrolApiserverV1beta1FlowSchema<ResponseContentType>, option?: RequestOption): Promise<Response$listFlowcontrolApiserverV1beta1FlowSchema$Status$200[ResponseContentType]>;
    /**
     * create a FlowSchema
     * operationId: createFlowcontrolApiserverV1beta1FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/flowschemas
     */
    createFlowcontrolApiserverV1beta1FlowSchema<ResponseContentType extends ResponseContentType$createFlowcontrolApiserverV1beta1FlowSchema>(params: Params$createFlowcontrolApiserverV1beta1FlowSchema<ResponseContentType>, option?: RequestOption): Promise<(Response$createFlowcontrolApiserverV1beta1FlowSchema$Status$200 | Response$createFlowcontrolApiserverV1beta1FlowSchema$Status$201 | Response$createFlowcontrolApiserverV1beta1FlowSchema$Status$202)[ResponseContentType]>;
    /**
     * delete collection of FlowSchema
     * operationId: deleteFlowcontrolApiserverV1beta1CollectionFlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/flowschemas
     */
    deleteFlowcontrolApiserverV1beta1CollectionFlowSchema<ResponseContentType extends ResponseContentType$deleteFlowcontrolApiserverV1beta1CollectionFlowSchema>(params: Params$deleteFlowcontrolApiserverV1beta1CollectionFlowSchema<ResponseContentType>, option?: RequestOption): Promise<Response$deleteFlowcontrolApiserverV1beta1CollectionFlowSchema$Status$200[ResponseContentType]>;
    /**
     * read the specified FlowSchema
     * operationId: readFlowcontrolApiserverV1beta1FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/flowschemas/{name}
     */
    readFlowcontrolApiserverV1beta1FlowSchema<ResponseContentType extends ResponseContentType$readFlowcontrolApiserverV1beta1FlowSchema>(params: Params$readFlowcontrolApiserverV1beta1FlowSchema<ResponseContentType>, option?: RequestOption): Promise<Response$readFlowcontrolApiserverV1beta1FlowSchema$Status$200[ResponseContentType]>;
    /**
     * replace the specified FlowSchema
     * operationId: replaceFlowcontrolApiserverV1beta1FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/flowschemas/{name}
     */
    replaceFlowcontrolApiserverV1beta1FlowSchema<ResponseContentType extends ResponseContentType$replaceFlowcontrolApiserverV1beta1FlowSchema>(params: Params$replaceFlowcontrolApiserverV1beta1FlowSchema<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceFlowcontrolApiserverV1beta1FlowSchema$Status$200 | Response$replaceFlowcontrolApiserverV1beta1FlowSchema$Status$201)[ResponseContentType]>;
    /**
     * delete a FlowSchema
     * operationId: deleteFlowcontrolApiserverV1beta1FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/flowschemas/{name}
     */
    deleteFlowcontrolApiserverV1beta1FlowSchema<ResponseContentType extends ResponseContentType$deleteFlowcontrolApiserverV1beta1FlowSchema>(params: Params$deleteFlowcontrolApiserverV1beta1FlowSchema<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteFlowcontrolApiserverV1beta1FlowSchema$Status$200 | Response$deleteFlowcontrolApiserverV1beta1FlowSchema$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified FlowSchema
     * operationId: patchFlowcontrolApiserverV1beta1FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/flowschemas/{name}
     */
    patchFlowcontrolApiserverV1beta1FlowSchema<RequestContentType extends RequestContentType$patchFlowcontrolApiserverV1beta1FlowSchema, ResponseContentType extends ResponseContentType$patchFlowcontrolApiserverV1beta1FlowSchema>(params: Params$patchFlowcontrolApiserverV1beta1FlowSchema<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchFlowcontrolApiserverV1beta1FlowSchema$Status$200 | Response$patchFlowcontrolApiserverV1beta1FlowSchema$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified FlowSchema
     * operationId: readFlowcontrolApiserverV1beta1FlowSchemaStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/flowschemas/{name}/status
     */
    readFlowcontrolApiserverV1beta1FlowSchemaStatus<ResponseContentType extends ResponseContentType$readFlowcontrolApiserverV1beta1FlowSchemaStatus>(params: Params$readFlowcontrolApiserverV1beta1FlowSchemaStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readFlowcontrolApiserverV1beta1FlowSchemaStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified FlowSchema
     * operationId: replaceFlowcontrolApiserverV1beta1FlowSchemaStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/flowschemas/{name}/status
     */
    replaceFlowcontrolApiserverV1beta1FlowSchemaStatus<ResponseContentType extends ResponseContentType$replaceFlowcontrolApiserverV1beta1FlowSchemaStatus>(params: Params$replaceFlowcontrolApiserverV1beta1FlowSchemaStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceFlowcontrolApiserverV1beta1FlowSchemaStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta1FlowSchemaStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified FlowSchema
     * operationId: patchFlowcontrolApiserverV1beta1FlowSchemaStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/flowschemas/{name}/status
     */
    patchFlowcontrolApiserverV1beta1FlowSchemaStatus<RequestContentType extends RequestContentType$patchFlowcontrolApiserverV1beta1FlowSchemaStatus, ResponseContentType extends ResponseContentType$patchFlowcontrolApiserverV1beta1FlowSchemaStatus>(params: Params$patchFlowcontrolApiserverV1beta1FlowSchemaStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchFlowcontrolApiserverV1beta1FlowSchemaStatus$Status$200 | Response$patchFlowcontrolApiserverV1beta1FlowSchemaStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind PriorityLevelConfiguration
     * operationId: listFlowcontrolApiserverV1beta1PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/prioritylevelconfigurations
     */
    listFlowcontrolApiserverV1beta1PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$listFlowcontrolApiserverV1beta1PriorityLevelConfiguration>(params: Params$listFlowcontrolApiserverV1beta1PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$listFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200[ResponseContentType]>;
    /**
     * create a PriorityLevelConfiguration
     * operationId: createFlowcontrolApiserverV1beta1PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/prioritylevelconfigurations
     */
    createFlowcontrolApiserverV1beta1PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$createFlowcontrolApiserverV1beta1PriorityLevelConfiguration>(params: Params$createFlowcontrolApiserverV1beta1PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$createFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200 | Response$createFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$201 | Response$createFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$202)[ResponseContentType]>;
    /**
     * delete collection of PriorityLevelConfiguration
     * operationId: deleteFlowcontrolApiserverV1beta1CollectionPriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/prioritylevelconfigurations
     */
    deleteFlowcontrolApiserverV1beta1CollectionPriorityLevelConfiguration<ResponseContentType extends ResponseContentType$deleteFlowcontrolApiserverV1beta1CollectionPriorityLevelConfiguration>(params: Params$deleteFlowcontrolApiserverV1beta1CollectionPriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$deleteFlowcontrolApiserverV1beta1CollectionPriorityLevelConfiguration$Status$200[ResponseContentType]>;
    /**
     * read the specified PriorityLevelConfiguration
     * operationId: readFlowcontrolApiserverV1beta1PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/prioritylevelconfigurations/{name}
     */
    readFlowcontrolApiserverV1beta1PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$readFlowcontrolApiserverV1beta1PriorityLevelConfiguration>(params: Params$readFlowcontrolApiserverV1beta1PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$readFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200[ResponseContentType]>;
    /**
     * replace the specified PriorityLevelConfiguration
     * operationId: replaceFlowcontrolApiserverV1beta1PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/prioritylevelconfigurations/{name}
     */
    replaceFlowcontrolApiserverV1beta1PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$replaceFlowcontrolApiserverV1beta1PriorityLevelConfiguration>(params: Params$replaceFlowcontrolApiserverV1beta1PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200 | Response$replaceFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$201)[ResponseContentType]>;
    /**
     * delete a PriorityLevelConfiguration
     * operationId: deleteFlowcontrolApiserverV1beta1PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/prioritylevelconfigurations/{name}
     */
    deleteFlowcontrolApiserverV1beta1PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$deleteFlowcontrolApiserverV1beta1PriorityLevelConfiguration>(params: Params$deleteFlowcontrolApiserverV1beta1PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200 | Response$deleteFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified PriorityLevelConfiguration
     * operationId: patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/prioritylevelconfigurations/{name}
     */
    patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration<RequestContentType extends RequestContentType$patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration, ResponseContentType extends ResponseContentType$patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration>(params: Params$patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200 | Response$patchFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified PriorityLevelConfiguration
     * operationId: readFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/prioritylevelconfigurations/{name}/status
     */
    readFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus<ResponseContentType extends ResponseContentType$readFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus>(params: Params$readFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified PriorityLevelConfiguration
     * operationId: replaceFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/prioritylevelconfigurations/{name}/status
     */
    replaceFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus<ResponseContentType extends ResponseContentType$replaceFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus>(params: Params$replaceFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified PriorityLevelConfiguration
     * operationId: patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/prioritylevelconfigurations/{name}/status
     */
    patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus<RequestContentType extends RequestContentType$patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus, ResponseContentType extends ResponseContentType$patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus>(params: Params$patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus$Status$200 | Response$patchFlowcontrolApiserverV1beta1PriorityLevelConfigurationStatus$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of FlowSchema. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchFlowcontrolApiserverV1beta1FlowSchemaList
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/watch/flowschemas
     */
    watchFlowcontrolApiserverV1beta1FlowSchemaList<ResponseContentType extends ResponseContentType$watchFlowcontrolApiserverV1beta1FlowSchemaList>(params: Params$watchFlowcontrolApiserverV1beta1FlowSchemaList<ResponseContentType>, option?: RequestOption): Promise<Response$watchFlowcontrolApiserverV1beta1FlowSchemaList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind FlowSchema. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchFlowcontrolApiserverV1beta1FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/watch/flowschemas/{name}
     */
    watchFlowcontrolApiserverV1beta1FlowSchema<ResponseContentType extends ResponseContentType$watchFlowcontrolApiserverV1beta1FlowSchema>(params: Params$watchFlowcontrolApiserverV1beta1FlowSchema<ResponseContentType>, option?: RequestOption): Promise<Response$watchFlowcontrolApiserverV1beta1FlowSchema$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of PriorityLevelConfiguration. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchFlowcontrolApiserverV1beta1PriorityLevelConfigurationList
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/watch/prioritylevelconfigurations
     */
    watchFlowcontrolApiserverV1beta1PriorityLevelConfigurationList<ResponseContentType extends ResponseContentType$watchFlowcontrolApiserverV1beta1PriorityLevelConfigurationList>(params: Params$watchFlowcontrolApiserverV1beta1PriorityLevelConfigurationList<ResponseContentType>, option?: RequestOption): Promise<Response$watchFlowcontrolApiserverV1beta1PriorityLevelConfigurationList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind PriorityLevelConfiguration. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchFlowcontrolApiserverV1beta1PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta1/watch/prioritylevelconfigurations/{name}
     */
    watchFlowcontrolApiserverV1beta1PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$watchFlowcontrolApiserverV1beta1PriorityLevelConfiguration>(params: Params$watchFlowcontrolApiserverV1beta1PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$watchFlowcontrolApiserverV1beta1PriorityLevelConfiguration$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getFlowcontrolApiserverV1beta2APIResources
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/
     */
    getFlowcontrolApiserverV1beta2APIResources<ResponseContentType extends ResponseContentType$getFlowcontrolApiserverV1beta2APIResources>(params: Params$getFlowcontrolApiserverV1beta2APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getFlowcontrolApiserverV1beta2APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind FlowSchema
     * operationId: listFlowcontrolApiserverV1beta2FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/flowschemas
     */
    listFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType extends ResponseContentType$listFlowcontrolApiserverV1beta2FlowSchema>(params: Params$listFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType>, option?: RequestOption): Promise<Response$listFlowcontrolApiserverV1beta2FlowSchema$Status$200[ResponseContentType]>;
    /**
     * create a FlowSchema
     * operationId: createFlowcontrolApiserverV1beta2FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/flowschemas
     */
    createFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType extends ResponseContentType$createFlowcontrolApiserverV1beta2FlowSchema>(params: Params$createFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType>, option?: RequestOption): Promise<(Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$200 | Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$201 | Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$202)[ResponseContentType]>;
    /**
     * delete collection of FlowSchema
     * operationId: deleteFlowcontrolApiserverV1beta2CollectionFlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/flowschemas
     */
    deleteFlowcontrolApiserverV1beta2CollectionFlowSchema<ResponseContentType extends ResponseContentType$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema>(params: Params$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema<ResponseContentType>, option?: RequestOption): Promise<Response$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema$Status$200[ResponseContentType]>;
    /**
     * read the specified FlowSchema
     * operationId: readFlowcontrolApiserverV1beta2FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/flowschemas/{name}
     */
    readFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType extends ResponseContentType$readFlowcontrolApiserverV1beta2FlowSchema>(params: Params$readFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType>, option?: RequestOption): Promise<Response$readFlowcontrolApiserverV1beta2FlowSchema$Status$200[ResponseContentType]>;
    /**
     * replace the specified FlowSchema
     * operationId: replaceFlowcontrolApiserverV1beta2FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/flowschemas/{name}
     */
    replaceFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType extends ResponseContentType$replaceFlowcontrolApiserverV1beta2FlowSchema>(params: Params$replaceFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceFlowcontrolApiserverV1beta2FlowSchema$Status$200 | Response$replaceFlowcontrolApiserverV1beta2FlowSchema$Status$201)[ResponseContentType]>;
    /**
     * delete a FlowSchema
     * operationId: deleteFlowcontrolApiserverV1beta2FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/flowschemas/{name}
     */
    deleteFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType extends ResponseContentType$deleteFlowcontrolApiserverV1beta2FlowSchema>(params: Params$deleteFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteFlowcontrolApiserverV1beta2FlowSchema$Status$200 | Response$deleteFlowcontrolApiserverV1beta2FlowSchema$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified FlowSchema
     * operationId: patchFlowcontrolApiserverV1beta2FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/flowschemas/{name}
     */
    patchFlowcontrolApiserverV1beta2FlowSchema<RequestContentType extends RequestContentType$patchFlowcontrolApiserverV1beta2FlowSchema, ResponseContentType extends ResponseContentType$patchFlowcontrolApiserverV1beta2FlowSchema>(params: Params$patchFlowcontrolApiserverV1beta2FlowSchema<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchFlowcontrolApiserverV1beta2FlowSchema$Status$200 | Response$patchFlowcontrolApiserverV1beta2FlowSchema$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified FlowSchema
     * operationId: readFlowcontrolApiserverV1beta2FlowSchemaStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/flowschemas/{name}/status
     */
    readFlowcontrolApiserverV1beta2FlowSchemaStatus<ResponseContentType extends ResponseContentType$readFlowcontrolApiserverV1beta2FlowSchemaStatus>(params: Params$readFlowcontrolApiserverV1beta2FlowSchemaStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified FlowSchema
     * operationId: replaceFlowcontrolApiserverV1beta2FlowSchemaStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/flowschemas/{name}/status
     */
    replaceFlowcontrolApiserverV1beta2FlowSchemaStatus<ResponseContentType extends ResponseContentType$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus>(params: Params$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified FlowSchema
     * operationId: patchFlowcontrolApiserverV1beta2FlowSchemaStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/flowschemas/{name}/status
     */
    patchFlowcontrolApiserverV1beta2FlowSchemaStatus<RequestContentType extends RequestContentType$patchFlowcontrolApiserverV1beta2FlowSchemaStatus, ResponseContentType extends ResponseContentType$patchFlowcontrolApiserverV1beta2FlowSchemaStatus>(params: Params$patchFlowcontrolApiserverV1beta2FlowSchemaStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200 | Response$patchFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind PriorityLevelConfiguration
     * operationId: listFlowcontrolApiserverV1beta2PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/prioritylevelconfigurations
     */
    listFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration>(params: Params$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200[ResponseContentType]>;
    /**
     * create a PriorityLevelConfiguration
     * operationId: createFlowcontrolApiserverV1beta2PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/prioritylevelconfigurations
     */
    createFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration>(params: Params$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201 | Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$202)[ResponseContentType]>;
    /**
     * delete collection of PriorityLevelConfiguration
     * operationId: deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/prioritylevelconfigurations
     */
    deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration<ResponseContentType extends ResponseContentType$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration>(params: Params$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration$Status$200[ResponseContentType]>;
    /**
     * read the specified PriorityLevelConfiguration
     * operationId: readFlowcontrolApiserverV1beta2PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/prioritylevelconfigurations/{name}
     */
    readFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration>(params: Params$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200[ResponseContentType]>;
    /**
     * replace the specified PriorityLevelConfiguration
     * operationId: replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/prioritylevelconfigurations/{name}
     */
    replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration>(params: Params$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201)[ResponseContentType]>;
    /**
     * delete a PriorityLevelConfiguration
     * operationId: deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/prioritylevelconfigurations/{name}
     */
    deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration>(params: Params$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | Response$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified PriorityLevelConfiguration
     * operationId: patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/prioritylevelconfigurations/{name}
     */
    patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration<RequestContentType extends RequestContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration, ResponseContentType extends ResponseContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration>(params: Params$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified PriorityLevelConfiguration
     * operationId: readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/prioritylevelconfigurations/{name}/status
     */
    readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus<ResponseContentType extends ResponseContentType$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus>(params: Params$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified PriorityLevelConfiguration
     * operationId: replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/prioritylevelconfigurations/{name}/status
     */
    replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus<ResponseContentType extends ResponseContentType$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus>(params: Params$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified PriorityLevelConfiguration
     * operationId: patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/prioritylevelconfigurations/{name}/status
     */
    patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus<RequestContentType extends RequestContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus, ResponseContentType extends ResponseContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus>(params: Params$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200 | Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of FlowSchema. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchFlowcontrolApiserverV1beta2FlowSchemaList
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/watch/flowschemas
     */
    watchFlowcontrolApiserverV1beta2FlowSchemaList<ResponseContentType extends ResponseContentType$watchFlowcontrolApiserverV1beta2FlowSchemaList>(params: Params$watchFlowcontrolApiserverV1beta2FlowSchemaList<ResponseContentType>, option?: RequestOption): Promise<Response$watchFlowcontrolApiserverV1beta2FlowSchemaList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind FlowSchema. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchFlowcontrolApiserverV1beta2FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/watch/flowschemas/{name}
     */
    watchFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType extends ResponseContentType$watchFlowcontrolApiserverV1beta2FlowSchema>(params: Params$watchFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType>, option?: RequestOption): Promise<Response$watchFlowcontrolApiserverV1beta2FlowSchema$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of PriorityLevelConfiguration. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/watch/prioritylevelconfigurations
     */
    watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList<ResponseContentType extends ResponseContentType$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList>(params: Params$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList<ResponseContentType>, option?: RequestOption): Promise<Response$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind PriorityLevelConfiguration. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/watch/prioritylevelconfigurations/{name}
     */
    watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration>(params: Params$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getInternalApiserverAPIGroup
     * Request URI: /apis/internal.apiserver.k8s.io/
     */
    getInternalApiserverAPIGroup<ResponseContentType extends ResponseContentType$getInternalApiserverAPIGroup>(params: Params$getInternalApiserverAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getInternalApiserverAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getInternalApiserverV1alpha1APIResources
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/
     */
    getInternalApiserverV1alpha1APIResources<ResponseContentType extends ResponseContentType$getInternalApiserverV1alpha1APIResources>(params: Params$getInternalApiserverV1alpha1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getInternalApiserverV1alpha1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind StorageVersion
     * operationId: listInternalApiserverV1alpha1StorageVersion
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/storageversions
     */
    listInternalApiserverV1alpha1StorageVersion<ResponseContentType extends ResponseContentType$listInternalApiserverV1alpha1StorageVersion>(params: Params$listInternalApiserverV1alpha1StorageVersion<ResponseContentType>, option?: RequestOption): Promise<Response$listInternalApiserverV1alpha1StorageVersion$Status$200[ResponseContentType]>;
    /**
     * create a StorageVersion
     * operationId: createInternalApiserverV1alpha1StorageVersion
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/storageversions
     */
    createInternalApiserverV1alpha1StorageVersion<ResponseContentType extends ResponseContentType$createInternalApiserverV1alpha1StorageVersion>(params: Params$createInternalApiserverV1alpha1StorageVersion<ResponseContentType>, option?: RequestOption): Promise<(Response$createInternalApiserverV1alpha1StorageVersion$Status$200 | Response$createInternalApiserverV1alpha1StorageVersion$Status$201 | Response$createInternalApiserverV1alpha1StorageVersion$Status$202)[ResponseContentType]>;
    /**
     * delete collection of StorageVersion
     * operationId: deleteInternalApiserverV1alpha1CollectionStorageVersion
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/storageversions
     */
    deleteInternalApiserverV1alpha1CollectionStorageVersion<ResponseContentType extends ResponseContentType$deleteInternalApiserverV1alpha1CollectionStorageVersion>(params: Params$deleteInternalApiserverV1alpha1CollectionStorageVersion<ResponseContentType>, option?: RequestOption): Promise<Response$deleteInternalApiserverV1alpha1CollectionStorageVersion$Status$200[ResponseContentType]>;
    /**
     * read the specified StorageVersion
     * operationId: readInternalApiserverV1alpha1StorageVersion
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/storageversions/{name}
     */
    readInternalApiserverV1alpha1StorageVersion<ResponseContentType extends ResponseContentType$readInternalApiserverV1alpha1StorageVersion>(params: Params$readInternalApiserverV1alpha1StorageVersion<ResponseContentType>, option?: RequestOption): Promise<Response$readInternalApiserverV1alpha1StorageVersion$Status$200[ResponseContentType]>;
    /**
     * replace the specified StorageVersion
     * operationId: replaceInternalApiserverV1alpha1StorageVersion
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/storageversions/{name}
     */
    replaceInternalApiserverV1alpha1StorageVersion<ResponseContentType extends ResponseContentType$replaceInternalApiserverV1alpha1StorageVersion>(params: Params$replaceInternalApiserverV1alpha1StorageVersion<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceInternalApiserverV1alpha1StorageVersion$Status$200 | Response$replaceInternalApiserverV1alpha1StorageVersion$Status$201)[ResponseContentType]>;
    /**
     * delete a StorageVersion
     * operationId: deleteInternalApiserverV1alpha1StorageVersion
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/storageversions/{name}
     */
    deleteInternalApiserverV1alpha1StorageVersion<ResponseContentType extends ResponseContentType$deleteInternalApiserverV1alpha1StorageVersion>(params: Params$deleteInternalApiserverV1alpha1StorageVersion<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteInternalApiserverV1alpha1StorageVersion$Status$200 | Response$deleteInternalApiserverV1alpha1StorageVersion$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified StorageVersion
     * operationId: patchInternalApiserverV1alpha1StorageVersion
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/storageversions/{name}
     */
    patchInternalApiserverV1alpha1StorageVersion<RequestContentType extends RequestContentType$patchInternalApiserverV1alpha1StorageVersion, ResponseContentType extends ResponseContentType$patchInternalApiserverV1alpha1StorageVersion>(params: Params$patchInternalApiserverV1alpha1StorageVersion<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchInternalApiserverV1alpha1StorageVersion$Status$200 | Response$patchInternalApiserverV1alpha1StorageVersion$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified StorageVersion
     * operationId: readInternalApiserverV1alpha1StorageVersionStatus
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/storageversions/{name}/status
     */
    readInternalApiserverV1alpha1StorageVersionStatus<ResponseContentType extends ResponseContentType$readInternalApiserverV1alpha1StorageVersionStatus>(params: Params$readInternalApiserverV1alpha1StorageVersionStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readInternalApiserverV1alpha1StorageVersionStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified StorageVersion
     * operationId: replaceInternalApiserverV1alpha1StorageVersionStatus
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/storageversions/{name}/status
     */
    replaceInternalApiserverV1alpha1StorageVersionStatus<ResponseContentType extends ResponseContentType$replaceInternalApiserverV1alpha1StorageVersionStatus>(params: Params$replaceInternalApiserverV1alpha1StorageVersionStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceInternalApiserverV1alpha1StorageVersionStatus$Status$200 | Response$replaceInternalApiserverV1alpha1StorageVersionStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified StorageVersion
     * operationId: patchInternalApiserverV1alpha1StorageVersionStatus
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/storageversions/{name}/status
     */
    patchInternalApiserverV1alpha1StorageVersionStatus<RequestContentType extends RequestContentType$patchInternalApiserverV1alpha1StorageVersionStatus, ResponseContentType extends ResponseContentType$patchInternalApiserverV1alpha1StorageVersionStatus>(params: Params$patchInternalApiserverV1alpha1StorageVersionStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchInternalApiserverV1alpha1StorageVersionStatus$Status$200 | Response$patchInternalApiserverV1alpha1StorageVersionStatus$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of StorageVersion. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchInternalApiserverV1alpha1StorageVersionList
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/watch/storageversions
     */
    watchInternalApiserverV1alpha1StorageVersionList<ResponseContentType extends ResponseContentType$watchInternalApiserverV1alpha1StorageVersionList>(params: Params$watchInternalApiserverV1alpha1StorageVersionList<ResponseContentType>, option?: RequestOption): Promise<Response$watchInternalApiserverV1alpha1StorageVersionList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind StorageVersion. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchInternalApiserverV1alpha1StorageVersion
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/watch/storageversions/{name}
     */
    watchInternalApiserverV1alpha1StorageVersion<ResponseContentType extends ResponseContentType$watchInternalApiserverV1alpha1StorageVersion>(params: Params$watchInternalApiserverV1alpha1StorageVersion<ResponseContentType>, option?: RequestOption): Promise<Response$watchInternalApiserverV1alpha1StorageVersion$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getNetworkingAPIGroup
     * Request URI: /apis/networking.k8s.io/
     */
    getNetworkingAPIGroup<ResponseContentType extends ResponseContentType$getNetworkingAPIGroup>(params: Params$getNetworkingAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getNetworkingAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getNetworkingV1APIResources
     * Request URI: /apis/networking.k8s.io/v1/
     */
    getNetworkingV1APIResources<ResponseContentType extends ResponseContentType$getNetworkingV1APIResources>(params: Params$getNetworkingV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getNetworkingV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind IngressClass
     * operationId: listNetworkingV1IngressClass
     * Request URI: /apis/networking.k8s.io/v1/ingressclasses
     */
    listNetworkingV1IngressClass<ResponseContentType extends ResponseContentType$listNetworkingV1IngressClass>(params: Params$listNetworkingV1IngressClass<ResponseContentType>, option?: RequestOption): Promise<Response$listNetworkingV1IngressClass$Status$200[ResponseContentType]>;
    /**
     * create an IngressClass
     * operationId: createNetworkingV1IngressClass
     * Request URI: /apis/networking.k8s.io/v1/ingressclasses
     */
    createNetworkingV1IngressClass<ResponseContentType extends ResponseContentType$createNetworkingV1IngressClass>(params: Params$createNetworkingV1IngressClass<ResponseContentType>, option?: RequestOption): Promise<(Response$createNetworkingV1IngressClass$Status$200 | Response$createNetworkingV1IngressClass$Status$201 | Response$createNetworkingV1IngressClass$Status$202)[ResponseContentType]>;
    /**
     * delete collection of IngressClass
     * operationId: deleteNetworkingV1CollectionIngressClass
     * Request URI: /apis/networking.k8s.io/v1/ingressclasses
     */
    deleteNetworkingV1CollectionIngressClass<ResponseContentType extends ResponseContentType$deleteNetworkingV1CollectionIngressClass>(params: Params$deleteNetworkingV1CollectionIngressClass<ResponseContentType>, option?: RequestOption): Promise<Response$deleteNetworkingV1CollectionIngressClass$Status$200[ResponseContentType]>;
    /**
     * read the specified IngressClass
     * operationId: readNetworkingV1IngressClass
     * Request URI: /apis/networking.k8s.io/v1/ingressclasses/{name}
     */
    readNetworkingV1IngressClass<ResponseContentType extends ResponseContentType$readNetworkingV1IngressClass>(params: Params$readNetworkingV1IngressClass<ResponseContentType>, option?: RequestOption): Promise<Response$readNetworkingV1IngressClass$Status$200[ResponseContentType]>;
    /**
     * replace the specified IngressClass
     * operationId: replaceNetworkingV1IngressClass
     * Request URI: /apis/networking.k8s.io/v1/ingressclasses/{name}
     */
    replaceNetworkingV1IngressClass<ResponseContentType extends ResponseContentType$replaceNetworkingV1IngressClass>(params: Params$replaceNetworkingV1IngressClass<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceNetworkingV1IngressClass$Status$200 | Response$replaceNetworkingV1IngressClass$Status$201)[ResponseContentType]>;
    /**
     * delete an IngressClass
     * operationId: deleteNetworkingV1IngressClass
     * Request URI: /apis/networking.k8s.io/v1/ingressclasses/{name}
     */
    deleteNetworkingV1IngressClass<ResponseContentType extends ResponseContentType$deleteNetworkingV1IngressClass>(params: Params$deleteNetworkingV1IngressClass<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteNetworkingV1IngressClass$Status$200 | Response$deleteNetworkingV1IngressClass$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified IngressClass
     * operationId: patchNetworkingV1IngressClass
     * Request URI: /apis/networking.k8s.io/v1/ingressclasses/{name}
     */
    patchNetworkingV1IngressClass<RequestContentType extends RequestContentType$patchNetworkingV1IngressClass, ResponseContentType extends ResponseContentType$patchNetworkingV1IngressClass>(params: Params$patchNetworkingV1IngressClass<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchNetworkingV1IngressClass$Status$200 | Response$patchNetworkingV1IngressClass$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind Ingress
     * operationId: listNetworkingV1IngressForAllNamespaces
     * Request URI: /apis/networking.k8s.io/v1/ingresses
     */
    listNetworkingV1IngressForAllNamespaces<ResponseContentType extends ResponseContentType$listNetworkingV1IngressForAllNamespaces>(params: Params$listNetworkingV1IngressForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listNetworkingV1IngressForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Ingress
     * operationId: listNetworkingV1NamespacedIngress
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/ingresses
     */
    listNetworkingV1NamespacedIngress<ResponseContentType extends ResponseContentType$listNetworkingV1NamespacedIngress>(params: Params$listNetworkingV1NamespacedIngress<ResponseContentType>, option?: RequestOption): Promise<Response$listNetworkingV1NamespacedIngress$Status$200[ResponseContentType]>;
    /**
     * create an Ingress
     * operationId: createNetworkingV1NamespacedIngress
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/ingresses
     */
    createNetworkingV1NamespacedIngress<ResponseContentType extends ResponseContentType$createNetworkingV1NamespacedIngress>(params: Params$createNetworkingV1NamespacedIngress<ResponseContentType>, option?: RequestOption): Promise<(Response$createNetworkingV1NamespacedIngress$Status$200 | Response$createNetworkingV1NamespacedIngress$Status$201 | Response$createNetworkingV1NamespacedIngress$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Ingress
     * operationId: deleteNetworkingV1CollectionNamespacedIngress
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/ingresses
     */
    deleteNetworkingV1CollectionNamespacedIngress<ResponseContentType extends ResponseContentType$deleteNetworkingV1CollectionNamespacedIngress>(params: Params$deleteNetworkingV1CollectionNamespacedIngress<ResponseContentType>, option?: RequestOption): Promise<Response$deleteNetworkingV1CollectionNamespacedIngress$Status$200[ResponseContentType]>;
    /**
     * read the specified Ingress
     * operationId: readNetworkingV1NamespacedIngress
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/ingresses/{name}
     */
    readNetworkingV1NamespacedIngress<ResponseContentType extends ResponseContentType$readNetworkingV1NamespacedIngress>(params: Params$readNetworkingV1NamespacedIngress<ResponseContentType>, option?: RequestOption): Promise<Response$readNetworkingV1NamespacedIngress$Status$200[ResponseContentType]>;
    /**
     * replace the specified Ingress
     * operationId: replaceNetworkingV1NamespacedIngress
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/ingresses/{name}
     */
    replaceNetworkingV1NamespacedIngress<ResponseContentType extends ResponseContentType$replaceNetworkingV1NamespacedIngress>(params: Params$replaceNetworkingV1NamespacedIngress<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceNetworkingV1NamespacedIngress$Status$200 | Response$replaceNetworkingV1NamespacedIngress$Status$201)[ResponseContentType]>;
    /**
     * delete an Ingress
     * operationId: deleteNetworkingV1NamespacedIngress
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/ingresses/{name}
     */
    deleteNetworkingV1NamespacedIngress<ResponseContentType extends ResponseContentType$deleteNetworkingV1NamespacedIngress>(params: Params$deleteNetworkingV1NamespacedIngress<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteNetworkingV1NamespacedIngress$Status$200 | Response$deleteNetworkingV1NamespacedIngress$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Ingress
     * operationId: patchNetworkingV1NamespacedIngress
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/ingresses/{name}
     */
    patchNetworkingV1NamespacedIngress<RequestContentType extends RequestContentType$patchNetworkingV1NamespacedIngress, ResponseContentType extends ResponseContentType$patchNetworkingV1NamespacedIngress>(params: Params$patchNetworkingV1NamespacedIngress<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchNetworkingV1NamespacedIngress$Status$200 | Response$patchNetworkingV1NamespacedIngress$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified Ingress
     * operationId: readNetworkingV1NamespacedIngressStatus
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/ingresses/{name}/status
     */
    readNetworkingV1NamespacedIngressStatus<ResponseContentType extends ResponseContentType$readNetworkingV1NamespacedIngressStatus>(params: Params$readNetworkingV1NamespacedIngressStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readNetworkingV1NamespacedIngressStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified Ingress
     * operationId: replaceNetworkingV1NamespacedIngressStatus
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/ingresses/{name}/status
     */
    replaceNetworkingV1NamespacedIngressStatus<ResponseContentType extends ResponseContentType$replaceNetworkingV1NamespacedIngressStatus>(params: Params$replaceNetworkingV1NamespacedIngressStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceNetworkingV1NamespacedIngressStatus$Status$200 | Response$replaceNetworkingV1NamespacedIngressStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified Ingress
     * operationId: patchNetworkingV1NamespacedIngressStatus
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/ingresses/{name}/status
     */
    patchNetworkingV1NamespacedIngressStatus<RequestContentType extends RequestContentType$patchNetworkingV1NamespacedIngressStatus, ResponseContentType extends ResponseContentType$patchNetworkingV1NamespacedIngressStatus>(params: Params$patchNetworkingV1NamespacedIngressStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchNetworkingV1NamespacedIngressStatus$Status$200 | Response$patchNetworkingV1NamespacedIngressStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind NetworkPolicy
     * operationId: listNetworkingV1NamespacedNetworkPolicy
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies
     */
    listNetworkingV1NamespacedNetworkPolicy<ResponseContentType extends ResponseContentType$listNetworkingV1NamespacedNetworkPolicy>(params: Params$listNetworkingV1NamespacedNetworkPolicy<ResponseContentType>, option?: RequestOption): Promise<Response$listNetworkingV1NamespacedNetworkPolicy$Status$200[ResponseContentType]>;
    /**
     * create a NetworkPolicy
     * operationId: createNetworkingV1NamespacedNetworkPolicy
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies
     */
    createNetworkingV1NamespacedNetworkPolicy<ResponseContentType extends ResponseContentType$createNetworkingV1NamespacedNetworkPolicy>(params: Params$createNetworkingV1NamespacedNetworkPolicy<ResponseContentType>, option?: RequestOption): Promise<(Response$createNetworkingV1NamespacedNetworkPolicy$Status$200 | Response$createNetworkingV1NamespacedNetworkPolicy$Status$201 | Response$createNetworkingV1NamespacedNetworkPolicy$Status$202)[ResponseContentType]>;
    /**
     * delete collection of NetworkPolicy
     * operationId: deleteNetworkingV1CollectionNamespacedNetworkPolicy
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies
     */
    deleteNetworkingV1CollectionNamespacedNetworkPolicy<ResponseContentType extends ResponseContentType$deleteNetworkingV1CollectionNamespacedNetworkPolicy>(params: Params$deleteNetworkingV1CollectionNamespacedNetworkPolicy<ResponseContentType>, option?: RequestOption): Promise<Response$deleteNetworkingV1CollectionNamespacedNetworkPolicy$Status$200[ResponseContentType]>;
    /**
     * read the specified NetworkPolicy
     * operationId: readNetworkingV1NamespacedNetworkPolicy
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies/{name}
     */
    readNetworkingV1NamespacedNetworkPolicy<ResponseContentType extends ResponseContentType$readNetworkingV1NamespacedNetworkPolicy>(params: Params$readNetworkingV1NamespacedNetworkPolicy<ResponseContentType>, option?: RequestOption): Promise<Response$readNetworkingV1NamespacedNetworkPolicy$Status$200[ResponseContentType]>;
    /**
     * replace the specified NetworkPolicy
     * operationId: replaceNetworkingV1NamespacedNetworkPolicy
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies/{name}
     */
    replaceNetworkingV1NamespacedNetworkPolicy<ResponseContentType extends ResponseContentType$replaceNetworkingV1NamespacedNetworkPolicy>(params: Params$replaceNetworkingV1NamespacedNetworkPolicy<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceNetworkingV1NamespacedNetworkPolicy$Status$200 | Response$replaceNetworkingV1NamespacedNetworkPolicy$Status$201)[ResponseContentType]>;
    /**
     * delete a NetworkPolicy
     * operationId: deleteNetworkingV1NamespacedNetworkPolicy
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies/{name}
     */
    deleteNetworkingV1NamespacedNetworkPolicy<ResponseContentType extends ResponseContentType$deleteNetworkingV1NamespacedNetworkPolicy>(params: Params$deleteNetworkingV1NamespacedNetworkPolicy<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteNetworkingV1NamespacedNetworkPolicy$Status$200 | Response$deleteNetworkingV1NamespacedNetworkPolicy$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified NetworkPolicy
     * operationId: patchNetworkingV1NamespacedNetworkPolicy
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies/{name}
     */
    patchNetworkingV1NamespacedNetworkPolicy<RequestContentType extends RequestContentType$patchNetworkingV1NamespacedNetworkPolicy, ResponseContentType extends ResponseContentType$patchNetworkingV1NamespacedNetworkPolicy>(params: Params$patchNetworkingV1NamespacedNetworkPolicy<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchNetworkingV1NamespacedNetworkPolicy$Status$200 | Response$patchNetworkingV1NamespacedNetworkPolicy$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind NetworkPolicy
     * operationId: listNetworkingV1NetworkPolicyForAllNamespaces
     * Request URI: /apis/networking.k8s.io/v1/networkpolicies
     */
    listNetworkingV1NetworkPolicyForAllNamespaces<ResponseContentType extends ResponseContentType$listNetworkingV1NetworkPolicyForAllNamespaces>(params: Params$listNetworkingV1NetworkPolicyForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listNetworkingV1NetworkPolicyForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of IngressClass. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchNetworkingV1IngressClassList
     * Request URI: /apis/networking.k8s.io/v1/watch/ingressclasses
     */
    watchNetworkingV1IngressClassList<ResponseContentType extends ResponseContentType$watchNetworkingV1IngressClassList>(params: Params$watchNetworkingV1IngressClassList<ResponseContentType>, option?: RequestOption): Promise<Response$watchNetworkingV1IngressClassList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind IngressClass. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchNetworkingV1IngressClass
     * Request URI: /apis/networking.k8s.io/v1/watch/ingressclasses/{name}
     */
    watchNetworkingV1IngressClass<ResponseContentType extends ResponseContentType$watchNetworkingV1IngressClass>(params: Params$watchNetworkingV1IngressClass<ResponseContentType>, option?: RequestOption): Promise<Response$watchNetworkingV1IngressClass$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Ingress. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchNetworkingV1IngressListForAllNamespaces
     * Request URI: /apis/networking.k8s.io/v1/watch/ingresses
     */
    watchNetworkingV1IngressListForAllNamespaces<ResponseContentType extends ResponseContentType$watchNetworkingV1IngressListForAllNamespaces>(params: Params$watchNetworkingV1IngressListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchNetworkingV1IngressListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Ingress. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchNetworkingV1NamespacedIngressList
     * Request URI: /apis/networking.k8s.io/v1/watch/namespaces/{namespace}/ingresses
     */
    watchNetworkingV1NamespacedIngressList<ResponseContentType extends ResponseContentType$watchNetworkingV1NamespacedIngressList>(params: Params$watchNetworkingV1NamespacedIngressList<ResponseContentType>, option?: RequestOption): Promise<Response$watchNetworkingV1NamespacedIngressList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Ingress. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchNetworkingV1NamespacedIngress
     * Request URI: /apis/networking.k8s.io/v1/watch/namespaces/{namespace}/ingresses/{name}
     */
    watchNetworkingV1NamespacedIngress<ResponseContentType extends ResponseContentType$watchNetworkingV1NamespacedIngress>(params: Params$watchNetworkingV1NamespacedIngress<ResponseContentType>, option?: RequestOption): Promise<Response$watchNetworkingV1NamespacedIngress$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of NetworkPolicy. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchNetworkingV1NamespacedNetworkPolicyList
     * Request URI: /apis/networking.k8s.io/v1/watch/namespaces/{namespace}/networkpolicies
     */
    watchNetworkingV1NamespacedNetworkPolicyList<ResponseContentType extends ResponseContentType$watchNetworkingV1NamespacedNetworkPolicyList>(params: Params$watchNetworkingV1NamespacedNetworkPolicyList<ResponseContentType>, option?: RequestOption): Promise<Response$watchNetworkingV1NamespacedNetworkPolicyList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind NetworkPolicy. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchNetworkingV1NamespacedNetworkPolicy
     * Request URI: /apis/networking.k8s.io/v1/watch/namespaces/{namespace}/networkpolicies/{name}
     */
    watchNetworkingV1NamespacedNetworkPolicy<ResponseContentType extends ResponseContentType$watchNetworkingV1NamespacedNetworkPolicy>(params: Params$watchNetworkingV1NamespacedNetworkPolicy<ResponseContentType>, option?: RequestOption): Promise<Response$watchNetworkingV1NamespacedNetworkPolicy$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of NetworkPolicy. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchNetworkingV1NetworkPolicyListForAllNamespaces
     * Request URI: /apis/networking.k8s.io/v1/watch/networkpolicies
     */
    watchNetworkingV1NetworkPolicyListForAllNamespaces<ResponseContentType extends ResponseContentType$watchNetworkingV1NetworkPolicyListForAllNamespaces>(params: Params$watchNetworkingV1NetworkPolicyListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchNetworkingV1NetworkPolicyListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getNodeAPIGroup
     * Request URI: /apis/node.k8s.io/
     */
    getNodeAPIGroup<ResponseContentType extends ResponseContentType$getNodeAPIGroup>(params: Params$getNodeAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getNodeAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getNodeV1APIResources
     * Request URI: /apis/node.k8s.io/v1/
     */
    getNodeV1APIResources<ResponseContentType extends ResponseContentType$getNodeV1APIResources>(params: Params$getNodeV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getNodeV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind RuntimeClass
     * operationId: listNodeV1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1/runtimeclasses
     */
    listNodeV1RuntimeClass<ResponseContentType extends ResponseContentType$listNodeV1RuntimeClass>(params: Params$listNodeV1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<Response$listNodeV1RuntimeClass$Status$200[ResponseContentType]>;
    /**
     * create a RuntimeClass
     * operationId: createNodeV1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1/runtimeclasses
     */
    createNodeV1RuntimeClass<ResponseContentType extends ResponseContentType$createNodeV1RuntimeClass>(params: Params$createNodeV1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<(Response$createNodeV1RuntimeClass$Status$200 | Response$createNodeV1RuntimeClass$Status$201 | Response$createNodeV1RuntimeClass$Status$202)[ResponseContentType]>;
    /**
     * delete collection of RuntimeClass
     * operationId: deleteNodeV1CollectionRuntimeClass
     * Request URI: /apis/node.k8s.io/v1/runtimeclasses
     */
    deleteNodeV1CollectionRuntimeClass<ResponseContentType extends ResponseContentType$deleteNodeV1CollectionRuntimeClass>(params: Params$deleteNodeV1CollectionRuntimeClass<ResponseContentType>, option?: RequestOption): Promise<Response$deleteNodeV1CollectionRuntimeClass$Status$200[ResponseContentType]>;
    /**
     * read the specified RuntimeClass
     * operationId: readNodeV1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1/runtimeclasses/{name}
     */
    readNodeV1RuntimeClass<ResponseContentType extends ResponseContentType$readNodeV1RuntimeClass>(params: Params$readNodeV1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<Response$readNodeV1RuntimeClass$Status$200[ResponseContentType]>;
    /**
     * replace the specified RuntimeClass
     * operationId: replaceNodeV1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1/runtimeclasses/{name}
     */
    replaceNodeV1RuntimeClass<ResponseContentType extends ResponseContentType$replaceNodeV1RuntimeClass>(params: Params$replaceNodeV1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceNodeV1RuntimeClass$Status$200 | Response$replaceNodeV1RuntimeClass$Status$201)[ResponseContentType]>;
    /**
     * delete a RuntimeClass
     * operationId: deleteNodeV1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1/runtimeclasses/{name}
     */
    deleteNodeV1RuntimeClass<ResponseContentType extends ResponseContentType$deleteNodeV1RuntimeClass>(params: Params$deleteNodeV1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteNodeV1RuntimeClass$Status$200 | Response$deleteNodeV1RuntimeClass$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified RuntimeClass
     * operationId: patchNodeV1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1/runtimeclasses/{name}
     */
    patchNodeV1RuntimeClass<RequestContentType extends RequestContentType$patchNodeV1RuntimeClass, ResponseContentType extends ResponseContentType$patchNodeV1RuntimeClass>(params: Params$patchNodeV1RuntimeClass<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchNodeV1RuntimeClass$Status$200 | Response$patchNodeV1RuntimeClass$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of RuntimeClass. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchNodeV1RuntimeClassList
     * Request URI: /apis/node.k8s.io/v1/watch/runtimeclasses
     */
    watchNodeV1RuntimeClassList<ResponseContentType extends ResponseContentType$watchNodeV1RuntimeClassList>(params: Params$watchNodeV1RuntimeClassList<ResponseContentType>, option?: RequestOption): Promise<Response$watchNodeV1RuntimeClassList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind RuntimeClass. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchNodeV1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1/watch/runtimeclasses/{name}
     */
    watchNodeV1RuntimeClass<ResponseContentType extends ResponseContentType$watchNodeV1RuntimeClass>(params: Params$watchNodeV1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<Response$watchNodeV1RuntimeClass$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getNodeV1alpha1APIResources
     * Request URI: /apis/node.k8s.io/v1alpha1/
     */
    getNodeV1alpha1APIResources<ResponseContentType extends ResponseContentType$getNodeV1alpha1APIResources>(params: Params$getNodeV1alpha1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getNodeV1alpha1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind RuntimeClass
     * operationId: listNodeV1alpha1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1alpha1/runtimeclasses
     */
    listNodeV1alpha1RuntimeClass<ResponseContentType extends ResponseContentType$listNodeV1alpha1RuntimeClass>(params: Params$listNodeV1alpha1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<Response$listNodeV1alpha1RuntimeClass$Status$200[ResponseContentType]>;
    /**
     * create a RuntimeClass
     * operationId: createNodeV1alpha1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1alpha1/runtimeclasses
     */
    createNodeV1alpha1RuntimeClass<ResponseContentType extends ResponseContentType$createNodeV1alpha1RuntimeClass>(params: Params$createNodeV1alpha1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<(Response$createNodeV1alpha1RuntimeClass$Status$200 | Response$createNodeV1alpha1RuntimeClass$Status$201 | Response$createNodeV1alpha1RuntimeClass$Status$202)[ResponseContentType]>;
    /**
     * delete collection of RuntimeClass
     * operationId: deleteNodeV1alpha1CollectionRuntimeClass
     * Request URI: /apis/node.k8s.io/v1alpha1/runtimeclasses
     */
    deleteNodeV1alpha1CollectionRuntimeClass<ResponseContentType extends ResponseContentType$deleteNodeV1alpha1CollectionRuntimeClass>(params: Params$deleteNodeV1alpha1CollectionRuntimeClass<ResponseContentType>, option?: RequestOption): Promise<Response$deleteNodeV1alpha1CollectionRuntimeClass$Status$200[ResponseContentType]>;
    /**
     * read the specified RuntimeClass
     * operationId: readNodeV1alpha1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1alpha1/runtimeclasses/{name}
     */
    readNodeV1alpha1RuntimeClass<ResponseContentType extends ResponseContentType$readNodeV1alpha1RuntimeClass>(params: Params$readNodeV1alpha1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<Response$readNodeV1alpha1RuntimeClass$Status$200[ResponseContentType]>;
    /**
     * replace the specified RuntimeClass
     * operationId: replaceNodeV1alpha1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1alpha1/runtimeclasses/{name}
     */
    replaceNodeV1alpha1RuntimeClass<ResponseContentType extends ResponseContentType$replaceNodeV1alpha1RuntimeClass>(params: Params$replaceNodeV1alpha1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceNodeV1alpha1RuntimeClass$Status$200 | Response$replaceNodeV1alpha1RuntimeClass$Status$201)[ResponseContentType]>;
    /**
     * delete a RuntimeClass
     * operationId: deleteNodeV1alpha1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1alpha1/runtimeclasses/{name}
     */
    deleteNodeV1alpha1RuntimeClass<ResponseContentType extends ResponseContentType$deleteNodeV1alpha1RuntimeClass>(params: Params$deleteNodeV1alpha1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteNodeV1alpha1RuntimeClass$Status$200 | Response$deleteNodeV1alpha1RuntimeClass$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified RuntimeClass
     * operationId: patchNodeV1alpha1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1alpha1/runtimeclasses/{name}
     */
    patchNodeV1alpha1RuntimeClass<RequestContentType extends RequestContentType$patchNodeV1alpha1RuntimeClass, ResponseContentType extends ResponseContentType$patchNodeV1alpha1RuntimeClass>(params: Params$patchNodeV1alpha1RuntimeClass<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchNodeV1alpha1RuntimeClass$Status$200 | Response$patchNodeV1alpha1RuntimeClass$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of RuntimeClass. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchNodeV1alpha1RuntimeClassList
     * Request URI: /apis/node.k8s.io/v1alpha1/watch/runtimeclasses
     */
    watchNodeV1alpha1RuntimeClassList<ResponseContentType extends ResponseContentType$watchNodeV1alpha1RuntimeClassList>(params: Params$watchNodeV1alpha1RuntimeClassList<ResponseContentType>, option?: RequestOption): Promise<Response$watchNodeV1alpha1RuntimeClassList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind RuntimeClass. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchNodeV1alpha1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1alpha1/watch/runtimeclasses/{name}
     */
    watchNodeV1alpha1RuntimeClass<ResponseContentType extends ResponseContentType$watchNodeV1alpha1RuntimeClass>(params: Params$watchNodeV1alpha1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<Response$watchNodeV1alpha1RuntimeClass$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getNodeV1beta1APIResources
     * Request URI: /apis/node.k8s.io/v1beta1/
     */
    getNodeV1beta1APIResources<ResponseContentType extends ResponseContentType$getNodeV1beta1APIResources>(params: Params$getNodeV1beta1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getNodeV1beta1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind RuntimeClass
     * operationId: listNodeV1beta1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1beta1/runtimeclasses
     */
    listNodeV1beta1RuntimeClass<ResponseContentType extends ResponseContentType$listNodeV1beta1RuntimeClass>(params: Params$listNodeV1beta1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<Response$listNodeV1beta1RuntimeClass$Status$200[ResponseContentType]>;
    /**
     * create a RuntimeClass
     * operationId: createNodeV1beta1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1beta1/runtimeclasses
     */
    createNodeV1beta1RuntimeClass<ResponseContentType extends ResponseContentType$createNodeV1beta1RuntimeClass>(params: Params$createNodeV1beta1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<(Response$createNodeV1beta1RuntimeClass$Status$200 | Response$createNodeV1beta1RuntimeClass$Status$201 | Response$createNodeV1beta1RuntimeClass$Status$202)[ResponseContentType]>;
    /**
     * delete collection of RuntimeClass
     * operationId: deleteNodeV1beta1CollectionRuntimeClass
     * Request URI: /apis/node.k8s.io/v1beta1/runtimeclasses
     */
    deleteNodeV1beta1CollectionRuntimeClass<ResponseContentType extends ResponseContentType$deleteNodeV1beta1CollectionRuntimeClass>(params: Params$deleteNodeV1beta1CollectionRuntimeClass<ResponseContentType>, option?: RequestOption): Promise<Response$deleteNodeV1beta1CollectionRuntimeClass$Status$200[ResponseContentType]>;
    /**
     * read the specified RuntimeClass
     * operationId: readNodeV1beta1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1beta1/runtimeclasses/{name}
     */
    readNodeV1beta1RuntimeClass<ResponseContentType extends ResponseContentType$readNodeV1beta1RuntimeClass>(params: Params$readNodeV1beta1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<Response$readNodeV1beta1RuntimeClass$Status$200[ResponseContentType]>;
    /**
     * replace the specified RuntimeClass
     * operationId: replaceNodeV1beta1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1beta1/runtimeclasses/{name}
     */
    replaceNodeV1beta1RuntimeClass<ResponseContentType extends ResponseContentType$replaceNodeV1beta1RuntimeClass>(params: Params$replaceNodeV1beta1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceNodeV1beta1RuntimeClass$Status$200 | Response$replaceNodeV1beta1RuntimeClass$Status$201)[ResponseContentType]>;
    /**
     * delete a RuntimeClass
     * operationId: deleteNodeV1beta1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1beta1/runtimeclasses/{name}
     */
    deleteNodeV1beta1RuntimeClass<ResponseContentType extends ResponseContentType$deleteNodeV1beta1RuntimeClass>(params: Params$deleteNodeV1beta1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteNodeV1beta1RuntimeClass$Status$200 | Response$deleteNodeV1beta1RuntimeClass$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified RuntimeClass
     * operationId: patchNodeV1beta1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1beta1/runtimeclasses/{name}
     */
    patchNodeV1beta1RuntimeClass<RequestContentType extends RequestContentType$patchNodeV1beta1RuntimeClass, ResponseContentType extends ResponseContentType$patchNodeV1beta1RuntimeClass>(params: Params$patchNodeV1beta1RuntimeClass<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchNodeV1beta1RuntimeClass$Status$200 | Response$patchNodeV1beta1RuntimeClass$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of RuntimeClass. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchNodeV1beta1RuntimeClassList
     * Request URI: /apis/node.k8s.io/v1beta1/watch/runtimeclasses
     */
    watchNodeV1beta1RuntimeClassList<ResponseContentType extends ResponseContentType$watchNodeV1beta1RuntimeClassList>(params: Params$watchNodeV1beta1RuntimeClassList<ResponseContentType>, option?: RequestOption): Promise<Response$watchNodeV1beta1RuntimeClassList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind RuntimeClass. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchNodeV1beta1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1beta1/watch/runtimeclasses/{name}
     */
    watchNodeV1beta1RuntimeClass<ResponseContentType extends ResponseContentType$watchNodeV1beta1RuntimeClass>(params: Params$watchNodeV1beta1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<Response$watchNodeV1beta1RuntimeClass$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getPolicyAPIGroup
     * Request URI: /apis/policy/
     */
    getPolicyAPIGroup<ResponseContentType extends ResponseContentType$getPolicyAPIGroup>(params: Params$getPolicyAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getPolicyAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getPolicyV1APIResources
     * Request URI: /apis/policy/v1/
     */
    getPolicyV1APIResources<ResponseContentType extends ResponseContentType$getPolicyV1APIResources>(params: Params$getPolicyV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getPolicyV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind PodDisruptionBudget
     * operationId: listPolicyV1NamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1/namespaces/{namespace}/poddisruptionbudgets
     */
    listPolicyV1NamespacedPodDisruptionBudget<ResponseContentType extends ResponseContentType$listPolicyV1NamespacedPodDisruptionBudget>(params: Params$listPolicyV1NamespacedPodDisruptionBudget<ResponseContentType>, option?: RequestOption): Promise<Response$listPolicyV1NamespacedPodDisruptionBudget$Status$200[ResponseContentType]>;
    /**
     * create a PodDisruptionBudget
     * operationId: createPolicyV1NamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1/namespaces/{namespace}/poddisruptionbudgets
     */
    createPolicyV1NamespacedPodDisruptionBudget<ResponseContentType extends ResponseContentType$createPolicyV1NamespacedPodDisruptionBudget>(params: Params$createPolicyV1NamespacedPodDisruptionBudget<ResponseContentType>, option?: RequestOption): Promise<(Response$createPolicyV1NamespacedPodDisruptionBudget$Status$200 | Response$createPolicyV1NamespacedPodDisruptionBudget$Status$201 | Response$createPolicyV1NamespacedPodDisruptionBudget$Status$202)[ResponseContentType]>;
    /**
     * delete collection of PodDisruptionBudget
     * operationId: deletePolicyV1CollectionNamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1/namespaces/{namespace}/poddisruptionbudgets
     */
    deletePolicyV1CollectionNamespacedPodDisruptionBudget<ResponseContentType extends ResponseContentType$deletePolicyV1CollectionNamespacedPodDisruptionBudget>(params: Params$deletePolicyV1CollectionNamespacedPodDisruptionBudget<ResponseContentType>, option?: RequestOption): Promise<Response$deletePolicyV1CollectionNamespacedPodDisruptionBudget$Status$200[ResponseContentType]>;
    /**
     * read the specified PodDisruptionBudget
     * operationId: readPolicyV1NamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1/namespaces/{namespace}/poddisruptionbudgets/{name}
     */
    readPolicyV1NamespacedPodDisruptionBudget<ResponseContentType extends ResponseContentType$readPolicyV1NamespacedPodDisruptionBudget>(params: Params$readPolicyV1NamespacedPodDisruptionBudget<ResponseContentType>, option?: RequestOption): Promise<Response$readPolicyV1NamespacedPodDisruptionBudget$Status$200[ResponseContentType]>;
    /**
     * replace the specified PodDisruptionBudget
     * operationId: replacePolicyV1NamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1/namespaces/{namespace}/poddisruptionbudgets/{name}
     */
    replacePolicyV1NamespacedPodDisruptionBudget<ResponseContentType extends ResponseContentType$replacePolicyV1NamespacedPodDisruptionBudget>(params: Params$replacePolicyV1NamespacedPodDisruptionBudget<ResponseContentType>, option?: RequestOption): Promise<(Response$replacePolicyV1NamespacedPodDisruptionBudget$Status$200 | Response$replacePolicyV1NamespacedPodDisruptionBudget$Status$201)[ResponseContentType]>;
    /**
     * delete a PodDisruptionBudget
     * operationId: deletePolicyV1NamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1/namespaces/{namespace}/poddisruptionbudgets/{name}
     */
    deletePolicyV1NamespacedPodDisruptionBudget<ResponseContentType extends ResponseContentType$deletePolicyV1NamespacedPodDisruptionBudget>(params: Params$deletePolicyV1NamespacedPodDisruptionBudget<ResponseContentType>, option?: RequestOption): Promise<(Response$deletePolicyV1NamespacedPodDisruptionBudget$Status$200 | Response$deletePolicyV1NamespacedPodDisruptionBudget$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified PodDisruptionBudget
     * operationId: patchPolicyV1NamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1/namespaces/{namespace}/poddisruptionbudgets/{name}
     */
    patchPolicyV1NamespacedPodDisruptionBudget<RequestContentType extends RequestContentType$patchPolicyV1NamespacedPodDisruptionBudget, ResponseContentType extends ResponseContentType$patchPolicyV1NamespacedPodDisruptionBudget>(params: Params$patchPolicyV1NamespacedPodDisruptionBudget<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchPolicyV1NamespacedPodDisruptionBudget$Status$200 | Response$patchPolicyV1NamespacedPodDisruptionBudget$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified PodDisruptionBudget
     * operationId: readPolicyV1NamespacedPodDisruptionBudgetStatus
     * Request URI: /apis/policy/v1/namespaces/{namespace}/poddisruptionbudgets/{name}/status
     */
    readPolicyV1NamespacedPodDisruptionBudgetStatus<ResponseContentType extends ResponseContentType$readPolicyV1NamespacedPodDisruptionBudgetStatus>(params: Params$readPolicyV1NamespacedPodDisruptionBudgetStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readPolicyV1NamespacedPodDisruptionBudgetStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified PodDisruptionBudget
     * operationId: replacePolicyV1NamespacedPodDisruptionBudgetStatus
     * Request URI: /apis/policy/v1/namespaces/{namespace}/poddisruptionbudgets/{name}/status
     */
    replacePolicyV1NamespacedPodDisruptionBudgetStatus<ResponseContentType extends ResponseContentType$replacePolicyV1NamespacedPodDisruptionBudgetStatus>(params: Params$replacePolicyV1NamespacedPodDisruptionBudgetStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replacePolicyV1NamespacedPodDisruptionBudgetStatus$Status$200 | Response$replacePolicyV1NamespacedPodDisruptionBudgetStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified PodDisruptionBudget
     * operationId: patchPolicyV1NamespacedPodDisruptionBudgetStatus
     * Request URI: /apis/policy/v1/namespaces/{namespace}/poddisruptionbudgets/{name}/status
     */
    patchPolicyV1NamespacedPodDisruptionBudgetStatus<RequestContentType extends RequestContentType$patchPolicyV1NamespacedPodDisruptionBudgetStatus, ResponseContentType extends ResponseContentType$patchPolicyV1NamespacedPodDisruptionBudgetStatus>(params: Params$patchPolicyV1NamespacedPodDisruptionBudgetStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchPolicyV1NamespacedPodDisruptionBudgetStatus$Status$200 | Response$patchPolicyV1NamespacedPodDisruptionBudgetStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind PodDisruptionBudget
     * operationId: listPolicyV1PodDisruptionBudgetForAllNamespaces
     * Request URI: /apis/policy/v1/poddisruptionbudgets
     */
    listPolicyV1PodDisruptionBudgetForAllNamespaces<ResponseContentType extends ResponseContentType$listPolicyV1PodDisruptionBudgetForAllNamespaces>(params: Params$listPolicyV1PodDisruptionBudgetForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listPolicyV1PodDisruptionBudgetForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of PodDisruptionBudget. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchPolicyV1NamespacedPodDisruptionBudgetList
     * Request URI: /apis/policy/v1/watch/namespaces/{namespace}/poddisruptionbudgets
     */
    watchPolicyV1NamespacedPodDisruptionBudgetList<ResponseContentType extends ResponseContentType$watchPolicyV1NamespacedPodDisruptionBudgetList>(params: Params$watchPolicyV1NamespacedPodDisruptionBudgetList<ResponseContentType>, option?: RequestOption): Promise<Response$watchPolicyV1NamespacedPodDisruptionBudgetList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind PodDisruptionBudget. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchPolicyV1NamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1/watch/namespaces/{namespace}/poddisruptionbudgets/{name}
     */
    watchPolicyV1NamespacedPodDisruptionBudget<ResponseContentType extends ResponseContentType$watchPolicyV1NamespacedPodDisruptionBudget>(params: Params$watchPolicyV1NamespacedPodDisruptionBudget<ResponseContentType>, option?: RequestOption): Promise<Response$watchPolicyV1NamespacedPodDisruptionBudget$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of PodDisruptionBudget. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchPolicyV1PodDisruptionBudgetListForAllNamespaces
     * Request URI: /apis/policy/v1/watch/poddisruptionbudgets
     */
    watchPolicyV1PodDisruptionBudgetListForAllNamespaces<ResponseContentType extends ResponseContentType$watchPolicyV1PodDisruptionBudgetListForAllNamespaces>(params: Params$watchPolicyV1PodDisruptionBudgetListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchPolicyV1PodDisruptionBudgetListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getPolicyV1beta1APIResources
     * Request URI: /apis/policy/v1beta1/
     */
    getPolicyV1beta1APIResources<ResponseContentType extends ResponseContentType$getPolicyV1beta1APIResources>(params: Params$getPolicyV1beta1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getPolicyV1beta1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind PodDisruptionBudget
     * operationId: listPolicyV1beta1NamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1beta1/namespaces/{namespace}/poddisruptionbudgets
     */
    listPolicyV1beta1NamespacedPodDisruptionBudget<ResponseContentType extends ResponseContentType$listPolicyV1beta1NamespacedPodDisruptionBudget>(params: Params$listPolicyV1beta1NamespacedPodDisruptionBudget<ResponseContentType>, option?: RequestOption): Promise<Response$listPolicyV1beta1NamespacedPodDisruptionBudget$Status$200[ResponseContentType]>;
    /**
     * create a PodDisruptionBudget
     * operationId: createPolicyV1beta1NamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1beta1/namespaces/{namespace}/poddisruptionbudgets
     */
    createPolicyV1beta1NamespacedPodDisruptionBudget<ResponseContentType extends ResponseContentType$createPolicyV1beta1NamespacedPodDisruptionBudget>(params: Params$createPolicyV1beta1NamespacedPodDisruptionBudget<ResponseContentType>, option?: RequestOption): Promise<(Response$createPolicyV1beta1NamespacedPodDisruptionBudget$Status$200 | Response$createPolicyV1beta1NamespacedPodDisruptionBudget$Status$201 | Response$createPolicyV1beta1NamespacedPodDisruptionBudget$Status$202)[ResponseContentType]>;
    /**
     * delete collection of PodDisruptionBudget
     * operationId: deletePolicyV1beta1CollectionNamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1beta1/namespaces/{namespace}/poddisruptionbudgets
     */
    deletePolicyV1beta1CollectionNamespacedPodDisruptionBudget<ResponseContentType extends ResponseContentType$deletePolicyV1beta1CollectionNamespacedPodDisruptionBudget>(params: Params$deletePolicyV1beta1CollectionNamespacedPodDisruptionBudget<ResponseContentType>, option?: RequestOption): Promise<Response$deletePolicyV1beta1CollectionNamespacedPodDisruptionBudget$Status$200[ResponseContentType]>;
    /**
     * read the specified PodDisruptionBudget
     * operationId: readPolicyV1beta1NamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1beta1/namespaces/{namespace}/poddisruptionbudgets/{name}
     */
    readPolicyV1beta1NamespacedPodDisruptionBudget<ResponseContentType extends ResponseContentType$readPolicyV1beta1NamespacedPodDisruptionBudget>(params: Params$readPolicyV1beta1NamespacedPodDisruptionBudget<ResponseContentType>, option?: RequestOption): Promise<Response$readPolicyV1beta1NamespacedPodDisruptionBudget$Status$200[ResponseContentType]>;
    /**
     * replace the specified PodDisruptionBudget
     * operationId: replacePolicyV1beta1NamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1beta1/namespaces/{namespace}/poddisruptionbudgets/{name}
     */
    replacePolicyV1beta1NamespacedPodDisruptionBudget<ResponseContentType extends ResponseContentType$replacePolicyV1beta1NamespacedPodDisruptionBudget>(params: Params$replacePolicyV1beta1NamespacedPodDisruptionBudget<ResponseContentType>, option?: RequestOption): Promise<(Response$replacePolicyV1beta1NamespacedPodDisruptionBudget$Status$200 | Response$replacePolicyV1beta1NamespacedPodDisruptionBudget$Status$201)[ResponseContentType]>;
    /**
     * delete a PodDisruptionBudget
     * operationId: deletePolicyV1beta1NamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1beta1/namespaces/{namespace}/poddisruptionbudgets/{name}
     */
    deletePolicyV1beta1NamespacedPodDisruptionBudget<ResponseContentType extends ResponseContentType$deletePolicyV1beta1NamespacedPodDisruptionBudget>(params: Params$deletePolicyV1beta1NamespacedPodDisruptionBudget<ResponseContentType>, option?: RequestOption): Promise<(Response$deletePolicyV1beta1NamespacedPodDisruptionBudget$Status$200 | Response$deletePolicyV1beta1NamespacedPodDisruptionBudget$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified PodDisruptionBudget
     * operationId: patchPolicyV1beta1NamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1beta1/namespaces/{namespace}/poddisruptionbudgets/{name}
     */
    patchPolicyV1beta1NamespacedPodDisruptionBudget<RequestContentType extends RequestContentType$patchPolicyV1beta1NamespacedPodDisruptionBudget, ResponseContentType extends ResponseContentType$patchPolicyV1beta1NamespacedPodDisruptionBudget>(params: Params$patchPolicyV1beta1NamespacedPodDisruptionBudget<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchPolicyV1beta1NamespacedPodDisruptionBudget$Status$200 | Response$patchPolicyV1beta1NamespacedPodDisruptionBudget$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified PodDisruptionBudget
     * operationId: readPolicyV1beta1NamespacedPodDisruptionBudgetStatus
     * Request URI: /apis/policy/v1beta1/namespaces/{namespace}/poddisruptionbudgets/{name}/status
     */
    readPolicyV1beta1NamespacedPodDisruptionBudgetStatus<ResponseContentType extends ResponseContentType$readPolicyV1beta1NamespacedPodDisruptionBudgetStatus>(params: Params$readPolicyV1beta1NamespacedPodDisruptionBudgetStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readPolicyV1beta1NamespacedPodDisruptionBudgetStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified PodDisruptionBudget
     * operationId: replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus
     * Request URI: /apis/policy/v1beta1/namespaces/{namespace}/poddisruptionbudgets/{name}/status
     */
    replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus<ResponseContentType extends ResponseContentType$replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus>(params: Params$replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus$Status$200 | Response$replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified PodDisruptionBudget
     * operationId: patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus
     * Request URI: /apis/policy/v1beta1/namespaces/{namespace}/poddisruptionbudgets/{name}/status
     */
    patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus<RequestContentType extends RequestContentType$patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus, ResponseContentType extends ResponseContentType$patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus>(params: Params$patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus$Status$200 | Response$patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind PodDisruptionBudget
     * operationId: listPolicyV1beta1PodDisruptionBudgetForAllNamespaces
     * Request URI: /apis/policy/v1beta1/poddisruptionbudgets
     */
    listPolicyV1beta1PodDisruptionBudgetForAllNamespaces<ResponseContentType extends ResponseContentType$listPolicyV1beta1PodDisruptionBudgetForAllNamespaces>(params: Params$listPolicyV1beta1PodDisruptionBudgetForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listPolicyV1beta1PodDisruptionBudgetForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind PodSecurityPolicy
     * operationId: listPolicyV1beta1PodSecurityPolicy
     * Request URI: /apis/policy/v1beta1/podsecuritypolicies
     */
    listPolicyV1beta1PodSecurityPolicy<ResponseContentType extends ResponseContentType$listPolicyV1beta1PodSecurityPolicy>(params: Params$listPolicyV1beta1PodSecurityPolicy<ResponseContentType>, option?: RequestOption): Promise<Response$listPolicyV1beta1PodSecurityPolicy$Status$200[ResponseContentType]>;
    /**
     * create a PodSecurityPolicy
     * operationId: createPolicyV1beta1PodSecurityPolicy
     * Request URI: /apis/policy/v1beta1/podsecuritypolicies
     */
    createPolicyV1beta1PodSecurityPolicy<ResponseContentType extends ResponseContentType$createPolicyV1beta1PodSecurityPolicy>(params: Params$createPolicyV1beta1PodSecurityPolicy<ResponseContentType>, option?: RequestOption): Promise<(Response$createPolicyV1beta1PodSecurityPolicy$Status$200 | Response$createPolicyV1beta1PodSecurityPolicy$Status$201 | Response$createPolicyV1beta1PodSecurityPolicy$Status$202)[ResponseContentType]>;
    /**
     * delete collection of PodSecurityPolicy
     * operationId: deletePolicyV1beta1CollectionPodSecurityPolicy
     * Request URI: /apis/policy/v1beta1/podsecuritypolicies
     */
    deletePolicyV1beta1CollectionPodSecurityPolicy<ResponseContentType extends ResponseContentType$deletePolicyV1beta1CollectionPodSecurityPolicy>(params: Params$deletePolicyV1beta1CollectionPodSecurityPolicy<ResponseContentType>, option?: RequestOption): Promise<Response$deletePolicyV1beta1CollectionPodSecurityPolicy$Status$200[ResponseContentType]>;
    /**
     * read the specified PodSecurityPolicy
     * operationId: readPolicyV1beta1PodSecurityPolicy
     * Request URI: /apis/policy/v1beta1/podsecuritypolicies/{name}
     */
    readPolicyV1beta1PodSecurityPolicy<ResponseContentType extends ResponseContentType$readPolicyV1beta1PodSecurityPolicy>(params: Params$readPolicyV1beta1PodSecurityPolicy<ResponseContentType>, option?: RequestOption): Promise<Response$readPolicyV1beta1PodSecurityPolicy$Status$200[ResponseContentType]>;
    /**
     * replace the specified PodSecurityPolicy
     * operationId: replacePolicyV1beta1PodSecurityPolicy
     * Request URI: /apis/policy/v1beta1/podsecuritypolicies/{name}
     */
    replacePolicyV1beta1PodSecurityPolicy<ResponseContentType extends ResponseContentType$replacePolicyV1beta1PodSecurityPolicy>(params: Params$replacePolicyV1beta1PodSecurityPolicy<ResponseContentType>, option?: RequestOption): Promise<(Response$replacePolicyV1beta1PodSecurityPolicy$Status$200 | Response$replacePolicyV1beta1PodSecurityPolicy$Status$201)[ResponseContentType]>;
    /**
     * delete a PodSecurityPolicy
     * operationId: deletePolicyV1beta1PodSecurityPolicy
     * Request URI: /apis/policy/v1beta1/podsecuritypolicies/{name}
     */
    deletePolicyV1beta1PodSecurityPolicy<ResponseContentType extends ResponseContentType$deletePolicyV1beta1PodSecurityPolicy>(params: Params$deletePolicyV1beta1PodSecurityPolicy<ResponseContentType>, option?: RequestOption): Promise<(Response$deletePolicyV1beta1PodSecurityPolicy$Status$200 | Response$deletePolicyV1beta1PodSecurityPolicy$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified PodSecurityPolicy
     * operationId: patchPolicyV1beta1PodSecurityPolicy
     * Request URI: /apis/policy/v1beta1/podsecuritypolicies/{name}
     */
    patchPolicyV1beta1PodSecurityPolicy<RequestContentType extends RequestContentType$patchPolicyV1beta1PodSecurityPolicy, ResponseContentType extends ResponseContentType$patchPolicyV1beta1PodSecurityPolicy>(params: Params$patchPolicyV1beta1PodSecurityPolicy<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchPolicyV1beta1PodSecurityPolicy$Status$200 | Response$patchPolicyV1beta1PodSecurityPolicy$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of PodDisruptionBudget. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchPolicyV1beta1NamespacedPodDisruptionBudgetList
     * Request URI: /apis/policy/v1beta1/watch/namespaces/{namespace}/poddisruptionbudgets
     */
    watchPolicyV1beta1NamespacedPodDisruptionBudgetList<ResponseContentType extends ResponseContentType$watchPolicyV1beta1NamespacedPodDisruptionBudgetList>(params: Params$watchPolicyV1beta1NamespacedPodDisruptionBudgetList<ResponseContentType>, option?: RequestOption): Promise<Response$watchPolicyV1beta1NamespacedPodDisruptionBudgetList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind PodDisruptionBudget. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchPolicyV1beta1NamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1beta1/watch/namespaces/{namespace}/poddisruptionbudgets/{name}
     */
    watchPolicyV1beta1NamespacedPodDisruptionBudget<ResponseContentType extends ResponseContentType$watchPolicyV1beta1NamespacedPodDisruptionBudget>(params: Params$watchPolicyV1beta1NamespacedPodDisruptionBudget<ResponseContentType>, option?: RequestOption): Promise<Response$watchPolicyV1beta1NamespacedPodDisruptionBudget$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of PodDisruptionBudget. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchPolicyV1beta1PodDisruptionBudgetListForAllNamespaces
     * Request URI: /apis/policy/v1beta1/watch/poddisruptionbudgets
     */
    watchPolicyV1beta1PodDisruptionBudgetListForAllNamespaces<ResponseContentType extends ResponseContentType$watchPolicyV1beta1PodDisruptionBudgetListForAllNamespaces>(params: Params$watchPolicyV1beta1PodDisruptionBudgetListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchPolicyV1beta1PodDisruptionBudgetListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of PodSecurityPolicy. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchPolicyV1beta1PodSecurityPolicyList
     * Request URI: /apis/policy/v1beta1/watch/podsecuritypolicies
     */
    watchPolicyV1beta1PodSecurityPolicyList<ResponseContentType extends ResponseContentType$watchPolicyV1beta1PodSecurityPolicyList>(params: Params$watchPolicyV1beta1PodSecurityPolicyList<ResponseContentType>, option?: RequestOption): Promise<Response$watchPolicyV1beta1PodSecurityPolicyList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind PodSecurityPolicy. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchPolicyV1beta1PodSecurityPolicy
     * Request URI: /apis/policy/v1beta1/watch/podsecuritypolicies/{name}
     */
    watchPolicyV1beta1PodSecurityPolicy<ResponseContentType extends ResponseContentType$watchPolicyV1beta1PodSecurityPolicy>(params: Params$watchPolicyV1beta1PodSecurityPolicy<ResponseContentType>, option?: RequestOption): Promise<Response$watchPolicyV1beta1PodSecurityPolicy$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getRbacAuthorizationAPIGroup
     * Request URI: /apis/rbac.authorization.k8s.io/
     */
    getRbacAuthorizationAPIGroup<ResponseContentType extends ResponseContentType$getRbacAuthorizationAPIGroup>(params: Params$getRbacAuthorizationAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getRbacAuthorizationAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getRbacAuthorizationV1APIResources
     * Request URI: /apis/rbac.authorization.k8s.io/v1/
     */
    getRbacAuthorizationV1APIResources<ResponseContentType extends ResponseContentType$getRbacAuthorizationV1APIResources>(params: Params$getRbacAuthorizationV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getRbacAuthorizationV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind ClusterRoleBinding
     * operationId: listRbacAuthorizationV1ClusterRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterrolebindings
     */
    listRbacAuthorizationV1ClusterRoleBinding<ResponseContentType extends ResponseContentType$listRbacAuthorizationV1ClusterRoleBinding>(params: Params$listRbacAuthorizationV1ClusterRoleBinding<ResponseContentType>, option?: RequestOption): Promise<Response$listRbacAuthorizationV1ClusterRoleBinding$Status$200[ResponseContentType]>;
    /**
     * create a ClusterRoleBinding
     * operationId: createRbacAuthorizationV1ClusterRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterrolebindings
     */
    createRbacAuthorizationV1ClusterRoleBinding<ResponseContentType extends ResponseContentType$createRbacAuthorizationV1ClusterRoleBinding>(params: Params$createRbacAuthorizationV1ClusterRoleBinding<ResponseContentType>, option?: RequestOption): Promise<(Response$createRbacAuthorizationV1ClusterRoleBinding$Status$200 | Response$createRbacAuthorizationV1ClusterRoleBinding$Status$201 | Response$createRbacAuthorizationV1ClusterRoleBinding$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ClusterRoleBinding
     * operationId: deleteRbacAuthorizationV1CollectionClusterRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterrolebindings
     */
    deleteRbacAuthorizationV1CollectionClusterRoleBinding<ResponseContentType extends ResponseContentType$deleteRbacAuthorizationV1CollectionClusterRoleBinding>(params: Params$deleteRbacAuthorizationV1CollectionClusterRoleBinding<ResponseContentType>, option?: RequestOption): Promise<Response$deleteRbacAuthorizationV1CollectionClusterRoleBinding$Status$200[ResponseContentType]>;
    /**
     * read the specified ClusterRoleBinding
     * operationId: readRbacAuthorizationV1ClusterRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterrolebindings/{name}
     */
    readRbacAuthorizationV1ClusterRoleBinding<ResponseContentType extends ResponseContentType$readRbacAuthorizationV1ClusterRoleBinding>(params: Params$readRbacAuthorizationV1ClusterRoleBinding<ResponseContentType>, option?: RequestOption): Promise<Response$readRbacAuthorizationV1ClusterRoleBinding$Status$200[ResponseContentType]>;
    /**
     * replace the specified ClusterRoleBinding
     * operationId: replaceRbacAuthorizationV1ClusterRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterrolebindings/{name}
     */
    replaceRbacAuthorizationV1ClusterRoleBinding<ResponseContentType extends ResponseContentType$replaceRbacAuthorizationV1ClusterRoleBinding>(params: Params$replaceRbacAuthorizationV1ClusterRoleBinding<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceRbacAuthorizationV1ClusterRoleBinding$Status$200 | Response$replaceRbacAuthorizationV1ClusterRoleBinding$Status$201)[ResponseContentType]>;
    /**
     * delete a ClusterRoleBinding
     * operationId: deleteRbacAuthorizationV1ClusterRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterrolebindings/{name}
     */
    deleteRbacAuthorizationV1ClusterRoleBinding<ResponseContentType extends ResponseContentType$deleteRbacAuthorizationV1ClusterRoleBinding>(params: Params$deleteRbacAuthorizationV1ClusterRoleBinding<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteRbacAuthorizationV1ClusterRoleBinding$Status$200 | Response$deleteRbacAuthorizationV1ClusterRoleBinding$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ClusterRoleBinding
     * operationId: patchRbacAuthorizationV1ClusterRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterrolebindings/{name}
     */
    patchRbacAuthorizationV1ClusterRoleBinding<RequestContentType extends RequestContentType$patchRbacAuthorizationV1ClusterRoleBinding, ResponseContentType extends ResponseContentType$patchRbacAuthorizationV1ClusterRoleBinding>(params: Params$patchRbacAuthorizationV1ClusterRoleBinding<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchRbacAuthorizationV1ClusterRoleBinding$Status$200 | Response$patchRbacAuthorizationV1ClusterRoleBinding$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind ClusterRole
     * operationId: listRbacAuthorizationV1ClusterRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterroles
     */
    listRbacAuthorizationV1ClusterRole<ResponseContentType extends ResponseContentType$listRbacAuthorizationV1ClusterRole>(params: Params$listRbacAuthorizationV1ClusterRole<ResponseContentType>, option?: RequestOption): Promise<Response$listRbacAuthorizationV1ClusterRole$Status$200[ResponseContentType]>;
    /**
     * create a ClusterRole
     * operationId: createRbacAuthorizationV1ClusterRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterroles
     */
    createRbacAuthorizationV1ClusterRole<ResponseContentType extends ResponseContentType$createRbacAuthorizationV1ClusterRole>(params: Params$createRbacAuthorizationV1ClusterRole<ResponseContentType>, option?: RequestOption): Promise<(Response$createRbacAuthorizationV1ClusterRole$Status$200 | Response$createRbacAuthorizationV1ClusterRole$Status$201 | Response$createRbacAuthorizationV1ClusterRole$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ClusterRole
     * operationId: deleteRbacAuthorizationV1CollectionClusterRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterroles
     */
    deleteRbacAuthorizationV1CollectionClusterRole<ResponseContentType extends ResponseContentType$deleteRbacAuthorizationV1CollectionClusterRole>(params: Params$deleteRbacAuthorizationV1CollectionClusterRole<ResponseContentType>, option?: RequestOption): Promise<Response$deleteRbacAuthorizationV1CollectionClusterRole$Status$200[ResponseContentType]>;
    /**
     * read the specified ClusterRole
     * operationId: readRbacAuthorizationV1ClusterRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterroles/{name}
     */
    readRbacAuthorizationV1ClusterRole<ResponseContentType extends ResponseContentType$readRbacAuthorizationV1ClusterRole>(params: Params$readRbacAuthorizationV1ClusterRole<ResponseContentType>, option?: RequestOption): Promise<Response$readRbacAuthorizationV1ClusterRole$Status$200[ResponseContentType]>;
    /**
     * replace the specified ClusterRole
     * operationId: replaceRbacAuthorizationV1ClusterRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterroles/{name}
     */
    replaceRbacAuthorizationV1ClusterRole<ResponseContentType extends ResponseContentType$replaceRbacAuthorizationV1ClusterRole>(params: Params$replaceRbacAuthorizationV1ClusterRole<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceRbacAuthorizationV1ClusterRole$Status$200 | Response$replaceRbacAuthorizationV1ClusterRole$Status$201)[ResponseContentType]>;
    /**
     * delete a ClusterRole
     * operationId: deleteRbacAuthorizationV1ClusterRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterroles/{name}
     */
    deleteRbacAuthorizationV1ClusterRole<ResponseContentType extends ResponseContentType$deleteRbacAuthorizationV1ClusterRole>(params: Params$deleteRbacAuthorizationV1ClusterRole<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteRbacAuthorizationV1ClusterRole$Status$200 | Response$deleteRbacAuthorizationV1ClusterRole$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ClusterRole
     * operationId: patchRbacAuthorizationV1ClusterRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterroles/{name}
     */
    patchRbacAuthorizationV1ClusterRole<RequestContentType extends RequestContentType$patchRbacAuthorizationV1ClusterRole, ResponseContentType extends ResponseContentType$patchRbacAuthorizationV1ClusterRole>(params: Params$patchRbacAuthorizationV1ClusterRole<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchRbacAuthorizationV1ClusterRole$Status$200 | Response$patchRbacAuthorizationV1ClusterRole$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind RoleBinding
     * operationId: listRbacAuthorizationV1NamespacedRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/rolebindings
     */
    listRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType extends ResponseContentType$listRbacAuthorizationV1NamespacedRoleBinding>(params: Params$listRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType>, option?: RequestOption): Promise<Response$listRbacAuthorizationV1NamespacedRoleBinding$Status$200[ResponseContentType]>;
    /**
     * create a RoleBinding
     * operationId: createRbacAuthorizationV1NamespacedRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/rolebindings
     */
    createRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType extends ResponseContentType$createRbacAuthorizationV1NamespacedRoleBinding>(params: Params$createRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType>, option?: RequestOption): Promise<(Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$200 | Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$201 | Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$202)[ResponseContentType]>;
    /**
     * delete collection of RoleBinding
     * operationId: deleteRbacAuthorizationV1CollectionNamespacedRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/rolebindings
     */
    deleteRbacAuthorizationV1CollectionNamespacedRoleBinding<ResponseContentType extends ResponseContentType$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding>(params: Params$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding<ResponseContentType>, option?: RequestOption): Promise<Response$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding$Status$200[ResponseContentType]>;
    /**
     * read the specified RoleBinding
     * operationId: readRbacAuthorizationV1NamespacedRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/rolebindings/{name}
     */
    readRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType extends ResponseContentType$readRbacAuthorizationV1NamespacedRoleBinding>(params: Params$readRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType>, option?: RequestOption): Promise<Response$readRbacAuthorizationV1NamespacedRoleBinding$Status$200[ResponseContentType]>;
    /**
     * replace the specified RoleBinding
     * operationId: replaceRbacAuthorizationV1NamespacedRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/rolebindings/{name}
     */
    replaceRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType extends ResponseContentType$replaceRbacAuthorizationV1NamespacedRoleBinding>(params: Params$replaceRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceRbacAuthorizationV1NamespacedRoleBinding$Status$200 | Response$replaceRbacAuthorizationV1NamespacedRoleBinding$Status$201)[ResponseContentType]>;
    /**
     * delete a RoleBinding
     * operationId: deleteRbacAuthorizationV1NamespacedRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/rolebindings/{name}
     */
    deleteRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType extends ResponseContentType$deleteRbacAuthorizationV1NamespacedRoleBinding>(params: Params$deleteRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteRbacAuthorizationV1NamespacedRoleBinding$Status$200 | Response$deleteRbacAuthorizationV1NamespacedRoleBinding$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified RoleBinding
     * operationId: patchRbacAuthorizationV1NamespacedRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/rolebindings/{name}
     */
    patchRbacAuthorizationV1NamespacedRoleBinding<RequestContentType extends RequestContentType$patchRbacAuthorizationV1NamespacedRoleBinding, ResponseContentType extends ResponseContentType$patchRbacAuthorizationV1NamespacedRoleBinding>(params: Params$patchRbacAuthorizationV1NamespacedRoleBinding<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchRbacAuthorizationV1NamespacedRoleBinding$Status$200 | Response$patchRbacAuthorizationV1NamespacedRoleBinding$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind Role
     * operationId: listRbacAuthorizationV1NamespacedRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/roles
     */
    listRbacAuthorizationV1NamespacedRole<ResponseContentType extends ResponseContentType$listRbacAuthorizationV1NamespacedRole>(params: Params$listRbacAuthorizationV1NamespacedRole<ResponseContentType>, option?: RequestOption): Promise<Response$listRbacAuthorizationV1NamespacedRole$Status$200[ResponseContentType]>;
    /**
     * create a Role
     * operationId: createRbacAuthorizationV1NamespacedRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/roles
     */
    createRbacAuthorizationV1NamespacedRole<ResponseContentType extends ResponseContentType$createRbacAuthorizationV1NamespacedRole>(params: Params$createRbacAuthorizationV1NamespacedRole<ResponseContentType>, option?: RequestOption): Promise<(Response$createRbacAuthorizationV1NamespacedRole$Status$200 | Response$createRbacAuthorizationV1NamespacedRole$Status$201 | Response$createRbacAuthorizationV1NamespacedRole$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Role
     * operationId: deleteRbacAuthorizationV1CollectionNamespacedRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/roles
     */
    deleteRbacAuthorizationV1CollectionNamespacedRole<ResponseContentType extends ResponseContentType$deleteRbacAuthorizationV1CollectionNamespacedRole>(params: Params$deleteRbacAuthorizationV1CollectionNamespacedRole<ResponseContentType>, option?: RequestOption): Promise<Response$deleteRbacAuthorizationV1CollectionNamespacedRole$Status$200[ResponseContentType]>;
    /**
     * read the specified Role
     * operationId: readRbacAuthorizationV1NamespacedRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/roles/{name}
     */
    readRbacAuthorizationV1NamespacedRole<ResponseContentType extends ResponseContentType$readRbacAuthorizationV1NamespacedRole>(params: Params$readRbacAuthorizationV1NamespacedRole<ResponseContentType>, option?: RequestOption): Promise<Response$readRbacAuthorizationV1NamespacedRole$Status$200[ResponseContentType]>;
    /**
     * replace the specified Role
     * operationId: replaceRbacAuthorizationV1NamespacedRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/roles/{name}
     */
    replaceRbacAuthorizationV1NamespacedRole<ResponseContentType extends ResponseContentType$replaceRbacAuthorizationV1NamespacedRole>(params: Params$replaceRbacAuthorizationV1NamespacedRole<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceRbacAuthorizationV1NamespacedRole$Status$200 | Response$replaceRbacAuthorizationV1NamespacedRole$Status$201)[ResponseContentType]>;
    /**
     * delete a Role
     * operationId: deleteRbacAuthorizationV1NamespacedRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/roles/{name}
     */
    deleteRbacAuthorizationV1NamespacedRole<ResponseContentType extends ResponseContentType$deleteRbacAuthorizationV1NamespacedRole>(params: Params$deleteRbacAuthorizationV1NamespacedRole<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteRbacAuthorizationV1NamespacedRole$Status$200 | Response$deleteRbacAuthorizationV1NamespacedRole$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Role
     * operationId: patchRbacAuthorizationV1NamespacedRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/roles/{name}
     */
    patchRbacAuthorizationV1NamespacedRole<RequestContentType extends RequestContentType$patchRbacAuthorizationV1NamespacedRole, ResponseContentType extends ResponseContentType$patchRbacAuthorizationV1NamespacedRole>(params: Params$patchRbacAuthorizationV1NamespacedRole<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchRbacAuthorizationV1NamespacedRole$Status$200 | Response$patchRbacAuthorizationV1NamespacedRole$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind RoleBinding
     * operationId: listRbacAuthorizationV1RoleBindingForAllNamespaces
     * Request URI: /apis/rbac.authorization.k8s.io/v1/rolebindings
     */
    listRbacAuthorizationV1RoleBindingForAllNamespaces<ResponseContentType extends ResponseContentType$listRbacAuthorizationV1RoleBindingForAllNamespaces>(params: Params$listRbacAuthorizationV1RoleBindingForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listRbacAuthorizationV1RoleBindingForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Role
     * operationId: listRbacAuthorizationV1RoleForAllNamespaces
     * Request URI: /apis/rbac.authorization.k8s.io/v1/roles
     */
    listRbacAuthorizationV1RoleForAllNamespaces<ResponseContentType extends ResponseContentType$listRbacAuthorizationV1RoleForAllNamespaces>(params: Params$listRbacAuthorizationV1RoleForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listRbacAuthorizationV1RoleForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ClusterRoleBinding. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchRbacAuthorizationV1ClusterRoleBindingList
     * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/clusterrolebindings
     */
    watchRbacAuthorizationV1ClusterRoleBindingList<ResponseContentType extends ResponseContentType$watchRbacAuthorizationV1ClusterRoleBindingList>(params: Params$watchRbacAuthorizationV1ClusterRoleBindingList<ResponseContentType>, option?: RequestOption): Promise<Response$watchRbacAuthorizationV1ClusterRoleBindingList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ClusterRoleBinding. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchRbacAuthorizationV1ClusterRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/clusterrolebindings/{name}
     */
    watchRbacAuthorizationV1ClusterRoleBinding<ResponseContentType extends ResponseContentType$watchRbacAuthorizationV1ClusterRoleBinding>(params: Params$watchRbacAuthorizationV1ClusterRoleBinding<ResponseContentType>, option?: RequestOption): Promise<Response$watchRbacAuthorizationV1ClusterRoleBinding$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ClusterRole. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchRbacAuthorizationV1ClusterRoleList
     * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/clusterroles
     */
    watchRbacAuthorizationV1ClusterRoleList<ResponseContentType extends ResponseContentType$watchRbacAuthorizationV1ClusterRoleList>(params: Params$watchRbacAuthorizationV1ClusterRoleList<ResponseContentType>, option?: RequestOption): Promise<Response$watchRbacAuthorizationV1ClusterRoleList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ClusterRole. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchRbacAuthorizationV1ClusterRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/clusterroles/{name}
     */
    watchRbacAuthorizationV1ClusterRole<ResponseContentType extends ResponseContentType$watchRbacAuthorizationV1ClusterRole>(params: Params$watchRbacAuthorizationV1ClusterRole<ResponseContentType>, option?: RequestOption): Promise<Response$watchRbacAuthorizationV1ClusterRole$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of RoleBinding. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchRbacAuthorizationV1NamespacedRoleBindingList
     * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/namespaces/{namespace}/rolebindings
     */
    watchRbacAuthorizationV1NamespacedRoleBindingList<ResponseContentType extends ResponseContentType$watchRbacAuthorizationV1NamespacedRoleBindingList>(params: Params$watchRbacAuthorizationV1NamespacedRoleBindingList<ResponseContentType>, option?: RequestOption): Promise<Response$watchRbacAuthorizationV1NamespacedRoleBindingList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind RoleBinding. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchRbacAuthorizationV1NamespacedRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/namespaces/{namespace}/rolebindings/{name}
     */
    watchRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType extends ResponseContentType$watchRbacAuthorizationV1NamespacedRoleBinding>(params: Params$watchRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType>, option?: RequestOption): Promise<Response$watchRbacAuthorizationV1NamespacedRoleBinding$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Role. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchRbacAuthorizationV1NamespacedRoleList
     * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/namespaces/{namespace}/roles
     */
    watchRbacAuthorizationV1NamespacedRoleList<ResponseContentType extends ResponseContentType$watchRbacAuthorizationV1NamespacedRoleList>(params: Params$watchRbacAuthorizationV1NamespacedRoleList<ResponseContentType>, option?: RequestOption): Promise<Response$watchRbacAuthorizationV1NamespacedRoleList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Role. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchRbacAuthorizationV1NamespacedRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/namespaces/{namespace}/roles/{name}
     */
    watchRbacAuthorizationV1NamespacedRole<ResponseContentType extends ResponseContentType$watchRbacAuthorizationV1NamespacedRole>(params: Params$watchRbacAuthorizationV1NamespacedRole<ResponseContentType>, option?: RequestOption): Promise<Response$watchRbacAuthorizationV1NamespacedRole$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of RoleBinding. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchRbacAuthorizationV1RoleBindingListForAllNamespaces
     * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/rolebindings
     */
    watchRbacAuthorizationV1RoleBindingListForAllNamespaces<ResponseContentType extends ResponseContentType$watchRbacAuthorizationV1RoleBindingListForAllNamespaces>(params: Params$watchRbacAuthorizationV1RoleBindingListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchRbacAuthorizationV1RoleBindingListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Role. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchRbacAuthorizationV1RoleListForAllNamespaces
     * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/roles
     */
    watchRbacAuthorizationV1RoleListForAllNamespaces<ResponseContentType extends ResponseContentType$watchRbacAuthorizationV1RoleListForAllNamespaces>(params: Params$watchRbacAuthorizationV1RoleListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchRbacAuthorizationV1RoleListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getSchedulingAPIGroup
     * Request URI: /apis/scheduling.k8s.io/
     */
    getSchedulingAPIGroup<ResponseContentType extends ResponseContentType$getSchedulingAPIGroup>(params: Params$getSchedulingAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getSchedulingAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getSchedulingV1APIResources
     * Request URI: /apis/scheduling.k8s.io/v1/
     */
    getSchedulingV1APIResources<ResponseContentType extends ResponseContentType$getSchedulingV1APIResources>(params: Params$getSchedulingV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getSchedulingV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind PriorityClass
     * operationId: listSchedulingV1PriorityClass
     * Request URI: /apis/scheduling.k8s.io/v1/priorityclasses
     */
    listSchedulingV1PriorityClass<ResponseContentType extends ResponseContentType$listSchedulingV1PriorityClass>(params: Params$listSchedulingV1PriorityClass<ResponseContentType>, option?: RequestOption): Promise<Response$listSchedulingV1PriorityClass$Status$200[ResponseContentType]>;
    /**
     * create a PriorityClass
     * operationId: createSchedulingV1PriorityClass
     * Request URI: /apis/scheduling.k8s.io/v1/priorityclasses
     */
    createSchedulingV1PriorityClass<ResponseContentType extends ResponseContentType$createSchedulingV1PriorityClass>(params: Params$createSchedulingV1PriorityClass<ResponseContentType>, option?: RequestOption): Promise<(Response$createSchedulingV1PriorityClass$Status$200 | Response$createSchedulingV1PriorityClass$Status$201 | Response$createSchedulingV1PriorityClass$Status$202)[ResponseContentType]>;
    /**
     * delete collection of PriorityClass
     * operationId: deleteSchedulingV1CollectionPriorityClass
     * Request URI: /apis/scheduling.k8s.io/v1/priorityclasses
     */
    deleteSchedulingV1CollectionPriorityClass<ResponseContentType extends ResponseContentType$deleteSchedulingV1CollectionPriorityClass>(params: Params$deleteSchedulingV1CollectionPriorityClass<ResponseContentType>, option?: RequestOption): Promise<Response$deleteSchedulingV1CollectionPriorityClass$Status$200[ResponseContentType]>;
    /**
     * read the specified PriorityClass
     * operationId: readSchedulingV1PriorityClass
     * Request URI: /apis/scheduling.k8s.io/v1/priorityclasses/{name}
     */
    readSchedulingV1PriorityClass<ResponseContentType extends ResponseContentType$readSchedulingV1PriorityClass>(params: Params$readSchedulingV1PriorityClass<ResponseContentType>, option?: RequestOption): Promise<Response$readSchedulingV1PriorityClass$Status$200[ResponseContentType]>;
    /**
     * replace the specified PriorityClass
     * operationId: replaceSchedulingV1PriorityClass
     * Request URI: /apis/scheduling.k8s.io/v1/priorityclasses/{name}
     */
    replaceSchedulingV1PriorityClass<ResponseContentType extends ResponseContentType$replaceSchedulingV1PriorityClass>(params: Params$replaceSchedulingV1PriorityClass<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceSchedulingV1PriorityClass$Status$200 | Response$replaceSchedulingV1PriorityClass$Status$201)[ResponseContentType]>;
    /**
     * delete a PriorityClass
     * operationId: deleteSchedulingV1PriorityClass
     * Request URI: /apis/scheduling.k8s.io/v1/priorityclasses/{name}
     */
    deleteSchedulingV1PriorityClass<ResponseContentType extends ResponseContentType$deleteSchedulingV1PriorityClass>(params: Params$deleteSchedulingV1PriorityClass<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteSchedulingV1PriorityClass$Status$200 | Response$deleteSchedulingV1PriorityClass$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified PriorityClass
     * operationId: patchSchedulingV1PriorityClass
     * Request URI: /apis/scheduling.k8s.io/v1/priorityclasses/{name}
     */
    patchSchedulingV1PriorityClass<RequestContentType extends RequestContentType$patchSchedulingV1PriorityClass, ResponseContentType extends ResponseContentType$patchSchedulingV1PriorityClass>(params: Params$patchSchedulingV1PriorityClass<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchSchedulingV1PriorityClass$Status$200 | Response$patchSchedulingV1PriorityClass$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of PriorityClass. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchSchedulingV1PriorityClassList
     * Request URI: /apis/scheduling.k8s.io/v1/watch/priorityclasses
     */
    watchSchedulingV1PriorityClassList<ResponseContentType extends ResponseContentType$watchSchedulingV1PriorityClassList>(params: Params$watchSchedulingV1PriorityClassList<ResponseContentType>, option?: RequestOption): Promise<Response$watchSchedulingV1PriorityClassList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind PriorityClass. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchSchedulingV1PriorityClass
     * Request URI: /apis/scheduling.k8s.io/v1/watch/priorityclasses/{name}
     */
    watchSchedulingV1PriorityClass<ResponseContentType extends ResponseContentType$watchSchedulingV1PriorityClass>(params: Params$watchSchedulingV1PriorityClass<ResponseContentType>, option?: RequestOption): Promise<Response$watchSchedulingV1PriorityClass$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getStorageAPIGroup
     * Request URI: /apis/storage.k8s.io/
     */
    getStorageAPIGroup<ResponseContentType extends ResponseContentType$getStorageAPIGroup>(params: Params$getStorageAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getStorageAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getStorageV1APIResources
     * Request URI: /apis/storage.k8s.io/v1/
     */
    getStorageV1APIResources<ResponseContentType extends ResponseContentType$getStorageV1APIResources>(params: Params$getStorageV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getStorageV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind CSIDriver
     * operationId: listStorageV1CSIDriver
     * Request URI: /apis/storage.k8s.io/v1/csidrivers
     */
    listStorageV1CSIDriver<ResponseContentType extends ResponseContentType$listStorageV1CSIDriver>(params: Params$listStorageV1CSIDriver<ResponseContentType>, option?: RequestOption): Promise<Response$listStorageV1CSIDriver$Status$200[ResponseContentType]>;
    /**
     * create a CSIDriver
     * operationId: createStorageV1CSIDriver
     * Request URI: /apis/storage.k8s.io/v1/csidrivers
     */
    createStorageV1CSIDriver<ResponseContentType extends ResponseContentType$createStorageV1CSIDriver>(params: Params$createStorageV1CSIDriver<ResponseContentType>, option?: RequestOption): Promise<(Response$createStorageV1CSIDriver$Status$200 | Response$createStorageV1CSIDriver$Status$201 | Response$createStorageV1CSIDriver$Status$202)[ResponseContentType]>;
    /**
     * delete collection of CSIDriver
     * operationId: deleteStorageV1CollectionCSIDriver
     * Request URI: /apis/storage.k8s.io/v1/csidrivers
     */
    deleteStorageV1CollectionCSIDriver<ResponseContentType extends ResponseContentType$deleteStorageV1CollectionCSIDriver>(params: Params$deleteStorageV1CollectionCSIDriver<ResponseContentType>, option?: RequestOption): Promise<Response$deleteStorageV1CollectionCSIDriver$Status$200[ResponseContentType]>;
    /**
     * read the specified CSIDriver
     * operationId: readStorageV1CSIDriver
     * Request URI: /apis/storage.k8s.io/v1/csidrivers/{name}
     */
    readStorageV1CSIDriver<ResponseContentType extends ResponseContentType$readStorageV1CSIDriver>(params: Params$readStorageV1CSIDriver<ResponseContentType>, option?: RequestOption): Promise<Response$readStorageV1CSIDriver$Status$200[ResponseContentType]>;
    /**
     * replace the specified CSIDriver
     * operationId: replaceStorageV1CSIDriver
     * Request URI: /apis/storage.k8s.io/v1/csidrivers/{name}
     */
    replaceStorageV1CSIDriver<ResponseContentType extends ResponseContentType$replaceStorageV1CSIDriver>(params: Params$replaceStorageV1CSIDriver<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceStorageV1CSIDriver$Status$200 | Response$replaceStorageV1CSIDriver$Status$201)[ResponseContentType]>;
    /**
     * delete a CSIDriver
     * operationId: deleteStorageV1CSIDriver
     * Request URI: /apis/storage.k8s.io/v1/csidrivers/{name}
     */
    deleteStorageV1CSIDriver<ResponseContentType extends ResponseContentType$deleteStorageV1CSIDriver>(params: Params$deleteStorageV1CSIDriver<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteStorageV1CSIDriver$Status$200 | Response$deleteStorageV1CSIDriver$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified CSIDriver
     * operationId: patchStorageV1CSIDriver
     * Request URI: /apis/storage.k8s.io/v1/csidrivers/{name}
     */
    patchStorageV1CSIDriver<RequestContentType extends RequestContentType$patchStorageV1CSIDriver, ResponseContentType extends ResponseContentType$patchStorageV1CSIDriver>(params: Params$patchStorageV1CSIDriver<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchStorageV1CSIDriver$Status$200 | Response$patchStorageV1CSIDriver$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind CSINode
     * operationId: listStorageV1CSINode
     * Request URI: /apis/storage.k8s.io/v1/csinodes
     */
    listStorageV1CSINode<ResponseContentType extends ResponseContentType$listStorageV1CSINode>(params: Params$listStorageV1CSINode<ResponseContentType>, option?: RequestOption): Promise<Response$listStorageV1CSINode$Status$200[ResponseContentType]>;
    /**
     * create a CSINode
     * operationId: createStorageV1CSINode
     * Request URI: /apis/storage.k8s.io/v1/csinodes
     */
    createStorageV1CSINode<ResponseContentType extends ResponseContentType$createStorageV1CSINode>(params: Params$createStorageV1CSINode<ResponseContentType>, option?: RequestOption): Promise<(Response$createStorageV1CSINode$Status$200 | Response$createStorageV1CSINode$Status$201 | Response$createStorageV1CSINode$Status$202)[ResponseContentType]>;
    /**
     * delete collection of CSINode
     * operationId: deleteStorageV1CollectionCSINode
     * Request URI: /apis/storage.k8s.io/v1/csinodes
     */
    deleteStorageV1CollectionCSINode<ResponseContentType extends ResponseContentType$deleteStorageV1CollectionCSINode>(params: Params$deleteStorageV1CollectionCSINode<ResponseContentType>, option?: RequestOption): Promise<Response$deleteStorageV1CollectionCSINode$Status$200[ResponseContentType]>;
    /**
     * read the specified CSINode
     * operationId: readStorageV1CSINode
     * Request URI: /apis/storage.k8s.io/v1/csinodes/{name}
     */
    readStorageV1CSINode<ResponseContentType extends ResponseContentType$readStorageV1CSINode>(params: Params$readStorageV1CSINode<ResponseContentType>, option?: RequestOption): Promise<Response$readStorageV1CSINode$Status$200[ResponseContentType]>;
    /**
     * replace the specified CSINode
     * operationId: replaceStorageV1CSINode
     * Request URI: /apis/storage.k8s.io/v1/csinodes/{name}
     */
    replaceStorageV1CSINode<ResponseContentType extends ResponseContentType$replaceStorageV1CSINode>(params: Params$replaceStorageV1CSINode<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceStorageV1CSINode$Status$200 | Response$replaceStorageV1CSINode$Status$201)[ResponseContentType]>;
    /**
     * delete a CSINode
     * operationId: deleteStorageV1CSINode
     * Request URI: /apis/storage.k8s.io/v1/csinodes/{name}
     */
    deleteStorageV1CSINode<ResponseContentType extends ResponseContentType$deleteStorageV1CSINode>(params: Params$deleteStorageV1CSINode<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteStorageV1CSINode$Status$200 | Response$deleteStorageV1CSINode$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified CSINode
     * operationId: patchStorageV1CSINode
     * Request URI: /apis/storage.k8s.io/v1/csinodes/{name}
     */
    patchStorageV1CSINode<RequestContentType extends RequestContentType$patchStorageV1CSINode, ResponseContentType extends ResponseContentType$patchStorageV1CSINode>(params: Params$patchStorageV1CSINode<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchStorageV1CSINode$Status$200 | Response$patchStorageV1CSINode$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind StorageClass
     * operationId: listStorageV1StorageClass
     * Request URI: /apis/storage.k8s.io/v1/storageclasses
     */
    listStorageV1StorageClass<ResponseContentType extends ResponseContentType$listStorageV1StorageClass>(params: Params$listStorageV1StorageClass<ResponseContentType>, option?: RequestOption): Promise<Response$listStorageV1StorageClass$Status$200[ResponseContentType]>;
    /**
     * create a StorageClass
     * operationId: createStorageV1StorageClass
     * Request URI: /apis/storage.k8s.io/v1/storageclasses
     */
    createStorageV1StorageClass<ResponseContentType extends ResponseContentType$createStorageV1StorageClass>(params: Params$createStorageV1StorageClass<ResponseContentType>, option?: RequestOption): Promise<(Response$createStorageV1StorageClass$Status$200 | Response$createStorageV1StorageClass$Status$201 | Response$createStorageV1StorageClass$Status$202)[ResponseContentType]>;
    /**
     * delete collection of StorageClass
     * operationId: deleteStorageV1CollectionStorageClass
     * Request URI: /apis/storage.k8s.io/v1/storageclasses
     */
    deleteStorageV1CollectionStorageClass<ResponseContentType extends ResponseContentType$deleteStorageV1CollectionStorageClass>(params: Params$deleteStorageV1CollectionStorageClass<ResponseContentType>, option?: RequestOption): Promise<Response$deleteStorageV1CollectionStorageClass$Status$200[ResponseContentType]>;
    /**
     * read the specified StorageClass
     * operationId: readStorageV1StorageClass
     * Request URI: /apis/storage.k8s.io/v1/storageclasses/{name}
     */
    readStorageV1StorageClass<ResponseContentType extends ResponseContentType$readStorageV1StorageClass>(params: Params$readStorageV1StorageClass<ResponseContentType>, option?: RequestOption): Promise<Response$readStorageV1StorageClass$Status$200[ResponseContentType]>;
    /**
     * replace the specified StorageClass
     * operationId: replaceStorageV1StorageClass
     * Request URI: /apis/storage.k8s.io/v1/storageclasses/{name}
     */
    replaceStorageV1StorageClass<ResponseContentType extends ResponseContentType$replaceStorageV1StorageClass>(params: Params$replaceStorageV1StorageClass<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceStorageV1StorageClass$Status$200 | Response$replaceStorageV1StorageClass$Status$201)[ResponseContentType]>;
    /**
     * delete a StorageClass
     * operationId: deleteStorageV1StorageClass
     * Request URI: /apis/storage.k8s.io/v1/storageclasses/{name}
     */
    deleteStorageV1StorageClass<ResponseContentType extends ResponseContentType$deleteStorageV1StorageClass>(params: Params$deleteStorageV1StorageClass<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteStorageV1StorageClass$Status$200 | Response$deleteStorageV1StorageClass$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified StorageClass
     * operationId: patchStorageV1StorageClass
     * Request URI: /apis/storage.k8s.io/v1/storageclasses/{name}
     */
    patchStorageV1StorageClass<RequestContentType extends RequestContentType$patchStorageV1StorageClass, ResponseContentType extends ResponseContentType$patchStorageV1StorageClass>(params: Params$patchStorageV1StorageClass<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchStorageV1StorageClass$Status$200 | Response$patchStorageV1StorageClass$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind VolumeAttachment
     * operationId: listStorageV1VolumeAttachment
     * Request URI: /apis/storage.k8s.io/v1/volumeattachments
     */
    listStorageV1VolumeAttachment<ResponseContentType extends ResponseContentType$listStorageV1VolumeAttachment>(params: Params$listStorageV1VolumeAttachment<ResponseContentType>, option?: RequestOption): Promise<Response$listStorageV1VolumeAttachment$Status$200[ResponseContentType]>;
    /**
     * create a VolumeAttachment
     * operationId: createStorageV1VolumeAttachment
     * Request URI: /apis/storage.k8s.io/v1/volumeattachments
     */
    createStorageV1VolumeAttachment<ResponseContentType extends ResponseContentType$createStorageV1VolumeAttachment>(params: Params$createStorageV1VolumeAttachment<ResponseContentType>, option?: RequestOption): Promise<(Response$createStorageV1VolumeAttachment$Status$200 | Response$createStorageV1VolumeAttachment$Status$201 | Response$createStorageV1VolumeAttachment$Status$202)[ResponseContentType]>;
    /**
     * delete collection of VolumeAttachment
     * operationId: deleteStorageV1CollectionVolumeAttachment
     * Request URI: /apis/storage.k8s.io/v1/volumeattachments
     */
    deleteStorageV1CollectionVolumeAttachment<ResponseContentType extends ResponseContentType$deleteStorageV1CollectionVolumeAttachment>(params: Params$deleteStorageV1CollectionVolumeAttachment<ResponseContentType>, option?: RequestOption): Promise<Response$deleteStorageV1CollectionVolumeAttachment$Status$200[ResponseContentType]>;
    /**
     * read the specified VolumeAttachment
     * operationId: readStorageV1VolumeAttachment
     * Request URI: /apis/storage.k8s.io/v1/volumeattachments/{name}
     */
    readStorageV1VolumeAttachment<ResponseContentType extends ResponseContentType$readStorageV1VolumeAttachment>(params: Params$readStorageV1VolumeAttachment<ResponseContentType>, option?: RequestOption): Promise<Response$readStorageV1VolumeAttachment$Status$200[ResponseContentType]>;
    /**
     * replace the specified VolumeAttachment
     * operationId: replaceStorageV1VolumeAttachment
     * Request URI: /apis/storage.k8s.io/v1/volumeattachments/{name}
     */
    replaceStorageV1VolumeAttachment<ResponseContentType extends ResponseContentType$replaceStorageV1VolumeAttachment>(params: Params$replaceStorageV1VolumeAttachment<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceStorageV1VolumeAttachment$Status$200 | Response$replaceStorageV1VolumeAttachment$Status$201)[ResponseContentType]>;
    /**
     * delete a VolumeAttachment
     * operationId: deleteStorageV1VolumeAttachment
     * Request URI: /apis/storage.k8s.io/v1/volumeattachments/{name}
     */
    deleteStorageV1VolumeAttachment<ResponseContentType extends ResponseContentType$deleteStorageV1VolumeAttachment>(params: Params$deleteStorageV1VolumeAttachment<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteStorageV1VolumeAttachment$Status$200 | Response$deleteStorageV1VolumeAttachment$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified VolumeAttachment
     * operationId: patchStorageV1VolumeAttachment
     * Request URI: /apis/storage.k8s.io/v1/volumeattachments/{name}
     */
    patchStorageV1VolumeAttachment<RequestContentType extends RequestContentType$patchStorageV1VolumeAttachment, ResponseContentType extends ResponseContentType$patchStorageV1VolumeAttachment>(params: Params$patchStorageV1VolumeAttachment<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchStorageV1VolumeAttachment$Status$200 | Response$patchStorageV1VolumeAttachment$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified VolumeAttachment
     * operationId: readStorageV1VolumeAttachmentStatus
     * Request URI: /apis/storage.k8s.io/v1/volumeattachments/{name}/status
     */
    readStorageV1VolumeAttachmentStatus<ResponseContentType extends ResponseContentType$readStorageV1VolumeAttachmentStatus>(params: Params$readStorageV1VolumeAttachmentStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readStorageV1VolumeAttachmentStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified VolumeAttachment
     * operationId: replaceStorageV1VolumeAttachmentStatus
     * Request URI: /apis/storage.k8s.io/v1/volumeattachments/{name}/status
     */
    replaceStorageV1VolumeAttachmentStatus<ResponseContentType extends ResponseContentType$replaceStorageV1VolumeAttachmentStatus>(params: Params$replaceStorageV1VolumeAttachmentStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceStorageV1VolumeAttachmentStatus$Status$200 | Response$replaceStorageV1VolumeAttachmentStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified VolumeAttachment
     * operationId: patchStorageV1VolumeAttachmentStatus
     * Request URI: /apis/storage.k8s.io/v1/volumeattachments/{name}/status
     */
    patchStorageV1VolumeAttachmentStatus<RequestContentType extends RequestContentType$patchStorageV1VolumeAttachmentStatus, ResponseContentType extends ResponseContentType$patchStorageV1VolumeAttachmentStatus>(params: Params$patchStorageV1VolumeAttachmentStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchStorageV1VolumeAttachmentStatus$Status$200 | Response$patchStorageV1VolumeAttachmentStatus$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of CSIDriver. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchStorageV1CSIDriverList
     * Request URI: /apis/storage.k8s.io/v1/watch/csidrivers
     */
    watchStorageV1CSIDriverList<ResponseContentType extends ResponseContentType$watchStorageV1CSIDriverList>(params: Params$watchStorageV1CSIDriverList<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1CSIDriverList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind CSIDriver. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchStorageV1CSIDriver
     * Request URI: /apis/storage.k8s.io/v1/watch/csidrivers/{name}
     */
    watchStorageV1CSIDriver<ResponseContentType extends ResponseContentType$watchStorageV1CSIDriver>(params: Params$watchStorageV1CSIDriver<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1CSIDriver$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of CSINode. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchStorageV1CSINodeList
     * Request URI: /apis/storage.k8s.io/v1/watch/csinodes
     */
    watchStorageV1CSINodeList<ResponseContentType extends ResponseContentType$watchStorageV1CSINodeList>(params: Params$watchStorageV1CSINodeList<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1CSINodeList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind CSINode. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchStorageV1CSINode
     * Request URI: /apis/storage.k8s.io/v1/watch/csinodes/{name}
     */
    watchStorageV1CSINode<ResponseContentType extends ResponseContentType$watchStorageV1CSINode>(params: Params$watchStorageV1CSINode<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1CSINode$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of StorageClass. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchStorageV1StorageClassList
     * Request URI: /apis/storage.k8s.io/v1/watch/storageclasses
     */
    watchStorageV1StorageClassList<ResponseContentType extends ResponseContentType$watchStorageV1StorageClassList>(params: Params$watchStorageV1StorageClassList<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1StorageClassList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind StorageClass. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchStorageV1StorageClass
     * Request URI: /apis/storage.k8s.io/v1/watch/storageclasses/{name}
     */
    watchStorageV1StorageClass<ResponseContentType extends ResponseContentType$watchStorageV1StorageClass>(params: Params$watchStorageV1StorageClass<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1StorageClass$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of VolumeAttachment. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchStorageV1VolumeAttachmentList
     * Request URI: /apis/storage.k8s.io/v1/watch/volumeattachments
     */
    watchStorageV1VolumeAttachmentList<ResponseContentType extends ResponseContentType$watchStorageV1VolumeAttachmentList>(params: Params$watchStorageV1VolumeAttachmentList<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1VolumeAttachmentList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind VolumeAttachment. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchStorageV1VolumeAttachment
     * Request URI: /apis/storage.k8s.io/v1/watch/volumeattachments/{name}
     */
    watchStorageV1VolumeAttachment<ResponseContentType extends ResponseContentType$watchStorageV1VolumeAttachment>(params: Params$watchStorageV1VolumeAttachment<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1VolumeAttachment$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getStorageV1alpha1APIResources
     * Request URI: /apis/storage.k8s.io/v1alpha1/
     */
    getStorageV1alpha1APIResources<ResponseContentType extends ResponseContentType$getStorageV1alpha1APIResources>(params: Params$getStorageV1alpha1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getStorageV1alpha1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind CSIStorageCapacity
     * operationId: listStorageV1alpha1CSIStorageCapacityForAllNamespaces
     * Request URI: /apis/storage.k8s.io/v1alpha1/csistoragecapacities
     */
    listStorageV1alpha1CSIStorageCapacityForAllNamespaces<ResponseContentType extends ResponseContentType$listStorageV1alpha1CSIStorageCapacityForAllNamespaces>(params: Params$listStorageV1alpha1CSIStorageCapacityForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listStorageV1alpha1CSIStorageCapacityForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind CSIStorageCapacity
     * operationId: listStorageV1alpha1NamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1alpha1/namespaces/{namespace}/csistoragecapacities
     */
    listStorageV1alpha1NamespacedCSIStorageCapacity<ResponseContentType extends ResponseContentType$listStorageV1alpha1NamespacedCSIStorageCapacity>(params: Params$listStorageV1alpha1NamespacedCSIStorageCapacity<ResponseContentType>, option?: RequestOption): Promise<Response$listStorageV1alpha1NamespacedCSIStorageCapacity$Status$200[ResponseContentType]>;
    /**
     * create a CSIStorageCapacity
     * operationId: createStorageV1alpha1NamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1alpha1/namespaces/{namespace}/csistoragecapacities
     */
    createStorageV1alpha1NamespacedCSIStorageCapacity<ResponseContentType extends ResponseContentType$createStorageV1alpha1NamespacedCSIStorageCapacity>(params: Params$createStorageV1alpha1NamespacedCSIStorageCapacity<ResponseContentType>, option?: RequestOption): Promise<(Response$createStorageV1alpha1NamespacedCSIStorageCapacity$Status$200 | Response$createStorageV1alpha1NamespacedCSIStorageCapacity$Status$201 | Response$createStorageV1alpha1NamespacedCSIStorageCapacity$Status$202)[ResponseContentType]>;
    /**
     * delete collection of CSIStorageCapacity
     * operationId: deleteStorageV1alpha1CollectionNamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1alpha1/namespaces/{namespace}/csistoragecapacities
     */
    deleteStorageV1alpha1CollectionNamespacedCSIStorageCapacity<ResponseContentType extends ResponseContentType$deleteStorageV1alpha1CollectionNamespacedCSIStorageCapacity>(params: Params$deleteStorageV1alpha1CollectionNamespacedCSIStorageCapacity<ResponseContentType>, option?: RequestOption): Promise<Response$deleteStorageV1alpha1CollectionNamespacedCSIStorageCapacity$Status$200[ResponseContentType]>;
    /**
     * read the specified CSIStorageCapacity
     * operationId: readStorageV1alpha1NamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1alpha1/namespaces/{namespace}/csistoragecapacities/{name}
     */
    readStorageV1alpha1NamespacedCSIStorageCapacity<ResponseContentType extends ResponseContentType$readStorageV1alpha1NamespacedCSIStorageCapacity>(params: Params$readStorageV1alpha1NamespacedCSIStorageCapacity<ResponseContentType>, option?: RequestOption): Promise<Response$readStorageV1alpha1NamespacedCSIStorageCapacity$Status$200[ResponseContentType]>;
    /**
     * replace the specified CSIStorageCapacity
     * operationId: replaceStorageV1alpha1NamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1alpha1/namespaces/{namespace}/csistoragecapacities/{name}
     */
    replaceStorageV1alpha1NamespacedCSIStorageCapacity<ResponseContentType extends ResponseContentType$replaceStorageV1alpha1NamespacedCSIStorageCapacity>(params: Params$replaceStorageV1alpha1NamespacedCSIStorageCapacity<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceStorageV1alpha1NamespacedCSIStorageCapacity$Status$200 | Response$replaceStorageV1alpha1NamespacedCSIStorageCapacity$Status$201)[ResponseContentType]>;
    /**
     * delete a CSIStorageCapacity
     * operationId: deleteStorageV1alpha1NamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1alpha1/namespaces/{namespace}/csistoragecapacities/{name}
     */
    deleteStorageV1alpha1NamespacedCSIStorageCapacity<ResponseContentType extends ResponseContentType$deleteStorageV1alpha1NamespacedCSIStorageCapacity>(params: Params$deleteStorageV1alpha1NamespacedCSIStorageCapacity<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteStorageV1alpha1NamespacedCSIStorageCapacity$Status$200 | Response$deleteStorageV1alpha1NamespacedCSIStorageCapacity$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified CSIStorageCapacity
     * operationId: patchStorageV1alpha1NamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1alpha1/namespaces/{namespace}/csistoragecapacities/{name}
     */
    patchStorageV1alpha1NamespacedCSIStorageCapacity<RequestContentType extends RequestContentType$patchStorageV1alpha1NamespacedCSIStorageCapacity, ResponseContentType extends ResponseContentType$patchStorageV1alpha1NamespacedCSIStorageCapacity>(params: Params$patchStorageV1alpha1NamespacedCSIStorageCapacity<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchStorageV1alpha1NamespacedCSIStorageCapacity$Status$200 | Response$patchStorageV1alpha1NamespacedCSIStorageCapacity$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of CSIStorageCapacity. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchStorageV1alpha1CSIStorageCapacityListForAllNamespaces
     * Request URI: /apis/storage.k8s.io/v1alpha1/watch/csistoragecapacities
     */
    watchStorageV1alpha1CSIStorageCapacityListForAllNamespaces<ResponseContentType extends ResponseContentType$watchStorageV1alpha1CSIStorageCapacityListForAllNamespaces>(params: Params$watchStorageV1alpha1CSIStorageCapacityListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1alpha1CSIStorageCapacityListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of CSIStorageCapacity. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchStorageV1alpha1NamespacedCSIStorageCapacityList
     * Request URI: /apis/storage.k8s.io/v1alpha1/watch/namespaces/{namespace}/csistoragecapacities
     */
    watchStorageV1alpha1NamespacedCSIStorageCapacityList<ResponseContentType extends ResponseContentType$watchStorageV1alpha1NamespacedCSIStorageCapacityList>(params: Params$watchStorageV1alpha1NamespacedCSIStorageCapacityList<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1alpha1NamespacedCSIStorageCapacityList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind CSIStorageCapacity. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchStorageV1alpha1NamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1alpha1/watch/namespaces/{namespace}/csistoragecapacities/{name}
     */
    watchStorageV1alpha1NamespacedCSIStorageCapacity<ResponseContentType extends ResponseContentType$watchStorageV1alpha1NamespacedCSIStorageCapacity>(params: Params$watchStorageV1alpha1NamespacedCSIStorageCapacity<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1alpha1NamespacedCSIStorageCapacity$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getStorageV1beta1APIResources
     * Request URI: /apis/storage.k8s.io/v1beta1/
     */
    getStorageV1beta1APIResources<ResponseContentType extends ResponseContentType$getStorageV1beta1APIResources>(params: Params$getStorageV1beta1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getStorageV1beta1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind CSIStorageCapacity
     * operationId: listStorageV1beta1CSIStorageCapacityForAllNamespaces
     * Request URI: /apis/storage.k8s.io/v1beta1/csistoragecapacities
     */
    listStorageV1beta1CSIStorageCapacityForAllNamespaces<ResponseContentType extends ResponseContentType$listStorageV1beta1CSIStorageCapacityForAllNamespaces>(params: Params$listStorageV1beta1CSIStorageCapacityForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listStorageV1beta1CSIStorageCapacityForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind CSIStorageCapacity
     * operationId: listStorageV1beta1NamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1beta1/namespaces/{namespace}/csistoragecapacities
     */
    listStorageV1beta1NamespacedCSIStorageCapacity<ResponseContentType extends ResponseContentType$listStorageV1beta1NamespacedCSIStorageCapacity>(params: Params$listStorageV1beta1NamespacedCSIStorageCapacity<ResponseContentType>, option?: RequestOption): Promise<Response$listStorageV1beta1NamespacedCSIStorageCapacity$Status$200[ResponseContentType]>;
    /**
     * create a CSIStorageCapacity
     * operationId: createStorageV1beta1NamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1beta1/namespaces/{namespace}/csistoragecapacities
     */
    createStorageV1beta1NamespacedCSIStorageCapacity<ResponseContentType extends ResponseContentType$createStorageV1beta1NamespacedCSIStorageCapacity>(params: Params$createStorageV1beta1NamespacedCSIStorageCapacity<ResponseContentType>, option?: RequestOption): Promise<(Response$createStorageV1beta1NamespacedCSIStorageCapacity$Status$200 | Response$createStorageV1beta1NamespacedCSIStorageCapacity$Status$201 | Response$createStorageV1beta1NamespacedCSIStorageCapacity$Status$202)[ResponseContentType]>;
    /**
     * delete collection of CSIStorageCapacity
     * operationId: deleteStorageV1beta1CollectionNamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1beta1/namespaces/{namespace}/csistoragecapacities
     */
    deleteStorageV1beta1CollectionNamespacedCSIStorageCapacity<ResponseContentType extends ResponseContentType$deleteStorageV1beta1CollectionNamespacedCSIStorageCapacity>(params: Params$deleteStorageV1beta1CollectionNamespacedCSIStorageCapacity<ResponseContentType>, option?: RequestOption): Promise<Response$deleteStorageV1beta1CollectionNamespacedCSIStorageCapacity$Status$200[ResponseContentType]>;
    /**
     * read the specified CSIStorageCapacity
     * operationId: readStorageV1beta1NamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1beta1/namespaces/{namespace}/csistoragecapacities/{name}
     */
    readStorageV1beta1NamespacedCSIStorageCapacity<ResponseContentType extends ResponseContentType$readStorageV1beta1NamespacedCSIStorageCapacity>(params: Params$readStorageV1beta1NamespacedCSIStorageCapacity<ResponseContentType>, option?: RequestOption): Promise<Response$readStorageV1beta1NamespacedCSIStorageCapacity$Status$200[ResponseContentType]>;
    /**
     * replace the specified CSIStorageCapacity
     * operationId: replaceStorageV1beta1NamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1beta1/namespaces/{namespace}/csistoragecapacities/{name}
     */
    replaceStorageV1beta1NamespacedCSIStorageCapacity<ResponseContentType extends ResponseContentType$replaceStorageV1beta1NamespacedCSIStorageCapacity>(params: Params$replaceStorageV1beta1NamespacedCSIStorageCapacity<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceStorageV1beta1NamespacedCSIStorageCapacity$Status$200 | Response$replaceStorageV1beta1NamespacedCSIStorageCapacity$Status$201)[ResponseContentType]>;
    /**
     * delete a CSIStorageCapacity
     * operationId: deleteStorageV1beta1NamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1beta1/namespaces/{namespace}/csistoragecapacities/{name}
     */
    deleteStorageV1beta1NamespacedCSIStorageCapacity<ResponseContentType extends ResponseContentType$deleteStorageV1beta1NamespacedCSIStorageCapacity>(params: Params$deleteStorageV1beta1NamespacedCSIStorageCapacity<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteStorageV1beta1NamespacedCSIStorageCapacity$Status$200 | Response$deleteStorageV1beta1NamespacedCSIStorageCapacity$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified CSIStorageCapacity
     * operationId: patchStorageV1beta1NamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1beta1/namespaces/{namespace}/csistoragecapacities/{name}
     */
    patchStorageV1beta1NamespacedCSIStorageCapacity<RequestContentType extends RequestContentType$patchStorageV1beta1NamespacedCSIStorageCapacity, ResponseContentType extends ResponseContentType$patchStorageV1beta1NamespacedCSIStorageCapacity>(params: Params$patchStorageV1beta1NamespacedCSIStorageCapacity<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchStorageV1beta1NamespacedCSIStorageCapacity$Status$200 | Response$patchStorageV1beta1NamespacedCSIStorageCapacity$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of CSIStorageCapacity. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchStorageV1beta1CSIStorageCapacityListForAllNamespaces
     * Request URI: /apis/storage.k8s.io/v1beta1/watch/csistoragecapacities
     */
    watchStorageV1beta1CSIStorageCapacityListForAllNamespaces<ResponseContentType extends ResponseContentType$watchStorageV1beta1CSIStorageCapacityListForAllNamespaces>(params: Params$watchStorageV1beta1CSIStorageCapacityListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1beta1CSIStorageCapacityListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of CSIStorageCapacity. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchStorageV1beta1NamespacedCSIStorageCapacityList
     * Request URI: /apis/storage.k8s.io/v1beta1/watch/namespaces/{namespace}/csistoragecapacities
     */
    watchStorageV1beta1NamespacedCSIStorageCapacityList<ResponseContentType extends ResponseContentType$watchStorageV1beta1NamespacedCSIStorageCapacityList>(params: Params$watchStorageV1beta1NamespacedCSIStorageCapacityList<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1beta1NamespacedCSIStorageCapacityList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind CSIStorageCapacity. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchStorageV1beta1NamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1beta1/watch/namespaces/{namespace}/csistoragecapacities/{name}
     */
    watchStorageV1beta1NamespacedCSIStorageCapacity<ResponseContentType extends ResponseContentType$watchStorageV1beta1NamespacedCSIStorageCapacity>(params: Params$watchStorageV1beta1NamespacedCSIStorageCapacity<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1beta1NamespacedCSIStorageCapacity$Status$200[ResponseContentType]>;
    /**
     * operationId: logFileListHandler
     * Request URI: /logs/
     */
    logFileListHandler(option?: RequestOption): Promise<void>;
    /**
     * operationId: logFileHandler
     * Request URI: /logs/{logpath}
     */
    logFileHandler(params: Params$logFileHandler, option?: RequestOption): Promise<void>;
    /**
     * get service account issuer OpenID JSON Web Key Set (contains public token verification keys)
     * operationId: getServiceAccountIssuerOpenIDKeyset
     * Request URI: /openid/v1/jwks/
     */
    getServiceAccountIssuerOpenIDKeyset(option?: RequestOption): Promise<Response$getServiceAccountIssuerOpenIDKeyset$Status$200["application/jwk-set+json"]>;
    /**
     * get the code version
     * operationId: getCodeVersion
     * Request URI: /version/
     */
    getCodeVersion(option?: RequestOption): Promise<Response$getCodeVersion$Status$200["application/json"]>;
}
